Class: DatadogAPIClient::APIClient

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/api_client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(config = Configuration.default) ⇒ APIClient

Initializes the APIClient

Parameters:

  • config (Hash) (defaults to: Configuration.default)

    a customizable set of options

Options Hash (config):

  • Configuration (Configuration)

    for initializing the object, default to Configuration.default



39
40
41
42
43
44
45
46
# File 'lib/datadog_api_client/api_client.rb', line 39

def initialize(config = Configuration.default)
  @config = config
  @user_agent = "#{DatadogAPIClient::USER_AGENT}"
  @default_headers = {
    'User-Agent' => @user_agent
  }
  @default_headers['Accept-Encoding'] = 'gzip' if @config.compress
end

Instance Attribute Details

#configObject

The Configuration object holding settings to be used in the API client.



30
31
32
# File 'lib/datadog_api_client/api_client.rb', line 30

def config
  @config
end

#default_headersHash

Defines the headers to be used in HTTP requests of all API calls by default.

Returns:

  • (Hash)


35
36
37
# File 'lib/datadog_api_client/api_client.rb', line 35

def default_headers
  @default_headers
end

Class Method Details

.defaultObject



48
49
50
# File 'lib/datadog_api_client/api_client.rb', line 48

def self.default
  @@default ||= APIClient.new
end

Instance Method Details

#build_collection_param(param, collection_format) ⇒ Object

Build parameter value according to the given collection format.

Parameters:

  • collection_format (String)

    one of :csv, :ssv, :tsv, :pipes and :multi



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/datadog_api_client/api_client.rb', line 420

def build_collection_param(param, collection_format)
  case collection_format
  when :csv
    param.join(',')
  when :ssv
    param.join(' ')
  when :tsv
    param.join("\t")
  when :pipes
    param.join('|')
  when :multi
    # return the array directly as httparty will handle it as expected
    param
  else
    fail "unknown collection format: #{collection_format.inspect}"
  end
end

#build_request(http_method, path, opts = {}) ⇒ HTTParty::Request

Build the HTTP request

Parameters:

  • http_method (String)

    HTTP method/verb (e.g. POST)

  • path (String)

    URL path (e.g. /account/new)

  • opts (Hash) (defaults to: {})

    a customizable set of options

Options Hash (opts):

  • :header_params (Hash)

    Header parameters

  • :query_params (Hash)

    Query parameters

  • :form_params (Hash)

    Query parameters

  • :body (Object)

    HTTP body (JSON/XML)

Returns:

  • (HTTParty::Request)

    A httparty Request



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/datadog_api_client/api_client.rb', line 134

def build_request(http_method, path, opts = {})
  url = build_request_url(path, opts)
  header_params = @default_headers.merge(opts[:header_params] || {})
  query_params = opts[:query_params] || {}
  form_params = opts[:form_params] || {}

  update_params_for_auth! header_params, query_params, opts[:auth_names]

  # set ssl_verifyhosts option based on @config.verify_ssl_host (true/false)
  _verify_ssl_host = @config.verify_ssl_host ? 2 : 0

  req_opts = {
    :method => http_method,
    :headers => header_params,
    :query => transform_hash(query_params),
    :timeout => @config.timeout,
    :verify_peer => @config.verify_ssl,
    :verify => _verify_ssl_host,
    :verbose => @config.debugging,
    :http_proxyaddr => @config.http_proxyaddr,
    :http_proxyport => @config.http_proxyport,
    :http_proxyuser => @config.http_proxyuser,
    :http_proxypass => @config.http_proxypass
  }

  req_opts[:pem] = File.read(@config.cert_file) if @config.cert_file
  req_opts[:pem_password] = File.read(@config.key_file) if @config.key_file

  opts[:stream_body] = true if opts[:return_type] == 'File'

  # set custom cert, if provided
  req_opts[:ssl_ca_file] = File.read(@config.ssl_ca_cert) if @config.ssl_ca_cert

  if ["POST", "PATCH", "PUT", "DELETE"].include?(http_method.const_get(:METHOD))
    req_body = build_request_body(header_params, form_params, opts[:body])
    req_opts.update :body => req_body
    if @config.debugging
      @config.logger.debug "HTTP request body param ~BEGIN~\n#{req_body}\n~END~\n"
    end
  end

  HTTParty::Request.new(http_method, url, req_opts)
end

#build_request_body(header_params, form_params, body) ⇒ String

Build the HTTP request body

Parameters:

  • header_params (Hash)

    Header parameters

  • form_params (Hash)

    Query parameters

  • body (Object)

    HTTP body (JSON/XML)

Returns:

  • (String)

    HTTP body data in the form of string



184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/datadog_api_client/api_client.rb', line 184

def build_request_body(header_params, form_params, body)
  # http form
  if header_params['Content-Type'] == 'application/x-www-form-urlencoded' ||
      header_params['Content-Type'] == 'multipart/form-data'
    data = {}
    form_params.each do |key, value|
      case value
      when ::File, ::Array, nil
        # let httparty handle File, Array and nil parameters
        data[key] = value
      else
        data[key] = value.to_s
      end
    end
  elsif body
    data = body.is_a?(String) ? body : body.to_json
  else
    data = nil
  end
  if header_params['Content-Encoding'] == 'gzip'
    gzip = Zlib::Deflate.new(nil, Zlib::MAX_WBITS + 16)
    data = gzip.deflate(data, Zlib::FINISH)
    gzip.close
  elsif header_params['Content-Encoding'] == 'deflate'
    data = Zlib::deflate(data)
  elsif header_params['Content-Encoding'] == 'zstd1'
    data = Zstandard.deflate(data)
  end
  data
end

#build_request_url(path, opts = {}) ⇒ Object



318
319
320
321
322
# File 'lib/datadog_api_client/api_client.rb', line 318

def build_request_url(path, opts = {})
  # Add leading and trailing slashes to path
  path = "/#{path}".gsub(/\/+/, '/')
  @config.base_url("#{opts[:api_version].respond_to?(:downcase) ? opts[:api_version].downcase : opts[:api_version]}.#{opts[:operation]}") + path
end

#call_api(http_method, path, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Call an API with given options.

Returns:

  • (Array<(Object, Integer, Hash)>)

    an array of 3 elements: the data deserialized from response body (could be nil), response status code and response headers.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/datadog_api_client/api_client.rb', line 56

def call_api(http_method, path, opts = {})
  request = build_request(http_method, path, opts)
  if opts[:stream_body]
    tempfile = nil
    encoding = nil

    response = request.perform do | chunk |
      unless tempfile
        content_disposition = chunk.http_response.header['Content-Disposition']
        if content_disposition && content_disposition =~ /filename=/i
          filename = content_disposition[/filename=['"]?([^'"\s]+)['"]?/, 1]
          prefix = sanitize_filename(filename)
        else
          prefix = 'download-'
        end
        prefix = prefix + '-' unless prefix.end_with?('-')
        unless encoding
          encoding = chunk.encoding
        end
        tempfile = Tempfile.open(prefix, @config.temp_folder_path, encoding: encoding)
        @tempfile = tempfile
      end
      chunk.force_encoding(encoding)
      tempfile.write(chunk)
    end
    if tempfile
      tempfile.close
      @config.logger.info "Temp file written to #{tempfile.path}, please copy the file to a proper folder "\
                        "with e.g. `FileUtils.cp(tempfile.path, '/new/file/path')` otherwise the temp file "\
                        "will be deleted automatically with GC. It's also recommended to delete the temp file "\
                        "explicitly with `tempfile.delete`"
    end
  else
    response = request.perform
  end

  if @config.debugging
    @config.logger.debug "HTTP response body ~BEGIN~\n#{response.body}\n~END~\n"
  end

  unless response.success?
    if response.request_timeout?
      fail APIError.new('Connection timed out')
    elsif response.code == 0
      # Errors from libcurl will be made visible here
      fail APIError.new(:code => 0,
                        :message => response.return_message)
    else
      body = response.body
      if response.headers['Content-Encoding'].eql?('gzip') && !(body.nil? || body.empty?) then
        gzip = Zlib::Inflate.new(Zlib::MAX_WBITS + 16)
        body = gzip.inflate(body)
        gzip.close
      end
      fail APIError.new(:code => response.code,
                        :response_headers => response.headers,
                        :response_body => body),
           response.message
    end
  end

  if opts[:return_type]
    data = deserialize(opts[:api_version], response, opts[:return_type])
  else
    data = nil
  end
  return data, response.code, response.headers
end

#convert_to_type(data, return_type, api_version) ⇒ Mixed

Convert data to the given return type.

Parameters:

  • data (Object)

    Data to be converted

  • return_type (String)

    Return type

Returns:

  • (Mixed)

    Data in a particular type



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/datadog_api_client/api_client.rb', line 272

def convert_to_type(data, return_type, api_version)
  return nil if data.nil?
  case return_type
  when 'String'
    data.to_s
  when 'Integer'
    data.to_i
  when 'Float'
    data.to_f
  when 'Boolean'
    data == true
  when 'Time'
    # parse date time (expecting ISO 8601 format)
    Time.parse data
  when 'Date'
    # parse date time (expecting ISO 8601 format)
    Date.parse data
  when 'Object'
    # generic object (usually a Hash), return directly
    data
  when /\AArray<(.+)>\z/
    # e.g. Array<Pet>
    sub_type = $1
    data.map { |item| convert_to_type(item, sub_type, api_version) }
  when /\AHash\<String, (.+)\>\z/
    # e.g. Hash<String, Integer>
    sub_type = $1
    {}.tap do |hash|
      data.each { |k, v| hash[k] = convert_to_type(v, sub_type, api_version) }
    end
  else
    # models (e.g. Pet) or oneOf
    klass = DatadogAPIClient.const_get(api_version).const_get(return_type)
    klass.respond_to?(:openapi_one_of) ? klass.build(data) : klass.build_from_hash(data)
  end
end

#deserialize(api_version, response, return_type) ⇒ Object

Deserialize the response to the given return type.

Parameters:

  • the (String)

    api version

  • response (Response)

    HTTP response

  • return_type (String)

    some examples: “User”, “Array<User>”, “Hash<String, Integer>”



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/datadog_api_client/api_client.rb', line 232

def deserialize(api_version, response, return_type)
  body = response.body

  # handle file downloading - return the File instance processed in request callbacks
  # note that response body is empty when the file is written in chunks in request on_body callback
  return @tempfile if return_type == 'File'

  return nil if body.nil? || body.empty?

  if response.headers['Content-Encoding'].eql?('gzip') then
    gzip = Zlib::Inflate.new(Zlib::MAX_WBITS + 16)
    body = gzip.inflate(body)
    gzip.close
  end

  # return response body directly for String return type
  return body if return_type == 'String'

  # ensuring a default content type
  content_type = response.headers['Content-Type'] || 'application/json'

  fail "Content-Type is not supported: #{content_type}" unless json_mime?(content_type)

  begin
    data = JSON.parse("[#{body}]", :symbolize_names => true)[0]
  rescue JSON::ParserError => e
    if %w(String Date Time).include?(return_type)
      data = body
    else
      raise e
    end
  end

  convert_to_type data, return_type, api_version
end

#json_mime?(mime) ⇒ Boolean

Check if the given MIME is a JSON MIME. JSON MIME examples:

application/json
application/json; charset=UTF8
APPLICATION/JSON
*/*

Parameters:

  • mime (String)

    MIME

Returns:

  • (Boolean)

    True if the MIME is application/json



223
224
225
# File 'lib/datadog_api_client/api_client.rb', line 223

def json_mime?(mime)
  (mime == '*/*') || !(mime =~ /Application\/.*json(?!p)(;.*)?/i).nil? || (mime == 'text/json')
end

#object_to_hash(obj) ⇒ String

Convert object(non-array) to hash.

Parameters:

  • obj (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



410
411
412
413
414
415
416
# File 'lib/datadog_api_client/api_client.rb', line 410

def object_to_hash(obj)
  if obj.respond_to?(:to_hash)
    obj.to_hash
  else
    obj
  end
end

#object_to_http_body(model) ⇒ String

Convert object (array, hash, object, etc) to JSON string.

Parameters:

  • model (Object)

    object to be converted into JSON string

Returns:

  • (String)

    JSON string representation of the object



371
372
373
374
375
376
377
378
379
380
# File 'lib/datadog_api_client/api_client.rb', line 371

def object_to_http_body(model)
  return model if model.nil? || model.is_a?(String)
  local_body = nil
  if model.is_a?(Array)
    local_body = model.map { |m| object_to_hash(m) }
  else
    local_body = object_to_hash(model)
  end
  transform_hash(local_body).to_json
end

#sanitize_filename(filename) ⇒ String

Sanitize filename by removing path. e.g. ../../sun.gif becomes sun.gif

Parameters:

  • filename (String)

    the filename to be sanitized

Returns:

  • (String)

    the sanitized filename



314
315
316
# File 'lib/datadog_api_client/api_client.rb', line 314

def sanitize_filename(filename)
  filename.gsub(/.*[\/\\]/, '')
end

#select_header_accept(accepts) ⇒ String

Return Accept header based on an array of accepts provided.

Parameters:

  • accepts (Array)

    array for Accept

Returns:

  • (String)

    the Accept header (e.g. application/json)



352
353
354
355
# File 'lib/datadog_api_client/api_client.rb', line 352

def select_header_accept(accepts)
  return nil if accepts.nil? || accepts.empty?
  accepts.join(', ')
end

#select_header_content_type(content_types) ⇒ String

Return Content-Type header based on an array of content types provided.

Parameters:

  • content_types (Array)

    array for Content-Type

Returns:

  • (String)

    the Content-Type header (e.g. application/json)



360
361
362
363
364
365
366
# File 'lib/datadog_api_client/api_client.rb', line 360

def select_header_content_type(content_types)
  # use application/json by default
  return 'application/json' if content_types.nil? || content_types.empty?
  # use JSON when present, otherwise use the first one
  json_content_type = content_types.find { |s| json_mime?(s) }
  json_content_type || content_types.first
end

#transform_hash(obj) ⇒ Object

Transform object (array, hash, object, etc) to serializable object.

Parameters:

  • obj (Object)

    to transform

Returns:

  • (Object)


385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
# File 'lib/datadog_api_client/api_client.rb', line 385

def transform_hash(obj)
  if obj.is_a?(Array)
    obj.map { |m| transform_hash(m) }
  elsif obj.is_a?(Hash)
    obj.each do | k, v |
      if v.class == Time
        t = v.strftime("%FT%T")
        if v.nsec > 0
          t << v.strftime(".%3N")
        end
        t << (v.utc? ? 'Z' : v.strftime("%:z"))

        obj[k] = t
      else
        obj[k] = transform_hash(v)
      end
    end
  end

  obj
end

#update_params_for_auth!(header_params, query_params, auth_names) ⇒ Object

Update header and query params based on authentication settings.

Parameters:

  • header_params (Hash)

    Header parameters

  • query_params (Hash)

    Query parameters

  • auth_names (String)

    Authentication scheme name



329
330
331
332
333
334
335
336
337
338
339
# File 'lib/datadog_api_client/api_client.rb', line 329

def update_params_for_auth!(header_params, query_params, auth_names)
  Array(auth_names).each do |auth_name|
    auth_setting = @config.auth_settings[auth_name]
    next unless auth_setting
    case auth_setting[:in]
    when 'header' then header_params[auth_setting[:key]] = auth_setting[:value]
    when 'query'  then query_params[auth_setting[:key]] = auth_setting[:value]
    else fail ArgumentError, 'Authentication token must be in `query` or `header`'
    end
  end
end

#user_agent=(user_agent) ⇒ Object

Sets user agent in HTTP header

Parameters:

  • user_agent (String)

    User agent (e.g. openapi-generator/ruby/1.0.0)



344
345
346
347
# File 'lib/datadog_api_client/api_client.rb', line 344

def user_agent=(user_agent)
  @user_agent = user_agent
  @default_headers['User-Agent'] = @user_agent
end