Class: DatadogAPIClient::Configuration
- Inherits:
-
Object
- Object
- DatadogAPIClient::Configuration
- Defined in:
- lib/datadog_api_client/configuration.rb
Instance Attribute Summary collapse
-
#access_token ⇒ Object
Defines the access token (Bearer) used with OAuth2.
-
#api_key ⇒ Hash
Defines API keys used with API Key authentications.
-
#api_key_prefix ⇒ Hash
Defines API key prefixes used with API Key authentications.
-
#backoff_base ⇒ Object
Retry backoff calculation parameters.
-
#backoff_multiplier ⇒ Object
Returns the value of attribute backoff_multiplier.
-
#base_path ⇒ Object
Defines url base path.
-
#cert_file ⇒ Object
TLS/SSL setting Client certificate file (for client certificate).
-
#client_side_validation ⇒ true, false
Set this to false to skip client side validation in the operation.
-
#compress ⇒ Object
Set this to add accept encoding header for compression.
-
#debugging ⇒ true, false
Set this to enable/disable debugging.
-
#enable_retry ⇒ Object
Enable retry when rate limited.
-
#force_ending_format ⇒ Object
Returns the value of attribute force_ending_format.
-
#host ⇒ Object
Defines url host.
-
#http_proxyaddr ⇒ Object
Proxy settings Address of proxy server to use.
-
#http_proxypass ⇒ Object
Password for proxy server authentication.
-
#http_proxyport ⇒ Object
Port of proxy server to use.
-
#http_proxyuser ⇒ Object
User for proxy server authentication.
-
#inject_format ⇒ Object
Returns the value of attribute inject_format.
-
#key_file ⇒ Object
TLS/SSL setting Client private key file (for client certificate).
-
#logger ⇒ #debug
Defines the logger used for debugging.
-
#max_retries ⇒ Object
Maximum number of retry attempts allowed.
-
#password ⇒ String
Defines the password used with HTTP basic authentication.
-
#scheme ⇒ Object
Defines url scheme.
-
#server_index ⇒ Object
Define server configuration index.
-
#server_operation_index ⇒ Object
Define server operation configuration index.
-
#server_operation_variables ⇒ Object
Default server operation variables.
-
#server_variables ⇒ Object
Default server variables.
-
#ssl_ca_cert ⇒ String
TLS/SSL setting Set this to customize the certificate file to verify the peer.
-
#temp_folder_path ⇒ String
Defines the temporary folder to store downloaded files (for API endpoints that have file response).
-
#timeout ⇒ Object
The time limit for HTTP request in seconds.
-
#unstable_operations ⇒ Object
Keep track of the unstable operations, and if they have been enabled.
-
#username ⇒ String
Defines the username used with HTTP basic authentication.
-
#verify_ssl ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server.
-
#verify_ssl_host ⇒ true, false
TLS/SSL setting Set this to false to skip verifying SSL host name Default to true.
Class Method Summary collapse
-
.default ⇒ Object
The default Configuration object.
Instance Method Summary collapse
-
#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object
Gets API key (with prefix if set).
-
#application_key=(app_key) ⇒ Object
Sets application key.
-
#auth_settings ⇒ Object
Returns Auth Settings hash for api client.
-
#base_url(operation = nil) ⇒ Object
Returns base URL for specified operation based on server settings.
-
#basic_auth_token ⇒ Object
Gets Basic Auth token string.
- #configure {|_self| ... } ⇒ Object
-
#initialize {|_self| ... } ⇒ Configuration
constructor
A new instance of Configuration.
- #operation_server_settings ⇒ Object
-
#server_settings ⇒ Object
Returns an array of Server setting.
-
#server_url(index, variables = {}, servers = nil) ⇒ Object
Returns URL based on server settings.
Constructor Details
#initialize {|_self| ... } ⇒ Configuration
Returns a new instance of Configuration.
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 |
# File 'lib/datadog_api_client/configuration.rb', line 162 def initialize @scheme = 'https' @host = 'api.datadoghq.com' @base_path = '' @server_index = 0 @server_operation_index = {} @server_variables = {} @server_operation_variables = {} @api_key = {} @api_key_prefix = {} @enable_retry = false @backoff_base = 2 @backoff_multiplier = 2 @max_retries = 3 @timeout = nil @client_side_validation = true @verify_ssl = true @verify_ssl_host = true @cert_file = nil @key_file = nil @debugging = false @inject_format = false @force_ending_format = false @compress = true @http_proxyaddr = nil @http_proxyport = nil @http_proxyuser = nil @http_proxypass = nil @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT) @unstable_operations = { "v2.cancel_fleet_deployment": false, "v2.create_fleet_deployment_configure": false, "v2.create_fleet_deployment_upgrade": false, "v2.create_fleet_schedule": false, "v2.delete_fleet_schedule": false, "v2.get_fleet_agent_info": false, "v2.get_fleet_deployment": false, "v2.get_fleet_schedule": false, "v2.list_fleet_agents": false, "v2.list_fleet_agent_tracers": false, "v2.list_fleet_agent_versions": false, "v2.list_fleet_clusters": false, "v2.list_fleet_deployments": false, "v2.list_fleet_instrumented_pods": false, "v2.list_fleet_schedules": false, "v2.list_fleet_tracers": false, "v2.trigger_fleet_schedule": false, "v2.update_fleet_schedule": false, "v2.create_llm_obs_annotation_queue": false, "v2.create_llm_obs_annotation_queue_interactions": false, "v2.create_llm_obs_dataset": false, "v2.create_llm_obs_dataset_records": false, "v2.create_llm_obs_experiment": false, "v2.create_llm_obs_experiment_events": false, "v2.create_llm_obs_project": false, "v2.delete_llm_obs_annotation_queue": false, "v2.delete_llm_obs_annotation_queue_interactions": false, "v2.delete_llm_obs_custom_eval_config": false, "v2.delete_llm_obs_dataset_records": false, "v2.delete_llm_obs_datasets": false, "v2.delete_llm_obs_experiments": false, "v2.delete_llm_obs_projects": false, "v2.get_llm_obs_annotated_interactions": false, "v2.get_llm_obs_custom_eval_config": false, "v2.list_llm_obs_annotation_queues": false, "v2.list_llm_obs_dataset_records": false, "v2.list_llm_obs_datasets": false, "v2.list_llm_obs_experiments": false, "v2.list_llm_obs_projects": false, "v2.update_llm_obs_annotation_queue": false, "v2.update_llm_obs_custom_eval_config": false, "v2.update_llm_obs_dataset": false, "v2.update_llm_obs_dataset_records": false, "v2.update_llm_obs_experiment": false, "v2.update_llm_obs_project": false, "v2.anonymize_users": false, "v2.create_open_api": false, "v2.delete_open_api": false, "v2.get_open_api": false, "v2.list_apis": false, "v2.update_open_api": false, "v2.get_investigation": false, "v2.list_investigations": false, "v2.trigger_investigation": false, "v2.create_case_jira_issue": false, "v2.create_case_notebook": false, "v2.create_case_service_now_ticket": false, "v2.link_incident": false, "v2.link_jira_issue_to_case": false, "v2.move_case_to_project": false, "v2.unlink_jira_issue": false, "v2.create_change_request": false, "v2.create_change_request_branch": false, "v2.delete_change_request_decision": false, "v2.get_change_request": false, "v2.update_change_request": false, "v2.update_change_request_decision": false, "v2.delete_test_optimization_service_settings": false, "v2.get_flaky_tests_management_policies": false, "v2.get_test_optimization_service_settings": false, "v2.search_flaky_tests": false, "v2.update_flaky_tests": false, "v2.update_flaky_tests_management_policies": false, "v2.update_test_optimization_service_settings": false, "v2.create_aws_cloud_auth_persona_mapping": false, "v2.delete_aws_cloud_auth_persona_mapping": false, "v2.get_aws_cloud_auth_persona_mapping": false, "v2.list_aws_cloud_auth_persona_mappings": false, "v2.activate_content_pack": false, "v2.bulk_export_security_monitoring_terraform_resources": false, "v2.cancel_historical_job": false, "v2.convert_job_result_to_signal": false, "v2.convert_security_monitoring_terraform_resource": false, "v2.deactivate_content_pack": false, "v2.delete_historical_job": false, "v2.export_security_monitoring_terraform_resource": false, "v2.get_content_packs_states": false, "v2.get_finding": false, "v2.get_historical_job": false, "v2.get_indicator_of_compromise": false, "v2.get_rule_version_history": false, "v2.get_secrets_rules": false, "v2.get_security_monitoring_histsignal": false, "v2.get_security_monitoring_histsignals_by_job_id": false, "v2.list_findings": false, "v2.list_historical_jobs": false, "v2.list_indicators_of_compromise": false, "v2.list_multiple_rulesets": false, "v2.list_scanned_assets_metadata": false, "v2.list_security_monitoring_histsignals": false, "v2.list_vulnerabilities": false, "v2.list_vulnerable_assets": false, "v2.mute_findings": false, "v2.run_historical_job": false, "v2.search_security_monitoring_histsignals": false, "v2.get_code_coverage_branch_summary": false, "v2.get_code_coverage_commit_summary": false, "v2.create_dashboard_secure_embed": false, "v2.delete_dashboard_secure_embed": false, "v2.get_dashboard_secure_embed": false, "v2.update_dashboard_secure_embed": false, "v2.create_dataset": false, "v2.delete_dataset": false, "v2.get_all_datasets": false, "v2.get_dataset": false, "v2.update_dataset": false, "v2.cancel_data_deletion_request": false, "v2.create_data_deletion_request": false, "v2.get_data_deletion_requests": false, "v2.create_deployment_gate": false, "v2.create_deployment_rule": false, "v2.delete_deployment_gate": false, "v2.delete_deployment_rule": false, "v2.get_deployment_gate": false, "v2.get_deployment_gate_rules": false, "v2.get_deployment_gates_evaluation_result": false, "v2.get_deployment_rule": false, "v2.list_deployment_gates": false, "v2.trigger_deployment_gates_evaluation": false, "v2.update_deployment_gate": false, "v2.update_deployment_rule": false, "v2.create_hamr_org_connection": false, "v2.get_hamr_org_connection": false, "v2.create_global_incident_handle": false, "v2.create_incident": false, "v2.create_incident_attachment": false, "v2.create_incident_integration": false, "v2.create_incident_notification_rule": false, "v2.create_incident_notification_template": false, "v2.create_incident_postmortem_attachment": false, "v2.create_incident_postmortem_template": false, "v2.create_incident_todo": false, "v2.create_incident_type": false, "v2.create_incident_user_defined_field": false, "v2.delete_global_incident_handle": false, "v2.delete_incident": false, "v2.delete_incident_attachment": false, "v2.delete_incident_integration": false, "v2.delete_incident_notification_rule": false, "v2.delete_incident_notification_template": false, "v2.delete_incident_postmortem_template": false, "v2.delete_incident_todo": false, "v2.delete_incident_type": false, "v2.delete_incident_user_defined_field": false, "v2.get_global_incident_settings": false, "v2.get_incident": false, "v2.get_incident_integration": false, "v2.get_incident_notification_rule": false, "v2.get_incident_notification_template": false, "v2.get_incident_postmortem_template": false, "v2.get_incident_todo": false, "v2.get_incident_type": false, "v2.get_incident_user_defined_field": false, "v2.import_incident": false, "v2.list_global_incident_handles": false, "v2.list_incident_attachments": false, "v2.list_incident_integrations": false, "v2.list_incident_notification_rules": false, "v2.list_incident_notification_templates": false, "v2.list_incident_postmortem_templates": false, "v2.list_incidents": false, "v2.list_incident_todos": false, "v2.list_incident_types": false, "v2.list_incident_user_defined_fields": false, "v2.search_incidents": false, "v2.update_global_incident_handle": false, "v2.update_global_incident_settings": false, "v2.update_incident": false, "v2.update_incident_attachment": false, "v2.update_incident_integration": false, "v2.update_incident_notification_rule": false, "v2.update_incident_notification_template": false, "v2.update_incident_postmortem_template": false, "v2.update_incident_todo": false, "v2.update_incident_type": false, "v2.update_incident_user_defined_field": false, "v2.create_aws_account_ccm_config": false, "v2.delete_aws_account_ccm_config": false, "v2.get_aws_account_ccm_config": false, "v2.update_aws_account_ccm_config": false, "v2.create_jira_issue_template": false, "v2.delete_jira_account": false, "v2.delete_jira_issue_template": false, "v2.get_jira_issue_template": false, "v2.list_jira_accounts": false, "v2.list_jira_issue_templates": false, "v2.update_jira_issue_template": false, "v2.create_tenancy_config": false, "v2.get_tenancy_configs": false, "v2.add_role_to_restriction_query": false, "v2.create_restriction_query": false, "v2.delete_restriction_query": false, "v2.get_restriction_query": false, "v2.get_role_restriction_query": false, "v2.list_restriction_queries": false, "v2.list_restriction_query_roles": false, "v2.list_user_restriction_queries": false, "v2.remove_role_from_restriction_query": false, "v2.replace_restriction_query": false, "v2.update_restriction_query": false, "v2.create_monitor_user_template": false, "v2.delete_monitor_user_template": false, "v2.get_monitor_user_template": false, "v2.list_monitor_user_templates": false, "v2.update_monitor_user_template": false, "v2.validate_existing_monitor_user_template": false, "v2.validate_monitor_user_template": false, "v2.bulk_update_org_group_memberships": false, "v2.create_org_group": false, "v2.create_org_group_policy": false, "v2.create_org_group_policy_override": false, "v2.delete_org_group": false, "v2.delete_org_group_policy": false, "v2.delete_org_group_policy_override": false, "v2.get_org_group": false, "v2.get_org_group_membership": false, "v2.get_org_group_policy": false, "v2.get_org_group_policy_override": false, "v2.list_org_group_memberships": false, "v2.list_org_group_policies": false, "v2.list_org_group_policy_configs": false, "v2.list_org_group_policy_overrides": false, "v2.list_org_groups": false, "v2.update_org_group": false, "v2.update_org_group_membership": false, "v2.update_org_group_policy": false, "v2.update_org_group_policy_override": false, "v2.list_role_templates": false, "v2.create_connection": false, "v2.delete_connection": false, "v2.get_account_facet_info": false, "v2.get_mapping": false, "v2.get_user_facet_info": false, "v2.list_connections": false, "v2.query_accounts": false, "v2.query_event_filtered_users": false, |