Class: DatadogAPIClient::V1::AWSAccount

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/aws_account.rb

Overview

Returns the AWS account associated with this integration.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#access_key_idObject

Your AWS access key ID. Only required if your AWS account is a GovCloud or China account.



29
30
31
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 29

def access_key_id
  @access_key_id
end

#account_idObject

Your AWS Account ID without dashes.



32
33
34
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 32

def 
  @account_id
end

#account_specific_namespace_rulesObject

An object, (in the form ‘“namespace2”:true/false`), that enables or disables metric collection for specific AWS namespaces for this AWS account only.



37
38
39
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 37

def 
  @account_specific_namespace_rules
end

#cspm_resource_collection_enabledObject

Whether Datadog collects cloud security posture management resources from your AWS account. This includes additional resources not covered under the general resource_collection.



40
41
42
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 40

def cspm_resource_collection_enabled
  @cspm_resource_collection_enabled
end

#excluded_regionsObject

An array of AWS regions to exclude from metrics collection.



43
44
45
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 43

def excluded_regions
  @excluded_regions
end

#filter_tagsObject

The array of EC2 tags (in the form key:value) defines a filter that Datadog uses when collecting metrics from EC2. Wildcards, such as ‘?` (for single characters) and `*` (for multiple characters) can also be used. Only hosts that match one of the defined tags will be imported into Datadog. The rest will be ignored. Host matching a given tag can also be excluded by adding `!` before the tag. For example, `env:production,instance-type:c1.*,!region:us-east-1`



51
52
53
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 51

def filter_tags
  @filter_tags
end

#host_tagsObject

Array of tags (in the form key:value) to add to all hosts and metrics reporting through this integration.



55
56
57
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 55

def host_tags
  @host_tags
end

#metrics_collection_enabledObject

Whether Datadog collects metrics for this AWS account.



58
59
60
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 58

def metrics_collection_enabled
  @metrics_collection_enabled
end

#resource_collection_enabledObject

Whether Datadog collects a standard set of resources from your AWS account.



61
62
63
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 61

def resource_collection_enabled
  @resource_collection_enabled
end

#role_nameObject

Your Datadog role delegation name.



64
65
66
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 64

def role_name
  @role_name
end

#secret_access_keyObject

Your AWS secret access key. Only required if your AWS account is a GovCloud or China account.



67
68
69
# File 'lib/datadog_api_client/v1/models/aws_account.rb', line 67

def secret_access_key
  @secret_access_key
end