Class: DatadogAPIClient::V1::AWSIntegrationAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v1/api/aws_integration_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ AWSIntegrationAPI

Returns a new instance of AWSIntegrationAPI.



22
23
24
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#create_aws_account(body, opts = {}) ⇒ Object

Create an AWS integration.



29
30
31
32
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 29

def (body, opts = {})
  data, _status_code, _headers = (body, opts)
  data
end

#create_aws_account_with_http_info(body, opts = {}) ⇒ Array<(AWSAccountCreateResponse, Integer, Hash)>

Create an AWS integration.

Create a Datadog-Amazon Web Services integration. Using the POST method updates your integration configuration by adding your new configuration to the existing one in your Datadog organization. A unique AWS Account ID for role based authentication.

Parameters:

  • body (AWSAccount)

    AWS Request Object

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AWSAccountCreateResponse, Integer, Hash)>)

    AWSAccountCreateResponse data, response status code and response headers



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 44

def (body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.create_aws_account ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AWSIntegrationAPI.create_aws_account"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'AWSAccountCreateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :create_aws_account,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#create_aws_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_aws_tag_filter(body, opts = {}) ⇒ Object

Set an AWS tag filter.



99
100
101
102
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 99

def create_aws_tag_filter(body, opts = {})
  data, _status_code, _headers = create_aws_tag_filter_with_http_info(body, opts)
  data
end

#create_aws_tag_filter_with_http_info(body, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Set an AWS tag filter.

Set an AWS tag filter.

Parameters:

  • body (AWSTagFilterCreateRequest)

    Set an AWS tag filter using an aws_account_identifier, namespace, and filtering string. Namespace options are application_elb, elb, lambda, network_elb, rds, sqs, and custom.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 111

def create_aws_tag_filter_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.create_aws_tag_filter ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AWSIntegrationAPI.create_aws_tag_filter"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws/filtering'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :create_aws_tag_filter,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#create_aws_tag_filter\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_new_aws_external_id(body, opts = {}) ⇒ Object

Generate a new external ID.



166
167
168
169
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 166

def create_new_aws_external_id(body, opts = {})
  data, _status_code, _headers = create_new_aws_external_id_with_http_info(body, opts)
  data
end

#create_new_aws_external_id_with_http_info(body, opts = {}) ⇒ Array<(AWSAccountCreateResponse, Integer, Hash)>

Generate a new external ID.

Generate a new AWS external ID for a given AWS account ID and role name pair.

Parameters:

Returns:

  • (Array<(AWSAccountCreateResponse, Integer, Hash)>)

    AWSAccountCreateResponse data, response status code and response headers



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 178

def create_new_aws_external_id_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.create_new_aws_external_id ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AWSIntegrationAPI.create_new_aws_external_id"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws/generate_new_external_id'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'AWSAccountCreateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :create_new_aws_external_id,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Put, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#create_new_aws_external_id\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_aws_account(body, opts = {}) ⇒ Object

Delete an AWS integration.



233
234
235
236
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 233

def (body, opts = {})
  data, _status_code, _headers = (body, opts)
  data
end

#delete_aws_account_with_http_info(body, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Delete an AWS integration.

Delete a Datadog-AWS integration matching the specified account_id and ‘role_name parameters`.

Parameters:

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 245

def (body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.delete_aws_account ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AWSIntegrationAPI.delete_aws_account"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :delete_aws_account,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#delete_aws_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_aws_tag_filter(body, opts = {}) ⇒ Object

Delete a tag filtering entry.



300
301
302
303
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 300

def delete_aws_tag_filter(body, opts = {})
  data, _status_code, _headers = delete_aws_tag_filter_with_http_info(body, opts)
  data
end

#delete_aws_tag_filter_with_http_info(body, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Delete a tag filtering entry.

Delete a tag filtering entry.

Parameters:

  • body (AWSTagFilterDeleteRequest)

    Delete a tag filtering entry for a given AWS account and dd-aws namespace.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 312

def delete_aws_tag_filter_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.delete_aws_tag_filter ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AWSIntegrationAPI.delete_aws_tag_filter"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws/filtering'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :delete_aws_tag_filter,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#delete_aws_tag_filter\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_available_aws_namespaces(opts = {}) ⇒ Object

List namespace rules.



367
368
369
370
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 367

def list_available_aws_namespaces(opts = {})
  data, _status_code, _headers = list_available_aws_namespaces_with_http_info(opts)
  data
end

#list_available_aws_namespaces_with_http_info(opts = {}) ⇒ Array<(Array<String>, Integer, Hash)>

List namespace rules.

List all namespace rules for a given Datadog-AWS integration. This endpoint takes no arguments.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<String>, Integer, Hash)>)

    Array<String> data, response status code and response headers



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 378

def list_available_aws_namespaces_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.list_available_aws_namespaces ...'
  end
  # resource path
  local_var_path = '/api/v1/integration/aws/available_namespace_rules'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<String>'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :list_available_aws_namespaces,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#list_available_aws_namespaces\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_aws_accounts(opts = {}) ⇒ Object

List all AWS integrations.



427
428
429
430
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 427

def list_aws_accounts(opts = {})
  data, _status_code, _headers = list_aws_accounts_with_http_info(opts)
  data
end

#list_aws_accounts_with_http_info(opts = {}) ⇒ Array<(AWSAccountListResponse, Integer, Hash)>

List all AWS integrations.

List all Datadog-AWS integrations available in your Datadog organization.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_id (String)

    Only return AWS accounts that matches this account_id.

  • :role_name (String)

    Only return AWS accounts that matches this role_name.

  • :access_key_id (String)

    Only return AWS accounts that matches this access_key_id.

Returns:

  • (Array<(AWSAccountListResponse, Integer, Hash)>)

    AWSAccountListResponse data, response status code and response headers



441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 441

def list_aws_accounts_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.list_aws_accounts ...'
  end
  # resource path
  local_var_path = '/api/v1/integration/aws'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'account_id'] = opts[:'account_id'] if !opts[:'account_id'].nil?
  query_params[:'role_name'] = opts[:'role_name'] if !opts[:'role_name'].nil?
  query_params[:'access_key_id'] = opts[:'access_key_id'] if !opts[:'access_key_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AWSAccountListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :list_aws_accounts,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#list_aws_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_aws_tag_filters(account_id, opts = {}) ⇒ Object

Get all AWS tag filters.



493
494
495
496
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 493

def list_aws_tag_filters(, opts = {})
  data, _status_code, _headers = list_aws_tag_filters_with_http_info(, opts)
  data
end

#list_aws_tag_filters_with_http_info(account_id, opts = {}) ⇒ Array<(AWSTagFilterListResponse, Integer, Hash)>

Get all AWS tag filters.

Get all AWS tag filters.

Parameters:

  • account_id (String)

    Only return AWS filters that matches this account_id.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AWSTagFilterListResponse, Integer, Hash)>)

    AWSTagFilterListResponse data, response status code and response headers



505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 505

def list_aws_tag_filters_with_http_info(, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.list_aws_tag_filters ...'
  end
  # verify the required parameter 'account_id' is set
  if @api_client.config.client_side_validation && .nil?
    fail ArgumentError, "Missing the required parameter 'account_id' when calling AWSIntegrationAPI.list_aws_tag_filters"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws/filtering'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'account_id'] = 

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AWSTagFilterListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :list_aws_tag_filters,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#list_aws_tag_filters\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_aws_account(body, opts = {}) ⇒ Object

Update an AWS integration.



559
560
561
562
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 559

def (body, opts = {})
  data, _status_code, _headers = (body, opts)
  data
end

#update_aws_account_with_http_info(body, opts = {}) ⇒ Array<(Object, Integer, Hash)>

Update an AWS integration.

Update a Datadog-Amazon Web Services integration.

Parameters:

  • body (AWSAccount)

    AWS request object

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :account_id (String)

    Only return AWS accounts that matches this account_id.

  • :role_name (String)

    Only return AWS accounts that match this role_name. Required if account_id is specified.

  • :access_key_id (String)

    Only return AWS accounts that matches this access_key_id. Required if none of the other two options are specified.

Returns:

  • (Array<(Object, Integer, Hash)>)

    Object data, response status code and response headers



574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
# File 'lib/datadog_api_client/v1/api/aws_integration_api.rb', line 574

def (body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AWSIntegrationAPI.update_aws_account ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AWSIntegrationAPI.update_aws_account"
  end
  # resource path
  local_var_path = '/api/v1/integration/aws'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'account_id'] = opts[:'account_id'] if !opts[:'account_id'].nil?
  query_params[:'role_name'] = opts[:'role_name'] if !opts[:'role_name'].nil?
  query_params[:'access_key_id'] = opts[:'access_key_id'] if !opts[:'access_key_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'Object'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_aws_account,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V1"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Put, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AWSIntegrationAPI#update_aws_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end