Class: DatadogAPIClient::V1::AWSLogsListServicesResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/aws_logs_list_services_response.rb

Overview

The list of current AWS services for which Datadog offers automatic log collection.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#idObject

Key value in returned object.



29
30
31
# File 'lib/datadog_api_client/v1/models/aws_logs_list_services_response.rb', line 29

def id
  @id
end

#labelObject

Name of service available for configuration with Datadog logs.



32
33
34
# File 'lib/datadog_api_client/v1/models/aws_logs_list_services_response.rb', line 32

def label
  @label
end