Class: DatadogAPIClient::V1::AWSLogsServicesRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::AWSLogsServicesRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/aws_logs_services_request.rb
Overview
A list of current AWS services for which Datadog offers automatic log collection.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
readonly
Your AWS Account ID without dashes.
-
#services ⇒ Object
readonly
Array of services IDs set to enable automatic log collection.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#account_id ⇒ Object
Your AWS Account ID without dashes.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/aws_logs_services_request.rb', line 29 def account_id @account_id end |
#services ⇒ Object
Array of services IDs set to enable automatic log collection. Discover the list of available services with the get list of AWS log ready services API endpoint.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/aws_logs_services_request.rb', line 32 def services @services end |