Class: DatadogAPIClient::V1::AlertGraphWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb

Overview

Alert graphs are timeseries graphs showing the current status of any monitor defined on your system.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#alert_idObject

ID of the alert to use in the widget.



29
30
31
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 29

def alert_id
  @alert_id
end

#timeObject

Time setting for the widget.



32
33
34
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 32

def time
  @time
end

#titleObject

The title of the widget.



35
36
37
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 35

def title
  @title
end

#title_alignObject

How to align the text on the widget.



38
39
40
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 38

def title_align
  @title_align
end

#title_sizeObject

Size of the title.



41
42
43
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 41

def title_size
  @title_size
end

#typeObject

Type of the alert graph widget.



44
45
46
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 44

def type
  @type
end

#viz_typeObject

Whether to display the Alert Graph as a timeseries or a top list.



47
48
49
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 47

def viz_type
  @viz_type
end