Class: DatadogAPIClient::V1::ApmStatsQueryDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ApmStatsQueryDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/apm_stats_query_definition.rb
Overview
The APM stats query for table and distributions widgets.
Instance Attribute Summary collapse
-
#columns ⇒ Object
Column properties used by the front end for display.
-
#env ⇒ Object
readonly
Environment name.
-
#name ⇒ Object
readonly
Operation name associated with service.
-
#primary_tag ⇒ Object
readonly
The organization’s host group name and value.
-
#resource ⇒ Object
Resource name.
-
#row_type ⇒ Object
readonly
The level of detail for the request.
-
#service ⇒ Object
readonly
Service name.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#columns ⇒ Object
Column properties used by the front end for display.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 29 def columns @columns end |
#env ⇒ Object
Environment name.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 32 def env @env end |
#name ⇒ Object
Operation name associated with service.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 35 def name @name end |
#primary_tag ⇒ Object
The organization’s host group name and value.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 38 def primary_tag @primary_tag end |
#resource ⇒ Object
Resource name.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 41 def resource @resource end |
#row_type ⇒ Object
The level of detail for the request.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 44 def row_type @row_type end |
#service ⇒ Object
Service name.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/apm_stats_query_definition.rb', line 47 def service @service end |