Class: DatadogAPIClient::V1::AzureAccount
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::AzureAccount
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/azure_account.rb
Overview
Datadog-Azure integrations configured for your organization.
Instance Attribute Summary collapse
-
#automute ⇒ Object
Silence monitors for expected Azure VM shutdowns.
-
#client_id ⇒ Object
Your Azure web application ID.
-
#client_secret ⇒ Object
Your Azure web application secret key.
-
#errors ⇒ Object
Errors in your configuration.
-
#host_filters ⇒ Object
Limit the Azure instances that are pulled into Datadog by using tags.
-
#new_client_id ⇒ Object
Your New Azure web application ID.
-
#new_tenant_name ⇒ Object
Your New Azure Active Directory ID.
-
#tenant_name ⇒ Object
Your Azure Active Directory ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#automute ⇒ Object
Silence monitors for expected Azure VM shutdowns.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 29 def automute @automute end |
#client_id ⇒ Object
Your Azure web application ID.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 32 def client_id @client_id end |
#client_secret ⇒ Object
Your Azure web application secret key.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 35 def client_secret @client_secret end |
#errors ⇒ Object
Errors in your configuration.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 38 def errors @errors end |
#host_filters ⇒ Object
Limit the Azure instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 42 def host_filters @host_filters end |
#new_client_id ⇒ Object
Your New Azure web application ID.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 45 def new_client_id @new_client_id end |
#new_tenant_name ⇒ Object
Your New Azure Active Directory ID.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 48 def new_tenant_name @new_tenant_name end |
#tenant_name ⇒ Object
Your Azure Active Directory ID.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/azure_account.rb', line 51 def tenant_name @tenant_name end |