Class: DatadogAPIClient::V1::ChangeWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/change_widget_definition.rb

Overview

The Change graph shows you the change in a value over the time period chosen.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

List of custom links.



29
30
31
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 29

def custom_links
  @custom_links
end

#requestsObject

Array of one request object to display in the widget.

See the dedicated [Request JSON schema documentation](docs.datadoghq.com/dashboards/graphing_json/request_json)

to learn how to build the `REQUEST_SCHEMA`.


35
36
37
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 35

def requests
  @requests
end

#timeObject

Time setting for the widget.



38
39
40
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 38

def time
  @time
end

#titleObject

Title of the widget.



41
42
43
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 41

def title
  @title
end

#title_alignObject

How to align the text on the widget.



44
45
46
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 44

def title_align
  @title_align
end

#title_sizeObject

Size of the title.



47
48
49
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 47

def title_size
  @title_size
end

#typeObject

Type of the change widget.



50
51
52
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 50

def type
  @type
end