Class: DatadogAPIClient::V1::CheckStatusWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::CheckStatusWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/check_status_widget_definition.rb
Overview
Check status shows the current status or number of results for any check performed.
Instance Attribute Summary collapse
-
#check ⇒ Object
readonly
Name of the check to use in the widget.
-
#group ⇒ Object
Group reporting a single check.
-
#group_by ⇒ Object
List of tag prefixes to group by in the case of a cluster check.
-
#grouping ⇒ Object
readonly
The kind of grouping to use.
-
#tags ⇒ Object
List of tags used to filter the groups reporting a cluster check.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the check status widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#check ⇒ Object
Name of the check to use in the widget.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 29 def check @check end |
#group ⇒ Object
Group reporting a single check.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 32 def group @group end |
#group_by ⇒ Object
List of tag prefixes to group by in the case of a cluster check.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 35 def group_by @group_by end |
#grouping ⇒ Object
The kind of grouping to use.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 38 def grouping @grouping end |
#tags ⇒ Object
List of tags used to filter the groups reporting a cluster check.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 41 def end |
#time ⇒ Object
Time setting for the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 44 def time @time end |
#title ⇒ Object
Title of the widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 47 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 50 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 53 def title_size @title_size end |
#type ⇒ Object
Type of the check status widget.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/check_status_widget_definition.rb', line 56 def type @type end |