Class: DatadogAPIClient::V1::DashboardList
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::DashboardList
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/dashboard_list.rb
Overview
Your Datadog Dashboards.
Instance Attribute Summary collapse
-
#author ⇒ Object
Object describing the creator of the shared element.
-
#created ⇒ Object
Date of creation of the dashboard list.
-
#dashboard_count ⇒ Object
The number of dashboards in the list.
-
#id ⇒ Object
The ID of the dashboard list.
-
#is_favorite ⇒ Object
Whether or not the list is in the favorites.
-
#modified ⇒ Object
Date of last edition of the dashboard list.
-
#name ⇒ Object
readonly
The name of the dashboard list.
-
#type ⇒ Object
The type of dashboard list.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#author ⇒ Object
Object describing the creator of the shared element.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 29 def end |
#created ⇒ Object
Date of creation of the dashboard list.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 32 def created @created end |
#dashboard_count ⇒ Object
The number of dashboards in the list.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 35 def dashboard_count @dashboard_count end |
#id ⇒ Object
The ID of the dashboard list.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 38 def id @id end |
#is_favorite ⇒ Object
Whether or not the list is in the favorites.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 41 def is_favorite @is_favorite end |
#modified ⇒ Object
Date of last edition of the dashboard list.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 44 def modified @modified end |
#name ⇒ Object
The name of the dashboard list.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 47 def name @name end |
#type ⇒ Object
The type of dashboard list.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/dashboard_list.rb', line 50 def type @type end |