Class: DatadogAPIClient::V1::DashboardTemplateVariable
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::DashboardTemplateVariable
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/dashboard_template_variable.rb
Overview
Template variable.
Instance Attribute Summary collapse
-
#available_values ⇒ Object
The list of values that the template variable drop-down is limited to.
-
#default ⇒ Object
(deprecated) The default value for the template variable on dashboard load.
-
#defaults ⇒ Object
One or many default values for template variables on load.
-
#name ⇒ Object
readonly
The name of the variable.
-
#prefix ⇒ Object
The tag prefix associated with the variable.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#available_values ⇒ Object
The list of values that the template variable drop-down is limited to.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/dashboard_template_variable.rb', line 29 def available_values @available_values end |
#default ⇒ Object
(deprecated) The default value for the template variable on dashboard load. Cannot be used in conjunction with defaults.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/dashboard_template_variable.rb', line 32 def default @default end |
#defaults ⇒ Object
One or many default values for template variables on load. If more than one default is specified, they will be unioned together with OR. Cannot be used in conjunction with default.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/dashboard_template_variable.rb', line 35 def defaults @defaults end |
#name ⇒ Object
The name of the variable.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/dashboard_template_variable.rb', line 38 def name @name end |
#prefix ⇒ Object
The tag prefix associated with the variable. Only tags with this prefix appear in the variable drop-down.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/dashboard_template_variable.rb', line 41 def prefix @prefix end |