Class: DatadogAPIClient::V1::DistributionWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::DistributionWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/distribution_widget_definition.rb
Overview
The Distribution visualization is another way of showing metrics aggregated across one or several tags, such as hosts. Unlike the heat map, a distribution graph’s x-axis is quantity rather than time.
Instance Attribute Summary collapse
-
#legend_size ⇒ Object
(Deprecated) The widget legend was replaced by a tooltip and sidebar.
-
#markers ⇒ Object
List of markers.
-
#requests ⇒ Object
readonly
Array of one request object to display in the widget.
-
#show_legend ⇒ Object
(Deprecated) The widget legend was replaced by a tooltip and sidebar.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the distribution widget.
-
#xaxis ⇒ Object
X Axis controls for the distribution widget.
-
#yaxis ⇒ Object
Y Axis controls for the distribution widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#legend_size ⇒ Object
(Deprecated) The widget legend was replaced by a tooltip and sidebar.
31 32 33 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 31 def legend_size @legend_size end |
#markers ⇒ Object
List of markers.
34 35 36 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 34 def markers @markers end |
#requests ⇒ Object
Array of one request object to display in the widget.
See the dedicated [Request JSON schema documentation](docs.datadoghq.com/dashboards/graphing_json/request_json)
to learn how to build the `REQUEST_SCHEMA`.
40 41 42 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 40 def requests @requests end |
#show_legend ⇒ Object
(Deprecated) The widget legend was replaced by a tooltip and sidebar.
43 44 45 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 43 def show_legend @show_legend end |
#time ⇒ Object
Time setting for the widget.
46 47 48 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 46 def time @time end |
#title ⇒ Object
Title of the widget.
49 50 51 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 49 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
52 53 54 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 52 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
55 56 57 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 55 def title_size @title_size end |
#type ⇒ Object
Type of the distribution widget.
58 59 60 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 58 def type @type end |
#xaxis ⇒ Object
X Axis controls for the distribution widget.
61 62 63 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 61 def xaxis @xaxis end |
#yaxis ⇒ Object
Y Axis controls for the distribution widget.
64 65 66 |
# File 'lib/datadog_api_client/v1/models/distribution_widget_definition.rb', line 64 def yaxis @yaxis end |