Class: DatadogAPIClient::V1::DistributionWidgetYAxis

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/distribution_widget_y_axis.rb

Overview

Y Axis controls for the distribution widget.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#include_zeroObject

True includes zero.



29
30
31
# File 'lib/datadog_api_client/v1/models/distribution_widget_y_axis.rb', line 29

def include_zero
  @include_zero
end

#labelObject

The label of the axis to display on the graph.



32
33
34
# File 'lib/datadog_api_client/v1/models/distribution_widget_y_axis.rb', line 32

def label
  @label
end

#maxObject

Specifies the maximum value to show on the y-axis. It takes a number, or auto for default behavior.



35
36
37
# File 'lib/datadog_api_client/v1/models/distribution_widget_y_axis.rb', line 35

def max
  @max
end

#minObject

Specifies minimum value to show on the y-axis. It takes a number, or auto for default behavior.



38
39
40
# File 'lib/datadog_api_client/v1/models/distribution_widget_y_axis.rb', line 38

def min
  @min
end

#scaleObject

Specifies the scale type. Possible values are linear or log.



41
42
43
# File 'lib/datadog_api_client/v1/models/distribution_widget_y_axis.rb', line 41

def scale
  @scale
end