Class: DatadogAPIClient::V1::DowntimeRecurrence

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/downtime_recurrence.rb

Overview

An object defining the recurrence of the downtime.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#periodObject

How often to repeat as an integer. For example, to repeat every 3 days, select a type of days and a period of 3.



30
31
32
# File 'lib/datadog_api_client/v1/models/downtime_recurrence.rb', line 30

def period
  @period
end

#rruleObject

The RRULE standard for defining recurring events (**requires to set “type” to rrule**) For example, to have a recurring event on the first day of each month, set the type to rrule and set the FREQ to MONTHLY and BYMONTHDAY to 1. Most common rrule options from the [iCalendar Spec](tools.ietf.org/html/rfc5545) are supported.

Note: Attributes specifying the duration in RRULE are not supported (for example, DTSTART, DTEND, DURATION). More examples available in this [downtime guide](docs.datadoghq.com/monitors/guide/suppress-alert-with-downtimes/?tab=api)



38
39
40
# File 'lib/datadog_api_client/v1/models/downtime_recurrence.rb', line 38

def rrule
  @rrule
end

#typeObject

The type of recurrence. Choose from days, weeks, months, years, rrule.



41
42
43
# File 'lib/datadog_api_client/v1/models/downtime_recurrence.rb', line 41

def type
  @type
end

#until_dateObject

The date at which the recurrence should end as a POSIX timestamp. until_occurences and until_date are mutually exclusive.



45
46
47
# File 'lib/datadog_api_client/v1/models/downtime_recurrence.rb', line 45

def until_date
  @until_date
end

#until_occurrencesObject

How many times the downtime is rescheduled. until_occurences and until_date are mutually exclusive.



49
50
51
# File 'lib/datadog_api_client/v1/models/downtime_recurrence.rb', line 49

def until_occurrences
  @until_occurrences
end

#week_daysObject

A list of week days to repeat on. Choose from Mon, Tue, Wed, Thu, Fri, Sat or Sun. Only applicable when type is weeks. First letter must be capitalized.



53
54
55
# File 'lib/datadog_api_client/v1/models/downtime_recurrence.rb', line 53

def week_days
  @week_days
end