Class: DatadogAPIClient::V1::EventTimelineWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::EventTimelineWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb
Overview
The event timeline is a widget version of the timeline that appears at the top of the Event Stream view. Only available on FREE layout dashboards.
Instance Attribute Summary collapse
-
#query ⇒ Object
readonly
Query to filter the event timeline with.
-
#tags_execution ⇒ Object
The execution method for multi-value filters.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the event timeline widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#query ⇒ Object
Query to filter the event timeline with.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 29 def query @query end |
#tags_execution ⇒ Object
The execution method for multi-value filters. Can be either and or or.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 32 def end |
#time ⇒ Object
Time setting for the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 35 def time @time end |
#title ⇒ Object
Title of the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 38 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 41 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 44 def title_size @title_size end |
#type ⇒ Object
Type of the event timeline widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/event_timeline_widget_definition.rb', line 47 def type @type end |