Class: DatadogAPIClient::V1::FormulaAndFunctionApmResourceStatsQueryDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::FormulaAndFunctionApmResourceStatsQueryDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb
Overview
APM resource stats query using formulas and functions.
Instance Attribute Summary collapse
-
#data_source ⇒ Object
readonly
Data source for APM resource stats queries.
-
#env ⇒ Object
readonly
APM environment.
-
#group_by ⇒ Object
Array of fields to group results by.
-
#name ⇒ Object
readonly
Name of this query to use in formulas.
-
#operation_name ⇒ Object
Name of operation on service.
-
#primary_tag_name ⇒ Object
Name of the second primary tag used within APM.
-
#primary_tag_value ⇒ Object
Value of the second primary tag by which to filter APM data.
-
#resource_name ⇒ Object
APM resource name.
-
#service ⇒ Object
readonly
APM service name.
-
#stat ⇒ Object
readonly
APM resource stat name.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#data_source ⇒ Object
Data source for APM resource stats queries.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 29 def data_source @data_source end |
#env ⇒ Object
APM environment.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 32 def env @env end |
#group_by ⇒ Object
Array of fields to group results by.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 35 def group_by @group_by end |
#name ⇒ Object
Name of this query to use in formulas.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 38 def name @name end |
#operation_name ⇒ Object
Name of operation on service.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 41 def operation_name @operation_name end |
#primary_tag_name ⇒ Object
Name of the second primary tag used within APM. Required when primary_tag_value is specified. See docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog
44 45 46 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 44 def primary_tag_name @primary_tag_name end |
#primary_tag_value ⇒ Object
Value of the second primary tag by which to filter APM data. primary_tag_name must also be specified.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 47 def primary_tag_value @primary_tag_value end |
#resource_name ⇒ Object
APM resource name.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 50 def resource_name @resource_name end |
#service ⇒ Object
APM service name.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 53 def service @service end |
#stat ⇒ Object
APM resource stat name.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_apm_resource_stats_query_definition.rb', line 56 def stat @stat end |