Class: DatadogAPIClient::V1::FormulaAndFunctionEventQueryDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::FormulaAndFunctionEventQueryDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb
Overview
A formula and functions events query.
Instance Attribute Summary collapse
-
#compute ⇒ Object
readonly
Compute options.
-
#data_source ⇒ Object
readonly
Data source for event platform-based queries.
-
#group_by ⇒ Object
Group by options.
-
#indexes ⇒ Object
An array of index names to query in the stream.
-
#name ⇒ Object
readonly
Name of the query for use in formulas.
-
#search ⇒ Object
Search options.
-
#storage ⇒ Object
Option for storage location.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#compute ⇒ Object
Compute options.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 29 def compute @compute end |
#data_source ⇒ Object
Data source for event platform-based queries.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 32 def data_source @data_source end |
#group_by ⇒ Object
Group by options.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 35 def group_by @group_by end |
#indexes ⇒ Object
An array of index names to query in the stream. Omit or use [] to query all indexes at once.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 38 def indexes @indexes end |
#name ⇒ Object
Name of the query for use in formulas.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 41 def name @name end |
#search ⇒ Object
Search options.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 44 def search @search end |
#storage ⇒ Object
Option for storage location. Feature in Private Beta.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/formula_and_function_event_query_definition.rb', line 47 def storage @storage end |