Class: DatadogAPIClient::V1::FreeTextWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::FreeTextWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/free_text_widget_definition.rb
Overview
Free text is a widget that allows you to add headings to your screenboard. Commonly used to state the overall purpose of the dashboard. Only available on FREE layout dashboards.
Instance Attribute Summary collapse
-
#color ⇒ Object
Color of the text.
-
#font_size ⇒ Object
Size of the text.
-
#text ⇒ Object
readonly
Text to display.
-
#text_align ⇒ Object
How to align the text on the widget.
-
#type ⇒ Object
readonly
Type of the free text widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#color ⇒ Object
Color of the text.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/free_text_widget_definition.rb', line 29 def color @color end |
#font_size ⇒ Object
Size of the text.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/free_text_widget_definition.rb', line 32 def font_size @font_size end |
#text ⇒ Object
Text to display.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/free_text_widget_definition.rb', line 35 def text @text end |
#text_align ⇒ Object
How to align the text on the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/free_text_widget_definition.rb', line 38 def text_align @text_align end |
#type ⇒ Object
Type of the free text widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/free_text_widget_definition.rb', line 41 def type @type end |