Class: DatadogAPIClient::V1::FunnelQuery
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::FunnelQuery
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/funnel_query.rb
Overview
Updated funnel widget.
Instance Attribute Summary collapse
-
#data_source ⇒ Object
readonly
Source from which to query items to display in the funnel.
-
#query_string ⇒ Object
readonly
The widget query.
-
#steps ⇒ Object
readonly
List of funnel steps.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#data_source ⇒ Object
Source from which to query items to display in the funnel.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/funnel_query.rb', line 29 def data_source @data_source end |
#query_string ⇒ Object
The widget query.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/funnel_query.rb', line 32 def query_string @query_string end |
#steps ⇒ Object
List of funnel steps.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/funnel_query.rb', line 35 def steps @steps end |