Class: DatadogAPIClient::V1::FunnelWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/funnel_widget_definition.rb

Overview

The funnel visualization displays a funnel of user sessions that maps a sequence of view navigation and user interaction in your application.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



48
49
50
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 48

def additional_properties
  @additional_properties
end

#descriptionObject

The description of the widget.



25
26
27
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 25

def description
  @description
end

#grouped_displayObject

Display mode for grouped funnel results.



28
29
30
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 28

def grouped_display
  @grouped_display
end

#requestsObject

Request payload used to query items.



31
32
33
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 31

def requests
  @requests
end

#timeObject

Time setting for the widget.



34
35
36
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 34

def time
  @time
end

#titleObject

The title of the widget.



37
38
39
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 37

def title
  @title
end

#title_alignObject

How to align the text on the widget.



40
41
42
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 40

def title_align
  @title_align
end

#title_sizeObject

The size of the title.



43
44
45
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 43

def title_size
  @title_size
end

#typeObject

Type of funnel widget.



46
47
48
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 46

def type
  @type
end