Class: DatadogAPIClient::V1::GCPAccount
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::GCPAccount
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/gcp_account.rb
Overview
Your Google Cloud Platform Account.
Instance Attribute Summary collapse
-
#auth_provider_x509_cert_url ⇒ Object
Should be
https://www.googleapis.com/oauth2/v1/certs. -
#auth_uri ⇒ Object
Should be
https://accounts.google.com/o/oauth2/auth. -
#automute ⇒ Object
Silence monitors for expected GCE instance shutdowns.
-
#client_email ⇒ Object
Your email found in your JSON service account key.
-
#client_id ⇒ Object
Your ID found in your JSON service account key.
-
#client_x509_cert_url ⇒ Object
Should be ‘www.googleapis.com/robot/v1/metadata/x509/$CLIENT_EMAIL` where `$CLIENT_EMAIL` is the email found in your JSON service account key.
-
#errors ⇒ Object
An array of errors.
-
#host_filters ⇒ Object
Limit the GCE instances that are pulled into Datadog by using tags.
-
#is_cspm_enabled ⇒ Object
When enabled, Datadog performs configuration checks across your Google Cloud environment by continuously scanning every resource.
-
#private_key ⇒ Object
Your private key name found in your JSON service account key.
-
#private_key_id ⇒ Object
Your private key ID found in your JSON service account key.
-
#project_id ⇒ Object
Your Google Cloud project ID found in your JSON service account key.
-
#token_uri ⇒ Object
Should be
https://accounts.google.com/o/oauth2/token. -
#type ⇒ Object
The value for service_account found in your JSON service account key.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#auth_provider_x509_cert_url ⇒ Object
Should be https://www.googleapis.com/oauth2/v1/certs.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 29 def auth_provider_x509_cert_url @auth_provider_x509_cert_url end |
#auth_uri ⇒ Object
Should be https://accounts.google.com/o/oauth2/auth.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 32 def auth_uri @auth_uri end |
#automute ⇒ Object
Silence monitors for expected GCE instance shutdowns.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 35 def automute @automute end |
#client_email ⇒ Object
Your email found in your JSON service account key.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 38 def client_email @client_email end |
#client_id ⇒ Object
Your ID found in your JSON service account key.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 41 def client_id @client_id end |
#client_x509_cert_url ⇒ Object
Should be ‘www.googleapis.com/robot/v1/metadata/x509/$CLIENT_EMAIL` where `$CLIENT_EMAIL` is the email found in your JSON service account key.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 45 def client_x509_cert_url @client_x509_cert_url end |
#errors ⇒ Object
An array of errors.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 48 def errors @errors end |
#host_filters ⇒ Object
Limit the GCE instances that are pulled into Datadog by using tags. Only hosts that match one of the defined tags are imported into Datadog.
52 53 54 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 52 def host_filters @host_filters end |
#is_cspm_enabled ⇒ Object
When enabled, Datadog performs configuration checks across your Google Cloud environment by continuously scanning every resource.
55 56 57 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 55 def is_cspm_enabled @is_cspm_enabled end |
#private_key ⇒ Object
Your private key name found in your JSON service account key.
58 59 60 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 58 def private_key @private_key end |
#private_key_id ⇒ Object
Your private key ID found in your JSON service account key.
61 62 63 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 61 def private_key_id @private_key_id end |
#project_id ⇒ Object
Your Google Cloud project ID found in your JSON service account key.
64 65 66 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 64 def project_id @project_id end |
#token_uri ⇒ Object
Should be https://accounts.google.com/o/oauth2/token.
67 68 69 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 67 def token_uri @token_uri end |
#type ⇒ Object
The value for service_account found in your JSON service account key.
70 71 72 |
# File 'lib/datadog_api_client/v1/models/gcp_account.rb', line 70 def type @type end |