Class: DatadogAPIClient::V1::GeomapWidgetDefinitionView

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/geomap_widget_definition_view.rb

Overview

The view of the world that the map should render.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#focusObject

The 2-letter ISO code of a country to focus the map on. Or WORLD.



29
30
31
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition_view.rb', line 29

def focus
  @focus
end