Class: DatadogAPIClient::V1::GroupWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/group_widget_definition.rb

Overview

The groups widget allows you to keep similar graphs together on your timeboard. Each group has a custom header, can hold one to many graphs, and is collapsible.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#background_colorObject

Background color of the group title.



29
30
31
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 29

def background_color
  @background_color
end

URL of image to display as a banner for the group.



32
33
34
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 32

def banner_img
  @banner_img
end

#layout_typeObject

Layout type of the group.



35
36
37
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 35

def layout_type
  @layout_type
end

#show_titleObject

Whether to show the title or not.



38
39
40
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 38

def show_title
  @show_title
end

#titleObject

Title of the widget.



41
42
43
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 41

def title
  @title
end

#title_alignObject

How to align the text on the widget.



44
45
46
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 44

def title_align
  @title_align
end

#typeObject

Type of the group widget.



47
48
49
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 47

def type
  @type
end

#widgetsObject

List of widget groups.



50
51
52
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 50

def widgets
  @widgets
end