Class: DatadogAPIClient::V1::HeatMapWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/heat_map_widget_definition.rb

Overview

The heat map visualization shows metrics aggregated across many tags, such as hosts. The more hosts that have a particular value, the darker that square is.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

List of custom links.



29
30
31
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 29

def custom_links
  @custom_links
end

#eventsObject

List of widget events.



32
33
34
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 32

def events
  @events
end

#legend_sizeObject

Available legend sizes for a widget. Should be one of “0”, “2”, “4”, “8”, “16”, or “auto”.



35
36
37
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 35

def legend_size
  @legend_size
end

#requestsObject

List of widget types.



38
39
40
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 38

def requests
  @requests
end

#show_legendObject

Whether or not to display the legend on this widget.



41
42
43
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 41

def show_legend
  @show_legend
end

#timeObject

Time setting for the widget.



44
45
46
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 44

def time
  @time
end

#titleObject

Title of the widget.



47
48
49
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 47

def title
  @title
end

#title_alignObject

How to align the text on the widget.



50
51
52
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 50

def title_align
  @title_align
end

#title_sizeObject

Size of the title.



53
54
55
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 53

def title_size
  @title_size
end

#typeObject

Type of the heat map widget.



56
57
58
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 56

def type
  @type
end

#yaxisObject

Axis controls for the widget.



59
60
61
# File 'lib/datadog_api_client/v1/models/heat_map_widget_definition.rb', line 59

def yaxis
  @yaxis
end