Class: DatadogAPIClient::V1::HostMapWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/host_map_widget_definition.rb

Overview

The host map widget graphs any metric across your hosts using the same visualization available from the main Host Map page.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

List of custom links.



29
30
31
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 29

def custom_links
  @custom_links
end

#groupObject

List of tag prefixes to group by.



32
33
34
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 32

def group
  @group
end

#no_group_hostsObject

Whether to show the hosts that don’t fit in a group.



35
36
37
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 35

def no_group_hosts
  @no_group_hosts
end

#no_metric_hostsObject

Whether to show the hosts with no metrics.



38
39
40
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 38

def no_metric_hosts
  @no_metric_hosts
end

#node_typeObject

Which type of node to use in the map.



41
42
43
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 41

def node_type
  @node_type
end

#notesObject

Notes on the title.



44
45
46
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 44

def notes
  @notes
end

#requestsObject

List of definitions.



47
48
49
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 47

def requests
  @requests
end

#scopeObject

List of tags used to filter the map.



50
51
52
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 50

def scope
  @scope
end

#styleObject

The style to apply to the widget.



53
54
55
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 53

def style
  @style
end

#titleObject

Title of the widget.



56
57
58
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 56

def title
  @title
end

#title_alignObject

How to align the text on the widget.



59
60
61
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 59

def title_align
  @title_align
end

#title_sizeObject

Size of the title.



62
63
64
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 62

def title_size
  @title_size
end

#typeObject

Type of the host map widget.



65
66
67
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 65

def type
  @type
end