Class: DatadogAPIClient::V1::HostMapWidgetGroupBy
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::HostMapWidgetGroupBy
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/host_map_widget_group_by.rb
Overview
Defines a grouping dimension for the infrastructure host map.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#column ⇒ Object
readonly
Column name from the entity table (for example, ‘cloud_provider`, `tags`, `labels`).
-
#key ⇒ Object
Key within the column for nested attribute types (for example, ‘service` within `tags`).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_group_by.rb', line 30 def additional_properties @additional_properties end |
#column ⇒ Object
Column name from the entity table (for example, ‘cloud_provider`, `tags`, `labels`).
25 26 27 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_group_by.rb', line 25 def column @column end |
#key ⇒ Object
Key within the column for nested attribute types (for example, ‘service` within `tags`).
28 29 30 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_group_by.rb', line 28 def key @key end |