Class: DatadogAPIClient::V1::HostMeta
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::HostMeta
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/host_meta.rb
Overview
Metadata associated with your host.
Instance Attribute Summary collapse
-
#agent_checks ⇒ Object
A list of Agent checks running on the host.
-
#agent_version ⇒ Object
The Datadog Agent version.
-
#cpu_cores ⇒ Object
The number of cores.
-
#fbsd_v ⇒ Object
An array of Mac versions.
-
#gohai ⇒ Object
JSON string containing system information.
-
#install_method ⇒ Object
Agent install method.
-
#mac_v ⇒ Object
An array of Mac versions.
-
#machine ⇒ Object
The machine architecture.
-
#nix_v ⇒ Object
Array of Unix versions.
-
#platform ⇒ Object
The OS platform.
-
#processor ⇒ Object
The processor.
-
#python_v ⇒ Object
The Python version.
-
#socket_fqdn ⇒ Object
The socket fqdn.
-
#socket_hostname ⇒ Object
The socket hostname.
-
#win_v ⇒ Object
An array of Windows versions.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#agent_checks ⇒ Object
A list of Agent checks running on the host.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 29 def agent_checks @agent_checks end |
#agent_version ⇒ Object
The Datadog Agent version.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 32 def agent_version @agent_version end |
#cpu_cores ⇒ Object
The number of cores.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 35 def cpu_cores @cpu_cores end |
#fbsd_v ⇒ Object
An array of Mac versions.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 38 def fbsd_v @fbsd_v end |
#gohai ⇒ Object
JSON string containing system information.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 41 def gohai @gohai end |
#install_method ⇒ Object
Agent install method.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 44 def install_method @install_method end |
#mac_v ⇒ Object
An array of Mac versions.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 47 def mac_v @mac_v end |
#machine ⇒ Object
The machine architecture.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 50 def machine @machine end |
#nix_v ⇒ Object
Array of Unix versions.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 53 def nix_v @nix_v end |
#platform ⇒ Object
The OS platform.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 56 def platform @platform end |
#processor ⇒ Object
The processor.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 59 def processor @processor end |
#python_v ⇒ Object
The Python version.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 62 def python_v @python_v end |
#socket_fqdn ⇒ Object
The socket fqdn.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 65 def socket_fqdn @socket_fqdn end |
#socket_hostname ⇒ Object
The socket hostname.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 68 def socket_hostname @socket_hostname end |
#win_v ⇒ Object
An array of Windows versions.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/host_meta.rb', line 71 def win_v @win_v end |