Class: DatadogAPIClient::V1::HostMuteResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/host_mute_response.rb

Overview

Response with the list of muted host for your organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#_endObject

POSIX timestamp in seconds when the host is unmuted.



32
33
34
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 32

def _end
  @_end
end

#actionObject

Action applied to the hosts.



29
30
31
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 29

def action
  @action
end

#hostnameObject

The host name.



35
36
37
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 35

def hostname
  @hostname
end

#messageObject

Message associated with the mute.



38
39
40
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 38

def message
  @message
end