Class: DatadogAPIClient::V1::IPRanges
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::IPRanges
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/ip_ranges.rb
Overview
IP ranges.
Instance Attribute Summary collapse
-
#agents ⇒ Object
Available prefix information for the Agent endpoints.
-
#api ⇒ Object
Available prefix information for the API endpoints.
-
#apm ⇒ Object
Available prefix information for the APM endpoints.
-
#logs ⇒ Object
Available prefix information for the Logs endpoints.
-
#modified ⇒ Object
Date when last updated, in the form
YYYY-MM-DD-hh-mm-ss. -
#orchestrator ⇒ Object
Available prefix information for the Orchestrator endpoints.
-
#process ⇒ Object
Available prefix information for the Process endpoints.
-
#synthetics ⇒ Object
Available prefix information for the Synthetics endpoints.
-
#synthetics_private_locations ⇒ Object
Available prefix information for the Synthetics Private Locations endpoints.
-
#version ⇒ Object
Version of the IP list.
-
#webhooks ⇒ Object
Available prefix information for the Webhook endpoints.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#agents ⇒ Object
Available prefix information for the Agent endpoints.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 29 def agents @agents end |
#api ⇒ Object
Available prefix information for the API endpoints.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 32 def api @api end |
#apm ⇒ Object
Available prefix information for the APM endpoints.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 35 def apm @apm end |
#logs ⇒ Object
Available prefix information for the Logs endpoints.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 38 def logs @logs end |
#modified ⇒ Object
Date when last updated, in the form YYYY-MM-DD-hh-mm-ss.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 41 def modified @modified end |
#orchestrator ⇒ Object
Available prefix information for the Orchestrator endpoints.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 44 def orchestrator @orchestrator end |
#process ⇒ Object
Available prefix information for the Process endpoints.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 47 def process @process end |
#synthetics ⇒ Object
Available prefix information for the Synthetics endpoints.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 50 def synthetics @synthetics end |
#synthetics_private_locations ⇒ Object
Available prefix information for the Synthetics Private Locations endpoints.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 53 def synthetics_private_locations @synthetics_private_locations end |
#version ⇒ Object
Version of the IP list.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 56 def version @version end |
#webhooks ⇒ Object
Available prefix information for the Webhook endpoints.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/ip_ranges.rb', line 59 def webhooks @webhooks end |