Class: DatadogAPIClient::V1::ListStreamQuery
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ListStreamQuery
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/list_stream_query.rb
Overview
Updated list stream widget.
Instance Attribute Summary collapse
-
#compute ⇒ Object
readonly
Compute configuration for the List Stream Widget.
-
#data_source ⇒ Object
readonly
Source from which to query items to display in the stream.
-
#event_size ⇒ Object
Size to use to display an event.
-
#group_by ⇒ Object
readonly
Group by configuration for the List Stream Widget.
-
#indexes ⇒ Object
List of indexes.
-
#query_string ⇒ Object
readonly
Widget query.
-
#storage ⇒ Object
Option for storage location.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#compute ⇒ Object
Compute configuration for the List Stream Widget. Compute can be used only with the logs_transaction_stream (from 1 to 5 items) list stream source.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 29 def compute @compute end |
#data_source ⇒ Object
Source from which to query items to display in the stream.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 32 def data_source @data_source end |
#event_size ⇒ Object
Size to use to display an event.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 35 def event_size @event_size end |
#group_by ⇒ Object
Group by configuration for the List Stream Widget. Group by can be used only with logs_pattern_stream (up to 3 items) or logs_transaction_stream (one group by item is required) list stream source.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 38 def group_by @group_by end |
#indexes ⇒ Object
List of indexes.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 41 def indexes @indexes end |
#query_string ⇒ Object
Widget query.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 44 def query_string @query_string end |
#storage ⇒ Object
Option for storage location. Feature in Private Beta.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/list_stream_query.rb', line 47 def storage @storage end |