Class: DatadogAPIClient::V1::ListStreamWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ListStreamWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/list_stream_widget_definition.rb
Overview
The list stream visualization displays a table of recent events in your application that match a search criteria using user-defined columns.
Instance Attribute Summary collapse
-
#legend_size ⇒ Object
Available legend sizes for a widget.
-
#requests ⇒ Object
readonly
Request payload used to query items.
-
#show_legend ⇒ Object
Whether or not to display the legend on this widget.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the list stream widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#legend_size ⇒ Object
Available legend sizes for a widget. Should be one of “0”, “2”, “4”, “8”, “16”, or “auto”.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 30 def legend_size @legend_size end |
#requests ⇒ Object
Request payload used to query items.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 33 def requests @requests end |
#show_legend ⇒ Object
Whether or not to display the legend on this widget.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 36 def show_legend @show_legend end |
#time ⇒ Object
Time setting for the widget.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 39 def time @time end |
#title ⇒ Object
Title of the widget.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 42 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 45 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 48 def title_size @title_size end |
#type ⇒ Object
Type of the list stream widget.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/list_stream_widget_definition.rb', line 51 def type @type end |