Class: DatadogAPIClient::V1::Log

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/log.rb

Overview

Object describing a log after being processed and stored by Datadog.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#contentObject

JSON object containing all log attributes and their associated values.



29
30
31
# File 'lib/datadog_api_client/v1/models/log.rb', line 29

def content
  @content
end

#idObject

Unique ID of the Log.



32
33
34
# File 'lib/datadog_api_client/v1/models/log.rb', line 32

def id
  @id
end