Class: DatadogAPIClient::V1::LogQueryDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogQueryDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/log_query_definition.rb
Overview
The log query.
Instance Attribute Summary collapse
-
#compute ⇒ Object
Define computation for a log query.
-
#group_by ⇒ Object
List of tag prefixes to group by in the case of a cluster check.
-
#index ⇒ Object
A coma separated-list of index names.
-
#multi_compute ⇒ Object
This field is mutually exclusive with
compute. -
#search ⇒ Object
The query being made on the logs.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#compute ⇒ Object
Define computation for a log query.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/log_query_definition.rb', line 29 def compute @compute end |
#group_by ⇒ Object
List of tag prefixes to group by in the case of a cluster check.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/log_query_definition.rb', line 32 def group_by @group_by end |
#index ⇒ Object
A coma separated-list of index names. Use “*” query all indexes at once. [Multiple Indexes](docs.datadoghq.com/logs/indexes/#multiple-indexes)
35 36 37 |
# File 'lib/datadog_api_client/v1/models/log_query_definition.rb', line 35 def index @index end |
#multi_compute ⇒ Object
This field is mutually exclusive with compute.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/log_query_definition.rb', line 38 def multi_compute @multi_compute end |
#search ⇒ Object
The query being made on the logs.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/log_query_definition.rb', line 41 def search @search end |