Class: DatadogAPIClient::V1::LogStreamWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogStreamWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/log_stream_widget_definition.rb
Overview
The Log Stream displays a log flow matching the defined query. Only available on FREE layout dashboards.
Instance Attribute Summary collapse
-
#columns ⇒ Object
Which columns to display on the widget.
-
#indexes ⇒ Object
An array of index names to query in the stream.
-
#logset ⇒ Object
ID of the log set to use.
-
#message_display ⇒ Object
Amount of log lines to display.
-
#query ⇒ Object
Query to filter the log stream with.
-
#show_date_column ⇒ Object
Whether to show the date column or not.
-
#show_message_column ⇒ Object
Whether to show the message column or not.
-
#sort ⇒ Object
Which column and order to sort by.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the log stream widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#columns ⇒ Object
Which columns to display on the widget.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 29 def columns @columns end |
#indexes ⇒ Object
An array of index names to query in the stream. Use [] to query all indexes at once.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 32 def indexes @indexes end |
#logset ⇒ Object
ID of the log set to use.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 35 def logset @logset end |
#message_display ⇒ Object
Amount of log lines to display
38 39 40 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 38 def @message_display end |
#query ⇒ Object
Query to filter the log stream with.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 41 def query @query end |
#show_date_column ⇒ Object
Whether to show the date column or not
44 45 46 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 44 def show_date_column @show_date_column end |
#show_message_column ⇒ Object
Whether to show the message column or not
47 48 49 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 47 def @show_message_column end |
#sort ⇒ Object
Which column and order to sort by
50 51 52 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 50 def sort @sort end |
#time ⇒ Object
Time setting for the widget.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 53 def time @time end |
#title ⇒ Object
Title of the widget.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 56 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 59 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 62 def title_size @title_size end |
#type ⇒ Object
Type of the log stream widget.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/log_stream_widget_definition.rb', line 65 def type @type end |