Class: DatadogAPIClient::V1::LogsAttributeRemapper

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_attribute_remapper.rb

Overview

The remapper processor remaps any source attribute(s) or tag to another target attribute or tag. Constraints on the tag/attribute name are explained in the [Tag Best Practice documentation](docs.datadoghq.com/logs/guide/log-parsing-best-practice). Some additional constraints are applied as : or ‘,` are not allowed in the target tag/attribute name.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#is_enabledObject

Whether or not the processor is enabled.



31
32
33
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 31

def is_enabled
  @is_enabled
end

#nameObject

Name of the processor.



34
35
36
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 34

def name
  @name
end

#override_on_conflictObject

Override or not the target element if already set,



37
38
39
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 37

def override_on_conflict
  @override_on_conflict
end

#preserve_sourceObject

Remove or preserve the remapped source element.



40
41
42
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 40

def preserve_source
  @preserve_source
end

#source_typeObject

Defines if the sources are from log attribute or tag.



43
44
45
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 43

def source_type
  @source_type
end

#sourcesObject

Array of source attributes.



46
47
48
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 46

def sources
  @sources
end

#targetObject

Final attribute or tag name to remap the sources to.



49
50
51
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 49

def target
  @target
end

#target_formatObject

If the target_type of the remapper is attribute, try to cast the value to a new specific type. If the cast is not possible, the original type is kept. string, integer, or double are the possible types. If the target_type is tag, this parameter may not be specified.



54
55
56
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 54

def target_format
  @target_format
end

#target_typeObject

Defines if the final attribute or tag name is from log attribute or tag.



57
58
59
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 57

def target_type
  @target_type
end

#typeObject

Type of logs attribute remapper.



60
61
62
# File 'lib/datadog_api_client/v1/models/logs_attribute_remapper.rb', line 60

def type
  @type
end