Class: DatadogAPIClient::V1::LogsByRetentionOrgUsage
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsByRetentionOrgUsage
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_by_retention_org_usage.rb
Overview
Indexed logs usage by retention for a single organization.
Instance Attribute Summary collapse
-
#usage ⇒ Object
Indexed logs usage for each active retention for the organization.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#usage ⇒ Object
Indexed logs usage for each active retention for the organization.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/logs_by_retention_org_usage.rb', line 29 def usage @usage end |