Class: DatadogAPIClient::V1::LogsExclusion

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_exclusion.rb

Overview

Represents the index exclusion filter object from configuration API.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#filterObject

Exclusion filter is defined by a query, a sampling rule, and a active/inactive toggle.



29
30
31
# File 'lib/datadog_api_client/v1/models/logs_exclusion.rb', line 29

def filter
  @filter
end

#is_enabledObject

Whether or not the exclusion filter is active.



32
33
34
# File 'lib/datadog_api_client/v1/models/logs_exclusion.rb', line 32

def is_enabled
  @is_enabled
end

#nameObject

Name of the index exclusion filter.



35
36
37
# File 'lib/datadog_api_client/v1/models/logs_exclusion.rb', line 35

def name
  @name
end