Class: DatadogAPIClient::V1::LogsGeoIPParser
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsGeoIPParser
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_geo_ip_parser.rb
Overview
The GeoIP parser takes an IP address attribute and extracts if available the Continent, Country, Subdivision, and City information in the target attribute path.
Instance Attribute Summary collapse
-
#is_enabled ⇒ Object
Whether or not the processor is enabled.
-
#name ⇒ Object
Name of the processor.
-
#sources ⇒ Object
readonly
Array of source attributes.
-
#target ⇒ Object
readonly
Name of the parent attribute that contains all the extracted details from the
sources. -
#type ⇒ Object
readonly
Type of GeoIP parser.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#is_enabled ⇒ Object
Whether or not the processor is enabled.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/logs_geo_ip_parser.rb', line 30 def is_enabled @is_enabled end |
#name ⇒ Object
Name of the processor.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/logs_geo_ip_parser.rb', line 33 def name @name end |
#sources ⇒ Object
Array of source attributes.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/logs_geo_ip_parser.rb', line 36 def sources @sources end |
#target ⇒ Object
Name of the parent attribute that contains all the extracted details from the sources.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/logs_geo_ip_parser.rb', line 39 def target @target end |
#type ⇒ Object
Type of GeoIP parser.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/logs_geo_ip_parser.rb', line 42 def type @type end |