Class: DatadogAPIClient::V1::LogsGrokParser

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_grok_parser.rb

Overview

Create custom grok rules to parse the full message or [a specific attribute of your raw event](docs.datadoghq.com/logs/log_configuration/parsing/#advanced-settings). For more information, see the [parsing section](docs.datadoghq.com/logs/log_configuration/parsing).

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#grokObject

Set of rules for the grok parser.



30
31
32
# File 'lib/datadog_api_client/v1/models/logs_grok_parser.rb', line 30

def grok
  @grok
end

#is_enabledObject

Whether or not the processor is enabled.



33
34
35
# File 'lib/datadog_api_client/v1/models/logs_grok_parser.rb', line 33

def is_enabled
  @is_enabled
end

#nameObject

Name of the processor.



36
37
38
# File 'lib/datadog_api_client/v1/models/logs_grok_parser.rb', line 36

def name
  @name
end

#samplesObject

List of sample logs to test this grok parser.



39
40
41
# File 'lib/datadog_api_client/v1/models/logs_grok_parser.rb', line 39

def samples
  @samples
end

#sourceObject

Name of the log attribute to parse.



42
43
44
# File 'lib/datadog_api_client/v1/models/logs_grok_parser.rb', line 42

def source
  @source
end

#typeObject

Type of logs grok parser.



45
46
47
# File 'lib/datadog_api_client/v1/models/logs_grok_parser.rb', line 45

def type
  @type
end