Class: DatadogAPIClient::V1::LogsIndexesOrder
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsIndexesOrder
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_indexes_order.rb
Overview
Object containing the ordered list of log index names.
Instance Attribute Summary collapse
-
#index_names ⇒ Object
readonly
Array of strings identifying by their name(s) the index(es) of your organization.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#index_names ⇒ Object
Array of strings identifying by their name(s) the index(es) of your organization. Logs are tested against the query filter of each index one by one, following the order of the array. Logs are eventually stored in the first matching index.
31 32 33 |
# File 'lib/datadog_api_client/v1/models/logs_indexes_order.rb', line 31 def index_names @index_names end |