Class: DatadogAPIClient::V1::LogsListResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_list_response.rb

Overview

Response object with all logs matching the request and pagination information.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#logsObject

Array of logs matching the request and the nextLogId if sent.



29
30
31
# File 'lib/datadog_api_client/v1/models/logs_list_response.rb', line 29

def logs
  @logs
end

#next_log_idObject

Hash identifier of the next log to return in the list. This parameter is used for the pagination feature.



33
34
35
# File 'lib/datadog_api_client/v1/models/logs_list_response.rb', line 33

def next_log_id
  @next_log_id
end

#statusObject

Status of the response.



36
37
38
# File 'lib/datadog_api_client/v1/models/logs_list_response.rb', line 36

def status
  @status
end