Class: DatadogAPIClient::V1::LogsLookupProcessor

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_lookup_processor.rb

Overview

Use the Lookup Processor to define a mapping between a log attribute and a human readable value saved in the processors mapping table. For example, you can use the Lookup Processor to map an internal service ID into a human readable service name. Alternatively, you could also use it to check if the MAC address that just attempted to connect to the production environment belongs to your list of stolen machines.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#default_lookupObject

Value to set the target attribute if the source value is not found in the list.



34
35
36
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 34

def default_lookup
  @default_lookup
end

#is_enabledObject

Whether or not the processor is enabled.



37
38
39
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 37

def is_enabled
  @is_enabled
end

#lookup_tableObject

Mapping table of values for the source attribute and their associated target attribute values, formatted as ‘[“source_key1,target_value1”, “source_key2,target_value2”]`



41
42
43
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 41

def lookup_table
  @lookup_table
end

#nameObject

Name of the processor.



44
45
46
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 44

def name
  @name
end

#sourceObject

Source attribute used to perform the lookup.



47
48
49
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 47

def source
  @source
end

#targetObject

Name of the attribute that contains the corresponding value in the mapping list or the default_lookup if not found in the mapping list.



51
52
53
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 51

def target
  @target
end

#typeObject

Type of logs lookup processor.



54
55
56
# File 'lib/datadog_api_client/v1/models/logs_lookup_processor.rb', line 54

def type
  @type
end