Class: DatadogAPIClient::V1::LogsPipeline

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_pipeline.rb

Overview

Pipelines and processors operate on incoming logs, parsing and transforming them into structured attributes for easier querying.

Note: These endpoints are only available for admin users. Make sure to use an application key created by an admin.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#filterObject

Filter for logs.



33
34
35
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 33

def filter
  @filter
end

#idObject

ID of the pipeline.



36
37
38
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 36

def id
  @id
end

#is_enabledObject

Whether or not the pipeline is enabled.



39
40
41
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 39

def is_enabled
  @is_enabled
end

#is_read_onlyObject

Whether or not the pipeline can be edited.



42
43
44
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 42

def is_read_only
  @is_read_only
end

#nameObject

Name of the pipeline.



45
46
47
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 45

def name
  @name
end

#processorsObject

Ordered list of processors in this pipeline.



48
49
50
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 48

def processors
  @processors
end

#typeObject

Type of pipeline.



51
52
53
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 51

def type
  @type
end