Class: DatadogAPIClient::V1::LogsPipelineProcessor

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_pipeline_processor.rb

Overview

Nested Pipelines are pipelines within a pipeline. Use Nested Pipelines to split the processing into two steps. For example, first use a high-level filtering such as team and then a second level of filtering based on the integration, service, or any other tag or attribute.

A pipeline can contain Nested Pipelines and Processors whereas a Nested Pipeline can only contain Processors.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#filterObject

Filter for logs.



33
34
35
# File 'lib/datadog_api_client/v1/models/logs_pipeline_processor.rb', line 33

def filter
  @filter
end

#is_enabledObject

Whether or not the processor is enabled.



36
37
38
# File 'lib/datadog_api_client/v1/models/logs_pipeline_processor.rb', line 36

def is_enabled
  @is_enabled
end

#nameObject

Name of the processor.



39
40
41
# File 'lib/datadog_api_client/v1/models/logs_pipeline_processor.rb', line 39

def name
  @name
end

#processorsObject

Ordered list of processors in this pipeline.



42
43
44
# File 'lib/datadog_api_client/v1/models/logs_pipeline_processor.rb', line 42

def processors
  @processors
end

#typeObject

Type of logs pipeline processor.



45
46
47
# File 'lib/datadog_api_client/v1/models/logs_pipeline_processor.rb', line 45

def type
  @type
end