Class: DatadogAPIClient::V1::LogsServiceRemapper

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_service_remapper.rb

Overview

Use this processor if you want to assign one or more attributes as the official service.

Note: If multiple service remapper processors can be applied to a given log, only the first one (according to the pipeline order) is taken into account.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#is_enabledObject

Whether or not the processor is enabled.



32
33
34
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 32

def is_enabled
  @is_enabled
end

#nameObject

Name of the processor.



35
36
37
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 35

def name
  @name
end

#sourcesObject

Array of source attributes.



38
39
40
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 38

def sources
  @sources
end

#typeObject

Type of logs service remapper.



41
42
43
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 41

def type
  @type
end