Class: DatadogAPIClient::V1::LogsTraceRemapper

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_trace_remapper.rb

Overview

There are two ways to improve correlation between application traces and logs.

1. Follow the documentation on [how to inject a trace ID in the application logs](https://docs.datadoghq.com/tracing/connect_logs_and_traces)
and by default log integrations take care of all the rest of the setup.

2. Use the Trace remapper processor to define a log attribute as its associated trace ID.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#is_enabledObject

Whether or not the processor is enabled.



34
35
36
# File 'lib/datadog_api_client/v1/models/logs_trace_remapper.rb', line 34

def is_enabled
  @is_enabled
end

#nameObject

Name of the processor.



37
38
39
# File 'lib/datadog_api_client/v1/models/logs_trace_remapper.rb', line 37

def name
  @name
end

#sourcesObject

Array of source attributes.



40
41
42
# File 'lib/datadog_api_client/v1/models/logs_trace_remapper.rb', line 40

def sources
  @sources
end

#typeObject

Type of logs trace remapper.



43
44
45
# File 'lib/datadog_api_client/v1/models/logs_trace_remapper.rb', line 43

def type
  @type
end