Class: DatadogAPIClient::V1::LogsURLParser

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_url_parser.rb

Overview

This processor extracts query parameters and other important parameters from a URL.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#is_enabledObject

Whether or not the processor is enabled.



29
30
31
# File 'lib/datadog_api_client/v1/models/logs_url_parser.rb', line 29

def is_enabled
  @is_enabled
end

#nameObject

Name of the processor.



32
33
34
# File 'lib/datadog_api_client/v1/models/logs_url_parser.rb', line 32

def name
  @name
end

#normalize_ending_slashesObject

Normalize the ending slashes or not.



35
36
37
# File 'lib/datadog_api_client/v1/models/logs_url_parser.rb', line 35

def normalize_ending_slashes
  @normalize_ending_slashes
end

#sourcesObject

Array of source attributes.



38
39
40
# File 'lib/datadog_api_client/v1/models/logs_url_parser.rb', line 38

def sources
  @sources
end

#targetObject

Name of the parent attribute that contains all the extracted details from the sources.



41
42
43
# File 'lib/datadog_api_client/v1/models/logs_url_parser.rb', line 41

def target
  @target
end

#typeObject

Type of logs URL parser.



44
45
46
# File 'lib/datadog_api_client/v1/models/logs_url_parser.rb', line 44

def type
  @type
end