Class: DatadogAPIClient::V1::LogsUserAgentParser

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/logs_user_agent_parser.rb

Overview

The User-Agent parser takes a User-Agent attribute and extracts the OS, browser, device, and other user data. It recognizes major bots like the Google Bot, Yahoo Slurp, and Bing.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#is_enabledObject

Whether or not the processor is enabled.



30
31
32
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 30

def is_enabled
  @is_enabled
end

#is_encodedObject

Define if the source attribute is URL encoded or not.



33
34
35
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 33

def is_encoded
  @is_encoded
end

#nameObject

Name of the processor.



36
37
38
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 36

def name
  @name
end

#sourcesObject

Array of source attributes.



39
40
41
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 39

def sources
  @sources
end

#targetObject

Name of the parent attribute that contains all the extracted details from the sources.



42
43
44
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 42

def target
  @target
end

#typeObject

Type of logs User-Agent parser.



45
46
47
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 45

def type
  @type
end