Class: DatadogAPIClient::V1::MetricsQueryMetadata
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MetricsQueryMetadata
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/metrics_query_metadata.rb
Overview
Object containing all metric names returned and their associated metadata.
Instance Attribute Summary collapse
-
#_end ⇒ Object
End of the time window, milliseconds since Unix epoch.
-
#aggr ⇒ Object
Aggregation type.
-
#display_name ⇒ Object
Display name of the metric.
-
#expression ⇒ Object
Metric expression.
-
#interval ⇒ Object
Number of seconds between data samples.
-
#length ⇒ Object
Number of data samples.
-
#metric ⇒ Object
Metric name.
-
#pointlist ⇒ Object
List of points of the time series.
-
#query_index ⇒ Object
The index of the series’ query within the request.
-
#scope ⇒ Object
Metric scope, comma separated list of tags.
-
#start ⇒ Object
Start of the time window, milliseconds since Unix epoch.
-
#tag_set ⇒ Object
Unique tags identifying this series.
-
#unit ⇒ Object
readonly
Detailed information about the metric unit.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#_end ⇒ Object
End of the time window, milliseconds since Unix epoch.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 35 def _end @_end end |
#aggr ⇒ Object
Aggregation type.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 29 def aggr @aggr end |
#display_name ⇒ Object
Display name of the metric.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 32 def display_name @display_name end |
#expression ⇒ Object
Metric expression.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 38 def expression @expression end |
#interval ⇒ Object
Number of seconds between data samples.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 41 def interval @interval end |
#length ⇒ Object
Number of data samples.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 44 def length @length end |
#metric ⇒ Object
Metric name.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 47 def metric @metric end |
#pointlist ⇒ Object
List of points of the time series.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 50 def pointlist @pointlist end |
#query_index ⇒ Object
The index of the series’ query within the request.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 53 def query_index @query_index end |
#scope ⇒ Object
Metric scope, comma separated list of tags.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 56 def scope @scope end |
#start ⇒ Object
Start of the time window, milliseconds since Unix epoch.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 59 def start @start end |
#tag_set ⇒ Object
Unique tags identifying this series.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 62 def tag_set @tag_set end |
#unit ⇒ Object
Detailed information about the metric unit. The first element describes the “primary unit” (for example, bytes in ‘bytes per second`). The second element describes the “per unit” (for example, second in `bytes per second`). If the second element is not present, the API returns null.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/metrics_query_metadata.rb', line 68 def unit @unit end |