Class: DatadogAPIClient::V1::MetricsQueryResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MetricsQueryResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/metrics_query_response.rb
Overview
Response Object that includes your query and the list of metrics retrieved.
Instance Attribute Summary collapse
-
#error ⇒ Object
Message indicating the errors if status is not
ok. -
#from_date ⇒ Object
Start of requested time window, milliseconds since Unix epoch.
-
#group_by ⇒ Object
List of tag keys on which to group.
-
#message ⇒ Object
Message indicating
successif status isok. -
#query ⇒ Object
Query string.
-
#res_type ⇒ Object
Type of response.
-
#series ⇒ Object
List of timeseries queried.
-
#status ⇒ Object
Status of the query.
-
#to_date ⇒ Object
End of requested time window, milliseconds since Unix epoch.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#error ⇒ Object
Message indicating the errors if status is not ok.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 29 def error @error end |
#from_date ⇒ Object
Start of requested time window, milliseconds since Unix epoch.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 32 def from_date @from_date end |
#group_by ⇒ Object
List of tag keys on which to group.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 35 def group_by @group_by end |
#message ⇒ Object
Message indicating success if status is ok.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 38 def @message end |
#query ⇒ Object
Query string
41 42 43 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 41 def query @query end |
#res_type ⇒ Object
Type of response.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 44 def res_type @res_type end |
#series ⇒ Object
List of timeseries queried.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 47 def series @series end |
#status ⇒ Object
Status of the query.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 50 def status @status end |
#to_date ⇒ Object
End of requested time window, milliseconds since Unix epoch.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/metrics_query_response.rb', line 53 def to_date @to_date end |