Class: DatadogAPIClient::V1::MetricsQueryUnit

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/metrics_query_unit.rb

Overview

Object containing the metric unit family, scale factor, name, and short name.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#familyObject

Unit family, allows for conversion between units of the same family, for scaling.



29
30
31
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 29

def family
  @family
end

#nameObject

Unit name



32
33
34
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 32

def name
  @name
end

#pluralObject

Plural form of the unit name.



35
36
37
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 35

def plural
  @plural
end

#scale_factorObject

Factor for scaling between units of the same family.



38
39
40
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 38

def scale_factor
  @scale_factor
end

#short_nameObject

Abbreviation of the unit.



41
42
43
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 41

def short_name
  @short_name
end