Class: DatadogAPIClient::V1::Monitor
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::Monitor
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/monitor.rb
Overview
Object describing a monitor.
Instance Attribute Summary collapse
-
#created ⇒ Object
Timestamp of the monitor creation.
-
#creator ⇒ Object
Object describing the creator of the shared element.
-
#deleted ⇒ Object
Whether or not the monitor is deleted.
-
#id ⇒ Object
ID of this monitor.
-
#message ⇒ Object
A message to include with notifications for this monitor.
-
#modified ⇒ Object
Last timestamp when the monitor was edited.
-
#multi ⇒ Object
Whether or not the monitor is broken down on different groups.
-
#name ⇒ Object
The monitor name.
-
#options ⇒ Object
List of options associated with your monitor.
-
#overall_state ⇒ Object
The different states your monitor can be in.
-
#priority ⇒ Object
readonly
Integer from 1 (high) to 5 (low) indicating alert severity.
-
#query ⇒ Object
readonly
The monitor query.
-
#restricted_roles ⇒ Object
A list of unique role identifiers to define which roles are allowed to edit the monitor.
-
#state ⇒ Object
Wrapper object with the different monitor states.
-
#tags ⇒ Object
Tags associated to your monitor.
-
#type ⇒ Object
readonly
The type of the monitor.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#created ⇒ Object
Timestamp of the monitor creation.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 29 def created @created end |
#creator ⇒ Object
Object describing the creator of the shared element.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 32 def creator @creator end |
#deleted ⇒ Object
Whether or not the monitor is deleted. (Always null)
35 36 37 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 35 def deleted @deleted end |
#id ⇒ Object
ID of this monitor.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 38 def id @id end |
#message ⇒ Object
A message to include with notifications for this monitor.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 41 def end |
#modified ⇒ Object
Last timestamp when the monitor was edited.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 44 def modified @modified end |
#multi ⇒ Object
Whether or not the monitor is broken down on different groups.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 47 def multi @multi end |
#name ⇒ Object
The monitor name.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 50 def name @name end |
#options ⇒ Object
List of options associated with your monitor.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 53 def end |
#overall_state ⇒ Object
The different states your monitor can be in.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 56 def overall_state @overall_state end |
#priority ⇒ Object
Integer from 1 (high) to 5 (low) indicating alert severity.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 59 def priority @priority end |
#query ⇒ Object
The monitor query.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 62 def query @query end |
#restricted_roles ⇒ Object
A list of unique role identifiers to define which roles are allowed to edit the monitor. The unique identifiers for all roles can be pulled from the [Roles API](docs.datadoghq.com/api/latest/roles/#list-roles) and are located in the data.id field. Editing a monitor includes any updates to the monitor configuration, monitor deletion, and muting of the monitor for any amount of time. restricted_roles is the successor of locked. For more information about locked and restricted_roles, see the [monitor options docs](docs.datadoghq.com/monitors/guide/monitor_api_options/#permissions-options).
65 66 67 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 65 def restricted_roles @restricted_roles end |
#state ⇒ Object
Wrapper object with the different monitor states.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 68 def state @state end |
#tags ⇒ Object
Tags associated to your monitor.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 71 def end |
#type ⇒ Object
The type of the monitor. For more information about type, see the [monitor options](docs.datadoghq.com/monitors/guide/monitor_api_options/) docs.
74 75 76 |
# File 'lib/datadog_api_client/v1/models/monitor.rb', line 74 def type @type end |