Class: DatadogAPIClient::V1::MonitorOptionsSchedulingOptionsEvaluationWindow
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MonitorOptionsSchedulingOptionsEvaluationWindow
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/monitor_options_scheduling_options_evaluation_window.rb
Overview
Configuration options for the evaluation window. If hour_starts is set, no other fields may be set. Otherwise, day_starts and month_starts must be set together.
Instance Attribute Summary collapse
-
#day_starts ⇒ Object
The time of the day at which a one day cumulative evaluation window starts.
-
#hour_starts ⇒ Object
readonly
The minute of the hour at which a one hour cumulative evaluation window starts.
-
#month_starts ⇒ Object
readonly
The day of the month at which a one month cumulative evaluation window starts.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#day_starts ⇒ Object
The time of the day at which a one day cumulative evaluation window starts. Must be defined in UTC time in HH:mm format.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/monitor_options_scheduling_options_evaluation_window.rb', line 29 def day_starts @day_starts end |
#hour_starts ⇒ Object
The minute of the hour at which a one hour cumulative evaluation window starts.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/monitor_options_scheduling_options_evaluation_window.rb', line 32 def hour_starts @hour_starts end |
#month_starts ⇒ Object
The day of the month at which a one month cumulative evaluation window starts.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/monitor_options_scheduling_options_evaluation_window.rb', line 35 def month_starts @month_starts end |