Class: DatadogAPIClient::V1::MonitorState
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MonitorState
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/monitor_state.rb
Overview
Wrapper object with the different monitor states.
Instance Attribute Summary collapse
-
#groups ⇒ Object
Dictionary where the keys are groups (comma separated lists of tags) and the values are the list of groups your monitor is broken down on.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#groups ⇒ Object
Dictionary where the keys are groups (comma separated lists of tags) and the values are the list of groups your monitor is broken down on.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/monitor_state.rb', line 30 def groups @groups end |