Class: DatadogAPIClient::V1::MonitorStateGroup
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MonitorStateGroup
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/monitor_state_group.rb
Overview
Monitor state for a single group.
Instance Attribute Summary collapse
-
#last_nodata_ts ⇒ Object
Latest timestamp the monitor was in NO_DATA state.
-
#last_notified_ts ⇒ Object
Latest timestamp of the notification sent for this monitor group.
-
#last_resolved_ts ⇒ Object
Latest timestamp the monitor group was resolved.
-
#last_triggered_ts ⇒ Object
Latest timestamp the monitor group triggered.
-
#name ⇒ Object
The name of the monitor.
-
#status ⇒ Object
The different states your monitor can be in.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#last_nodata_ts ⇒ Object
Latest timestamp the monitor was in NO_DATA state.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/monitor_state_group.rb', line 29 def last_nodata_ts @last_nodata_ts end |
#last_notified_ts ⇒ Object
Latest timestamp of the notification sent for this monitor group.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/monitor_state_group.rb', line 32 def last_notified_ts @last_notified_ts end |
#last_resolved_ts ⇒ Object
Latest timestamp the monitor group was resolved.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/monitor_state_group.rb', line 35 def last_resolved_ts @last_resolved_ts end |
#last_triggered_ts ⇒ Object
Latest timestamp the monitor group triggered.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/monitor_state_group.rb', line 38 def last_triggered_ts @last_triggered_ts end |
#name ⇒ Object
The name of the monitor.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/monitor_state_group.rb', line 41 def name @name end |
#status ⇒ Object
The different states your monitor can be in.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/monitor_state_group.rb', line 44 def status @status end |