Class: DatadogAPIClient::V1::MonitorSummaryWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb

Overview

The monitor summary widget displays a summary view of all your Datadog monitors, or a subset based on a query. Only available on FREE layout dashboards.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#color_preferenceObject

Which color to use on the widget.



29
30
31
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 29

def color_preference
  @color_preference
end

#countObject

The number of monitors to display.



32
33
34
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 32

def count
  @count
end

#display_formatObject

What to display on the widget.



35
36
37
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 35

def display_format
  @display_format
end

#hide_zero_countsObject

Whether to show counts of 0 or not.



38
39
40
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 38

def hide_zero_counts
  @hide_zero_counts
end

#queryObject

Query to filter the monitors with.



41
42
43
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 41

def query
  @query
end

#show_last_triggeredObject

Whether to show the time that has elapsed since the monitor/group triggered.



44
45
46
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 44

def show_last_triggered
  @show_last_triggered
end

#show_priorityObject

Whether to show the priorities column.



47
48
49
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 47

def show_priority
  @show_priority
end

#sortObject

Widget sorting methods.



50
51
52
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 50

def sort
  @sort
end

#startObject

The start of the list. Typically 0.



53
54
55
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 53

def start
  @start
end

#summary_typeObject

Which summary type should be used.



56
57
58
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 56

def summary_type
  @summary_type
end

#titleObject

Title of the widget.



59
60
61
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 59

def title
  @title
end

#title_alignObject

How to align the text on the widget.



62
63
64
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 62

def title_align
  @title_align
end

#title_sizeObject

Size of the title.



65
66
67
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 65

def title_size
  @title_size
end

#typeObject

Type of the monitor summary widget.



68
69
70
# File 'lib/datadog_api_client/v1/models/monitor_summary_widget_definition.rb', line 68

def type
  @type
end