Class: DatadogAPIClient::V1::NoteWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/note_widget_definition.rb

Overview

The notes and links widget is similar to free text widget, but allows for more formatting options.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#background_colorObject

Background color of the note.



29
30
31
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 29

def background_color
  @background_color
end

#contentObject

Content of the note.



32
33
34
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 32

def content
  @content
end

#font_sizeObject

Size of the text.



35
36
37
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 35

def font_size
  @font_size
end

#has_paddingObject

Whether to add padding or not.



38
39
40
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 38

def has_padding
  @has_padding
end

#show_tickObject

Whether to show a tick or not.



41
42
43
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 41

def show_tick
  @show_tick
end

#text_alignObject

How to align the text on the widget.



44
45
46
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 44

def text_align
  @text_align
end

#tick_edgeObject

Define how you want to align the text on the widget.



47
48
49
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 47

def tick_edge
  @tick_edge
end

#tick_posObject

Where to position the tick on an edge.



50
51
52
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 50

def tick_pos
  @tick_pos
end

#typeObject

Type of the note widget.



53
54
55
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 53

def type
  @type
end

#vertical_alignObject

Vertical alignment.



56
57
58
# File 'lib/datadog_api_client/v1/models/note_widget_definition.rb', line 56

def vertical_align
  @vertical_align
end