Class: DatadogAPIClient::V1::NotebookAbsoluteTime
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::NotebookAbsoluteTime
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/notebook_absolute_time.rb
Overview
Absolute timeframe.
Instance Attribute Summary collapse
-
#_end ⇒ Object
readonly
The end time.
-
#live ⇒ Object
Indicates whether the timeframe should be shifted to end at the current time.
-
#start ⇒ Object
readonly
The start time.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#_end ⇒ Object
The end time.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/notebook_absolute_time.rb', line 29 def _end @_end end |
#live ⇒ Object
Indicates whether the timeframe should be shifted to end at the current time.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/notebook_absolute_time.rb', line 32 def live @live end |
#start ⇒ Object
The start time.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/notebook_absolute_time.rb', line 35 def start @start end |