Class: DatadogAPIClient::V1::NotebookCellUpdateRequest

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/notebook_cell_update_request.rb

Overview

The description of a notebook cell update request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#attributesObject

The attributes of a notebook cell in update cell request. Valid cell types are markdown, timeseries, toplist, heatmap, distribution, log_stream. [More information on each graph visualization type.](docs.datadoghq.com/dashboards/widgets/)



30
31
32
# File 'lib/datadog_api_client/v1/models/notebook_cell_update_request.rb', line 30

def attributes
  @attributes
end

#idObject

Notebook cell ID.



33
34
35
# File 'lib/datadog_api_client/v1/models/notebook_cell_update_request.rb', line 33

def id
  @id
end

#typeObject

Type of the Notebook Cell resource.



36
37
38
# File 'lib/datadog_api_client/v1/models/notebook_cell_update_request.rb', line 36

def type
  @type
end