Class: DatadogAPIClient::V1::NotebookDistributionCellAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/notebook_distribution_cell_attributes.rb

Overview

The attributes of a notebook distribution cell.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#definitionObject

The Distribution visualization is another way of showing metrics aggregated across one or several tags, such as hosts. Unlike the heat map, a distribution graph’s x-axis is quantity rather than time.



31
32
33
# File 'lib/datadog_api_client/v1/models/notebook_distribution_cell_attributes.rb', line 31

def definition
  @definition
end

#graph_sizeObject

The size of the graph.



34
35
36
# File 'lib/datadog_api_client/v1/models/notebook_distribution_cell_attributes.rb', line 34

def graph_size
  @graph_size
end

#split_byObject

Object describing how to split the graph to display multiple visualizations per request.



37
38
39
# File 'lib/datadog_api_client/v1/models/notebook_distribution_cell_attributes.rb', line 37

def split_by
  @split_by
end

#timeObject

Timeframe for the notebook cell. When ‘null’, the notebook global time is used.



40
41
42
# File 'lib/datadog_api_client/v1/models/notebook_distribution_cell_attributes.rb', line 40

def time
  @time
end