Class: DatadogAPIClient::V1::NotebookLogStreamCellAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::NotebookLogStreamCellAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/notebook_log_stream_cell_attributes.rb
Overview
The attributes of a notebook log_stream cell.
Instance Attribute Summary collapse
-
#definition ⇒ Object
readonly
The Log Stream displays a log flow matching the defined query.
-
#graph_size ⇒ Object
The size of the graph.
-
#time ⇒ Object
Timeframe for the notebook cell.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#definition ⇒ Object
The Log Stream displays a log flow matching the defined query. Only available on FREE layout dashboards.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/notebook_log_stream_cell_attributes.rb', line 29 def definition @definition end |
#graph_size ⇒ Object
The size of the graph.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/notebook_log_stream_cell_attributes.rb', line 32 def graph_size @graph_size end |
#time ⇒ Object
Timeframe for the notebook cell. When ‘null’, the notebook global time is used.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/notebook_log_stream_cell_attributes.rb', line 35 def time @time end |