Class: DatadogAPIClient::V1::NotebookMarkdownCellAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::NotebookMarkdownCellAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/notebook_markdown_cell_attributes.rb
Overview
The attributes of a notebook markdown cell.
Instance Attribute Summary collapse
-
#definition ⇒ Object
readonly
Text in a notebook is formatted with [Markdown](daringfireball.net/projects/markdown/), which enables the use of headings, subheadings, links, images, lists, and code blocks.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#definition ⇒ Object
Text in a notebook is formatted with [Markdown](daringfireball.net/projects/markdown/), which enables the use of headings, subheadings, links, images, lists, and code blocks.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/notebook_markdown_cell_attributes.rb', line 29 def definition @definition end |