Class: DatadogAPIClient::V1::NotebookResponseDataAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb

Overview

The attributes of a notebook.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#authorObject

Attributes of user object returned by the API.



29
30
31
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 29

def author
  @author
end

#cellsObject

List of cells to display in the notebook.



32
33
34
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 32

def cells
  @cells
end

#createdObject

UTC time stamp for when the notebook was created.



35
36
37
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 35

def created
  @created
end

#metadataObject

Metadata associated with the notebook.



38
39
40
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 38

def 
  @metadata
end

#modifiedObject

UTC time stamp for when the notebook was last modified.



41
42
43
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 41

def modified
  @modified
end

#nameObject

The name of the notebook.



44
45
46
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 44

def name
  @name
end

#statusObject

Publication status of the notebook. For now, always “published”.



47
48
49
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 47

def status
  @status
end

#timeObject

Notebook global timeframe.



50
51
52
# File 'lib/datadog_api_client/v1/models/notebook_response_data_attributes.rb', line 50

def time
  @time
end