Class: DatadogAPIClient::V1::NotebooksResponseData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/notebooks_response_data.rb

Overview

The data for a notebook in get all response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#attributesObject

The attributes of a notebook in get all response.



29
30
31
# File 'lib/datadog_api_client/v1/models/notebooks_response_data.rb', line 29

def attributes
  @attributes
end

#idObject

Unique notebook ID, assigned when you create the notebook.



32
33
34
# File 'lib/datadog_api_client/v1/models/notebooks_response_data.rb', line 32

def id
  @id
end

#typeObject

Type of the Notebook resource.



35
36
37
# File 'lib/datadog_api_client/v1/models/notebooks_response_data.rb', line 35

def type
  @type
end