Class: DatadogAPIClient::V1::NotebooksResponseDataAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::NotebooksResponseDataAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb
Overview
The attributes of a notebook in get all response.
Instance Attribute Summary collapse
-
#author ⇒ Object
Attributes of user object returned by the API.
-
#cells ⇒ Object
List of cells to display in the notebook.
-
#created ⇒ Object
UTC time stamp for when the notebook was created.
-
#metadata ⇒ Object
Metadata associated with the notebook.
-
#modified ⇒ Object
UTC time stamp for when the notebook was last modified.
-
#name ⇒ Object
readonly
The name of the notebook.
-
#status ⇒ Object
Publication status of the notebook.
-
#time ⇒ Object
Notebook global timeframe.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#author ⇒ Object
Attributes of user object returned by the API.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 29 def end |
#cells ⇒ Object
List of cells to display in the notebook.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 32 def cells @cells end |
#created ⇒ Object
UTC time stamp for when the notebook was created.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 35 def created @created end |
#metadata ⇒ Object
Metadata associated with the notebook.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 38 def end |
#modified ⇒ Object
UTC time stamp for when the notebook was last modified.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 41 def modified @modified end |
#name ⇒ Object
The name of the notebook.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 44 def name @name end |
#status ⇒ Object
Publication status of the notebook. For now, always “published”.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 47 def status @status end |
#time ⇒ Object
Notebook global timeframe.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/notebooks_response_data_attributes.rb', line 50 def time @time end |