Class: DatadogAPIClient::V1::NotebooksResponsePage

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/notebooks_response_page.rb

Overview

Pagination metadata returned by the API.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#total_countObject

The total number of notebooks that would be returned if the request was not filtered by start and count parameters.



29
30
31
# File 'lib/datadog_api_client/v1/models/notebooks_response_page.rb', line 29

def total_count
  @total_count
end

#total_filtered_countObject

The total number of notebooks returned.



32
33
34
# File 'lib/datadog_api_client/v1/models/notebooks_response_page.rb', line 32

def total_filtered_count
  @total_filtered_count
end