Class: DatadogAPIClient::V1::OrganizationSettingsSamlAutocreateUsersDomains

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/organization_settings_saml_autocreate_users_domains.rb

Overview

Has two properties, enabled (boolean) and domains, which is a list of domains without the @ symbol.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#domainsObject

List of domains where the SAML automated user creation is enabled.



29
30
31
# File 'lib/datadog_api_client/v1/models/organization_settings_saml_autocreate_users_domains.rb', line 29

def domains
  @domains
end

#enabledObject

Whether or not the automated user creation based on SAML domain is enabled.



32
33
34
# File 'lib/datadog_api_client/v1/models/organization_settings_saml_autocreate_users_domains.rb', line 32

def enabled
  @enabled
end