Class: DatadogAPIClient::V1::PagerDutyService
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::PagerDutyService
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/pager_duty_service.rb
Overview
The PagerDuty service that is available for integration with Datadog.
Instance Attribute Summary collapse
-
#service_key ⇒ Object
readonly
Your service key in PagerDuty.
-
#service_name ⇒ Object
readonly
Your service name associated with a service key in PagerDuty.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#service_key ⇒ Object
Your service key in PagerDuty.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/pager_duty_service.rb', line 29 def service_key @service_key end |
#service_name ⇒ Object
Your service name associated with a service key in PagerDuty.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/pager_duty_service.rb', line 32 def service_name @service_name end |