Class: DatadogAPIClient::V1::ReferenceTableLogsLookupProcessor
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ReferenceTableLogsLookupProcessor
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb
Overview
Note: Reference Tables are in public beta. Use the Lookup Processor to define a mapping between a log attribute and a human readable value saved in a Reference Table. For example, you can use the Lookup Processor to map an internal service ID into a human readable service name. Alternatively, you could also use it to check if the MAC address that just attempted to connect to the production environment belongs to your list of stolen machines.
Instance Attribute Summary collapse
-
#is_enabled ⇒ Object
Whether or not the processor is enabled.
-
#lookup_enrichment_table ⇒ Object
readonly
Name of the Reference Table for the source attribute and their associated target attribute values.
-
#name ⇒ Object
Name of the processor.
-
#source ⇒ Object
readonly
Source attribute used to perform the lookup.
-
#target ⇒ Object
readonly
Name of the attribute that contains the corresponding value in the mapping list.
-
#type ⇒ Object
readonly
Type of logs lookup processor.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#is_enabled ⇒ Object
Whether or not the processor is enabled.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb', line 35 def is_enabled @is_enabled end |
#lookup_enrichment_table ⇒ Object
Name of the Reference Table for the source attribute and their associated target attribute values.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb', line 38 def lookup_enrichment_table @lookup_enrichment_table end |
#name ⇒ Object
Name of the processor.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb', line 41 def name @name end |
#source ⇒ Object
Source attribute used to perform the lookup.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb', line 44 def source @source end |
#target ⇒ Object
Name of the attribute that contains the corresponding value in the mapping list.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb', line 47 def target @target end |
#type ⇒ Object
Type of logs lookup processor.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/reference_table_logs_lookup_processor.rb', line 50 def type @type end |