Class: DatadogAPIClient::V1::RunWorkflowWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::RunWorkflowWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb
Overview
Run workflow is widget that allows you to run a workflow from a dashboard.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#inputs ⇒ Object
Array of workflow inputs to map to dashboard template variables.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the run workflow widget.
-
#workflow_id ⇒ Object
readonly
Workflow id.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 29 def custom_links @custom_links end |
#inputs ⇒ Object
Array of workflow inputs to map to dashboard template variables.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 32 def inputs @inputs end |
#time ⇒ Object
Time setting for the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 35 def time @time end |
#title ⇒ Object
Title of your widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 38 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 41 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 44 def title_size @title_size end |
#type ⇒ Object
Type of the run workflow widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 47 def type @type end |
#workflow_id ⇒ Object
Workflow id.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/run_workflow_widget_definition.rb', line 50 def workflow_id @workflow_id end |