Class: DatadogAPIClient::V1::SLOBulkDeleteError

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/slo_bulk_delete_error.rb

Overview

Object describing the error.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#idObject

The ID of the service level objective object associated with this error.



30
31
32
# File 'lib/datadog_api_client/v1/models/slo_bulk_delete_error.rb', line 30

def id
  @id
end

#messageObject

The error message.



33
34
35
# File 'lib/datadog_api_client/v1/models/slo_bulk_delete_error.rb', line 33

def message
  @message
end

#timeframeObject

The timeframe of the threshold associated with this error or “all” if all thresholds are affected.



37
38
39
# File 'lib/datadog_api_client/v1/models/slo_bulk_delete_error.rb', line 37

def timeframe
  @timeframe
end