Class: DatadogAPIClient::V1::SLOListResponseMetadata

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/slo_list_response_metadata.rb

Overview

The metadata object containing additional information about the list of SLOs.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#pageObject

The object containing information about the pages of the list of SLOs.



29
30
31
# File 'lib/datadog_api_client/v1/models/slo_list_response_metadata.rb', line 29

def page
  @page
end