Class: DatadogAPIClient::V1::SLOOverallStatuses
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SLOOverallStatuses
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/slo_overall_statuses.rb
Overview
Overall status of the SLO by timeframes.
Instance Attribute Summary collapse
-
#error ⇒ Object
Error message if SLO status or error budget could not be calculated.
-
#error_budget_remaining ⇒ Object
Remaining error budget of the SLO in percentage.
-
#indexed_at ⇒ Object
timestamp (UNIX time in seconds) of when the SLO status and error budget were calculated.
-
#raw_error_budget_remaining ⇒ Object
Error budget remaining for an SLO.
-
#span_precision ⇒ Object
The amount of decimal places the SLI value is accurate to.
-
#state ⇒ Object
State of the SLO.
-
#status ⇒ Object
The status of the SLO.
-
#target ⇒ Object
The target of the SLO.
-
#timeframe ⇒ Object
The SLO time window options.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#error ⇒ Object
Error message if SLO status or error budget could not be calculated.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 29 def error @error end |
#error_budget_remaining ⇒ Object
Remaining error budget of the SLO in percentage.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 32 def error_budget_remaining @error_budget_remaining end |
#indexed_at ⇒ Object
timestamp (UNIX time in seconds) of when the SLO status and error budget were calculated.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 36 def indexed_at @indexed_at end |
#raw_error_budget_remaining ⇒ Object
Error budget remaining for an SLO.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 39 def raw_error_budget_remaining @raw_error_budget_remaining end |
#span_precision ⇒ Object
The amount of decimal places the SLI value is accurate to.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 42 def span_precision @span_precision end |
#state ⇒ Object
State of the SLO.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 45 def state @state end |
#status ⇒ Object
The status of the SLO.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 48 def status @status end |
#target ⇒ Object
The target of the SLO.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 51 def target @target end |
#timeframe ⇒ Object
The SLO time window options.
54 55 56 |
# File 'lib/datadog_api_client/v1/models/slo_overall_statuses.rb', line 54 def timeframe @timeframe end |