Class: DatadogAPIClient::V1::SLOStatus
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SLOStatus
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/slo_status.rb
Overview
Status of the SLO’s primary timeframe.
Instance Attribute Summary collapse
-
#calculation_error ⇒ Object
Error message if SLO status or error budget could not be calculated.
-
#error_budget_remaining ⇒ Object
Remaining error budget of the SLO in percentage.
-
#indexed_at ⇒ Object
timestamp (UNIX time in seconds) of when the SLO status and error budget were calculated.
-
#raw_error_budget_remaining ⇒ Object
Error budget remaining for an SLO.
-
#sli ⇒ Object
The current service level indicator (SLI) of the SLO, also known as ‘status’.
-
#span_precision ⇒ Object
The number of decimal places the SLI value is accurate to.
-
#state ⇒ Object
State of the SLO.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#calculation_error ⇒ Object
Error message if SLO status or error budget could not be calculated.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 29 def calculation_error @calculation_error end |
#error_budget_remaining ⇒ Object
Remaining error budget of the SLO in percentage.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 32 def error_budget_remaining @error_budget_remaining end |
#indexed_at ⇒ Object
timestamp (UNIX time in seconds) of when the SLO status and error budget were calculated.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 36 def indexed_at @indexed_at end |
#raw_error_budget_remaining ⇒ Object
Error budget remaining for an SLO.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 39 def raw_error_budget_remaining @raw_error_budget_remaining end |
#sli ⇒ Object
The current service level indicator (SLI) of the SLO, also known as ‘status’. This is a percentage value from 0-100 (inclusive).
42 43 44 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 42 def sli @sli end |
#span_precision ⇒ Object
The number of decimal places the SLI value is accurate to.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 45 def span_precision @span_precision end |
#state ⇒ Object
State of the SLO.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/slo_status.rb', line 48 def state @state end |