Class: DatadogAPIClient::V1::SLOThreshold

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/slo_threshold.rb

Overview

SLO thresholds (target and optionally warning) for a single time window.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#targetObject

The target value for the service level indicator within the corresponding timeframe.



30
31
32
# File 'lib/datadog_api_client/v1/models/slo_threshold.rb', line 30

def target
  @target
end

#target_displayObject

A string representation of the target that indicates its precision. It uses trailing zeros to show significant decimal places (for example 98.00).

Always included in service level objective responses. Ignored in create/update requests.



37
38
39
# File 'lib/datadog_api_client/v1/models/slo_threshold.rb', line 37

def target_display
  @target_display
end

#timeframeObject

The SLO time window options.



40
41
42
# File 'lib/datadog_api_client/v1/models/slo_threshold.rb', line 40

def timeframe
  @timeframe
end

#warningObject

The warning value for the service level objective.



43
44
45
# File 'lib/datadog_api_client/v1/models/slo_threshold.rb', line 43

def warning
  @warning
end

#warning_displayObject

A string representation of the warning target (see the description of the target_display field for details).

Included in service level objective responses if a warning target exists. Ignored in create/update requests.



50
51
52
# File 'lib/datadog_api_client/v1/models/slo_threshold.rb', line 50

def warning_display
  @warning_display
end