Class: DatadogAPIClient::V1::ScatterplotTableRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ScatterplotTableRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/scatterplot_table_request.rb
Overview
Scatterplot request containing formulas and functions.
Instance Attribute Summary collapse
-
#formulas ⇒ Object
List of Scatterplot formulas that operate on queries.
-
#queries ⇒ Object
List of queries that can be returned directly or used in formulas.
-
#response_format ⇒ Object
Timeseries or Scalar response.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#formulas ⇒ Object
List of Scatterplot formulas that operate on queries.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/scatterplot_table_request.rb', line 29 def formulas @formulas end |
#queries ⇒ Object
List of queries that can be returned directly or used in formulas.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/scatterplot_table_request.rb', line 32 def queries @queries end |
#response_format ⇒ Object
Timeseries or Scalar response.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/scatterplot_table_request.rb', line 35 def response_format @response_format end |