Class: DatadogAPIClient::V1::SearchServiceLevelObjectiveData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SearchServiceLevelObjectiveData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/search_service_level_objective_data.rb
Overview
A service level objective ID and attributes.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
A service level objective object includes a service level indicator, thresholds for one or more timeframes, and metadata (
name,description, andtags). -
#id ⇒ Object
A unique identifier for the service level objective object.
-
#type ⇒ Object
The type of the object, must be
slo.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
A service level objective object includes a service level indicator, thresholds for one or more timeframes, and metadata (name, description, and tags).
30 31 32 |
# File 'lib/datadog_api_client/v1/models/search_service_level_objective_data.rb', line 30 def attributes @attributes end |
#id ⇒ Object
A unique identifier for the service level objective object.
Always included in service level objective responses.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/search_service_level_objective_data.rb', line 35 def id @id end |
#type ⇒ Object
The type of the object, must be slo.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/search_service_level_objective_data.rb', line 38 def type @type end |