Class: DatadogAPIClient::V1::ServiceLevelObjective

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/service_level_objective.rb

Overview

A service level objective object includes a service level indicator, thresholds for one or more timeframes, and metadata (name, description, tags, etc.).

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#created_atObject

Creation timestamp (UNIX time in seconds)

Always included in service level objective responses.



32
33
34
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 32

def created_at
  @created_at
end

#creatorObject

Object describing the creator of the shared element.



35
36
37
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 35

def creator
  @creator
end

#descriptionObject

A user-defined description of the service level objective.

Always included in service level objective responses (but may be null). Optional in create/update requests.



41
42
43
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 41

def description
  @description
end

#groupsObject

A list of (up to 100) monitor groups that narrow the scope of a monitor service level objective.

Included in service level objective responses if it is not empty. Optional in create/update requests for monitor service level objectives, but may only be used when then length of the monitor_ids field is one.



48
49
50
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 48

def groups
  @groups
end

#idObject

A unique identifier for the service level objective object.

Always included in service level objective responses.



53
54
55
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 53

def id
  @id
end

#modified_atObject

Modification timestamp (UNIX time in seconds)

Always included in service level objective responses.



58
59
60
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 58

def modified_at
  @modified_at
end

#monitor_idsObject

A list of monitor ids that defines the scope of a monitor service level objective. **Required if type is monitor**.



62
63
64
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 62

def monitor_ids
  @monitor_ids
end

#monitor_tagsObject

The union of monitor tags for all monitors referenced by the monitor_ids field. Always included in service level objective responses for monitor-based service level objectives (but may be empty). Ignored in create/update requests. Does not affect which monitors are included in the service level objective (that is determined entirely by the monitor_ids field).



70
71
72
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 70

def monitor_tags
  @monitor_tags
end

#nameObject

The name of the service level objective object.



73
74
75
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 73

def name
  @name
end

#queryObject

A metric-based SLO. **Required if type is metric**. Note that Datadog only allows the sum by aggregator to be used because this will sum up all request counts instead of averaging them, or taking the max or min of all of those requests.



78
79
80
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 78

def query
  @query
end

#tagsObject

A list of tags associated with this service level objective. Always included in service level objective responses (but may be empty). Optional in create/update requests.



83
84
85
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 83

def tags
  @tags
end

#target_thresholdObject

The target threshold such that when the service level indicator is above this threshold over the given timeframe, the objective is being met.



87
88
89
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 87

def target_threshold
  @target_threshold
end

#thresholdsObject

The thresholds (timeframes and associated targets) for this service level objective object.



91
92
93
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 91

def thresholds
  @thresholds
end

#timeframeObject

The SLO time window options.



94
95
96
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 94

def timeframe
  @timeframe
end

#typeObject

The type of the service level objective.



97
98
99
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 97

def type
  @type
end

#warning_thresholdObject

The optional warning threshold such that when the service level indicator is below this value for the given threshold, but above the target threshold, the objective appears in a “warning” state. This value must be greater than the target threshold.



103
104
105
# File 'lib/datadog_api_client/v1/models/service_level_objective.rb', line 103

def warning_threshold
  @warning_threshold
end