Class: DatadogAPIClient::V1::ServiceMapWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ServiceMapWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/service_map_widget_definition.rb
Overview
This widget displays a map of a service to all of the services that call it, and all of the services that it calls.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#filters ⇒ Object
readonly
Your environment and primary tag (or * if enabled for your account).
-
#service ⇒ Object
readonly
The ID of the service you want to map.
-
#title ⇒ Object
The title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the service map widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 29 def custom_links @custom_links end |
#filters ⇒ Object
Your environment and primary tag (or * if enabled for your account).
32 33 34 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 32 def filters @filters end |
#service ⇒ Object
The ID of the service you want to map.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 35 def service @service end |
#title ⇒ Object
The title of your widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 38 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 41 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 44 def title_size @title_size end |
#type ⇒ Object
Type of the service map widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/service_map_widget_definition.rb', line 47 def type @type end |