Class: DatadogAPIClient::V1::SignalStateUpdateRequest

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/signal_state_update_request.rb

Overview

Attributes describing the change of state for a given state.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#archive_commentObject

Optional comment to explain why a signal is being archived.



29
30
31
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 29

def archive_comment
  @archive_comment
end

#archive_reasonObject

Reason why a signal has been archived.



32
33
34
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 32

def archive_reason
  @archive_reason
end

#stateObject

The new triage state of the signal.



35
36
37
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 35

def state
  @state
end

#versionObject

Version of the updated signal. If server side version is higher, update will be rejected.



38
39
40
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 38

def version
  @version
end