Class: DatadogAPIClient::V1::SlackIntegrationChannel
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SlackIntegrationChannel
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/slack_integration_channel.rb
Overview
The Slack channel configuration.
Instance Attribute Summary collapse
-
#display ⇒ Object
Configuration options for what is shown in an alert event message.
-
#name ⇒ Object
Your channel name.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#display ⇒ Object
Configuration options for what is shown in an alert event message.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/slack_integration_channel.rb', line 29 def display @display end |
#name ⇒ Object
Your channel name.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/slack_integration_channel.rb', line 32 def name @name end |