Class: DatadogAPIClient::V1::SunburstWidgetLegendInlineAutomatic
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SunburstWidgetLegendInlineAutomatic
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/sunburst_widget_legend_inline_automatic.rb
Overview
Configuration of inline or automatic legends.
Instance Attribute Summary collapse
-
#hide_percent ⇒ Object
Whether to hide the percentages of the groups.
-
#hide_value ⇒ Object
Whether to hide the values of the groups.
-
#type ⇒ Object
readonly
Whether to show the legend inline or let it be automatically generated.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#hide_percent ⇒ Object
Whether to hide the percentages of the groups.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/sunburst_widget_legend_inline_automatic.rb', line 29 def hide_percent @hide_percent end |
#hide_value ⇒ Object
Whether to hide the values of the groups.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/sunburst_widget_legend_inline_automatic.rb', line 32 def hide_value @hide_value end |
#type ⇒ Object
Whether to show the legend inline or let it be automatically generated.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/sunburst_widget_legend_inline_automatic.rb', line 35 def type @type end |