Class: DatadogAPIClient::V1::SyntheticsAPIStep

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_api_step.rb

Overview

The steps used in a Synthetics multistep API test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#_retryObject

Object describing the retry strategy to apply to a Synthetic test.



48
49
50
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 48

def _retry
  @_retry
end

#allow_failureObject

Determines whether or not to continue with test if this step fails.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 29

def allow_failure
  @allow_failure
end

#assertionsObject

Array of assertions used for the test.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 32

def assertions
  @assertions
end

#extracted_valuesObject

Array of values to parse and save as variables from the response.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 35

def extracted_values
  @extracted_values
end

#is_criticalObject

Determines whether or not to consider the entire test as failed if this step fails. Can be used only if allowFailure is true.



39
40
41
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 39

def is_critical
  @is_critical
end

#nameObject

The name of the step.



42
43
44
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 42

def name
  @name
end

#requestObject

Object describing the Synthetic test request.



45
46
47
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 45

def request
  @request
end

#subtypeObject

The subtype of the Synthetic multistep API test step, currently only supporting http.



51
52
53
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 51

def subtype
  @subtype
end