Class: DatadogAPIClient::V1::SyntheticsAPITestResultData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsAPITestResultData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb
Overview
Object containing results for your Synthetic API test.
Instance Attribute Summary collapse
-
#cert ⇒ Object
Object describing the SSL certificate used for a Synthetic test.
-
#event_type ⇒ Object
Status of a Synthetic test.
-
#failure ⇒ Object
The API test failure details.
-
#http_status_code ⇒ Object
The API test HTTP status code.
-
#request_headers ⇒ Object
Request header object used for the API test.
-
#response_body ⇒ Object
Response body returned for the API test.
-
#response_headers ⇒ Object
Response headers returned for the API test.
-
#response_size ⇒ Object
Global size in byte of the API test response.
-
#timings ⇒ Object
Object containing all metrics and their values collected for a Synthetic API test.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#cert ⇒ Object
Object describing the SSL certificate used for a Synthetic test.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 29 def cert @cert end |
#event_type ⇒ Object
Status of a Synthetic test.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 32 def event_type @event_type end |
#failure ⇒ Object
The API test failure details.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 35 def failure @failure end |
#http_status_code ⇒ Object
The API test HTTP status code.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 38 def http_status_code @http_status_code end |
#request_headers ⇒ Object
Request header object used for the API test.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 41 def request_headers @request_headers end |
#response_body ⇒ Object
Response body returned for the API test.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 44 def response_body @response_body end |
#response_headers ⇒ Object
Response headers returned for the API test.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 47 def response_headers @response_headers end |
#response_size ⇒ Object
Global size in byte of the API test response.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 50 def response_size @response_size end |
#timings ⇒ Object
Object containing all metrics and their values collected for a Synthetic API test. Learn more about those metrics in [Synthetics documentation](docs.datadoghq.com/synthetics/#metrics).
54 55 56 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_data.rb', line 54 def timings @timings end |