Class: DatadogAPIClient::V1::SyntheticsApiTestResultFailure
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsApiTestResultFailure
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_api_test_result_failure.rb
Overview
The API test failure details.
Instance Attribute Summary collapse
-
#code ⇒ Object
Error code that can be returned by a Synthetic test.
-
#message ⇒ Object
The API test error message.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#code ⇒ Object
Error code that can be returned by a Synthetic test.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_failure.rb', line 29 def code @code end |
#message ⇒ Object
The API test error message.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_test_result_failure.rb', line 32 def end |