Class: DatadogAPIClient::V1::SyntheticsBasicAuthOauthClient

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb

Overview

Object to handle ‘oauth client` authentication when performing the test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#access_token_urlObject

Access token URL to use when performing the authentication.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 29

def access_token_url
  @access_token_url
end

#audienceObject

Audience to use when performing the authentication.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 32

def audience
  @audience
end

#client_idObject

Client ID to use when performing the authentication.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 35

def client_id
  @client_id
end

#client_secretObject

Client secret to use when performing the authentication.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 38

def client_secret
  @client_secret
end

#resourceObject

Resource to use when performing the authentication.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 41

def resource
  @resource
end

#scopeObject

Scope to use when performing the authentication.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 44

def scope
  @scope
end

#token_api_authenticationObject

Type of token to use when performing the authentication.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 47

def token_api_authentication
  @token_api_authentication
end

#typeObject

The type of basic authentication to use when performing the test.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_client.rb', line 50

def type
  @type
end