Class: DatadogAPIClient::V1::SyntheticsBasicAuthOauthROP
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsBasicAuthOauthROP
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb
Overview
Object to handle ‘oauth rop` authentication when performing the test.
Instance Attribute Summary collapse
-
#access_token_url ⇒ Object
readonly
Access token URL to use when performing the authentication.
-
#audience ⇒ Object
Audience to use when performing the authentication.
-
#client_id ⇒ Object
Client ID to use when performing the authentication.
-
#client_secret ⇒ Object
Client secret to use when performing the authentication.
-
#password ⇒ Object
readonly
Password to use when performing the authentication.
-
#resource ⇒ Object
Resource to use when performing the authentication.
-
#scope ⇒ Object
Scope to use when performing the authentication.
-
#token_api_authentication ⇒ Object
readonly
Type of token to use when performing the authentication.
-
#type ⇒ Object
The type of basic authentication to use when performing the test.
-
#username ⇒ Object
readonly
Username to use when performing the authentication.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#access_token_url ⇒ Object
Access token URL to use when performing the authentication.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 29 def access_token_url @access_token_url end |
#audience ⇒ Object
Audience to use when performing the authentication.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 32 def audience @audience end |
#client_id ⇒ Object
Client ID to use when performing the authentication.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 35 def client_id @client_id end |
#client_secret ⇒ Object
Client secret to use when performing the authentication.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 38 def client_secret @client_secret end |
#password ⇒ Object
Password to use when performing the authentication.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 41 def password @password end |
#resource ⇒ Object
Resource to use when performing the authentication.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 44 def resource @resource end |
#scope ⇒ Object
Scope to use when performing the authentication.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 47 def scope @scope end |
#token_api_authentication ⇒ Object
Type of token to use when performing the authentication.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 50 def token_api_authentication @token_api_authentication end |
#type ⇒ Object
The type of basic authentication to use when performing the test.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 53 def type @type end |
#username ⇒ Object
Username to use when performing the authentication.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_oauth_rop.rb', line 56 def username @username end |