Class: DatadogAPIClient::V1::SyntheticsBasicAuthWeb
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsBasicAuthWeb
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_basic_auth_web.rb
Overview
Object to handle basic authentication when performing the test.
Instance Attribute Summary collapse
-
#password ⇒ Object
readonly
Password to use for the basic authentication.
-
#type ⇒ Object
The type of basic authentication to use when performing the test.
-
#username ⇒ Object
readonly
Username to use for the basic authentication.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#password ⇒ Object
Password to use for the basic authentication.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_web.rb', line 29 def password @password end |
#type ⇒ Object
The type of basic authentication to use when performing the test.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_web.rb', line 32 def type @type end |
#username ⇒ Object
Username to use for the basic authentication.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_basic_auth_web.rb', line 35 def username @username end |