Class: DatadogAPIClient::V1::SyntheticsBatchDetailsData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_batch_details_data.rb

Overview

Wrapper object that contains the details of a batch.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#metadataObject

Metadata for the Synthetics tests run.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_batch_details_data.rb', line 29

def 
  @metadata
end

#resultsObject

List of results for the batch.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_batch_details_data.rb', line 32

def results
  @results
end

#statusObject

Determines whether or not the batch has passed, failed, or is in progress.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_batch_details_data.rb', line 35

def status
  @status
end