Class: DatadogAPIClient::V1::SyntheticsBatchResult

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_batch_result.rb

Overview

Object with the results of a Synthetics batch.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#deviceObject

The device ID.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 29

def device
  @device
end

#durationObject

Total duration in millisecond of the test.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 32

def duration
  @duration
end

#execution_ruleObject

Execution rule for a Synthetics test.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 35

def execution_rule
  @execution_rule
end

#locationObject

Name of the location.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 38

def location
  @location
end

#result_idObject

The ID of the result to get.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 41

def result_id
  @result_id
end

#retriesObject

Number of times this result has been retried.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 44

def retries
  @retries
end

#statusObject

Determines whether or not the batch has passed, failed, or is in progress.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 47

def status
  @status
end

#test_nameObject

Name of the test.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 50

def test_name
  @test_name
end

#test_public_idObject

The public ID of the Synthetic test.



53
54
55
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 53

def test_public_id
  @test_public_id
end

#test_typeObject

Type of the Synthetic test, either api or browser.



56
57
58
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 56

def test_type
  @test_type
end