Class: DatadogAPIClient::V1::SyntheticsBrowserTest

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_browser_test.rb

Overview

Object containing details about a Synthetic browser test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#configObject

Configuration object for a Synthetic browser test.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 29

def config
  @config
end

#locationsObject

Array of locations used to run the test.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 32

def locations
  @locations
end

#messageObject

Notification message associated with the test. Message can either be text or an empty string.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 35

def message
  @message
end

#monitor_idObject

The associated monitor ID.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 38

def monitor_id
  @monitor_id
end

#nameObject

Name of the test.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 41

def name
  @name
end

#optionsObject

Object describing the extra options for a Synthetic test.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 44

def options
  @options
end

#public_idObject

The public ID of the test.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 47

def public_id
  @public_id
end

#statusObject

Define whether you want to start (live) or pause (paused) a Synthetic test.



51
52
53
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 51

def status
  @status
end

#stepsObject

Array of steps for the test.



54
55
56
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 54

def steps
  @steps
end

#tagsObject

Array of tags attached to the test.



57
58
59
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 57

def tags
  @tags
end

#typeObject

Type of the Synthetic test, browser.



60
61
62
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test.rb', line 60

def type
  @type
end