Class: DatadogAPIClient::V1::SyntheticsBrowserTestConfig
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsBrowserTestConfig
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_browser_test_config.rb
Overview
Configuration object for a Synthetic browser test.
Instance Attribute Summary collapse
-
#assertions ⇒ Object
readonly
Array of assertions used for the test.
-
#config_variables ⇒ Object
Array of variables used for the test.
-
#request ⇒ Object
readonly
Object describing the Synthetic test request.
-
#set_cookie ⇒ Object
Cookies to be used for the request, using the [Set-Cookie](developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie) syntax.
-
#variables ⇒ Object
Array of variables used for the test steps.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#assertions ⇒ Object
Array of assertions used for the test.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_config.rb', line 29 def assertions @assertions end |
#config_variables ⇒ Object
Array of variables used for the test.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_config.rb', line 32 def config_variables @config_variables end |
#request ⇒ Object
Object describing the Synthetic test request.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_config.rb', line 35 def request @request end |
#set_cookie ⇒ Object
Cookies to be used for the request, using the [Set-Cookie](developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Set-Cookie) syntax.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_config.rb', line 38 def @set_cookie end |
#variables ⇒ Object
Array of variables used for the test steps.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_config.rb', line 41 def variables @variables end |