Class: DatadogAPIClient::V1::SyntheticsBrowserTestResultData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb

Overview

Object containing results for your Synthetic browser test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#browser_typeObject

Type of browser device used for the browser test.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 29

def browser_type
  @browser_type
end

#browser_versionObject

Browser version used for the browser test.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 32

def browser_version
  @browser_version
end

#deviceObject

Object describing the device used to perform the Synthetic test.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 35

def device
  @device
end

#durationObject

Global duration in second of the browser test.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 38

def duration
  @duration
end

#errorObject

Error returned for the browser test.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 41

def error
  @error
end

#failureObject

The browser test failure details.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 44

def failure
  @failure
end

#passedObject

Whether or not the browser test was conducted.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 47

def passed
  @passed
end

#received_email_countObject

The amount of email received during the browser test.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 50

def received_email_count
  @received_email_count
end

#start_urlObject

Starting URL for the browser test.



53
54
55
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 53

def start_url
  @start_url
end

#step_detailsObject

Array containing the different browser test steps.



56
57
58
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 56

def step_details
  @step_details
end

#thumbnails_bucket_keyObject

Whether or not a thumbnail is associated with the browser test.



59
60
61
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 59

def thumbnails_bucket_key
  @thumbnails_bucket_key
end

#time_to_interactiveObject

Time in second to wait before the browser test starts after reaching the start URL.



63
64
65
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_data.rb', line 63

def time_to_interactive
  @time_to_interactive
end