Class: DatadogAPIClient::V1::SyntheticsBrowserTestResultShort

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb

Overview

Object with the results of a single Synthetic browser test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#check_timeObject

Last time the browser test was performed.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 29

def check_time
  @check_time
end

#probe_dcObject

Location from which the Browser test was performed.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 32

def probe_dc
  @probe_dc
end

#resultObject

Object with the result of the last browser test run.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 35

def result
  @result
end

#result_idObject

ID of the browser test result.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 38

def result_id
  @result_id
end

#statusObject

The status of your Synthetic monitor.

  • O for not triggered

  • 1 for triggered

  • 2 for no data



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 44

def status
  @status
end