Class: DatadogAPIClient::V1::SyntheticsBrowserTestResultShortResult

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_browser_test_result_short_result.rb

Overview

Object with the result of the last browser test run.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#deviceObject

Object describing the device used to perform the Synthetic test.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short_result.rb', line 29

def device
  @device
end

#durationObject

Length in milliseconds of the browser test run.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short_result.rb', line 32

def duration
  @duration
end

#error_countObject

Amount of errors collected for a single browser test run.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short_result.rb', line 35

def error_count
  @error_count
end

#step_count_completedObject

Amount of browser test steps completed before failing.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short_result.rb', line 38

def step_count_completed
  @step_count_completed
end

#step_count_totalObject

Total amount of browser test steps.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short_result.rb', line 41

def step_count_total
  @step_count_total
end