Class: DatadogAPIClient::V1::SyntheticsConfigVariable

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_config_variable.rb

Overview

Object defining a variable that can be used in your test configuration.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#exampleObject

Example for the variable.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_config_variable.rb', line 29

def example
  @example
end

#idObject

ID of the variable for global variables.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_config_variable.rb', line 32

def id
  @id
end

#nameObject

Name of the variable.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_config_variable.rb', line 35

def name
  @name
end

#patternObject

Pattern of the variable.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_config_variable.rb', line 38

def pattern
  @pattern
end

#secureObject

Whether the value of this variable will be obfuscated in test results. Only for config variables of type text.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_config_variable.rb', line 41

def secure
  @secure
end

#typeObject

Type of the configuration variable.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_config_variable.rb', line 44

def type
  @type
end