Class: DatadogAPIClient::V1::SyntheticsDeleteTestsResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsDeleteTestsResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_delete_tests_response.rb
Overview
Response object for deleting Synthetic tests.
Instance Attribute Summary collapse
-
#deleted_tests ⇒ Object
Array of objects containing a deleted Synthetic test ID with the associated deletion timestamp.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#deleted_tests ⇒ Object
Array of objects containing a deleted Synthetic test ID with the associated deletion timestamp.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/synthetics_delete_tests_response.rb', line 30 def deleted_tests @deleted_tests end |