Class: DatadogAPIClient::V1::SyntheticsGlobalVariable

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_global_variable.rb

Overview

Synthetics global variable.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#attributesObject

Attributes of the global variable.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 29

def attributes
  @attributes
end

#descriptionObject

Description of the global variable.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 32

def description
  @description
end

#idObject

Unique identifier of the global variable.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 35

def id
  @id
end

#nameObject

Name of the global variable. Unique across Synthetics global variables.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 38

def name
  @name
end

#parse_test_optionsObject

Parser options to use for retrieving a Synthetics global variable from a Synthetics Test. Used in conjunction with parse_test_public_id.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 41

def parse_test_options
  @parse_test_options
end

#parse_test_public_idObject

A Synthetic test ID to use as a test to generate the variable value.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 44

def parse_test_public_id
  @parse_test_public_id
end

#tagsObject

Tags of the global variable.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 47

def tags
  @tags
end

#valueObject

Value of the global variable.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable.rb', line 50

def value
  @value
end