Class: DatadogAPIClient::V1::SyntheticsGlobalVariableAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsGlobalVariableAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_global_variable_attributes.rb
Overview
Attributes of the global variable.
Instance Attribute Summary collapse
-
#restricted_roles ⇒ Object
A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#restricted_roles ⇒ Object
A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_attributes.rb', line 29 def restricted_roles @restricted_roles end |