Class: DatadogAPIClient::V1::SyntheticsGlobalVariableValue

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_global_variable_value.rb

Overview

Value of the global variable.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#optionsObject

Options for the Global Variable for MFA.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_value.rb', line 29

def options
  @options
end

#secureObject

Determines if the value of the variable is hidden.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_value.rb', line 32

def secure
  @secure
end

#valueObject

Value of the global variable. When reading a global variable, the value will not be present if the variable is hidden with the secure property.



36
37
38
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_value.rb', line 36

def value
  @value
end