Class: DatadogAPIClient::V1::SyntheticsStepDetail

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_step_detail.rb

Overview

Object describing a step for a Synthetic test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#browser_errorsObject

Array of errors collected for a browser test.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 29

def browser_errors
  @browser_errors
end

#check_typeObject

Type of assertion to apply in an API test.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 32

def check_type
  @check_type
end

#descriptionObject

Description of the test.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 35

def description
  @description
end

#durationObject

Total duration in millisecond of the test.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 38

def duration
  @duration
end

#errorObject

Error returned by the test.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 41

def error
  @error
end

#playing_tabObject

Navigate between different tabs for your browser test.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 44

def playing_tab
  @playing_tab
end

#screenshot_bucket_keyObject

Whether or not screenshots where collected by the test.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 47

def screenshot_bucket_key
  @screenshot_bucket_key
end

#skippedObject

Whether or not to skip this step.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 50

def skipped
  @skipped
end

#snapshot_bucket_keyObject

Whether or not snapshots where collected by the test.



53
54
55
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 53

def snapshot_bucket_key
  @snapshot_bucket_key
end

#step_idObject

The step ID.



56
57
58
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 56

def step_id
  @step_id
end

#sub_test_step_detailsObject

If this steps include a sub-test. [Subtests documentation](docs.datadoghq.com/synthetics/browser_tests/advanced_options/#subtests).



60
61
62
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 60

def sub_test_step_details
  @sub_test_step_details
end

#time_to_interactiveObject

Time before starting the step.



63
64
65
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 63

def time_to_interactive
  @time_to_interactive
end

#typeObject

Step type used in your Synthetic test.



66
67
68
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 66

def type
  @type
end

#urlObject

URL to perform the step against.



69
70
71
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 69

def url
  @url
end

#valueObject

Value for the step.



72
73
74
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 72

def value
  @value
end

#vitals_metricsObject

Array of Core Web Vitals metrics for the step.



75
76
77
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 75

def vitals_metrics
  @vitals_metrics
end

#warningsObject

Warning collected that didn’t failed the step.



78
79
80
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 78

def warnings
  @warnings
end