Class: DatadogAPIClient::V1::SyntheticsTestDetails

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_test_details.rb

Overview

Object containing details about your Synthetic test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#configObject

Configuration object for a Synthetic test.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 29

def config
  @config
end

#creatorObject

Object describing the creator of the shared element.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 32

def creator
  @creator
end

#locationsObject

Array of locations used to run the test.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 35

def locations
  @locations
end

#messageObject

Notification message associated with the test.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 38

def message
  @message
end

#monitor_idObject

The associated monitor ID.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 41

def monitor_id
  @monitor_id
end

#nameObject

Name of the test.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 44

def name
  @name
end

#optionsObject

Object describing the extra options for a Synthetic test.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 47

def options
  @options
end

#public_idObject

The test public ID.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 50

def public_id
  @public_id
end

#statusObject

Define whether you want to start (live) or pause (paused) a Synthetic test.



54
55
56
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 54

def status
  @status
end

#stepsObject

For browser test, the steps of the test.



57
58
59
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 57

def steps
  @steps
end

#subtypeObject

The subtype of the Synthetic API test, http, ssl, tcp, dns, icmp, udp, websocket, grpc or multi.



61
62
63
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 61

def subtype
  @subtype
end

#tagsObject

Array of tags attached to the test.



64
65
66
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 64

def tags
  @tags
end

#typeObject

Type of the Synthetic test, either api or browser.



67
68
69
# File 'lib/datadog_api_client/v1/models/synthetics_test_details.rb', line 67

def type
  @type
end