Class: DatadogAPIClient::V1::SyntheticsTestOptions
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsTestOptions
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_test_options.rb
Overview
Object describing the extra options for a Synthetic test.
Instance Attribute Summary collapse
-
#_retry ⇒ Object
Object describing the retry strategy to apply to a Synthetic test.
-
#accept_self_signed ⇒ Object
For SSL tests, whether or not the test should allow self signed certificates.
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#allow_insecure ⇒ Object
Allows loading insecure content for an HTTP request in an API test.
-
#blocked_request_patterns ⇒ Object
Array of URL patterns to block.
-
#check_certificate_revocation ⇒ Object
For SSL tests, whether or not the test should fail on revoked certificate in stapled OCSP.
-
#ci ⇒ Object
CI/CD options for a Synthetic test.
-
#device_ids ⇒ Object
For browser test, array with the different device IDs used to run the test.
-
#disable_aia_intermediate_fetching ⇒ Object
For SSL tests, whether or not the test should disable fetching intermediate certificates from AIA.
-
#disable_cors ⇒ Object
Whether or not to disable CORS mechanism.
-
#disable_csp ⇒ Object
Disable Content Security Policy for browser tests.
-
#enable_profiling ⇒ Object
Enable profiling for browser tests.
-
#enable_security_testing ⇒ Object
Enable security testing for browser tests.
-
#follow_redirects ⇒ Object
For API HTTP test, whether or not the test should follow redirects.
-
#http_version ⇒ Object
HTTP version to use for a Synthetic test.
-
#ignore_server_certificate_error ⇒ Object
Ignore server certificate error for browser tests.
-
#initial_navigation_timeout ⇒ Object
Timeout before declaring the initial step as failed (in seconds) for browser tests.
-
#min_failure_duration ⇒ Object
Minimum amount of time in failure required to trigger an alert.
-
#min_location_failed ⇒ Object
Minimum number of locations in failure required to trigger an alert.
-
#monitor_name ⇒ Object
The monitor name is used for the alert title as well as for all monitor dashboard widgets and SLOs.
-
#monitor_options ⇒ Object
Object containing the options for a Synthetic test as a monitor (for example, renotification).
-
#monitor_priority ⇒ Object
readonly
Integer from 1 (high) to 5 (low) indicating alert severity.
-
#no_screenshot ⇒ Object
Prevents saving screenshots of the steps.
-
#restricted_roles ⇒ Object
A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.
-
#rum_settings ⇒ Object
The RUM data collection settings for the Synthetic browser test.
-
#scheduling ⇒ Object
Object containing timeframes and timezone used for advanced scheduling.
-
#tick_every ⇒ Object
readonly
The frequency at which to run the Synthetic test (in seconds).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#_retry ⇒ Object
Object describing the retry strategy to apply to a Synthetic test.
94 95 96 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 94 def _retry @_retry end |
#accept_self_signed ⇒ Object
For SSL tests, whether or not the test should allow self signed certificates.
26 27 28 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 26 def accept_self_signed @accept_self_signed end |
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
115 116 117 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 115 def additional_properties @additional_properties end |
#allow_insecure ⇒ Object
Allows loading insecure content for an HTTP request in an API test.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 29 def allow_insecure @allow_insecure end |
#blocked_request_patterns ⇒ Object
Array of URL patterns to block.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 32 def blocked_request_patterns @blocked_request_patterns end |
#check_certificate_revocation ⇒ Object
For SSL tests, whether or not the test should fail on revoked certificate in stapled OCSP.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 35 def check_certificate_revocation @check_certificate_revocation end |
#ci ⇒ Object
CI/CD options for a Synthetic test.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 38 def ci @ci end |
#device_ids ⇒ Object
For browser test, array with the different device IDs used to run the test.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 41 def device_ids @device_ids end |
#disable_aia_intermediate_fetching ⇒ Object
For SSL tests, whether or not the test should disable fetching intermediate certificates from AIA.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 44 def disable_aia_intermediate_fetching @disable_aia_intermediate_fetching end |
#disable_cors ⇒ Object
Whether or not to disable CORS mechanism.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 47 def disable_cors @disable_cors end |
#disable_csp ⇒ Object
Disable Content Security Policy for browser tests.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 50 def disable_csp @disable_csp end |
#enable_profiling ⇒ Object
Enable profiling for browser tests.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 53 def enable_profiling @enable_profiling end |
#enable_security_testing ⇒ Object
Enable security testing for browser tests. Security testing is not available anymore. This field is deprecated and won’t be used.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 56 def enable_security_testing @enable_security_testing end |
#follow_redirects ⇒ Object
For API HTTP test, whether or not the test should follow redirects.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 59 def follow_redirects @follow_redirects end |
#http_version ⇒ Object
HTTP version to use for a Synthetic test.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 62 def http_version @http_version end |
#ignore_server_certificate_error ⇒ Object
Ignore server certificate error for browser tests.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 65 def ignore_server_certificate_error @ignore_server_certificate_error end |
#initial_navigation_timeout ⇒ Object
Timeout before declaring the initial step as failed (in seconds) for browser tests.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 68 def end |
#min_failure_duration ⇒ Object
Minimum amount of time in failure required to trigger an alert.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 71 def min_failure_duration @min_failure_duration end |
#min_location_failed ⇒ Object
Minimum number of locations in failure required to trigger an alert.
75 76 77 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 75 def min_location_failed @min_location_failed end |
#monitor_name ⇒ Object
The monitor name is used for the alert title as well as for all monitor dashboard widgets and SLOs.
78 79 80 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 78 def monitor_name @monitor_name end |
#monitor_options ⇒ Object
Object containing the options for a Synthetic test as a monitor (for example, renotification).
82 83 84 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 82 def end |
#monitor_priority ⇒ Object
Integer from 1 (high) to 5 (low) indicating alert severity.
85 86 87 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 85 def monitor_priority @monitor_priority end |
#no_screenshot ⇒ Object
Prevents saving screenshots of the steps.
88 89 90 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 88 def no_screenshot @no_screenshot end |
#restricted_roles ⇒ Object
A list of role identifiers that can be pulled from the Roles API, for restricting read and write access. This field is deprecated. Use the restriction policies API to manage permissions.
91 92 93 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 91 def restricted_roles @restricted_roles end |
#rum_settings ⇒ Object
The RUM data collection settings for the Synthetic browser test. Note: There are 3 ways to format RUM settings:
‘{ isEnabled: false }` RUM data is not collected.
‘{ isEnabled: true }` RUM data is collected from the Synthetic test’s default application.
‘{ isEnabled: true, applicationId: “xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx”, clientTokenId: 12345 }` RUM data is collected using the specified application.
107 108 109 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 107 def rum_settings @rum_settings end |
#scheduling ⇒ Object
Object containing timeframes and timezone used for advanced scheduling.
110 111 112 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 110 def scheduling @scheduling end |
#tick_every ⇒ Object
The frequency at which to run the Synthetic test (in seconds).
113 114 115 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 113 def tick_every @tick_every end |