Class: DatadogAPIClient::V1::SyntheticsTestOptionsMonitorOptions

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_test_options_monitor_options.rb

Overview

Object containing the options for a Synthetic test as a monitor (for example, renotification).

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#renotify_intervalObject

Time interval before renotifying if the test is still failing (in minutes).



31
32
33
# File 'lib/datadog_api_client/v1/models/synthetics_test_options_monitor_options.rb', line 31

def renotify_interval
  @renotify_interval
end