Class: DatadogAPIClient::V1::SyntheticsTestRequest

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_test_request.rb

Overview

Object describing the Synthetic test request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#allow_insecureObject

Allows loading insecure content for an HTTP request in a multistep test step.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 29

def allow_insecure
  @allow_insecure
end

#basic_authObject

Object to handle basic authentication when performing the test.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 32

def basic_auth
  @basic_auth
end

#bodyObject

Body to include in the test.



35
36
37
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 35

def body
  @body
end

#body_typeObject

Type of the request body.



38
39
40
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 38

def body_type
  @body_type
end

#call_typeObject

The type of gRPC call to perform.



41
42
43
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 41

def call_type
  @call_type
end

#certificateObject

Client certificate to use when performing the test request.



44
45
46
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 44

def certificate
  @certificate
end

#certificate_domainsObject

By default, the client certificate is applied on the domain of the starting URL for browser tests. If you want your client certificate to be applied on other domains instead, add them in certificateDomains.



47
48
49
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 47

def certificate_domains
  @certificate_domains
end

#dns_serverObject

DNS server to use for DNS tests.



50
51
52
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 50

def dns_server
  @dns_server
end

#dns_server_portObject

DNS server port to use for DNS tests.



53
54
55
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 53

def dns_server_port
  @dns_server_port
end

#follow_redirectsObject

Specifies whether or not the request follows redirects.



56
57
58
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 56

def follow_redirects
  @follow_redirects
end

#headersObject

Headers to include when performing the test.



59
60
61
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 59

def headers
  @headers
end

#hostObject

Host name to perform the test with.



62
63
64
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 62

def host
  @host
end

#messageObject

Message to send for UDP or WebSocket tests.



65
66
67
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 65

def message
  @message
end

#metadataObject

Metadata to include when performing the gRPC test.



68
69
70
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 68

def 
  @metadata
end

#methodObject

Either the HTTP method/verb to use or a gRPC method available on the service set in the service field. Required if subtype is HTTP or if subtype is grpc and callType is unary.



71
72
73
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 71

def method
  @method
end

#no_saving_response_bodyObject

Determines whether or not to save the response body.



74
75
76
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 74

def no_saving_response_body
  @no_saving_response_body
end

#number_of_packetsObject

Number of pings to use per test.



77
78
79
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 77

def number_of_packets
  @number_of_packets
end

#portObject

Port to use when performing the test.



80
81
82
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 80

def port
  @port
end

#proxyObject

The proxy to perform the test.



83
84
85
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 83

def proxy
  @proxy
end

#queryObject

Query to use for the test.



86
87
88
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 86

def query
  @query
end

#servernameObject

For SSL tests, it specifies on which server you want to initiate the TLS handshake, allowing the server to present one of multiple possible certificates on the same IP address and TCP port number.



91
92
93
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 91

def servername
  @servername
end

#serviceObject

The gRPC service on which you want to perform the gRPC call.



94
95
96
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 94

def service
  @service
end

#should_track_hopsObject

Turns on a traceroute probe to discover all gateways along the path to the host destination.



97
98
99
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 97

def should_track_hops
  @should_track_hops
end

#timeoutObject

Timeout in seconds for the test.



100
101
102
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 100

def timeout
  @timeout
end

#urlObject

URL to perform the test with.



103
104
105
# File 'lib/datadog_api_client/v1/models/synthetics_test_request.rb', line 103

def url
  @url
end