Class: DatadogAPIClient::V1::SyntheticsTiming

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_timing.rb

Overview

Object containing all metrics and their values collected for a Synthetic API test. Learn more about those metrics in [Synthetics documentation](docs.datadoghq.com/synthetics/#metrics).

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#dnsObject

The duration in millisecond of the DNS lookup.



30
31
32
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 30

def dns
  @dns
end

#downloadObject

The time in millisecond to download the response.



33
34
35
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 33

def download
  @download
end

#first_byteObject

The time in millisecond to first byte.



36
37
38
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 36

def first_byte
  @first_byte
end

#handshakeObject

The duration in millisecond of the TLS handshake.



39
40
41
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 39

def handshake
  @handshake
end

#redirectObject

The time in millisecond spent during redirections.



42
43
44
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 42

def redirect
  @redirect
end

#sslObject

The duration in millisecond of the TLS handshake.



45
46
47
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 45

def ssl
  @ssl
end

#tcpObject

Time in millisecond to establish the TCP connection.



48
49
50
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 48

def tcp
  @tcp
end

#totalObject

The overall time in millisecond the request took to be processed.



51
52
53
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 51

def total
  @total
end

#waitObject

Time spent in millisecond waiting for a response.



54
55
56
# File 'lib/datadog_api_client/v1/models/synthetics_timing.rb', line 54

def wait
  @wait
end