Class: DatadogAPIClient::V1::SyntheticsVariableParser

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_variable_parser.rb

Overview

Details of the parser to use for the global variable.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#typeObject

Type of parser for a Synthetics global variable from a synthetics test.



29
30
31
# File 'lib/datadog_api_client/v1/models/synthetics_variable_parser.rb', line 29

def type
  @type
end

#valueObject

Regex or JSON path used for the parser. Not used with type raw.



32
33
34
# File 'lib/datadog_api_client/v1/models/synthetics_variable_parser.rb', line 32

def value
  @value
end