Class: DatadogAPIClient::V1::TagToHosts

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/tag_to_hosts.rb

Overview

In this object, the key is the tag, the value is a list of host names that are reporting that tag.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#tagsObject

A list of tags to apply to the host.



29
30
31
# File 'lib/datadog_api_client/v1/models/tag_to_hosts.rb', line 29

def tags
  @tags
end