Class: DatadogAPIClient::V1::TimeseriesWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::TimeseriesWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/timeseries_widget_definition.rb
Overview
The timeseries visualization allows you to display the evolution of one or more metrics, log events, or Indexed Spans over time.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#events ⇒ Object
List of widget events.
-
#legend_columns ⇒ Object
Columns displayed in the legend.
-
#legend_layout ⇒ Object
Layout of the legend.
-
#legend_size ⇒ Object
Available legend sizes for a widget.
-
#markers ⇒ Object
List of markers.
-
#requests ⇒ Object
readonly
List of timeseries widget requests.
-
#right_yaxis ⇒ Object
Axis controls for the widget.
-
#show_legend ⇒ Object
(screenboard only) Show the legend for this widget.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the timeseries widget.
-
#yaxis ⇒ Object
Axis controls for the widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 29 def custom_links @custom_links end |
#events ⇒ Object
List of widget events.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 32 def events @events end |
#legend_columns ⇒ Object
Columns displayed in the legend.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 35 def legend_columns @legend_columns end |
#legend_layout ⇒ Object
Layout of the legend.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 38 def legend_layout @legend_layout end |
#legend_size ⇒ Object
Available legend sizes for a widget. Should be one of “0”, “2”, “4”, “8”, “16”, or “auto”.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 41 def legend_size @legend_size end |
#markers ⇒ Object
List of markers.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 44 def markers @markers end |
#requests ⇒ Object
List of timeseries widget requests.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 47 def requests @requests end |
#right_yaxis ⇒ Object
Axis controls for the widget.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 50 def right_yaxis @right_yaxis end |
#show_legend ⇒ Object
(screenboard only) Show the legend for this widget.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 53 def show_legend @show_legend end |
#time ⇒ Object
Time setting for the widget.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 56 def time @time end |
#title ⇒ Object
Title of your widget.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 59 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 62 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 65 def title_size @title_size end |
#type ⇒ Object
Type of the timeseries widget.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 68 def type @type end |
#yaxis ⇒ Object
Axis controls for the widget.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/timeseries_widget_definition.rb', line 71 def yaxis @yaxis end |