Class: DatadogAPIClient::V1::ToplistWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/toplist_widget_definition.rb

Overview

The top list visualization enables you to display a list of Tag value like hostname or service with the most or least of any metric value, such as highest consumers of CPU, hosts with the least disk space, etc.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

List of custom links.



29
30
31
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 29

def custom_links
  @custom_links
end

#requestsObject

List of top list widget requests.



32
33
34
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 32

def requests
  @requests
end

#timeObject

Time setting for the widget.



35
36
37
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 35

def time
  @time
end

#titleObject

Title of your widget.



38
39
40
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 38

def title
  @title
end

#title_alignObject

How to align the text on the widget.



41
42
43
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 41

def title_align
  @title_align
end

#title_sizeObject

Size of the title.



44
45
46
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 44

def title_size
  @title_size
end

#typeObject

Type of the top list widget.



47
48
49
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 47

def type
  @type
end