Class: DatadogAPIClient::V1::TreeMapWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::TreeMapWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/tree_map_widget_definition.rb
Overview
The treemap visualization enables you to display hierarchical and nested data. It is well suited for queries that describe part-whole relationships, such as resource usage by availability zone, data center, or team.
Instance Attribute Summary collapse
-
#color_by ⇒ Object
(deprecated) The attribute formerly used to determine color in the widget.
-
#custom_links ⇒ Object
List of custom links.
-
#group_by ⇒ Object
(deprecated) The attribute formerly used to group elements in the widget.
-
#requests ⇒ Object
readonly
List of treemap widget requests.
-
#size_by ⇒ Object
(deprecated) The attribute formerly used to determine size in the widget.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of your widget.
-
#type ⇒ Object
readonly
Type of the treemap widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#color_by ⇒ Object
(deprecated) The attribute formerly used to determine color in the widget.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 29 def color_by @color_by end |
#custom_links ⇒ Object
List of custom links.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 32 def custom_links @custom_links end |
#group_by ⇒ Object
(deprecated) The attribute formerly used to group elements in the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 35 def group_by @group_by end |
#requests ⇒ Object
List of treemap widget requests.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 38 def requests @requests end |
#size_by ⇒ Object
(deprecated) The attribute formerly used to determine size in the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 41 def size_by @size_by end |
#time ⇒ Object
Time setting for the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 44 def time @time end |
#title ⇒ Object
Title of your widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 47 def title @title end |
#type ⇒ Object
Type of the treemap widget.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/tree_map_widget_definition.rb', line 50 def type @type end |