Class: DatadogAPIClient::V1::UsageAttributionBody

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_attribution_body.rb

Overview

Usage Summary by tag for a given organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#monthObject

Datetime in ISO-8601 format, UTC, precise to month: [YYYY-MM].



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 29

def month
  @month
end

#org_nameObject

The name of the organization.



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 32

def org_name
  @org_name
end

#public_idObject

The organization public ID.



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 35

def public_id
  @public_id
end

#tag_config_sourceObject

The source of the usage attribution tag configuration and the selected tags in the format ‘<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>`.



38
39
40
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 38

def tag_config_source
  @tag_config_source
end

#tagsObject

Tag keys and values.

A null value here means that the requested tag breakdown cannot be applied because it does not match the [tags configured for usage attribution](docs.datadoghq.com/account_management/billing/usage_attribution/#getting-started). In this scenario the API returns the total usage, not broken down by tags.



45
46
47
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 45

def tags
  @tags
end

#updated_atObject

Shows the the most recent hour in the current months for all organizations for which all usages were calculated.



48
49
50
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 48

def updated_at
  @updated_at
end

#valuesObject

Fields in Usage Summary by tag(s).



51
52
53
# File 'lib/datadog_api_client/v1/models/usage_attribution_body.rb', line 51

def values
  @values
end