Class: DatadogAPIClient::V1::UsageAttributionValues

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_attribution_values.rb

Overview

Fields in Usage Summary by tag(s).

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#api_percentageObject

The percentage of synthetic API test usage by tag(s).



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 29

def api_percentage
  @api_percentage
end

#api_usageObject

The synthetic API test usage by tag(s).



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 32

def api_usage
  @api_usage
end

#apm_fargate_percentageObject

The percentage of APM ECS Fargate task usage by tag(s).



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 35

def apm_fargate_percentage
  @apm_fargate_percentage
end

#apm_fargate_usageObject

The APM ECS Fargate task usage by tag(s).



38
39
40
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 38

def apm_fargate_usage
  @apm_fargate_usage
end

#apm_host_percentageObject

The percentage of APM host usage by tag(s).



41
42
43
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 41

def apm_host_percentage
  @apm_host_percentage
end

#apm_host_usageObject

The APM host usage by tag(s).



44
45
46
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 44

def apm_host_usage
  @apm_host_usage
end

#appsec_fargate_percentageObject

The percentage of Application Security Monitoring ECS Fargate task usage by tag(s).



47
48
49
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 47

def appsec_fargate_percentage
  @appsec_fargate_percentage
end

#appsec_fargate_usageObject

The Application Security Monitoring ECS Fargate task usage by tag(s).



50
51
52
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 50

def appsec_fargate_usage
  @appsec_fargate_usage
end

#appsec_percentageObject

The percentage of Application Security Monitoring host usage by tag(s).



53
54
55
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 53

def appsec_percentage
  @appsec_percentage
end

#appsec_usageObject

The Application Security Monitoring host usage by tag(s).



56
57
58
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 56

def appsec_usage
  @appsec_usage
end

#browser_percentageObject

The percentage of synthetic browser test usage by tag(s).



59
60
61
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 59

def browser_percentage
  @browser_percentage
end

#browser_usageObject

The synthetic browser test usage by tag(s).



62
63
64
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 62

def browser_usage
  @browser_usage
end

#container_percentageObject

The percentage of container usage by tag(s).



65
66
67
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 65

def container_percentage
  @container_percentage
end

#container_usageObject

The container usage by tag(s).



68
69
70
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 68

def container_usage
  @container_usage
end

#cspm_container_percentageObject

The percentage of Cloud Security Posture Management container usage by tag(s)



71
72
73
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 71

def cspm_container_percentage
  @cspm_container_percentage
end

#cspm_container_usageObject

The Cloud Security Posture Management container usage by tag(s)



74
75
76
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 74

def cspm_container_usage
  @cspm_container_usage
end

#cspm_host_percentageObject

The percentage of Cloud Security Posture Management host usage by tag(s)



77
78
79
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 77

def cspm_host_percentage
  @cspm_host_percentage
end

#cspm_host_usageObject

The Cloud Security Posture Management host usage by tag(s)



80
81
82
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 80

def cspm_host_usage
  @cspm_host_usage
end

#custom_timeseries_percentageObject

The percentage of custom metrics usage by tag(s).



83
84
85
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 83

def custom_timeseries_percentage
  @custom_timeseries_percentage
end

#custom_timeseries_usageObject

The custom metrics usage by tag(s).



86
87
88
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 86

def custom_timeseries_usage
  @custom_timeseries_usage
end

#cws_container_percentageObject

The percentage of Cloud Workload Security container usage by tag(s)



89
90
91
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 89

def cws_container_percentage
  @cws_container_percentage
end

#cws_container_usageObject

The Cloud Workload Security container usage by tag(s)



92
93
94
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 92

def cws_container_usage
  @cws_container_usage
end

#cws_host_percentageObject

The percentage of Cloud Workload Security host usage by tag(s)



95
96
97
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 95

def cws_host_percentage
  @cws_host_percentage
end

#cws_host_usageObject

The Cloud Workload Security host usage by tag(s)



98
99
100
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 98

def cws_host_usage
  @cws_host_usage
end

#dbm_hosts_percentageObject

The percentage of Database Monitoring host usage by tag(s).



101
102
103
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 101

def dbm_hosts_percentage
  @dbm_hosts_percentage
end

#dbm_hosts_usageObject

The Database Monitoring host usage by tag(s).



104
105
106
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 104

def dbm_hosts_usage
  @dbm_hosts_usage
end

#dbm_queries_percentageObject

The percentage of Database Monitoring normalized queries usage by tag(s).



107
108
109
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 107

def dbm_queries_percentage
  @dbm_queries_percentage
end

#dbm_queries_usageObject

The Database Monitoring normalized queries usage by tag(s).



110
111
112
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 110

def dbm_queries_usage
  @dbm_queries_usage
end

#estimated_indexed_logs_percentageObject

The percentage of estimated live indexed logs usage by tag(s).



113
114
115
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 113

def estimated_indexed_logs_percentage
  @estimated_indexed_logs_percentage
end

#estimated_indexed_logs_usageObject

The estimated live indexed logs usage by tag(s).



116
117
118
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 116

def estimated_indexed_logs_usage
  @estimated_indexed_logs_usage
end

#estimated_indexed_spans_percentageObject

The percentage of estimated indexed spans usage by tag(s).



119
120
121
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 119

def estimated_indexed_spans_percentage
  @estimated_indexed_spans_percentage
end

#estimated_indexed_spans_usageObject

The estimated indexed spans usage by tag(s).



122
123
124
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 122

def estimated_indexed_spans_usage
  @estimated_indexed_spans_usage
end

#estimated_ingested_logs_percentageObject

The percentage of estimated live ingested logs usage by tag(s).



125
126
127
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 125

def estimated_ingested_logs_percentage
  @estimated_ingested_logs_percentage
end

#estimated_ingested_logs_usageObject

The estimated live ingested logs usage by tag(s).



128
129
130
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 128

def estimated_ingested_logs_usage
  @estimated_ingested_logs_usage
end

#estimated_ingested_spans_percentageObject

The percentage of estimated ingested spans usage by tag(s).



131
132
133
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 131

def estimated_ingested_spans_percentage
  @estimated_ingested_spans_percentage
end

#estimated_ingested_spans_usageObject

The estimated ingested spans usage by tag(s).



134
135
136
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 134

def estimated_ingested_spans_usage
  @estimated_ingested_spans_usage
end

#estimated_rum_sessions_percentageObject

The percentage of estimated rum sessions usage by tag(s).



137
138
139
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 137

def estimated_rum_sessions_percentage
  @estimated_rum_sessions_percentage
end

#estimated_rum_sessions_usageObject

The estimated rum sessions usage by tag(s).



140
141
142
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 140

def estimated_rum_sessions_usage
  @estimated_rum_sessions_usage
end

#infra_host_percentageObject

The percentage of infrastructure host usage by tag(s).



143
144
145
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 143

def infra_host_percentage
  @infra_host_percentage
end

#infra_host_usageObject

The infrastructure host usage by tag(s).



146
147
148
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 146

def infra_host_usage
  @infra_host_usage
end

#lambda_functions_percentageObject

The percentage of Lambda function usage by tag(s).



149
150
151
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 149

def lambda_functions_percentage
  @lambda_functions_percentage
end

#lambda_functions_usageObject

The Lambda function usage by tag(s).



152
153
154
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 152

def lambda_functions_usage
  @lambda_functions_usage
end

#lambda_invocations_percentageObject

The percentage of Lambda invocation usage by tag(s).



155
156
157
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 155

def lambda_invocations_percentage
  @lambda_invocations_percentage
end

#lambda_invocations_usageObject

The Lambda invocation usage by tag(s).



158
159
160
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 158

def lambda_invocations_usage
  @lambda_invocations_usage
end

#npm_host_percentageObject

The percentage of network host usage by tag(s).



161
162
163
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 161

def npm_host_percentage
  @npm_host_percentage
end

#npm_host_usageObject

The network host usage by tag(s).



164
165
166
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 164

def npm_host_usage
  @npm_host_usage
end

#profiled_container_percentageObject

The percentage of profiled containers usage by tag(s).



167
168
169
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 167

def profiled_container_percentage
  @profiled_container_percentage
end

#profiled_container_usageObject

The profiled container usage by tag(s).



170
171
172
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 170

def profiled_container_usage
  @profiled_container_usage
end

#profiled_hosts_percentageObject

The percentage of profiled hosts usage by tag(s).



173
174
175
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 173

def profiled_hosts_percentage
  @profiled_hosts_percentage
end

#profiled_hosts_usageObject

The profiled host usage by tag(s).



176
177
178
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 176

def profiled_hosts_usage
  @profiled_hosts_usage
end

#snmp_percentageObject

The percentage of network device usage by tag(s).



179
180
181
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 179

def snmp_percentage
  @snmp_percentage
end

#snmp_usageObject

The network device usage by tag(s).



182
183
184
# File 'lib/datadog_api_client/v1/models/usage_attribution_values.rb', line 182

def snmp_usage
  @snmp_usage
end