Class: DatadogAPIClient::V1::UsageBillableSummaryBody
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageBillableSummaryBody
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_billable_summary_body.rb
Overview
Response with properties for each aggregated usage type.
Instance Attribute Summary collapse
-
#account_billable_usage ⇒ Object
The total account usage.
-
#elapsed_usage_hours ⇒ Object
Elapsed usage hours for some billable product.
-
#first_billable_usage_hour ⇒ Object
The first billable hour for the org.
-
#last_billable_usage_hour ⇒ Object
The last billable hour for the org.
-
#org_billable_usage ⇒ Object
The number of units used within the billable timeframe.
-
#percentage_in_account ⇒ Object
The percentage of account usage the org represents.
-
#usage_unit ⇒ Object
Units pertaining to the usage.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#account_billable_usage ⇒ Object
The total account usage.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 29 def account_billable_usage @account_billable_usage end |
#elapsed_usage_hours ⇒ Object
Elapsed usage hours for some billable product.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 32 def elapsed_usage_hours @elapsed_usage_hours end |
#first_billable_usage_hour ⇒ Object
The first billable hour for the org.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 35 def first_billable_usage_hour @first_billable_usage_hour end |
#last_billable_usage_hour ⇒ Object
The last billable hour for the org.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 38 def last_billable_usage_hour @last_billable_usage_hour end |
#org_billable_usage ⇒ Object
The number of units used within the billable timeframe.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 41 def org_billable_usage @org_billable_usage end |
#percentage_in_account ⇒ Object
The percentage of account usage the org represents.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 44 def percentage_in_account @percentage_in_account end |
#usage_unit ⇒ Object
Units pertaining to the usage.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_body.rb', line 47 def usage_unit @usage_unit end |