Class: DatadogAPIClient::V1::UsageBillableSummaryResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_billable_summary_response.rb

Overview

Response with monthly summary of data billed by Datadog.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#usageObject

An array of objects regarding usage of billable summary.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_billable_summary_response.rb', line 29

def usage
  @usage
end