Class: DatadogAPIClient::V1::UsageCIVisibilityHour

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb

Overview

CI visibility usage in a given hour.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#ci_pipeline_indexed_spansObject

The number of spans for pipelines in the queried hour.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 29

def ci_pipeline_indexed_spans
  @ci_pipeline_indexed_spans
end

#ci_test_indexed_spansObject

The number of spans for tests in the queried hour.



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 32

def ci_test_indexed_spans
  @ci_test_indexed_spans
end

#ci_visibility_pipeline_committersObject

Shows the total count of all active Git committers for Pipelines in the current month. A committer is active if they commit at least 3 times in a given month.



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 35

def ci_visibility_pipeline_committers
  @ci_visibility_pipeline_committers
end

#ci_visibility_test_committersObject

The total count of all active Git committers for tests in the current month. A committer is active if they commit at least 3 times in a given month.



38
39
40
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 38

def ci_visibility_test_committers
  @ci_visibility_test_committers
end

#org_nameObject

The organization name.



41
42
43
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 41

def org_name
  @org_name
end

#public_idObject

The organization public ID.



44
45
46
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 44

def public_id
  @public_id
end