Class: DatadogAPIClient::V1::UsageCWSHour

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_cws_hour.rb

Overview

Cloud Workload Security usage for a given organization for a given hour.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#cws_container_countObject

The total number of Cloud Workload Security container hours from the start of the given hour’s month until the given hour.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_cws_hour.rb', line 29

def cws_container_count
  @cws_container_count
end

#cws_host_countObject

The total number of Cloud Workload Security host hours from the start of the given hour’s month until the given hour.



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_cws_hour.rb', line 32

def cws_host_count
  @cws_host_count
end

#hourObject

The hour for the usage.



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_cws_hour.rb', line 35

def hour
  @hour
end

#org_nameObject

The organization name.



38
39
40
# File 'lib/datadog_api_client/v1/models/usage_cws_hour.rb', line 38

def org_name
  @org_name
end

#public_idObject

The organization public ID.



41
42
43
# File 'lib/datadog_api_client/v1/models/usage_cws_hour.rb', line 41

def public_id
  @public_id
end