Class: DatadogAPIClient::V1::UsageCustomReportsAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageCustomReportsAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_custom_reports_attributes.rb
Overview
The response containing attributes for custom reports.
Instance Attribute Summary collapse
-
#computed_on ⇒ Object
The date the specified custom report was computed.
-
#end_date ⇒ Object
The ending date of custom report.
-
#size ⇒ Object
size.
-
#start_date ⇒ Object
The starting date of custom report.
-
#tags ⇒ Object
A list of tags to apply to custom reports.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#computed_on ⇒ Object
The date the specified custom report was computed.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_custom_reports_attributes.rb', line 29 def computed_on @computed_on end |
#end_date ⇒ Object
The ending date of custom report.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_custom_reports_attributes.rb', line 32 def end_date @end_date end |
#size ⇒ Object
size
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_custom_reports_attributes.rb', line 35 def size @size end |
#start_date ⇒ Object
The starting date of custom report.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_custom_reports_attributes.rb', line 38 def start_date @start_date end |
#tags ⇒ Object
A list of tags to apply to custom reports.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_custom_reports_attributes.rb', line 41 def @tags end |