Class: DatadogAPIClient::V1::UsageLambdaHour

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_lambda_hour.rb

Overview

Number of lambda functions and sum of the invocations of all lambda functions for each hour for a given organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#func_countObject

Contains the number of different functions for each region and AWS account.



30
31
32
# File 'lib/datadog_api_client/v1/models/usage_lambda_hour.rb', line 30

def func_count
  @func_count
end

#hourObject

The hour for the usage.



33
34
35
# File 'lib/datadog_api_client/v1/models/usage_lambda_hour.rb', line 33

def hour
  @hour
end

#invocations_sumObject

Contains the sum of invocations of all functions.



36
37
38
# File 'lib/datadog_api_client/v1/models/usage_lambda_hour.rb', line 36

def invocations_sum
  @invocations_sum
end

#org_nameObject

The organization name.



39
40
41
# File 'lib/datadog_api_client/v1/models/usage_lambda_hour.rb', line 39

def org_name
  @org_name
end

#public_idObject

The organization public ID.



42
43
44
# File 'lib/datadog_api_client/v1/models/usage_lambda_hour.rb', line 42

def public_id
  @public_id
end