Class: DatadogAPIClient::V1::UsageLambdaResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_lambda_response.rb

Overview

Response containing the number of lambda functions and sum of the invocations of all lambda functions for each hour for a given organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#usageObject

Get hourly usage for Lambda.



30
31
32
# File 'lib/datadog_api_client/v1/models/usage_lambda_response.rb', line 30

def usage
  @usage
end