Class: DatadogAPIClient::V1::UsageLogsByIndexHour

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb

Overview

Number of indexed logs for each hour and index for a given organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#event_countObject

The total number of indexed logs for the queried hour.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 29

def event_count
  @event_count
end

#hourObject

The hour for the usage.



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 32

def hour
  @hour
end

#index_idObject

The index ID for this usage.



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 35

def index_id
  @index_id
end

#index_nameObject

The user specified name for this index ID.



38
39
40
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 38

def index_name
  @index_name
end

#org_nameObject

The organization name.



41
42
43
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 41

def org_name
  @org_name
end

#public_idObject

The organization public ID.



44
45
46
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 44

def public_id
  @public_id
end

#retentionObject

The retention period (in days) for this index ID.



47
48
49
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_hour.rb', line 47

def retention
  @retention
end