Class: DatadogAPIClient::V1::UsageLogsByIndexResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_logs_by_index_response.rb

Overview

Response containing the number of indexed logs for each hour and index for a given organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#usageObject

An array of objects regarding hourly usage of logs by index response.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_logs_by_index_response.rb', line 29

def usage
  @usage
end