Class: DatadogAPIClient::V1::UsageLogsByRetentionHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageLogsByRetentionHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb
Overview
The number of indexed logs for each hour for a given organization broken down by retention period.
Instance Attribute Summary collapse
-
#indexed_events_count ⇒ Object
Total logs indexed with this retention period during a given hour.
-
#live_indexed_events_count ⇒ Object
Live logs indexed with this retention period during a given hour.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
-
#rehydrated_indexed_events_count ⇒ Object
Rehydrated logs indexed with this retention period during a given hour.
-
#retention ⇒ Object
The retention period in days or “custom” for all custom retention usage.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#indexed_events_count ⇒ Object
Total logs indexed with this retention period during a given hour.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb', line 29 def indexed_events_count @indexed_events_count end |
#live_indexed_events_count ⇒ Object
Live logs indexed with this retention period during a given hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb', line 32 def live_indexed_events_count @live_indexed_events_count end |
#org_name ⇒ Object
The organization name.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb', line 35 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb', line 38 def public_id @public_id end |
#rehydrated_indexed_events_count ⇒ Object
Rehydrated logs indexed with this retention period during a given hour.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb', line 41 def rehydrated_indexed_events_count @rehydrated_indexed_events_count end |
#retention ⇒ Object
The retention period in days or “custom” for all custom retention usage.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_hour.rb', line 44 def retention @retention end |