Class: DatadogAPIClient::V1::UsageLogsByRetentionResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_logs_by_retention_response.rb

Overview

Response containing the indexed logs usage broken down by retention period for an organization during a given hour.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#usageObject

Get hourly usage for indexed logs by retention period.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_response.rb', line 29

def usage
  @usage
end