Class: DatadogAPIClient::V1::UsageLogsHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageLogsHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_logs_hour.rb
Overview
Hour usage for logs.
Instance Attribute Summary collapse
-
#billable_ingested_bytes ⇒ Object
Contains the number of billable log bytes ingested.
-
#hour ⇒ Object
The hour for the usage.
-
#indexed_events_count ⇒ Object
Contains the number of log events indexed.
-
#ingested_events_bytes ⇒ Object
Contains the number of log bytes ingested.
-
#logs_live_indexed_count ⇒ Object
Contains the number of live log events indexed (data available as of December 1, 2020).
-
#logs_live_ingested_bytes ⇒ Object
Contains the number of live log bytes ingested (data available as of December 1, 2020).
-
#logs_rehydrated_indexed_count ⇒ Object
Contains the number of rehydrated log events indexed (data available as of December 1, 2020).
-
#logs_rehydrated_ingested_bytes ⇒ Object
Contains the number of rehydrated log bytes ingested (data available as of December 1, 2020).
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#billable_ingested_bytes ⇒ Object
Contains the number of billable log bytes ingested.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 29 def billable_ingested_bytes @billable_ingested_bytes end |
#hour ⇒ Object
The hour for the usage.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 32 def hour @hour end |
#indexed_events_count ⇒ Object
Contains the number of log events indexed.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 35 def indexed_events_count @indexed_events_count end |
#ingested_events_bytes ⇒ Object
Contains the number of log bytes ingested.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 38 def ingested_events_bytes @ingested_events_bytes end |
#logs_live_indexed_count ⇒ Object
Contains the number of live log events indexed (data available as of December 1, 2020).
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 41 def logs_live_indexed_count @logs_live_indexed_count end |
#logs_live_ingested_bytes ⇒ Object
Contains the number of live log bytes ingested (data available as of December 1, 2020).
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 44 def logs_live_ingested_bytes @logs_live_ingested_bytes end |
#logs_rehydrated_indexed_count ⇒ Object
Contains the number of rehydrated log events indexed (data available as of December 1, 2020).
47 48 49 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 47 def logs_rehydrated_indexed_count @logs_rehydrated_indexed_count end |
#logs_rehydrated_ingested_bytes ⇒ Object
Contains the number of rehydrated log bytes ingested (data available as of December 1, 2020).
50 51 52 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 50 def logs_rehydrated_ingested_bytes @logs_rehydrated_ingested_bytes end |
#org_name ⇒ Object
The organization name.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 53 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/usage_logs_hour.rb', line 56 def public_id @public_id end |