Class: DatadogAPIClient::V1::UsageProfilingHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageProfilingHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_profiling_hour.rb
Overview
The number of profiled hosts for each hour for a given organization.
Instance Attribute Summary collapse
-
#avg_container_agent_count ⇒ Object
Get average number of container agents for that hour.
-
#host_count ⇒ Object
Contains the total number of profiled hosts reporting during a given hour.
-
#hour ⇒ Object
The hour for the usage.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#avg_container_agent_count ⇒ Object
Get average number of container agents for that hour.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_profiling_hour.rb', line 29 def avg_container_agent_count @avg_container_agent_count end |
#host_count ⇒ Object
Contains the total number of profiled hosts reporting during a given hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_profiling_hour.rb', line 32 def host_count @host_count end |
#hour ⇒ Object
The hour for the usage.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_profiling_hour.rb', line 35 def hour @hour end |
#org_name ⇒ Object
The organization name.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_profiling_hour.rb', line 38 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_profiling_hour.rb', line 41 def public_id @public_id end |