Class: DatadogAPIClient::V1::UsageSummaryResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_summary_response.rb

Overview

Response summarizing all usage aggregated across the months in the request for all organizations, and broken down by month and by organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#agent_host_top99p_sumObject

Shows the 99th percentile of all agent hosts over all hours in the current months for all organizations.



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 29

def agent_host_top99p_sum
  @agent_host_top99p_sum
end

#apm_azure_app_service_host_top99p_sumObject

Shows the 99th percentile of all Azure app services using APM over all hours in the current months all organizations.



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 32

def apm_azure_app_service_host_top99p_sum
  @apm_azure_app_service_host_top99p_sum
end

#apm_fargate_count_avg_sumObject

Shows the average of all APM ECS Fargate tasks over all hours in the current months for all organizations.



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 35

def apm_fargate_count_avg_sum
  @apm_fargate_count_avg_sum
end

#apm_host_top99p_sumObject

Shows the 99th percentile of all distinct APM hosts over all hours in the current months for all organizations.



38
39
40
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 38

def apm_host_top99p_sum
  @apm_host_top99p_sum
end

#appsec_fargate_count_avg_sumObject

Shows the average of all Application Security Monitoring ECS Fargate tasks over all hours in the current months for all organizations.



41
42
43
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 41

def appsec_fargate_count_avg_sum
  @appsec_fargate_count_avg_sum
end

#audit_logs_lines_indexed_agg_sumObject

Shows the sum of all audit logs lines indexed over all hours in the current months for all organizations.



44
45
46
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 44

def audit_logs_lines_indexed_agg_sum
  @audit_logs_lines_indexed_agg_sum
end

#avg_profiled_fargate_tasks_sumObject

Shows the average of all profiled Fargate tasks over all hours in the current months for all organizations.



47
48
49
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 47

def avg_profiled_fargate_tasks_sum
  @avg_profiled_fargate_tasks_sum
end

#aws_host_top99p_sumObject

Shows the 99th percentile of all AWS hosts over all hours in the current months for all organizations.



50
51
52
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 50

def aws_host_top99p_sum
  @aws_host_top99p_sum
end

#aws_lambda_func_countObject

Shows the average of the number of functions that executed 1 or more times each hour in the current months for all organizations.



53
54
55
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 53

def aws_lambda_func_count
  @aws_lambda_func_count
end

#aws_lambda_invocations_sumObject

Shows the sum of all AWS Lambda invocations over all hours in the current months for all organizations.



56
57
58
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 56

def aws_lambda_invocations_sum
  @aws_lambda_invocations_sum
end

#azure_app_service_top99p_sumObject

Shows the 99th percentile of all Azure app services over all hours in the current months for all organizations.



59
60
61
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 59

def azure_app_service_top99p_sum
  @azure_app_service_top99p_sum
end

#azure_host_top99p_sumObject

Shows the 99th percentile of all Azure hosts over all hours in the current months for all organizations.



62
63
64
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 62

def azure_host_top99p_sum
  @azure_host_top99p_sum
end

#billable_ingested_bytes_agg_sumObject

Shows the sum of all log bytes ingested over all hours in the current months for all organizations.



65
66
67
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 65

def billable_ingested_bytes_agg_sum
  @billable_ingested_bytes_agg_sum
end

#browser_rum_lite_session_count_agg_sumObject

Shows the sum of all browser lite sessions over all hours in the current months for all organizations.



68
69
70
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 68

def browser_rum_lite_session_count_agg_sum
  @browser_rum_lite_session_count_agg_sum
end

#browser_rum_replay_session_count_agg_sumObject

Shows the sum of all browser replay sessions over all hours in the current months for all organizations.



71
72
73
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 71

def browser_rum_replay_session_count_agg_sum
  @browser_rum_replay_session_count_agg_sum
end

#browser_rum_units_agg_sumObject

Shows the sum of all browser RUM units over all hours in the current months for all organizations.



74
75
76
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 74

def browser_rum_units_agg_sum
  @browser_rum_units_agg_sum
end

#ci_pipeline_indexed_spans_agg_sumObject

Shows the sum of all CI pipeline indexed spans over all hours in the current months for all organizations.



77
78
79
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 77

def ci_pipeline_indexed_spans_agg_sum
  @ci_pipeline_indexed_spans_agg_sum
end

#ci_test_indexed_spans_agg_sumObject

Shows the sum of all CI test indexed spans over all hours in the current months for all organizations.



80
81
82
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 80

def ci_test_indexed_spans_agg_sum
  @ci_test_indexed_spans_agg_sum
end

#ci_visibility_pipeline_committers_hwm_sumObject

Shows the high-water mark of all CI visibility pipeline committers over all hours in the current months for all organizations.



83
84
85
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 83

def ci_visibility_pipeline_committers_hwm_sum
  @ci_visibility_pipeline_committers_hwm_sum
end

#ci_visibility_test_committers_hwm_sumObject

Shows the high-water mark of all CI visibility test committers over all hours in the current months for all organizations.



86
87
88
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 86

def ci_visibility_test_committers_hwm_sum
  @ci_visibility_test_committers_hwm_sum
end

#cloud_cost_management_host_count_avg_sumObject

Sum of the host count average for Cloud Cost Management.



89
90
91
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 89

def cloud_cost_management_host_count_avg_sum
  @cloud_cost_management_host_count_avg_sum
end

#container_avg_sumObject

Shows the average of all distinct containers over all hours in the current months for all organizations.



92
93
94
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 92

def container_avg_sum
  @container_avg_sum
end

#container_excl_agent_avg_sumObject

Shows the average of the containers without the Datadog Agent over all hours in the current month for all organizations.



95
96
97
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 95

def container_excl_agent_avg_sum
  @container_excl_agent_avg_sum
end

#container_hwm_sumObject

Shows the sum of the high-water marks of all distinct containers over all hours in the current months for all organizations.



98
99
100
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 98

def container_hwm_sum
  @container_hwm_sum
end

#cspm_aas_host_top99p_sumObject

Shows the 99th percentile of all Cloud Security Posture Management Azure app services hosts over all hours in the current months for all organizations.



101
102
103
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 101

def cspm_aas_host_top99p_sum
  @cspm_aas_host_top99p_sum
end

#cspm_aws_host_top99p_sumObject

Shows the 99th percentile of all Cloud Security Posture Management AWS hosts over all hours in the current months for all organizations.



104
105
106
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 104

def cspm_aws_host_top99p_sum
  @cspm_aws_host_top99p_sum
end

#cspm_azure_host_top99p_sumObject

Shows the 99th percentile of all Cloud Security Posture Management Azure hosts over all hours in the current months for all organizations.



107
108
109
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 107

def cspm_azure_host_top99p_sum
  @cspm_azure_host_top99p_sum
end

#cspm_container_avg_sumObject

Shows the average number of Cloud Security Posture Management containers over all hours in the current months for all organizations.



110
111
112
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 110

def cspm_container_avg_sum
  @cspm_container_avg_sum
end

#cspm_container_hwm_sumObject

Shows the sum of the the high-water marks of Cloud Security Posture Management containers over all hours in the current months for all organizations.



113
114
115
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 113

def cspm_container_hwm_sum
  @cspm_container_hwm_sum
end

#cspm_gcp_host_top99p_sumObject

Shows the 99th percentile of all Cloud Security Posture Management GCP hosts over all hours in the current months for all organizations.



116
117
118
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 116

def cspm_gcp_host_top99p_sum
  @cspm_gcp_host_top99p_sum
end

#cspm_host_top99p_sumObject

Shows the 99th percentile of all Cloud Security Posture Management hosts over all hours in the current months for all organizations.



119
120
121
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 119

def cspm_host_top99p_sum
  @cspm_host_top99p_sum
end

#custom_ts_sumObject

Shows the average number of distinct custom metrics over all hours in the current months for all organizations.



122
123
124
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 122

def custom_ts_sum
  @custom_ts_sum
end

#cws_containers_avg_sumObject

Shows the average of all distinct Cloud Workload Security containers over all hours in the current months for all organizations.



125
126
127
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 125

def cws_containers_avg_sum
  @cws_containers_avg_sum
end

#cws_host_top99p_sumObject

Shows the 99th percentile of all Cloud Workload Security hosts over all hours in the current months for all organizations.



128
129
130
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 128

def cws_host_top99p_sum
  @cws_host_top99p_sum
end

#dbm_host_top99p_sumObject

Shows the 99th percentile of all Database Monitoring hosts over all hours in the current month for all organizations.



131
132
133
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 131

def dbm_host_top99p_sum
  @dbm_host_top99p_sum
end

#dbm_queries_avg_sumObject

Shows the average of all distinct Database Monitoring Normalized Queries over all hours in the current month for all organizations.



134
135
136
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 134

def dbm_queries_avg_sum
  @dbm_queries_avg_sum
end

#end_dateObject

Shows the last date of usage in the current months for all organizations.



137
138
139
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 137

def end_date
  @end_date
end

#fargate_tasks_count_avg_sumObject

Shows the average of all Fargate tasks over all hours in the current months for all organizations.



140
141
142
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 140

def fargate_tasks_count_avg_sum
  @fargate_tasks_count_avg_sum
end

#fargate_tasks_count_hwm_sumObject

Shows the sum of the high-water marks of all Fargate tasks over all hours in the current months for all organizations.



143
144
145
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 143

def fargate_tasks_count_hwm_sum
  @fargate_tasks_count_hwm_sum
end

#gcp_host_top99p_sumObject

Shows the 99th percentile of all GCP hosts over all hours in the current months for all organizations.



146
147
148
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 146

def gcp_host_top99p_sum
  @gcp_host_top99p_sum
end

#heroku_host_top99p_sumObject

Shows the 99th percentile of all Heroku dynos over all hours in the current months for all organizations.



149
150
151
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 149

def heroku_host_top99p_sum
  @heroku_host_top99p_sum
end

#incident_management_monthly_active_users_hwm_sumObject

Shows sum of the the high-water marks of incident management monthly active users in the current months for all organizations.



152
153
154
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 152

def incident_management_monthly_active_users_hwm_sum
  @incident_management_monthly_active_users_hwm_sum
end

#indexed_events_count_agg_sumObject

Shows the sum of all log events indexed over all hours in the current months for all organizations.



155
156
157
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 155

def indexed_events_count_agg_sum
  @indexed_events_count_agg_sum
end

#infra_host_top99p_sumObject

Shows the 99th percentile of all distinct infrastructure hosts over all hours in the current months for all organizations.



158
159
160
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 158

def infra_host_top99p_sum
  @infra_host_top99p_sum
end

#ingested_events_bytes_agg_sumObject

Shows the sum of all log bytes ingested over all hours in the current months for all organizations.



161
162
163
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 161

def ingested_events_bytes_agg_sum
  @ingested_events_bytes_agg_sum
end

#iot_device_agg_sumObject

Shows the sum of all IoT devices over all hours in the current months for all organizations.



164
165
166
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 164

def iot_device_agg_sum
  @iot_device_agg_sum
end

#iot_device_top99p_sumObject

Shows the 99th percentile of all IoT devices over all hours in the current months of all organizations.



167
168
169
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 167

def iot_device_top99p_sum
  @iot_device_top99p_sum
end

#last_updatedObject

Shows the the most recent hour in the current months for all organizations for which all usages were calculated.



170
171
172
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 170

def last_updated
  @last_updated
end

#live_indexed_events_agg_sumObject

Shows the sum of all live logs indexed over all hours in the current months for all organizations (data available as of December 1, 2020).



173
174
175
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 173

def live_indexed_events_agg_sum
  @live_indexed_events_agg_sum
end

#live_ingested_bytes_agg_sumObject

Shows the sum of all live logs bytes ingested over all hours in the current months for all organizations (data available as of December 1, 2020).



176
177
178
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 176

def live_ingested_bytes_agg_sum
  @live_ingested_bytes_agg_sum
end

#logs_by_retentionObject

Object containing logs usage data broken down by retention period.



179
180
181
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 179

def logs_by_retention
  @logs_by_retention
end

#mobile_rum_lite_session_count_agg_sumObject

Shows the sum of all mobile lite sessions over all hours in the current months for all organizations.



182
183
184
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 182

def mobile_rum_lite_session_count_agg_sum
  @mobile_rum_lite_session_count_agg_sum
end

#mobile_rum_session_count_agg_sumObject

Shows the sum of all mobile RUM Sessions over all hours in the current months for all organizations.



185
186
187
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 185

def mobile_rum_session_count_agg_sum
  @mobile_rum_session_count_agg_sum
end

#mobile_rum_session_count_android_agg_sumObject

Shows the sum of all mobile RUM Sessions on Android over all hours in the current months for all organizations.



188
189
190
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 188

def mobile_rum_session_count_android_agg_sum
  @mobile_rum_session_count_android_agg_sum
end

#mobile_rum_session_count_ios_agg_sumObject

Shows the sum of all mobile RUM Sessions on iOS over all hours in the current months for all organizations.



191
192
193
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 191

def mobile_rum_session_count_ios_agg_sum
  @mobile_rum_session_count_ios_agg_sum
end

#mobile_rum_session_count_reactnative_agg_sumObject

Shows the sum of all mobile RUM Sessions on React Native over all hours in the current months for all organizations.



194
195
196
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 194

def mobile_rum_session_count_reactnative_agg_sum
  @mobile_rum_session_count_reactnative_agg_sum
end

#mobile_rum_units_agg_sumObject

Shows the sum of all mobile RUM units over all hours in the current months for all organizations.



197
198
199
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 197

def mobile_rum_units_agg_sum
  @mobile_rum_units_agg_sum
end

#netflow_indexed_events_count_agg_sumObject

Shows the sum of all Network flows indexed over all hours in the current months for all organizations.



200
201
202
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 200

def netflow_indexed_events_count_agg_sum
  @netflow_indexed_events_count_agg_sum
end

#npm_host_top99p_sumObject

Shows the 99th percentile of all distinct Networks hosts over all hours in the current months for all organizations.



203
204
205
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 203

def npm_host_top99p_sum
  @npm_host_top99p_sum
end

#observability_pipelines_bytes_processed_agg_sumObject

Sum of all observability pipelines bytes processed over all hours in the current months for all organizations.



206
207
208
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 206

def observability_pipelines_bytes_processed_agg_sum
  @observability_pipelines_bytes_processed_agg_sum
end

#online_archive_events_count_agg_sumObject

Sum of all online archived events over all hours in the current months for all organizations.



209
210
211
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 209

def online_archive_events_count_agg_sum
  @online_archive_events_count_agg_sum
end

#opentelemetry_apm_host_top99p_sumObject

Shows the 99th percentile of APM hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current months for all organizations.



212
213
214
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 212

def opentelemetry_apm_host_top99p_sum
  @opentelemetry_apm_host_top99p_sum
end

#opentelemetry_host_top99p_sumObject

Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current months for all organizations.



215
216
217
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 215

def opentelemetry_host_top99p_sum
  @opentelemetry_host_top99p_sum
end

#profiling_container_agent_count_avgObject

Shows the average number of profiled containers over all hours in the current months for all organizations.



218
219
220
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 218

def profiling_container_agent_count_avg
  @profiling_container_agent_count_avg
end

#profiling_host_count_top99p_sumObject

Shows the 99th percentile of all profiled hosts over all hours in the current months for all organizations.



221
222
223
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 221

def profiling_host_count_top99p_sum
  @profiling_host_count_top99p_sum
end

#rehydrated_indexed_events_agg_sumObject

Shows the sum of all rehydrated logs indexed over all hours in the current months for all organizations (data available as of December 1, 2020).



224
225
226
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 224

def rehydrated_indexed_events_agg_sum
  @rehydrated_indexed_events_agg_sum
end

#rehydrated_ingested_bytes_agg_sumObject

Shows the sum of all rehydrated logs bytes ingested over all hours in the current months for all organizations (data available as of December 1, 2020).



227
228
229
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 227

def rehydrated_ingested_bytes_agg_sum
  @rehydrated_ingested_bytes_agg_sum
end

#rum_browser_and_mobile_session_countObject

Shows the sum of all mobile sessions and all browser lite and legacy sessions over all hours in the current month for all organizations.



230
231
232
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 230

def rum_browser_and_mobile_session_count
  @rum_browser_and_mobile_session_count
end

#rum_session_count_agg_sumObject

Shows the sum of all browser RUM Lite Sessions over all hours in the current months for all organizations.



233
234
235
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 233

def rum_session_count_agg_sum
  @rum_session_count_agg_sum
end

#rum_total_session_count_agg_sumObject

Shows the sum of RUM Sessions (browser and mobile) over all hours in the current months for all organizations.



236
237
238
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 236

def rum_total_session_count_agg_sum
  @rum_total_session_count_agg_sum
end

#rum_units_agg_sumObject

Shows the sum of all browser and mobile RUM units over all hours in the current months for all organizations.



239
240
241
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 239

def rum_units_agg_sum
  @rum_units_agg_sum
end

#sds_apm_scanned_bytes_sumObject

Sum of all APM bytes scanned with sensitive data scanner in the current months for all organizations.



242
243
244
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 242

def sds_apm_scanned_bytes_sum
  @sds_apm_scanned_bytes_sum
end

#sds_events_scanned_bytes_sumObject

Sum of all event stream events bytes scanned with sensitive data scanner in the current months for all organizations.



245
246
247
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 245

def sds_events_scanned_bytes_sum
  @sds_events_scanned_bytes_sum
end

#sds_logs_scanned_bytes_sumObject

Shows the sum of all bytes scanned of logs usage by the Sensitive Data Scanner over all hours in the current month for all organizations.



248
249
250
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 248

def sds_logs_scanned_bytes_sum
  @sds_logs_scanned_bytes_sum
end

#sds_rum_scanned_bytes_sumObject

Sum of all RUM bytes scanned with sensitive data scanner in the current months for all organizations.



251
252
253
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 251

def sds_rum_scanned_bytes_sum
  @sds_rum_scanned_bytes_sum
end

#sds_total_scanned_bytes_sumObject

Shows the sum of all bytes scanned across all usage types by the Sensitive Data Scanner over all hours in the current month for all organizations.



254
255
256
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 254

def sds_total_scanned_bytes_sum
  @sds_total_scanned_bytes_sum
end

#start_dateObject

Shows the first date of usage in the current months for all organizations.



257
258
259
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 257

def start_date
  @start_date
end

#synthetics_browser_check_calls_count_agg_sumObject

Shows the sum of all Synthetic browser tests over all hours in the current months for all organizations.



260
261
262
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 260

def synthetics_browser_check_calls_count_agg_sum
  @synthetics_browser_check_calls_count_agg_sum
end

#synthetics_check_calls_count_agg_sumObject

Shows the sum of all Synthetic API tests over all hours in the current months for all organizations.



263
264
265
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 263

def synthetics_check_calls_count_agg_sum
  @synthetics_check_calls_count_agg_sum
end

#synthetics_parallel_testing_max_slots_hwm_sumObject

Shows the sum of the high-water marks of used synthetics parallel testing slots over all hours in the current month for all organizations.



266
267
268
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 266

def synthetics_parallel_testing_max_slots_hwm_sum
  @synthetics_parallel_testing_max_slots_hwm_sum
end

#trace_search_indexed_events_count_agg_sumObject

Shows the sum of all Indexed Spans indexed over all hours in the current months for all organizations.



269
270
271
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 269

def trace_search_indexed_events_count_agg_sum
  @trace_search_indexed_events_count_agg_sum
end

#twol_ingested_events_bytes_agg_sumObject

Shows the sum of all ingested APM span bytes over all hours in the current months for all organizations.



272
273
274
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 272

def twol_ingested_events_bytes_agg_sum
  @twol_ingested_events_bytes_agg_sum
end

#usageObject

An array of objects regarding hourly usage.



275
276
277
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 275

def usage
  @usage
end

#vsphere_host_top99p_sumObject

Shows the 99th percentile of all vSphere hosts over all hours in the current months for all organizations.



278
279
280
# File 'lib/datadog_api_client/v1/models/usage_summary_response.rb', line 278

def vsphere_host_top99p_sum
  @vsphere_host_top99p_sum
end