Class: DatadogAPIClient::V1::UsageTopAvgMetricsMetadata

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/usage_top_avg_metrics_metadata.rb

Overview

The object containing document metadata.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#dayObject

The day value from the user request that contains the returned usage data. (If day was used the request)



29
30
31
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_metadata.rb', line 29

def day
  @day
end

#monthObject

The month value from the user request that contains the returned usage data. (If month was used the request)



32
33
34
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_metadata.rb', line 32

def month
  @month
end

#paginationObject

The metadata for the current pagination.



35
36
37
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_metadata.rb', line 35

def pagination
  @pagination
end