Class: DatadogAPIClient::V1::User
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::User
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/user.rb
Overview
Create, edit, and disable users.
Instance Attribute Summary collapse
-
#access_role ⇒ Object
The access role of the user.
-
#disabled ⇒ Object
The new disabled status of the user.
-
#email ⇒ Object
The new email of the user.
-
#handle ⇒ Object
The user handle, must be a valid email.
-
#icon ⇒ Object
Gravatar icon associated to the user.
-
#name ⇒ Object
The name of the user.
-
#verified ⇒ Object
Whether or not the user logged in Datadog at least once.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#access_role ⇒ Object
The access role of the user. Options are st (standard user), adm (admin user), or ro (read-only user).
29 30 31 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 29 def access_role @access_role end |
#disabled ⇒ Object
The new disabled status of the user.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 32 def disabled @disabled end |
#email ⇒ Object
The new email of the user.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 35 def email @email end |
#handle ⇒ Object
The user handle, must be a valid email.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 38 def handle @handle end |
#icon ⇒ Object
Gravatar icon associated to the user.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 41 def icon @icon end |
#name ⇒ Object
The name of the user.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 44 def name @name end |
#verified ⇒ Object
Whether or not the user logged in Datadog at least once.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/user.rb', line 47 def verified @verified end |