Class: DatadogAPIClient::V1::WebhooksIntegration

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/webhooks_integration.rb

Overview

Datadog-Webhooks integration.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#custom_headersObject

If null, uses no header. If given a JSON payload, these will be headers attached to your webhook.



30
31
32
# File 'lib/datadog_api_client/v1/models/webhooks_integration.rb', line 30

def custom_headers
  @custom_headers
end

#encode_asObject

Encoding type. Can be given either json or form.



33
34
35
# File 'lib/datadog_api_client/v1/models/webhooks_integration.rb', line 33

def encode_as
  @encode_as
end

#nameObject

The name of the webhook. It corresponds with ‘<WEBHOOK_NAME>`. Learn more on how to use it in [monitor notifications](docs.datadoghq.com/monitors/notify).



38
39
40
# File 'lib/datadog_api_client/v1/models/webhooks_integration.rb', line 38

def name
  @name
end

#payloadObject

If null, uses the default payload. If given a JSON payload, the webhook returns the payload specified by the given payload. [Webhooks variable usage](docs.datadoghq.com/integrations/webhooks/#usage).



44
45
46
# File 'lib/datadog_api_client/v1/models/webhooks_integration.rb', line 44

def payload
  @payload
end

#urlObject

URL of the webhook.



47
48
49
# File 'lib/datadog_api_client/v1/models/webhooks_integration.rb', line 47

def url
  @url
end