Class: DatadogAPIClient::V1::WebhooksIntegrationUpdateRequest

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/webhooks_integration_update_request.rb

Overview

Update request of a Webhooks integration object.

*All properties are optional.*

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#custom_headersObject

If null, uses no header. If given a JSON payload, these will be headers attached to your webhook.



32
33
34
# File 'lib/datadog_api_client/v1/models/webhooks_integration_update_request.rb', line 32

def custom_headers
  @custom_headers
end

#encode_asObject

Encoding type. Can be given either json or form.



35
36
37
# File 'lib/datadog_api_client/v1/models/webhooks_integration_update_request.rb', line 35

def encode_as
  @encode_as
end

#nameObject

The name of the webhook. It corresponds with ‘<WEBHOOK_NAME>`. Learn more on how to use it in [monitor notifications](docs.datadoghq.com/monitors/notify).



40
41
42
# File 'lib/datadog_api_client/v1/models/webhooks_integration_update_request.rb', line 40

def name
  @name
end

#payloadObject

If null, uses the default payload. If given a JSON payload, the webhook returns the payload specified by the given payload. [Webhooks variable usage](docs.datadoghq.com/integrations/webhooks/#usage).



46
47
48
# File 'lib/datadog_api_client/v1/models/webhooks_integration_update_request.rb', line 46

def payload
  @payload
end

#urlObject

URL of the webhook.



49
50
51
# File 'lib/datadog_api_client/v1/models/webhooks_integration_update_request.rb', line 49

def url
  @url
end