Class: DatadogAPIClient::V1::Widget

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/widget.rb

Overview

Information about widget.

Note: The layout property is required for widgets in dashboards with free layout_type.

For the **new dashboard layout**, the `layout` property depends on the `reflow_type` of the dashboard.
- If `reflow_type` is `fixed`, `layout` is required.
- If `reflow_type` is `auto`, `layout` should not be set.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#definitionObject

[Definition of the widget](docs.datadoghq.com/dashboards/widgets/).



34
35
36
# File 'lib/datadog_api_client/v1/models/widget.rb', line 34

def definition
  @definition
end

#idObject

ID of the widget.



37
38
39
# File 'lib/datadog_api_client/v1/models/widget.rb', line 37

def id
  @id
end

#layoutObject

The layout for a widget on a free or **new dashboard layout** dashboard.



40
41
42
# File 'lib/datadog_api_client/v1/models/widget.rb', line 40

def layout
  @layout
end