Class: DatadogAPIClient::V1::WidgetAxis
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::WidgetAxis
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/widget_axis.rb
Overview
Axis controls for the widget.
Instance Attribute Summary collapse
-
#include_zero ⇒ Object
True includes zero.
-
#label ⇒ Object
The label of the axis to display on the graph.
-
#max ⇒ Object
Specifies the maximum value to show on the y-axis.
-
#min ⇒ Object
Specifies minimum value to show on the y-axis.
-
#scale ⇒ Object
Specifies the scale type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#include_zero ⇒ Object
True includes zero.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/widget_axis.rb', line 29 def include_zero @include_zero end |
#label ⇒ Object
The label of the axis to display on the graph.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/widget_axis.rb', line 32 def label @label end |
#max ⇒ Object
Specifies the maximum value to show on the y-axis. It takes a number, or auto for default behavior.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/widget_axis.rb', line 35 def max @max end |
#min ⇒ Object
Specifies minimum value to show on the y-axis. It takes a number, or auto for default behavior.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/widget_axis.rb', line 38 def min @min end |
#scale ⇒ Object
Specifies the scale type. Possible values are linear, log, sqrt, ‘pow##` (for example pow2, pow0.5 etc.).
41 42 43 |
# File 'lib/datadog_api_client/v1/models/widget_axis.rb', line 41 def scale @scale end |