Class: DatadogAPIClient::V1::WidgetCustomLink

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/widget_custom_link.rb

Overview

Custom links help you connect a data value to a URL, like a Datadog page or your AWS console.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#is_hiddenObject

The flag for toggling context menu link visibility.



29
30
31
# File 'lib/datadog_api_client/v1/models/widget_custom_link.rb', line 29

def is_hidden
  @is_hidden
end

#labelObject

The label for the custom link URL. Keep the label short and descriptive. Use metrics and tags as variables.



32
33
34
# File 'lib/datadog_api_client/v1/models/widget_custom_link.rb', line 32

def label
  @label
end

The URL of the custom link. URL must include http or https. A relative URL must start with /.



35
36
37
# File 'lib/datadog_api_client/v1/models/widget_custom_link.rb', line 35

def link
  @link
end

#override_labelObject

The label ID that refers to a context menu link. Can be logs, hosts, traces, profiles, processes, containers, or rum.



38
39
40
# File 'lib/datadog_api_client/v1/models/widget_custom_link.rb', line 38

def override_label
  @override_label
end