Class: DatadogAPIClient::V1::WidgetFormulaStyle

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/widget_formula_style.rb

Overview

Styling options for widget formulas.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#paletteObject

The color palette used to display the formula. A guide to the available color palettes can be found at docs.datadoghq.com/dashboards/guide/widget_colors



29
30
31
# File 'lib/datadog_api_client/v1/models/widget_formula_style.rb', line 29

def palette
  @palette
end

#palette_indexObject

Index specifying which color to use within the palette.



32
33
34
# File 'lib/datadog_api_client/v1/models/widget_formula_style.rb', line 32

def palette_index
  @palette_index
end