Class: DatadogAPIClient::V1::WidgetLayout

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/widget_layout.rb

Overview

The layout for a widget on a free or **new dashboard layout** dashboard.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#heightObject

The height of the widget. Should be a non-negative integer.



29
30
31
# File 'lib/datadog_api_client/v1/models/widget_layout.rb', line 29

def height
  @height
end

#is_column_breakObject

Whether the widget should be the first one on the second column in high density or not. Note: Only for the **new dashboard layout** and only one widget in the dashboard should have this property set to true.



33
34
35
# File 'lib/datadog_api_client/v1/models/widget_layout.rb', line 33

def is_column_break
  @is_column_break
end

#widthObject

The width of the widget. Should be a non-negative integer.



36
37
38
# File 'lib/datadog_api_client/v1/models/widget_layout.rb', line 36

def width
  @width
end

#xObject

The position of the widget on the x (horizontal) axis. Should be a non-negative integer.



39
40
41
# File 'lib/datadog_api_client/v1/models/widget_layout.rb', line 39

def x
  @x
end

#yObject

The position of the widget on the y (vertical) axis. Should be a non-negative integer.



42
43
44
# File 'lib/datadog_api_client/v1/models/widget_layout.rb', line 42

def y
  @y
end