Class: DatadogAPIClient::V1::WidgetMarker

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/widget_marker.rb

Overview

Markers allow you to add visual conditional formatting for your graphs.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#display_typeObject

Combination of:

- A severity error, warning, ok, or info
- A line type: dashed, solid, or bold

In this case of a Distribution widget, this can be set to be x_axis_percentile.



33
34
35
# File 'lib/datadog_api_client/v1/models/widget_marker.rb', line 33

def display_type
  @display_type
end

#labelObject

Label to display over the marker.



36
37
38
# File 'lib/datadog_api_client/v1/models/widget_marker.rb', line 36

def label
  @label
end

#timeObject

Timestamp for the widget.



39
40
41
# File 'lib/datadog_api_client/v1/models/widget_marker.rb', line 39

def time
  @time
end

#valueObject

Value to apply. Can be a single value y = 15 or a range of values 0 < y < 10.



42
43
44
# File 'lib/datadog_api_client/v1/models/widget_marker.rb', line 42

def value
  @value
end