Class: DatadogAPIClient::V1::WidgetTime
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::WidgetTime
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/widget_time.rb
Overview
Time setting for the widget.
Instance Attribute Summary collapse
-
#live_span ⇒ Object
The available timeframes depend on the widget you are using.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#live_span ⇒ Object
The available timeframes depend on the widget you are using.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/widget_time.rb', line 29 def live_span @live_span end |