Class: DatadogAPIClient::V2::AgentTriggerWrapper

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/agent_trigger_wrapper.rb

Overview

Schema for an agent-based trigger.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



30
31
32
# File 'lib/datadog_api_client/v2/models/agent_trigger_wrapper.rb', line 30

def additional_properties
  @additional_properties
end

#agent_triggerObject

Trigger a workflow from an agent via the MCP execute tool. Workflow can be executed from Bits Chat, Bits Agent Builder, Claude Code, Codex, Cursor, and any other coding agent using the Datadog MCP.



25
26
27
# File 'lib/datadog_api_client/v2/models/agent_trigger_wrapper.rb', line 25

def agent_trigger
  @agent_trigger
end

#start_step_namesObject

Names of existing workflow steps that run first after a trigger fires.



28
29
30
# File 'lib/datadog_api_client/v2/models/agent_trigger_wrapper.rb', line 28

def start_step_names
  @start_step_names
end