Class: DatadogAPIClient::V2::AnnotationKind
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::AnnotationKind
- Includes:
- BaseEnumModel
- Defined in:
- lib/datadog_api_client/v2/models/annotation_kind.rb
Overview
Kind of annotation. ‘pointInTime` annotations mark a single moment in time, while `timeRegion` annotations span a window of time and require an `end_time`.
Constant Summary collapse
- POINT_IN_TIME =
"pointInTime".freeze
- TIME_REGION =
"timeRegion".freeze