Class: DatadogAPIClient::V2::AnonymizeUserError
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::AnonymizeUserError
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/anonymize_user_error.rb
Overview
Error encountered when anonymizing a specific user.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#error ⇒ Object
readonly
Error message describing why anonymization failed.
-
#user_id ⇒ Object
readonly
UUID of the user that failed to be anonymized.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/anonymize_user_error.rb', line 30 def additional_properties @additional_properties end |
#error ⇒ Object
Error message describing why anonymization failed.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/anonymize_user_error.rb', line 25 def error @error end |
#user_id ⇒ Object
UUID of the user that failed to be anonymized.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/anonymize_user_error.rb', line 28 def user_id @user_id end |