Class: DatadogAPIClient::V2::AnonymizeUsersResponseAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::AnonymizeUsersResponseAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/anonymize_users_response_attributes.rb
Overview
Attributes of an anonymize users response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#anonymize_errors ⇒ Object
readonly
List of errors encountered during anonymization, one entry per failed user.
-
#anonymized_user_ids ⇒ Object
readonly
List of user IDs (UUIDs) that were successfully anonymized.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/anonymize_users_response_attributes.rb', line 30 def additional_properties @additional_properties end |
#anonymize_errors ⇒ Object
List of errors encountered during anonymization, one entry per failed user.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/anonymize_users_response_attributes.rb', line 25 def anonymize_errors @anonymize_errors end |
#anonymized_user_ids ⇒ Object
List of user IDs (UUIDs) that were successfully anonymized.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/anonymize_users_response_attributes.rb', line 28 def anonymized_user_ids @anonymized_user_ids end |