Class: DatadogAPIClient::V2::ApmMetricsQuery
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ApmMetricsQuery
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/apm_metrics_query.rb
Overview
A query for APM trace metrics such as hits, errors, and latency percentiles, aggregated across services.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#data_source ⇒ Object
readonly
A data source for APM metrics queries.
-
#group_by ⇒ Object
Optional fields to group the query results by.
-
#name ⇒ Object
readonly
The variable name for use in formulas.
-
#operation_mode ⇒ Object
Optional operation mode to aggregate across operation names.
-
#operation_name ⇒ Object
Name of operation on service.
-
#peer_tags ⇒ Object
Tags to query for a specific downstream entity (peer.service, peer.db_instance, peer.s3, peer.s3.bucket, etc.).
-
#query_filter ⇒ Object
Additional filters for the query using metrics query syntax (for example, env, primary_tag).
-
#resource_hash ⇒ Object
The resource hash for exact matching.
-
#resource_name ⇒ Object
The full name of a specific resource to filter by.
-
#service ⇒ Object
The service name to filter by.
-
#span_kind ⇒ Object
Describes the relationship between the span, its parents, and its children in a trace.
-
#stat ⇒ Object
readonly
The APM metric statistic to query.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
60 61 62 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 60 def additional_properties @additional_properties end |
#data_source ⇒ Object
A data source for APM metrics queries.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 25 def data_source @data_source end |
#group_by ⇒ Object
Optional fields to group the query results by.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 28 def group_by @group_by end |
#name ⇒ Object
The variable name for use in formulas.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 31 def name @name end |
#operation_mode ⇒ Object
Optional operation mode to aggregate across operation names.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 34 def operation_mode @operation_mode end |
#operation_name ⇒ Object
Name of operation on service. If not provided, the primary operation name is used.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 37 def operation_name @operation_name end |
#peer_tags ⇒ Object
Tags to query for a specific downstream entity (peer.service, peer.db_instance, peer.s3, peer.s3.bucket, etc.).
40 41 42 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 40 def @peer_tags end |
#query_filter ⇒ Object
Additional filters for the query using metrics query syntax (for example, env, primary_tag).
43 44 45 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 43 def query_filter @query_filter end |
#resource_hash ⇒ Object
The resource hash for exact matching.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 46 def resource_hash @resource_hash end |
#resource_name ⇒ Object
The full name of a specific resource to filter by.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 49 def resource_name @resource_name end |
#service ⇒ Object
The service name to filter by.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 52 def service @service end |
#span_kind ⇒ Object
Describes the relationship between the span, its parents, and its children in a trace.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 55 def span_kind @span_kind end |
#stat ⇒ Object
The APM metric statistic to query.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/apm_metrics_query.rb', line 58 def stat @stat end |