Class: DatadogAPIClient::V2::ApmResourceStatsQuery

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/apm_resource_stats_query.rb

Overview

A query for APM resource statistics such as latency, error rate, and hit count, grouped by resource name.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



57
58
59
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 57

def additional_properties
  @additional_properties
end

#cross_org_uuidsObject

Organization UUIDs to query when using [cross-organization visibility](/account_management/org_settings/cross_org_visibility/). Limited to one organization UUID.



25
26
27
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 25

def cross_org_uuids
  @cross_org_uuids
end

#data_sourceObject

A data source for APM resource statistics queries.



28
29
30
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 28

def data_source
  @data_source
end

#envObject

The environment to query.



31
32
33
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 31

def env
  @env
end

#group_byObject

Tag keys to group results by.



34
35
36
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 34

def group_by
  @group_by
end

#nameObject

The variable name for use in formulas.



37
38
39
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 37

def name
  @name
end

#operation_nameObject

The APM operation name.



40
41
42
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 40

def operation_name
  @operation_name
end

#primary_tag_nameObject

Name of the second primary tag used within APM. Required when ‘primary_tag_value` is specified. See docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog



43
44
45
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 43

def primary_tag_name
  @primary_tag_name
end

#primary_tag_valueObject

Value of the second primary tag by which to filter APM data. ‘primary_tag_name` must also be specified.



46
47
48
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 46

def primary_tag_value
  @primary_tag_value
end

#resource_nameObject

The resource name to filter by.



49
50
51
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 49

def resource_name
  @resource_name
end

#serviceObject

The service name to filter by.



52
53
54
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 52

def service
  @service
end

#statObject

The APM resource statistic to query.



55
56
57
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 55

def stat
  @stat
end