Class: DatadogAPIClient::V2::AppBuilderAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v2/api/app_builder_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ AppBuilderAPI

Returns a new instance of AppBuilderAPI.



22
23
24
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#create_app(body, opts = {}) ⇒ Object

Create App.



29
30
31
32
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 29

def create_app(body, opts = {})
  data, _status_code, _headers = create_app_with_http_info(body, opts)
  data
end

#create_app_with_http_info(body, opts = {}) ⇒ Array<(CreateAppResponse, Integer, Hash)>

Create App.

Create a new app, returning the app ID. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • body (CreateAppRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CreateAppResponse, Integer, Hash)>)

    CreateAppResponse data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 41

def create_app_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.create_app ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.create_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CreateAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :create_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#create_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_publish_request(app_id, body, opts = {}) ⇒ Object

Create Publish Request.



96
97
98
99
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 96

def create_publish_request(app_id, body, opts = {})
  data, _status_code, _headers = create_publish_request_with_http_info(app_id, body, opts)
  data
end

#create_publish_request_with_http_info(app_id, body, opts = {}) ⇒ Array<(PublishAppResponse, Integer, Hash)>

Create Publish Request.

Create a publish request to ask for approval to publish an app whose protection level is ‘approval_required`. Publishing happens automatically once the request is approved by a user with the appropriate permissions.

Parameters:

Returns:

  • (Array<(PublishAppResponse, Integer, Hash)>)

    PublishAppResponse data, response status code and response headers



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 109

def create_publish_request_with_http_info(app_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.create_publish_request ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.create_publish_request"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.create_publish_request"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/publish-request'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'PublishAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :create_publish_request,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#create_publish_request\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_app(app_id, opts = {}) ⇒ Object

Delete App.



168
169
170
171
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 168

def delete_app(app_id, opts = {})
  data, _status_code, _headers = delete_app_with_http_info(app_id, opts)
  data
end

#delete_app_with_http_info(app_id, opts = {}) ⇒ Array<(DeleteAppResponse, Integer, Hash)>

Delete App.

Delete a single app. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • app_id (UUID)

    The ID of the app to delete.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(DeleteAppResponse, Integer, Hash)>)

    DeleteAppResponse data, response status code and response headers



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 180

def delete_app_with_http_info(app_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.delete_app ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.delete_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :delete_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#delete_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_apps(body, opts = {}) ⇒ Object

Delete Multiple Apps.



233
234
235
236
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 233

def delete_apps(body, opts = {})
  data, _status_code, _headers = delete_apps_with_http_info(body, opts)
  data
end

#delete_apps_with_http_info(body, opts = {}) ⇒ Array<(DeleteAppsResponse, Integer, Hash)>

Delete Multiple Apps.

Delete multiple apps in a single request from a list of app IDs. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

Returns:

  • (Array<(DeleteAppsResponse, Integer, Hash)>)

    DeleteAppsResponse data, response status code and response headers



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 245

def delete_apps_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.delete_apps ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.delete_apps"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'DeleteAppsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :delete_apps,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#delete_apps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_app(app_id, opts = {}) ⇒ Object

Get App.



300
301
302
303
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 300

def get_app(app_id, opts = {})
  data, _status_code, _headers = get_app_with_http_info(app_id, opts)
  data
end

#get_app_with_http_info(app_id, opts = {}) ⇒ Array<(GetAppResponse, Integer, Hash)>

Get App.

Get the full definition of an app. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • app_id (UUID)

    The ID of the app to retrieve.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :version (String)

    The version number of the app to retrieve. If not specified, the latest version is returned. Version numbers start at 1 and increment with each update. The special values ‘latest` and `deployed` can be used to retrieve the latest version or the published version, respectively.

Returns:

  • (Array<(GetAppResponse, Integer, Hash)>)

    GetAppResponse data, response status code and response headers



313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 313

def get_app_with_http_info(app_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.get_app ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.get_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :get_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#get_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_app_versions(app_id, opts = {}) ⇒ Object

List App Versions.



449
450
451
452
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 449

def list_app_versions(app_id, opts = {})
  data, _status_code, _headers = list_app_versions_with_http_info(app_id, opts)
  data
end

#list_app_versions_with_http_info(app_id, opts = {}) ⇒ Array<(ListAppVersionsResponse, Integer, Hash)>

List App Versions.

List the versions of an app. This endpoint is paginated.

Parameters:

  • app_id (UUID)

    The ID of the app.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The number of versions to return per page.

  • :page (Integer)

    The page number to return.

Returns:

  • (Array<(ListAppVersionsResponse, Integer, Hash)>)

    ListAppVersionsResponse data, response status code and response headers



463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 463

def list_app_versions_with_http_info(app_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.list_app_versions ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.list_app_versions"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/versions'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListAppVersionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :list_app_versions,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#list_app_versions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_apps(opts = {}) ⇒ Object

List Apps.



367
368
369
370
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 367

def list_apps(opts = {})
  data, _status_code, _headers = list_apps_with_http_info(opts)
  data
end

#list_apps_with_http_info(opts = {}) ⇒ Array<(ListAppsResponse, Integer, Hash)>

List Apps.

List all apps, with optional filters and sorting. This endpoint is paginated. Only basic app information such as the app ID, name, and description is returned by this endpoint. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The number of apps to return per page.

  • :page (Integer)

    The page number to return.

  • :filter_user_name (String)

    Filter apps by the app creator. Usually the user’s email.

  • :filter_user_uuid (UUID)

    Filter apps by the app creator’s UUID.

  • :filter_name (String)

    Filter by app name.

  • :filter_query (String)

    Filter apps by the app name or the app creator.

  • :filter_deployed (Boolean)

    Filter apps by whether they are published.

  • :filter_tags (String)

    Filter apps by tags.

  • :filter_favorite (Boolean)

    Filter apps by whether you have added them to your favorites.

  • :filter_self_service (Boolean)

    Filter apps by whether they are enabled for self-service.

  • :sort (Array<AppsSortField>)

    The fields and direction to sort apps by.

Returns:

  • (Array<(ListAppsResponse, Integer, Hash)>)

    ListAppsResponse data, response status code and response headers



389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 389

def list_apps_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.list_apps ...'
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'filter[user_name]'] = opts[:'filter_user_name'] if !opts[:'filter_user_name'].nil?
  query_params[:'filter[user_uuid]'] = opts[:'filter_user_uuid'] if !opts[:'filter_user_uuid'].nil?
  query_params[:'filter[name]'] = opts[:'filter_name'] if !opts[:'filter_name'].nil?
  query_params[:'filter[query]'] = opts[:'filter_query'] if !opts[:'filter_query'].nil?
  query_params[:'filter[deployed]'] = opts[:'filter_deployed'] if !opts[:'filter_deployed'].nil?
  query_params[:'filter[tags]'] = opts[:'filter_tags'] if !opts[:'filter_tags'].nil?
  query_params[:'filter[favorite]'] = opts[:'filter_favorite'] if !opts[:'filter_favorite'].nil?
  query_params[:'filter[self_service]'] = opts[:'filter_self_service'] if !opts[:'filter_self_service'].nil?
  query_params[:'sort'] = @api_client.build_collection_param(opts[:'sort'], :csv) if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListAppsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :list_apps,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#list_apps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#publish_app(app_id, opts = {}) ⇒ Object

Publish App.



518
519
520
521
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 518

def publish_app(app_id, opts = {})
  data, _status_code, _headers = publish_app_with_http_info(app_id, opts)
  data
end

#publish_app_with_http_info(app_id, opts = {}) ⇒ Array<(PublishAppResponse, Integer, Hash)>

Publish App.

Publish an app for use by other users. To ensure the app is accessible to the correct users, you also need to set a [Restriction Policy](docs.datadoghq.com/api/latest/restriction-policies/) on the app if a policy does not yet exist. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • app_id (UUID)

    The ID of the app to publish.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PublishAppResponse, Integer, Hash)>)

    PublishAppResponse data, response status code and response headers



530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 530

def publish_app_with_http_info(app_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.publish_app ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.publish_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/deployment'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PublishAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :publish_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#publish_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#revert_app(app_id, version, opts = {}) ⇒ Object

Revert App.



583
584
585
586
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 583

def revert_app(app_id, version, opts = {})
  data, _status_code, _headers = revert_app_with_http_info(app_id, version, opts)
  data
end

#revert_app_with_http_info(app_id, version, opts = {}) ⇒ Array<(UpdateAppResponse, Integer, Hash)>

Revert App.

Revert an app to a previous version. The version to revert to is selected through the ‘version` query parameter. The reverted version becomes the new latest version of the app.

Parameters:

  • app_id (UUID)

    The ID of the app.

  • version (String)

    The version number of the app to revert to. Cannot be ‘latest`. The special value `deployed` can be used to revert to the currently published version.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UpdateAppResponse, Integer, Hash)>)

    UpdateAppResponse data, response status code and response headers



596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 596

def revert_app_with_http_info(app_id, version, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.revert_app ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.revert_app"
  end
  # verify the required parameter 'version' is set
  if @api_client.config.client_side_validation && version.nil?
    fail ArgumentError, "Missing the required parameter 'version' when calling AppBuilderAPI.revert_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/revert'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'version'] = version

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :revert_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#revert_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#unpublish_app(app_id, opts = {}) ⇒ Object

Unpublish App.



654
655
656
657
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 654

def unpublish_app(app_id, opts = {})
  data, _status_code, _headers = unpublish_app_with_http_info(app_id, opts)
  data
end

#unpublish_app_with_http_info(app_id, opts = {}) ⇒ Array<(UnpublishAppResponse, Integer, Hash)>

Unpublish App.

Unpublish an app, removing the live version of the app. Unpublishing creates a new instance of a ‘deployment` object on the app, with a nil `app_version_id` (`00000000-0000-0000-0000-000000000000`). The app can still be updated and published again in the future. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • app_id (UUID)

    The ID of the app to unpublish.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UnpublishAppResponse, Integer, Hash)>)

    UnpublishAppResponse data, response status code and response headers



666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 666

def unpublish_app_with_http_info(app_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.unpublish_app ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.unpublish_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/deployment'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UnpublishAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :unpublish_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#unpublish_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_app(app_id, body, opts = {}) ⇒ Object

Update App.



719
720
721
722
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 719

def update_app(app_id, body, opts = {})
  data, _status_code, _headers = update_app_with_http_info(app_id, body, opts)
  data
end

#update_app_favorite(app_id, body, opts = {}) ⇒ Object

Update App Favorite Status.



791
792
793
794
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 791

def update_app_favorite(app_id, body, opts = {})
  update_app_favorite_with_http_info(app_id, body, opts)
  nil
end

#update_app_favorite_with_http_info(app_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update App Favorite Status.

Add or remove an app from the current user’s favorites. Favorited apps can be filtered for using the ‘filter` query parameter on the [List Apps](docs.datadoghq.com/api/latest/app-builder/#list-apps) endpoint.

Parameters:

  • app_id (UUID)

    The ID of the app.

  • body (UpdateAppFavoriteRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 804

def update_app_favorite_with_http_info(app_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.update_app_favorite ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.update_app_favorite"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.update_app_favorite"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/favorite'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_app_favorite,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#update_app_favorite\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_app_self_service(app_id, body, opts = {}) ⇒ Object

Update App Self-Service Status.



863
864
865
866
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 863

def update_app_self_service(app_id, body, opts = {})
  update_app_self_service_with_http_info(app_id, body, opts)
  nil
end

#update_app_self_service_with_http_info(app_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update App Self-Service Status.

Enable or disable self-service for an app. Self-service apps can be discovered and run by users in your organization without explicit access being granted.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 876

def update_app_self_service_with_http_info(app_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.update_app_self_service ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.update_app_self_service"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.update_app_self_service"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/self-service'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_app_self_service,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#update_app_self_service\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_app_tags(app_id, body, opts = {}) ⇒ Object

Update App Tags.



935
936
937
938
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 935

def update_app_tags(app_id, body, opts = {})
  update_app_tags_with_http_info(app_id, body, opts)
  nil
end

#update_app_tags_with_http_info(app_id, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Update App Tags.

Replace the tags on an app. The provided list overwrites the existing tags entirely; tags not present in the request body are removed.

Parameters:

  • app_id (UUID)

    The ID of the app.

  • body (UpdateAppTagsRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



948
949
950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 948

def update_app_tags_with_http_info(app_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.update_app_tags ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.update_app_tags"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.update_app_tags"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/tags'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_app_tags,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#update_app_tags\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_app_version_name(app_id, version, body, opts = {}) ⇒ Object

Name App Version.



1007
1008
1009
1010
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 1007

def update_app_version_name(app_id, version, body, opts = {})
  update_app_version_name_with_http_info(app_id, version, body, opts)
  nil
end

#update_app_version_name_with_http_info(app_id, version, body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Name App Version.

Assign a human-readable name to a specific version of an app. The version is selected through the ‘version` query parameter.

Parameters:

  • app_id (UUID)

    The ID of the app.

  • version (String)

    The version number of the app to name. The special values ‘latest` and `deployed` can also be used to target the latest or currently published version.

  • body (UpdateAppVersionNameRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 1021

def update_app_version_name_with_http_info(app_id, version, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.update_app_version_name ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.update_app_version_name"
  end
  # verify the required parameter 'version' is set
  if @api_client.config.client_side_validation && version.nil?
    fail ArgumentError, "Missing the required parameter 'version' when calling AppBuilderAPI.update_app_version_name"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.update_app_version_name"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/version-name'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'version'] = version

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_app_version_name,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#update_app_version_name\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_app_with_http_info(app_id, body, opts = {}) ⇒ Array<(UpdateAppResponse, Integer, Hash)>

Update App.

Update an existing app. This creates a new version of the app. This API requires a [registered application key](docs.datadoghq.com/api/latest/action-connection/#register-a-new-app-key). Alternatively, you can configure these permissions [in the UI](docs.datadoghq.com/account_management/api-app-keys/#actions-api-access).

Parameters:

  • app_id (UUID)

    The ID of the app to update.

  • body (UpdateAppRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UpdateAppResponse, Integer, Hash)>)

    UpdateAppResponse data, response status code and response headers



732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 732

def update_app_with_http_info(app_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.update_app ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.update_app"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.update_app"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_app,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#update_app\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_protection_level(app_id, body, opts = {}) ⇒ Object

Update App Protection Level.



1085
1086
1087
1088
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 1085

def update_protection_level(app_id, body, opts = {})
  data, _status_code, _headers = update_protection_level_with_http_info(app_id, body, opts)
  data
end

#update_protection_level_with_http_info(app_id, body, opts = {}) ⇒ Array<(UpdateAppResponse, Integer, Hash)>

Update App Protection Level.

Update the publication protection level of an app. When set to ‘approval_required`, future publishes must go through an approval workflow before going live.

Parameters:

Returns:

  • (Array<(UpdateAppResponse, Integer, Hash)>)

    UpdateAppResponse data, response status code and response headers



1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
1147
1148
1149
1150
1151
1152
# File 'lib/datadog_api_client/v2/api/app_builder_api.rb', line 1098

def update_protection_level_with_http_info(app_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AppBuilderAPI.update_protection_level ...'
  end
  # verify the required parameter 'app_id' is set
  if @api_client.config.client_side_validation && app_id.nil?
    fail ArgumentError, "Missing the required parameter 'app_id' when calling AppBuilderAPI.update_protection_level"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling AppBuilderAPI.update_protection_level"
  end
  # resource path
  local_var_path = '/api/v2/app-builder/apps/{app_id}/protection-level'.sub('{app_id}', CGI.escape(app_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateAppResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_protection_level,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AppBuilderAPI#update_protection_level\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end