Class: DatadogAPIClient::V2::ApplicationKeyUpdateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/application_key_update_attributes.rb

Overview

Attributes used to update an application Key.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#nameObject

Name of the application key.



29
30
31
# File 'lib/datadog_api_client/v2/models/application_key_update_attributes.rb', line 29

def name
  @name
end

#scopesObject

Array of scopes to grant the application key. This feature is in private beta, please contact Datadog support to enable scopes for your application keys.



32
33
34
# File 'lib/datadog_api_client/v2/models/application_key_update_attributes.rb', line 32

def scopes
  @scopes
end