Class: DatadogAPIClient::V2::ApplicationSecurityServiceAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/application_security_service_attributes.rb

Overview

Application Security details describing a service in a given environment.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



120
121
122
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 120

def additional_properties
  @additional_properties
end

#agent_versionsObject

The Datadog Agent versions reporting for the service.



25
26
27
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 25

def agent_versions
  @agent_versions
end

#app_typeObject

The application type of the service, such as ‘web` or `serverless`.



28
29
30
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 28

def app_type
  @app_type
end

#asm_threat_compatibleObject

Whether the service is compatible with Application Security Management (Threats).



31
32
33
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 31

def asm_threat_compatible
  @asm_threat_compatible
end

#backend_waf_event_countObject

The number of backend WAF events detected for the service.



34
35
36
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 34

def backend_waf_event_count
  @backend_waf_event_count
end

#business_logicObject

The enabled business logic detection rules for the service.



37
38
39
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 37

def business_logic
  @business_logic
end

#colorObject

Deprecated: a display color associated with the service in the UI.



40
41
42
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 40

def color
  @color
end

#envObject

The environment the service runs in.



43
44
45
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 43

def env
  @env
end

#event_countObject

The number of Application Security events detected for the service.



46
47
48
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 46

def event_count
  @event_count
end

#event_trendObject

Deprecated: the trend of Application Security events over time.



49
50
51
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 49

def event_trend
  @event_trend
end

#has_appsec_enabledObject

Whether Application Security Management (Threats) is enabled for the service.



52
53
54
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 52

def has_appsec_enabled
  @has_appsec_enabled
end

#hitsObject

Deprecated: the number of hits for the service.



55
56
57
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 55

def hits
  @hits
end

#iast_product_activationObject

Whether Interactive Application Security Testing (IAST) is enabled for the service.



58
59
60
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 58

def iast_product_activation
  @iast_product_activation
end

#iast_product_compatibilityObject

The Interactive Application Security Testing (IAST) compatibility status of the service.



61
62
63
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 61

def iast_product_compatibility
  @iast_product_compatibility
end

#iast_product_compatibility_reasonsObject

The reasons explaining the Interactive Application Security Testing (IAST) compatibility status.



64
65
66
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 64

def iast_product_compatibility_reasons
  @iast_product_compatibility_reasons
end

#languagesObject

The programming languages detected for the service.



67
68
69
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 67

def languages
  @languages
end

#last_ingested_spansObject

The Unix timestamp, in seconds, of the last ingested span for the service.



70
71
72
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 70

def last_ingested_spans
  @last_ingested_spans
end

#rc_capabilitiesObject

The Remote Configuration capabilities reported by the service.



73
74
75
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 73

def rc_capabilities
  @rc_capabilities
end

The recommended business logic detection rules for the service.



76
77
78
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 76

def recommended_business_logic
  @recommended_business_logic
end

#risk_product_activationObject

Whether Software Composition Analysis (SCA) is enabled for the service.



79
80
81
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 79

def risk_product_activation
  @risk_product_activation
end

#risk_product_compatibilityObject

The Software Composition Analysis (SCA) compatibility status of the service.



82
83
84
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 82

def risk_product_compatibility
  @risk_product_compatibility
end

#risk_product_compatibility_reasonsObject

The reasons explaining the Software Composition Analysis (SCA) compatibility status.



85
86
87
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 85

def risk_product_compatibility_reasons
  @risk_product_compatibility_reasons
end

#rules_versionObject

The WAF rules versions applied to the service.



88
89
90
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 88

def rules_version
  @rules_version
end

#serviceObject

The name of the service.



91
92
93
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 91

def service
  @service
end

#signal_countObject

Deprecated: the number of security signals for the service.



94
95
96
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 94

def signal_count
  @signal_count
end

#signal_trendObject

Deprecated: the trend of security signals over time.



97
98
99
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 97

def signal_trend
  @signal_trend
end

#sourceObject

The data sources that contributed information about the service.



100
101
102
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 100

def source
  @source
end

#teamsObject

The teams that own the service.



103
104
105
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 103

def teams
  @teams
end

#tracer_versionsObject

The Datadog tracing library versions reporting for the service.



106
107
108
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 106

def tracer_versions
  @tracer_versions
end

#vm_activationObject

The Vulnerability Management activation status of the service.



109
110
111
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 109

def vm_activation
  @vm_activation
end

#vuln_critical_countObject

Deprecated: the number of critical-severity vulnerabilities for the service.



112
113
114
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 112

def vuln_critical_count
  @vuln_critical_count
end

#vuln_high_countObject

Deprecated: the number of high-severity vulnerabilities for the service.



115
116
117
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 115

def vuln_high_count
  @vuln_high_count
end

#without_filter_servicesObject

The total number of services available without applying the service filter.



118
119
120
# File 'lib/datadog_api_client/v2/models/application_security_service_attributes.rb', line 118

def without_filter_services
  @without_filter_services
end