Class: DatadogAPIClient::V2::ApplicationSecurityWafExclusionFilterCreateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb

Overview

Attributes for creating a WAF exclusion filter.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_properties ⇒ Object

Returns the value of attribute additional_properties.



48
49
50
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 48

def additional_properties
  @additional_properties
end

#description ⇒ Object

A description for the exclusion filter.



25
26
27
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 25

def description
  @description
end

#enabled ⇒ Object

Indicates whether the exclusion filter is enabled.



28
29
30
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 28

def enabled
  @enabled
end

#ip_list ⇒ Object

The client IP addresses matched by the exclusion filter (CIDR notation is supported).



31
32
33
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 31

def ip_list
  @ip_list
end

#on_match ⇒ Object

The action taken when the exclusion filter matches. When set to monitor, security traces are emitted but the requests are not blocked. By default, security traces are not emitted and the requests are not blocked.



34
35
36
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 34

def on_match
  @on_match
end

#parameters ⇒ Object

A list of parameters matched by the exclusion filter in the HTTP query string and HTTP request body. Nested parameters can be matched by joining fields with a dot character.



37
38
39
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 37

def parameters
  @parameters
end

#path_glob ⇒ Object

The HTTP path glob expression matched by the exclusion filter.



40
41
42
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 40

def path_glob
  @path_glob
end

#rules_target ⇒ Object

The WAF rules targeted by the exclusion filter.



43
44
45
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 43

def rules_target
  @rules_target
end

#scope ⇒ Object

The services where the exclusion filter is deployed.



46
47
48
# File 'lib/datadog_api_client/v2/models/application_security_waf_exclusion_filter_create_attributes.rb', line 46

def scope
  @scope
end