Class: DatadogAPIClient::V2::AuthNMappingAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/authn_mapping_attributes.rb

Overview

Attributes of AuthN Mapping.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#attribute_keyObject

Key portion of a key/value pair of the attribute sent from the Identity Provider.



29
30
31
# File 'lib/datadog_api_client/v2/models/authn_mapping_attributes.rb', line 29

def attribute_key
  @attribute_key
end

#attribute_valueObject

Value portion of a key/value pair of the attribute sent from the Identity Provider.



32
33
34
# File 'lib/datadog_api_client/v2/models/authn_mapping_attributes.rb', line 32

def attribute_value
  @attribute_value
end

#created_atObject

Creation time of the AuthN Mapping.



35
36
37
# File 'lib/datadog_api_client/v2/models/authn_mapping_attributes.rb', line 35

def created_at
  @created_at
end

#modified_atObject

Time of last AuthN Mapping modification.



38
39
40
# File 'lib/datadog_api_client/v2/models/authn_mapping_attributes.rb', line 38

def modified_at
  @modified_at
end

#saml_assertion_attribute_idObject

The ID of the SAML assertion attribute.



41
42
43
# File 'lib/datadog_api_client/v2/models/authn_mapping_attributes.rb', line 41

def saml_assertion_attribute_id
  @saml_assertion_attribute_id
end