Class: DatadogAPIClient::V2::AutomationRuleTriggerData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb

Overview

Additional configuration for the trigger, dependent on the trigger type. For ‘status_transitioned` triggers, specify `from_status_name` and `to_status_name`. For `attribute_value_changed` triggers, specify `field` and `change_type`.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



39
40
41
# File 'lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb', line 39

def additional_properties
  @additional_properties
end

#approval_typeObject

The approval outcome to match. Used with ‘case_review_approved` triggers.



25
26
27
# File 'lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb', line 25

def approval_type
  @approval_type
end

#change_typeObject

The kind of attribute change to match. Allowed values: ‘VALUE_ADDED`, `VALUE_DELETED`, `ANY_CHANGES`. Used with `attribute_value_changed` triggers.



28
29
30
# File 'lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb', line 28

def change_type
  @change_type
end

#fieldObject

The case attribute field name to monitor for changes. Used with ‘attribute_value_changed` triggers.



31
32
33
# File 'lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb', line 31

def field
  @field
end

#from_status_nameObject

The originating status name. Used with ‘status_transitioned` triggers to match transitions from this status.



34
35
36
# File 'lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb', line 34

def from_status_name
  @from_status_name
end

#to_status_nameObject

The destination status name. Used with ‘status_transitioned` triggers to match transitions to this status.



37
38
39
# File 'lib/datadog_api_client/v2/models/automation_rule_trigger_data.rb', line 37

def to_status_name
  @to_status_name
end