Class: DatadogAPIClient::V2::CIAppEventAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/ci_app_event_attributes.rb

Overview

JSON object containing all event attributes and their associated values.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#attributesObject

JSON object of attributes from CI Visibility events.



29
30
31
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 29

def attributes
  @attributes
end

#serviceObject

The name of the application or service generating CI Visibility events. It is used to switch from CI Visibility to APM, so make sure you define the same value when you use both products.



34
35
36
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 34

def service
  @service
end

#tagsObject

Array of tags associated with your event.



37
38
39
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 37

def tags
  @tags
end

#timestampObject

Timestamp of your event.



40
41
42
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 40

def timestamp
  @timestamp
end