Class: DatadogAPIClient::V2::CIAppGitHubAccountAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CIAppGitHubAccountAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb
Overview
Attributes describing a GitHub account's CI Visibility opt-in status.
Instance Attribute Summary collapse
-
#account ⇒ Object
The GitHub account (organization or user) name.
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#enabled ⇒ Object
Whether CI Visibility is enabled at the account level.
-
#host ⇒ Object
The GitHub host (
github.comor a GitHub Enterprise Server (GHES) hostname) this account belongs to. -
#repo_count ⇒ Object
The number of repositories known for this account.
-
#repositories ⇒ Object
The repositories belonging to this account, with their individual opt-in status.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#account ⇒ Object
The GitHub account (organization or user) name.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb', line 25 def account @account end |
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb', line 39 def additional_properties @additional_properties end |
#enabled ⇒ Object
Whether CI Visibility is enabled at the account level.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb', line 28 def enabled @enabled end |
#host ⇒ Object
The GitHub host (github.com or a GitHub Enterprise Server (GHES) hostname) this account belongs to.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb', line 31 def host @host end |
#repo_count ⇒ Object
The number of repositories known for this account.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb', line 34 def repo_count @repo_count end |
#repositories ⇒ Object
The repositories belonging to this account, with their individual opt-in status.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/ci_app_git_hub_account_attributes.rb', line 37 def repositories @repositories end |