Class: DatadogAPIClient::V2::CIAppPipelineEventInProgressJob

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb

Overview

Details of a running CI job.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



80
81
82
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 80

def additional_properties
  @additional_properties
end

#dependenciesObject

A list of job IDs that this job depends on.



25
26
27
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 25

def dependencies
  @dependencies
end

#errorObject

Contains information of the CI error.



28
29
30
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 28

def error
  @error
end

#gitObject

If pipelines are triggered due to actions to a Git repository, then all payloads must contain this. Note that either tag or branch has to be provided, but not both.



32
33
34
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 32

def git
  @git
end

#idObject

The UUID for the job. It must match the ID of the corresponding finished job.



35
36
37
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 35

def id
  @id
end

#levelObject

Used to distinguish between pipelines, stages, jobs, and steps.



38
39
40
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 38

def level
  @level
end

#metricsObject

A list of user-defined metrics. The metrics must follow the key:value pattern and the value must be numeric.



41
42
43
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 41

def metrics
  @metrics
end

#nameObject

The name for the job.



44
45
46
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 44

def name
  @name
end

#nodeObject

Contains information of the host running the pipeline, stage, job, or step.



47
48
49
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 47

def node
  @node
end

#parametersObject

A map of key-value parameters or environment variables that were defined for the pipeline.



50
51
52
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 50

def parameters
  @parameters
end

#pipeline_nameObject

The parent pipeline name.



53
54
55
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 53

def pipeline_name
  @pipeline_name
end

#pipeline_unique_idObject

The parent pipeline UUID.



56
57
58
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 56

def pipeline_unique_id
  @pipeline_unique_id
end

#queue_timeObject

The queue time in milliseconds, if applicable.



59
60
61
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 59

def queue_time
  @queue_time
end

#stage_idObject

The parent stage UUID (if applicable).



62
63
64
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 62

def stage_id
  @stage_id
end

#stage_nameObject

The parent stage name (if applicable).



65
66
67
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 65

def stage_name
  @stage_name
end

#startObject

Time when the job run instance started (it should not include any queue time). The time format must be RFC3339.



69
70
71
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 69

def start
  @start
end

#statusObject

The in-progress status of the job.



72
73
74
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 72

def status
  @status
end

#tagsObject

A list of user-defined tags. The tags must follow the key:value pattern.



75
76
77
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 75

def tags
  @tags
end

#urlObject

The URL to look at the job in the CI provider UI.



78
79
80
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 78

def url
  @url
end