Class: DatadogAPIClient::V2::CIAppPipelinesQueryFilter
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CIAppPipelinesQueryFilter
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/ci_app_pipelines_query_filter.rb
Overview
The search and filter query settings.
Instance Attribute Summary collapse
-
#from ⇒ Object
The minimum time for the requested events; supports date, math, and regular timestamps (in milliseconds).
-
#query ⇒ Object
The search query following the Log search syntax.
-
#to ⇒ Object
The maximum time for the requested events, supports date, math, and regular timestamps (in milliseconds).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#from ⇒ Object
The minimum time for the requested events; supports date, math, and regular timestamps (in milliseconds).
29 30 31 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipelines_query_filter.rb', line 29 def from @from end |
#query ⇒ Object
The search query following the Log search syntax.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipelines_query_filter.rb', line 32 def query @query end |
#to ⇒ Object
The maximum time for the requested events, supports date, math, and regular timestamps (in milliseconds).
35 36 37 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipelines_query_filter.rb', line 35 def to @to end |