Class: DatadogAPIClient::V2::CIAppTestEvent
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CIAppTestEvent
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/ci_app_test_event.rb
Overview
Object description of test event after being processed and stored by Datadog.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
JSON object containing all event attributes and their associated values.
-
#id ⇒ Object
Unique ID of the event.
-
#type ⇒ Object
Type of the event.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
JSON object containing all event attributes and their associated values.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/ci_app_test_event.rb', line 29 def attributes @attributes end |
#id ⇒ Object
Unique ID of the event.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/ci_app_test_event.rb', line 32 def id @id end |
#type ⇒ Object
Type of the event.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/ci_app_test_event.rb', line 35 def type @type end |