Class: DatadogAPIClient::V2::CIAppTestsAggregateRequest

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/ci_app_tests_aggregate_request.rb

Overview

The object sent with the request to retrieve aggregation buckets of test events from your organization.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#computeObject

The list of metrics or timeseries to compute for the retrieved buckets.



29
30
31
# File 'lib/datadog_api_client/v2/models/ci_app_tests_aggregate_request.rb', line 29

def compute
  @compute
end

#filterObject

The search and filter query settings.



32
33
34
# File 'lib/datadog_api_client/v2/models/ci_app_tests_aggregate_request.rb', line 32

def filter
  @filter
end

#group_byObject

The rules for the group-by.



35
36
37
# File 'lib/datadog_api_client/v2/models/ci_app_tests_aggregate_request.rb', line 35

def group_by
  @group_by
end

#optionsObject

Global query options that are used during the query. Only supply timezone or time offset, not both. Otherwise, the query fails.



39
40
41
# File 'lib/datadog_api_client/v2/models/ci_app_tests_aggregate_request.rb', line 39

def options
  @options
end