Class: DatadogAPIClient::V2::CIAppTestsGroupBy

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb

Overview

A group-by rule.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#facetObject

The name of the facet to use (required).



29
30
31
# File 'lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb', line 29

def facet
  @facet
end

#histogramObject

Used to perform a histogram computation (only for measure facets). At most, 100 buckets are allowed, the number of buckets is ‘(max - min)/interval`.



33
34
35
# File 'lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb', line 33

def histogram
  @histogram
end

#limitObject

The maximum buckets to return for this group-by.



36
37
38
# File 'lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb', line 36

def limit
  @limit
end

#missingObject

The value to use for logs that don’t have the facet used to group-by.



39
40
41
# File 'lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb', line 39

def missing
  @missing
end

#sortObject

A sort rule.



42
43
44
# File 'lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb', line 42

def sort
  @sort
end

#totalObject

A resulting object to put the given computes in over all the matching records.



45
46
47
# File 'lib/datadog_api_client/v2/models/ci_app_tests_group_by.rb', line 45

def total
  @total
end