Class: DatadogAPIClient::V2::CaseBulkUpdateRequestAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/case_bulk_update_request_attributes.rb

Overview

Attributes for the bulk update, specifying which cases to update and the action to apply.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



33
34
35
# File 'lib/datadog_api_client/v2/models/case_bulk_update_request_attributes.rb', line 33

def additional_properties
  @additional_properties
end

#case_idsObject

An array of case identifiers to apply the bulk action to.



25
26
27
# File 'lib/datadog_api_client/v2/models/case_bulk_update_request_attributes.rb', line 25

def case_ids
  @case_ids
end

#payloadObject

A key-value map of action-specific parameters. The required keys depend on the action type (for example, ‘priority` for the priority action, `assignee_id` for assign).



28
29
30
# File 'lib/datadog_api_client/v2/models/case_bulk_update_request_attributes.rb', line 28

def payload
  @payload
end

#typeObject

The type of action to apply in a bulk update. Allowed values are ‘priority`, `status`, `assign`, `unassign`, `archive`, `unarchive`, `jira`, `servicenow`, `linear`, `update_project`.



31
32
33
# File 'lib/datadog_api_client/v2/models/case_bulk_update_request_attributes.rb', line 31

def type
  @type
end