Class: DatadogAPIClient::V2::CloudConfigurationRuleCreatePayload
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CloudConfigurationRuleCreatePayload
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb
Overview
Create a new cloud configuration rule.
Instance Attribute Summary collapse
-
#cases ⇒ Object
readonly
Description of generated findings and signals (severity and channels to be notified in case of a signal).
-
#compliance_signal_options ⇒ Object
readonly
How to generate compliance signals.
-
#is_enabled ⇒ Object
readonly
Whether the rule is enabled.
-
#message ⇒ Object
readonly
Message in markdown format for generated findings and signals.
-
#name ⇒ Object
readonly
The name of the rule.
-
#options ⇒ Object
readonly
Options on cloud configuration rules.
-
#tags ⇒ Object
Tags for generated findings and signals.
-
#type ⇒ Object
The rule type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#cases ⇒ Object
Description of generated findings and signals (severity and channels to be notified in case of a signal). Must contain exactly one item.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 30 def cases @cases end |
#compliance_signal_options ⇒ Object
How to generate compliance signals. Useful for cloud_configuration rules only.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 33 def end |
#is_enabled ⇒ Object
Whether the rule is enabled.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 36 def is_enabled @is_enabled end |
#message ⇒ Object
Message in markdown format for generated findings and signals.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 39 def end |
#name ⇒ Object
The name of the rule.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 42 def name @name end |
#options ⇒ Object
Options on cloud configuration rules.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 45 def end |
#tags ⇒ Object
Tags for generated findings and signals.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 48 def end |
#type ⇒ Object
The rule type.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/cloud_configuration_rule_create_payload.rb', line 51 def type @type end |