Class: DatadogAPIClient::V2::CloudWorkloadSecurityAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v2/api/cloud_workload_security_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ CloudWorkloadSecurityAPI

Returns a new instance of CloudWorkloadSecurityAPI.



22
23
24
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#create_cloud_workload_security_agent_rule(body, opts = {}) ⇒ Object

Create a Cloud Workload Security Agent rule.



29
30
31
32
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 29

def create_cloud_workload_security_agent_rule(body, opts = {})
  data, _status_code, _headers = create_cloud_workload_security_agent_rule_with_http_info(body, opts)
  data
end

#create_cloud_workload_security_agent_rule_with_http_info(body, opts = {}) ⇒ Array<(CloudWorkloadSecurityAgentRuleResponse, Integer, Hash)>

Create a Cloud Workload Security Agent rule.

Create a new Agent rule with the given parameters.

Parameters:

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 41

def create_cloud_workload_security_agent_rule_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudWorkloadSecurityAPI.create_cloud_workload_security_agent_rule ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CloudWorkloadSecurityAPI.create_cloud_workload_security_agent_rule"
  end
  # resource path
  local_var_path = '/api/v2/security_monitoring/cloud_workload_security/agent_rules'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CloudWorkloadSecurityAgentRuleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :create_cloud_workload_security_agent_rule,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudWorkloadSecurityAPI#create_cloud_workload_security_agent_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_cloud_workload_security_agent_rule(agent_rule_id, opts = {}) ⇒ Object

Delete a Cloud Workload Security Agent rule.



96
97
98
99
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 96

def delete_cloud_workload_security_agent_rule(agent_rule_id, opts = {})
  delete_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, opts)
  nil
end

#delete_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a Cloud Workload Security Agent rule.

Delete a specific Agent rule.

Parameters:

  • agent_rule_id (String)

    The ID of the Agent rule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 108

def delete_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudWorkloadSecurityAPI.delete_cloud_workload_security_agent_rule ...'
  end
  # verify the required parameter 'agent_rule_id' is set
  if @api_client.config.client_side_validation && agent_rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'agent_rule_id' when calling CloudWorkloadSecurityAPI.delete_cloud_workload_security_agent_rule"
  end
  # resource path
  local_var_path = '/api/v2/security_monitoring/cloud_workload_security/agent_rules/{agent_rule_id}'.sub('{agent_rule_id}', CGI.escape(agent_rule_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :delete_cloud_workload_security_agent_rule,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudWorkloadSecurityAPI#delete_cloud_workload_security_agent_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#download_cloud_workload_policy_file(opts = {}) ⇒ Object

Get the latest Cloud Workload Security policy.



161
162
163
164
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 161

def download_cloud_workload_policy_file(opts = {})
  data, _status_code, _headers = download_cloud_workload_policy_file_with_http_info(opts)
  data
end

#download_cloud_workload_policy_file_with_http_info(opts = {}) ⇒ Array<(File, Integer, Hash)>

Get the latest Cloud Workload Security policy.

The download endpoint generates a Cloud Workload Security policy file from your currently active Cloud Workload Security rules, and downloads them as a .policy file. This file can then be deployed to your Agents to update the policy running in your environment.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(File, Integer, Hash)>)

    File data, response status code and response headers



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 174

def download_cloud_workload_policy_file_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudWorkloadSecurityAPI.download_cloud_workload_policy_file ...'
  end
  # resource path
  local_var_path = '/api/v2/security/cloud_workload/policy/download'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/yaml', 'application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'File'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :download_cloud_workload_policy_file,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudWorkloadSecurityAPI#download_cloud_workload_policy_file\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_cloud_workload_security_agent_rule(agent_rule_id, opts = {}) ⇒ Object

Get a Cloud Workload Security Agent rule.



223
224
225
226
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 223

def get_cloud_workload_security_agent_rule(agent_rule_id, opts = {})
  data, _status_code, _headers = get_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, opts)
  data
end

#get_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, opts = {}) ⇒ Array<(CloudWorkloadSecurityAgentRuleResponse, Integer, Hash)>

Get a Cloud Workload Security Agent rule.

Get the details of a specific Agent rule.

Parameters:

  • agent_rule_id (String)

    The ID of the Agent rule.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 235

def get_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudWorkloadSecurityAPI.get_cloud_workload_security_agent_rule ...'
  end
  # verify the required parameter 'agent_rule_id' is set
  if @api_client.config.client_side_validation && agent_rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'agent_rule_id' when calling CloudWorkloadSecurityAPI.get_cloud_workload_security_agent_rule"
  end
  # resource path
  local_var_path = '/api/v2/security_monitoring/cloud_workload_security/agent_rules/{agent_rule_id}'.sub('{agent_rule_id}', CGI.escape(agent_rule_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CloudWorkloadSecurityAgentRuleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :get_cloud_workload_security_agent_rule,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudWorkloadSecurityAPI#get_cloud_workload_security_agent_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_cloud_workload_security_agent_rules(opts = {}) ⇒ Object

Get all Cloud Workload Security Agent rules.



288
289
290
291
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 288

def list_cloud_workload_security_agent_rules(opts = {})
  data, _status_code, _headers = list_cloud_workload_security_agent_rules_with_http_info(opts)
  data
end

#list_cloud_workload_security_agent_rules_with_http_info(opts = {}) ⇒ Array<(CloudWorkloadSecurityAgentRulesListResponse, Integer, Hash)>

Get all Cloud Workload Security Agent rules.

Get the list of Agent rules.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 299

def list_cloud_workload_security_agent_rules_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudWorkloadSecurityAPI.list_cloud_workload_security_agent_rules ...'
  end
  # resource path
  local_var_path = '/api/v2/security_monitoring/cloud_workload_security/agent_rules'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CloudWorkloadSecurityAgentRulesListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :list_cloud_workload_security_agent_rules,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudWorkloadSecurityAPI#list_cloud_workload_security_agent_rules\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_cloud_workload_security_agent_rule(agent_rule_id, body, opts = {}) ⇒ Object

Update a Cloud Workload Security Agent rule.



348
349
350
351
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 348

def update_cloud_workload_security_agent_rule(agent_rule_id, body, opts = {})
  data, _status_code, _headers = update_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, body, opts)
  data
end

#update_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, body, opts = {}) ⇒ Array<(CloudWorkloadSecurityAgentRuleResponse, Integer, Hash)>

Update a Cloud Workload Security Agent rule.

Update a specific Agent rule. Returns the Agent rule object when the request is successful.

Parameters:

Returns:



362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/datadog_api_client/v2/api/cloud_workload_security_api.rb', line 362

def update_cloud_workload_security_agent_rule_with_http_info(agent_rule_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: CloudWorkloadSecurityAPI.update_cloud_workload_security_agent_rule ...'
  end
  # verify the required parameter 'agent_rule_id' is set
  if @api_client.config.client_side_validation && agent_rule_id.nil?
    fail ArgumentError, "Missing the required parameter 'agent_rule_id' when calling CloudWorkloadSecurityAPI.update_cloud_workload_security_agent_rule"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling CloudWorkloadSecurityAPI.update_cloud_workload_security_agent_rule"
  end
  # resource path
  local_var_path = '/api/v2/security_monitoring/cloud_workload_security/agent_rules/{agent_rule_id}'.sub('{agent_rule_id}', CGI.escape(agent_rule_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'CloudWorkloadSecurityAgentRuleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_cloud_workload_security_agent_rule,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: CloudWorkloadSecurityAPI#update_cloud_workload_security_agent_rule\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end