Class: DatadogAPIClient::V2::CloudWorkloadSecurityAgentRuleData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CloudWorkloadSecurityAgentRuleData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_data.rb
Overview
Object for a single Agent rule.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
A Cloud Workload Security Agent rule returned by the API.
-
#id ⇒ Object
The ID of the Agent rule.
-
#type ⇒ Object
The type of the resource.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
A Cloud Workload Security Agent rule returned by the API.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_data.rb', line 29 def attributes @attributes end |
#id ⇒ Object
The ID of the Agent rule.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_data.rb', line 32 def id @id end |
#type ⇒ Object
The type of the resource. The value should always be agent_rule.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_data.rb', line 35 def type @type end |