Class: DatadogAPIClient::V2::ControlNotificationEventSetting

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/control_notification_event_setting.rb

Overview

The notification settings for a single event type on a control.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



33
34
35
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 33

def additional_properties
  @additional_properties
end

#enabledObject

Whether notifications are enabled for this event type.



25
26
27
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 25

def enabled
  @enabled
end

#event_typeObject

The event type the notification settings apply to, such as new_detection.



28
29
30
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 28

def event_type
  @event_type
end

#targetsObject

The destinations that receive notifications for an event type.



31
32
33
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 31

def targets
  @targets
end