Class: DatadogAPIClient::V2::ControlNotificationSettingsAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ControlNotificationSettingsAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/control_notification_settings_attributes.rb
Overview
The attributes of a governance control's notification settings.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#event_settings ⇒ Object
readonly
The notification settings for each supported event type on the control.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/control_notification_settings_attributes.rb', line 27 def additional_properties @additional_properties end |
#event_settings ⇒ Object
The notification settings for each supported event type on the control.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/control_notification_settings_attributes.rb', line 25 def event_settings @event_settings end |