Class: DatadogAPIClient::V2::ControlNotificationTarget
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ControlNotificationTarget
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/control_notification_target.rb
Overview
A destination that receives notifications for an event type.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#handle ⇒ Object
readonly
The destination handle, such as an email address, Slack channel, or user handle.
-
#type ⇒ Object
readonly
The type of notification destination.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/control_notification_target.rb', line 30 def additional_properties @additional_properties end |
#handle ⇒ Object
The destination handle, such as an email address, Slack channel, or user handle.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/control_notification_target.rb', line 25 def handle @handle end |
#type ⇒ Object
The type of notification destination.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/control_notification_target.rb', line 28 def type @type end |