Class: DatadogAPIClient::V2::CostAnomaliesResponseDataAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb

Overview

Cost anomaly results and aggregated totals for the queried window.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



39
40
41
# File 'lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb', line 39

def additional_properties
  @additional_properties
end

#anomaliesObject

The list of cost anomalies that match the request.



25
26
27
# File 'lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb', line 25

def anomalies
  @anomalies
end

#avg_daily_anomalous_costObject

Average daily anomalous cost change across the queried window.



28
29
30
# File 'lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb', line 28

def avg_daily_anomalous_cost
  @avg_daily_anomalous_cost
end

#total_actual_costObject

Total actual cost spent across the queried window for the matching providers.



31
32
33
# File 'lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb', line 31

def total_actual_cost
  @total_actual_cost
end

#total_anomalous_costObject

Sum of the anomalous cost change across all returned anomalies.



34
35
36
# File 'lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb', line 34

def total_anomalous_cost
  @total_anomalous_cost
end

#total_countObject

Total number of anomalies that match the request.



37
38
39
# File 'lib/datadog_api_client/v2/models/cost_anomalies_response_data_attributes.rb', line 37

def total_count
  @total_count
end