Class: DatadogAPIClient::V2::CostByOrgAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/cost_by_org_attributes.rb

Overview

Cost attributes data.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#chargesObject

List of charges data reported for the requested month.



29
30
31
# File 'lib/datadog_api_client/v2/models/cost_by_org_attributes.rb', line 29

def charges
  @charges
end

#dateObject

The month requested.



32
33
34
# File 'lib/datadog_api_client/v2/models/cost_by_org_attributes.rb', line 32

def date
  @date
end

#org_nameObject

The organization name.



35
36
37
# File 'lib/datadog_api_client/v2/models/cost_by_org_attributes.rb', line 35

def org_name
  @org_name
end

#public_idObject

The organization public ID.



38
39
40
# File 'lib/datadog_api_client/v2/models/cost_by_org_attributes.rb', line 38

def public_id
  @public_id
end

#regionObject

The region of the Datadog instance that the organization belongs to.



41
42
43
# File 'lib/datadog_api_client/v2/models/cost_by_org_attributes.rb', line 41

def region
  @region
end

#total_costObject

The total cost of products for the month.



44
45
46
# File 'lib/datadog_api_client/v2/models/cost_by_org_attributes.rb', line 44

def total_cost
  @total_cost
end