Class: DatadogAPIClient::V2::CostCurrencyResponse

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/cost_currency_response.rb

Overview

The dominant Cloud Cost Management billing currency for the requested period. The ‘data` array contains at most one entry, and is empty when no currency data is available.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



27
28
29
# File 'lib/datadog_api_client/v2/models/cost_currency_response.rb', line 27

def additional_properties
  @additional_properties
end

#dataObject

The dominant billing currency. Empty when no data is available, or a single entry otherwise.



25
26
27
# File 'lib/datadog_api_client/v2/models/cost_currency_response.rb', line 25

def data
  @data
end