Class: DatadogAPIClient::V2::CostTagKeyMetadataAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CostTagKeyMetadataAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb
Overview
Attributes of a Cloud Cost Management tag key metadata entry.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#cardinality_by_account ⇒ Object
readonly
Number of unique tag values observed for this tag key, keyed by cloud account ID.
-
#cost_covered ⇒ Object
readonly
Total cost (in the report currency) of cost line items that carry this tag key for the requested period.
-
#date ⇒ Object
The day this row corresponds to, in ‘YYYY-MM-DD` format.
-
#metric ⇒ Object
readonly
The Cloud Cost Management metric this row aggregates, for example ‘aws.cost.net.amortized`.
-
#row_count ⇒ Object
readonly
Number of cost rows that carry this tag key over the requested period.
-
#tag_sources ⇒ Object
readonly
Origins where this tag key was observed (for example, ‘aws-user-defined`).
-
#top_values_by_account ⇒ Object
readonly
A sample of the most frequent tag values observed for this tag key, keyed by cloud account ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 45 def additional_properties @additional_properties end |
#cardinality_by_account ⇒ Object
Number of unique tag values observed for this tag key, keyed by cloud account ID.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 25 def cardinality_by_account @cardinality_by_account end |
#cost_covered ⇒ Object
Total cost (in the report currency) of cost line items that carry this tag key for the requested period.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 28 def cost_covered @cost_covered end |
#date ⇒ Object
The day this row corresponds to, in ‘YYYY-MM-DD` format. Present only when `filter=true`; omitted for the monthly roll-up returned by default.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 31 def date @date end |
#metric ⇒ Object
The Cloud Cost Management metric this row aggregates, for example ‘aws.cost.net.amortized`.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 34 def metric @metric end |
#row_count ⇒ Object
Number of cost rows that carry this tag key over the requested period.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 37 def row_count @row_count end |
#tag_sources ⇒ Object
Origins where this tag key was observed (for example, ‘aws-user-defined`).
40 41 42 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 40 def tag_sources @tag_sources end |
#top_values_by_account ⇒ Object
A sample of the most frequent tag values observed for this tag key, keyed by cloud account ID.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/cost_tag_key_metadata_attributes.rb', line 43 def top_values_by_account @top_values_by_account end |