Class: DatadogAPIClient::V2::CreateDegradationTemplateRequestDataAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/create_degradation_template_request_data_attributes.rb

Overview

The attributes for creating a degradation template.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



36
37
38
# File 'lib/datadog_api_client/v2/models/create_degradation_template_request_data_attributes.rb', line 36

def additional_properties
  @additional_properties
end

#components_affectedObject

The components affected by a degradation created from this template.



25
26
27
# File 'lib/datadog_api_client/v2/models/create_degradation_template_request_data_attributes.rb', line 25

def components_affected
  @components_affected
end

#degradation_titleObject

The title used for a degradation created from this template.



28
29
30
# File 'lib/datadog_api_client/v2/models/create_degradation_template_request_data_attributes.rb', line 28

def degradation_title
  @degradation_title
end

#nameObject

The name of the degradation template.



31
32
33
# File 'lib/datadog_api_client/v2/models/create_degradation_template_request_data_attributes.rb', line 31

def name
  @name
end

#updatesObject

The pre-filled updates for a degradation created from this template.



34
35
36
# File 'lib/datadog_api_client/v2/models/create_degradation_template_request_data_attributes.rb', line 34

def updates
  @updates
end