Class: DatadogAPIClient::V2::CustomCostListResponseMeta

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/custom_cost_list_response_meta.rb

Overview

Meta for the response from the List Custom Costs endpoints.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



36
37
38
# File 'lib/datadog_api_client/v2/models/custom_cost_list_response_meta.rb', line 36

def additional_properties
  @additional_properties
end

#count_by_statusObject

Number of Custom Costs files per status.



25
26
27
# File 'lib/datadog_api_client/v2/models/custom_cost_list_response_meta.rb', line 25

def count_by_status
  @count_by_status
end

#providersObject

List of available providers.



28
29
30
# File 'lib/datadog_api_client/v2/models/custom_cost_list_response_meta.rb', line 28

def providers
  @providers
end

#total_filtered_countObject

Number of Custom Costs files returned by the List Custom Costs endpoint



31
32
33
# File 'lib/datadog_api_client/v2/models/custom_cost_list_response_meta.rb', line 31

def total_filtered_count
  @total_filtered_count
end

#versionObject

Version of Custom Costs file



34
35
36
# File 'lib/datadog_api_client/v2/models/custom_cost_list_response_meta.rb', line 34

def version
  @version
end