Class: DatadogAPIClient::V2::CustomDestinationForwardDestinationSplunk

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/custom_destination_forward_destination_splunk.rb

Overview

The Splunk HTTP Event Collector (HEC) destination.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#access_tokenObject

Access token of the Splunk HTTP Event Collector. This field is not returned by the API.



25
26
27
# File 'lib/datadog_api_client/v2/models/custom_destination_forward_destination_splunk.rb', line 25

def access_token
  @access_token
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



42
43
44
# File 'lib/datadog_api_client/v2/models/custom_destination_forward_destination_splunk.rb', line 42

def additional_properties
  @additional_properties
end

#endpointObject

The destination for which logs will be forwarded to. Must have HTTPS scheme and forwarding back to Datadog is not allowed.



29
30
31
# File 'lib/datadog_api_client/v2/models/custom_destination_forward_destination_splunk.rb', line 29

def endpoint
  @endpoint
end

#sourcetypeObject

The Splunk sourcetype for the events sent to this Splunk destination.

If the field is absent from the request and no sourcetype has been previously set on this destination, the default sourcetype ‘_json` is used. On update, if the field is absent from the request but a sourcetype was previously set, the previous value is kept. If set to `null`, the sourcetype field is omitted from the forwarded event entirely. Otherwise, the provided string value is used as the sourcetype.



37
38
39
# File 'lib/datadog_api_client/v2/models/custom_destination_forward_destination_splunk.rb', line 37

def sourcetype
  @sourcetype
end

#typeObject

Type of the Splunk HTTP Event Collector (HEC) destination.



40
41
42
# File 'lib/datadog_api_client/v2/models/custom_destination_forward_destination_splunk.rb', line 40

def type
  @type
end