Class: DatadogAPIClient::V2::CustomerOrgAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CustomerOrgAPI
- Defined in:
- lib/datadog_api_client/v2/api/customer_org_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#disable_customer_org(body, opts = {}) ⇒ Object
Disable the authenticated customer organization.
-
#disable_customer_org_with_http_info(body, opts = {}) ⇒ Array<(CustomerOrgDisableResponse, Integer, Hash)>
Disable the authenticated customer organization.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ CustomerOrgAPI
constructor
A new instance of CustomerOrgAPI.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ CustomerOrgAPI
Returns a new instance of CustomerOrgAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/customer_org_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/customer_org_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#disable_customer_org(body, opts = {}) ⇒ Object
Disable the authenticated customer organization.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/customer_org_api.rb', line 29 def disable_customer_org(body, opts = {}) data, _status_code, _headers = disable_customer_org_with_http_info(body, opts) data end |
#disable_customer_org_with_http_info(body, opts = {}) ⇒ Array<(CustomerOrgDisableResponse, Integer, Hash)>
Disable the authenticated customer organization.
Disable the Datadog organization associated with the authenticated user or API key. The request body uses JSON:API format. If ‘org_uuid` is supplied, it must match the authenticated org or the request is rejected. Successful calls disable the org and return the resulting state from the downstream service. Requires the `org_management` permission.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/datadog_api_client/v2/api/customer_org_api.rb', line 45 def disable_customer_org_with_http_info(body, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.disable_customer_org".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.disable_customer_org") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.disable_customer_org")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: CustomerOrgAPI.disable_customer_org ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling CustomerOrgAPI.disable_customer_org" end # resource path local_var_path = '/api/v2/org/disable' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'CustomerOrgDisableResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :disable_customer_org, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: CustomerOrgAPI#disable_customer_org\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |