Class: DatadogAPIClient::V2::DORADeploymentPatchRequestAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/dora_deployment_patch_request_attributes.rb

Overview

Attributes for patching a DORA deployment event.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



30
31
32
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_request_attributes.rb', line 30

def additional_properties
  @additional_properties
end

#change_failureObject

Indicates whether the deployment resulted in a change failure.



25
26
27
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_request_attributes.rb', line 25

def change_failure
  @change_failure
end

#remediationObject

Remediation details for the deployment. Optional, but required to calculate failed deployment recovery time. Specify either id or version to identify the remediation deployment, but not both.



28
29
30
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_request_attributes.rb', line 28

def remediation
  @remediation
end