Class: DatadogAPIClient::V2::DashboardListItem
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DashboardListItem
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/dashboard_list_item.rb
Overview
A dashboard within a list.
Instance Attribute Summary collapse
-
#author ⇒ Object
Creator of the object.
-
#created ⇒ Object
Date of creation of the dashboard.
-
#icon ⇒ Object
URL to the icon of the dashboard.
-
#id ⇒ Object
readonly
ID of the dashboard.
-
#is_favorite ⇒ Object
Whether or not the dashboard is in the favorites.
-
#is_read_only ⇒ Object
Whether or not the dashboard is read only.
-
#is_shared ⇒ Object
Whether the dashboard is publicly shared or not.
-
#modified ⇒ Object
Date of last edition of the dashboard.
-
#popularity ⇒ Object
readonly
Popularity of the dashboard.
-
#title ⇒ Object
Title of the dashboard.
-
#type ⇒ Object
readonly
The type of the dashboard.
-
#url ⇒ Object
URL path to the dashboard.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#author ⇒ Object
Creator of the object.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 29 def end |
#created ⇒ Object
Date of creation of the dashboard.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 32 def created @created end |
#icon ⇒ Object
URL to the icon of the dashboard.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 35 def icon @icon end |
#id ⇒ Object
ID of the dashboard.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 38 def id @id end |
#is_favorite ⇒ Object
Whether or not the dashboard is in the favorites.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 41 def is_favorite @is_favorite end |
#is_read_only ⇒ Object
Whether or not the dashboard is read only.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 44 def is_read_only @is_read_only end |
#is_shared ⇒ Object
Whether the dashboard is publicly shared or not.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 47 def is_shared @is_shared end |
#modified ⇒ Object
Date of last edition of the dashboard.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 50 def modified @modified end |
#popularity ⇒ Object
Popularity of the dashboard.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 53 def popularity @popularity end |
#title ⇒ Object
Title of the dashboard.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 56 def title @title end |
#type ⇒ Object
The type of the dashboard.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 59 def type @type end |
#url ⇒ Object
URL path to the dashboard.
62 63 64 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_item.rb', line 62 def url @url end |