Class: DatadogAPIClient::V2::DataScalarColumn
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DataScalarColumn
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/data_scalar_column.rb
Overview
A column containing the numerical results for a formula or query.
Instance Attribute Summary collapse
-
#meta ⇒ Object
Metadata for the resulting numerical values.
-
#name ⇒ Object
The name referencing the formula or query for this column.
-
#type ⇒ Object
The type of column present.
-
#values ⇒ Object
The array of numerical values for one formula or query.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#meta ⇒ Object
Metadata for the resulting numerical values.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/data_scalar_column.rb', line 29 def end |
#name ⇒ Object
The name referencing the formula or query for this column.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/data_scalar_column.rb', line 32 def name @name end |
#type ⇒ Object
The type of column present.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/data_scalar_column.rb', line 35 def type @type end |
#values ⇒ Object
The array of numerical values for one formula or query.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/data_scalar_column.rb', line 38 def values @values end |