Class: DatadogAPIClient::V2::DeploymentGatesEvaluationRequestData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_data.rb

Overview

Data for a deployment gate evaluation request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



32
33
34
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_data.rb', line 32

def additional_properties
  @additional_properties
end

#attributesObject

Attributes for a deployment gate evaluation request. When configuration is provided, rules are evaluated inline from that configuration. When omitted, rules are resolved from the preconfigured gate for the given service and environment.



27
28
29
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_data.rb', line 27

def attributes
  @attributes
end

#typeObject

JSON:API type for a deployment gate evaluation request.



30
31
32
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_data.rb', line 30

def type
  @type
end