Module: DatadogAPIClient::V2::DeploymentGatesEvaluationRule

Extended by:
BaseOneOfModel
Defined in:
lib/datadog_api_client/v2/models/deployment_gates_evaluation_rule.rb

Overview

A rule to evaluate as part of a deployment gate evaluation.

Instance Attribute Summary

Attributes included from BaseOneOfModel

#_unparsed

Class Method Summary collapse

Class Method Details

.build(data) ⇒ Object

Builds the object

Parameters:

  • data (Mixed)

    Data to be matched against the list of oneOf items

Returns:

  • (Object)

    Returns the model or the data itself



40
41
42
43
44
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_rule.rb', line 40

def build(data)
  discriminator_value = data[openapi_discriminator_name]
  return nil unless discriminator_value

end

.openapi_discriminator_nameObject

Discriminator’s property name (OpenAPI v3)



33
34
35
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_rule.rb', line 33

def openapi_discriminator_name
  :'type'
end

.openapi_one_ofObject

List of class defined in oneOf (OpenAPI v3)



26
27
28
29
30
31
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_rule.rb', line 26

def openapi_one_of
  [
    :'DeploymentGatesMonitorRule',
    :'DeploymentGatesFDDRule'
  ]
end