Class: DatadogAPIClient::V2::DeploymentGatesFDDRule

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/deployment_gates_fdd_rule.rb

Overview

A faulty deployment detection rule to evaluate as part of a deployment gate evaluation.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



36
37
38
# File 'lib/datadog_api_client/v2/models/deployment_gates_fdd_rule.rb', line 36

def additional_properties
  @additional_properties
end

#dry_runObject

Rule-level dry run. When enabled, the rule is evaluated normally but it always returns ‘pass`. The real result is visible in the Datadog UI.



25
26
27
# File 'lib/datadog_api_client/v2/models/deployment_gates_fdd_rule.rb', line 25

def dry_run
  @dry_run
end

#nameObject

Human-readable name for this rule.



28
29
30
# File 'lib/datadog_api_client/v2/models/deployment_gates_fdd_rule.rb', line 28

def name
  @name
end

#optionsObject

Options for a ‘faulty_deployment_detection` rule.



31
32
33
# File 'lib/datadog_api_client/v2/models/deployment_gates_fdd_rule.rb', line 31

def options
  @options
end

#typeObject

The type identifier for a faulty deployment detection rule.



34
35
36
# File 'lib/datadog_api_client/v2/models/deployment_gates_fdd_rule.rb', line 34

def type
  @type
end