Class: DatadogAPIClient::V2::EventAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/event_attributes.rb

Overview

Object description of attributes from your event.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#aggregation_keyObject

Aggregation key of the event.



29
30
31
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 29

def aggregation_key
  @aggregation_key
end

#date_happenedObject

POSIX timestamp of the event. Must be sent as an integer (no quotation marks). Limited to events no older than 18 hours.



33
34
35
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 33

def date_happened
  @date_happened
end

#device_nameObject

A device name.



36
37
38
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 36

def device_name
  @device_name
end

#durationObject

The duration between the triggering of the event and its recovery in nanoseconds.



39
40
41
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 39

def duration
  @duration
end

#event_objectObject

The event title.



42
43
44
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 42

def event_object
  @event_object
end

#evtObject

The metadata associated with a request.



45
46
47
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 45

def evt
  @evt
end

#hostnameObject

Host name to associate with the event. Any tags associated with the host are also applied to this event.



49
50
51
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 49

def hostname
  @hostname
end

#monitorObject

Attributes from the monitor that triggered the event.



52
53
54
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 52

def monitor
  @monitor
end

#monitor_groupsObject

List of groups referred to in the event.



55
56
57
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 55

def monitor_groups
  @monitor_groups
end

#monitor_idObject

ID of the monitor that triggered the event. When an event isn’t related to a monitor, this field is empty.



58
59
60
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 58

def monitor_id
  @monitor_id
end

#priorityObject

The priority of the event’s monitor. For example, normal or low.



61
62
63
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 61

def priority
  @priority
end

Related event ID.



64
65
66
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 64

def related_event_id
  @related_event_id
end

#serviceObject

Service that triggered the event.



67
68
69
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 67

def service
  @service
end

#source_type_nameObject

The type of event being posted. For example, nagios, hudson, jenkins, my_apps, chef, puppet, git or bitbucket. The list of standard source attribute values is [available here](docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value).



72
73
74
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 72

def source_type_name
  @source_type_name
end

#sourcecategoryObject

Identifier for the source of the event, such as a monitor alert, an externally-submitted event, or an integration.



75
76
77
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 75

def sourcecategory
  @sourcecategory
end

#statusObject

If an alert event is enabled, its status is one of the following: failure, error, warning, info, success, user_update, recommendation, or snapshot.



80
81
82
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 80

def status
  @status
end

#tagsObject

A list of tags to apply to the event.



83
84
85
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 83

def tags
  @tags
end

#timestampObject

POSIX timestamp of your event in milliseconds.



86
87
88
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 86

def timestamp
  @timestamp
end

#titleObject

The event title.



89
90
91
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 89

def title
  @title
end