Class: DatadogAPIClient::V2::EventsCompute

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/events_compute.rb

Overview

The instructions for what to compute for this query.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#aggregationObject

The type of aggregation that can be performed on events-based queries.



29
30
31
# File 'lib/datadog_api_client/v2/models/events_compute.rb', line 29

def aggregation
  @aggregation
end

#intervalObject

Interval for compute in milliseconds.



32
33
34
# File 'lib/datadog_api_client/v2/models/events_compute.rb', line 32

def interval
  @interval
end

#metricObject

The “measure” attribute on which to perform the computation.



35
36
37
# File 'lib/datadog_api_client/v2/models/events_compute.rb', line 35

def metric
  @metric
end