Class: DatadogAPIClient::V2::EventsScalarQuery

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/events_scalar_query.rb

Overview

An individual scalar query for logs, RUM, traces, CI pipelines, security signals, and other event-based data sources. Use this query type for any data source powered by the Events Platform. See the data_source field for the full list of supported sources.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



45
46
47
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 45

def additional_properties
  @additional_properties
end

#computeObject

The instructions for what to compute for this query.



25
26
27
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 25

def compute
  @compute
end

#cross_org_uuidsObject

Organization UUIDs to query when using [cross-organization visibility](/account_management/org_settings/cross_org_visibility/). Limited to one organization UUID.



28
29
30
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 28

def cross_org_uuids
  @cross_org_uuids
end

#data_sourceObject

A data source that is powered by the Events Platform.



31
32
33
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 31

def data_source
  @data_source
end

#group_byObject

The list of facets on which to split results.



34
35
36
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 34

def group_by
  @group_by
end

#indexesObject

The indexes in which to search.



37
38
39
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 37

def indexes
  @indexes
end

#nameObject

The variable name for use in formulas.



40
41
42
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 40

def name
  @name
end

#searchObject

Configuration of the search/filter for an events query.



43
44
45
# File 'lib/datadog_api_client/v2/models/events_scalar_query.rb', line 43

def search
  @search
end