Class: DatadogAPIClient::V2::FlakyTestHistory
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FlakyTestHistory
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/flaky_test_history.rb
Overview
A single history entry representing a status change for a flaky test.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#commit_sha ⇒ Object
readonly
The commit SHA associated with this status change.
-
#policy_id ⇒ Object
The policy that triggered this status change.
-
#policy_meta ⇒ Object
Metadata about the policy that triggered this status change.
-
#status ⇒ Object
readonly
The test status at this point in history.
-
#timestamp ⇒ Object
readonly
Unix timestamp in milliseconds when this status change occurred.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/flaky_test_history.rb', line 39 def additional_properties @additional_properties end |
#commit_sha ⇒ Object
The commit SHA associated with this status change. Will be an empty string if the commit SHA is not available.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/flaky_test_history.rb', line 25 def commit_sha @commit_sha end |
#policy_id ⇒ Object
The policy that triggered this status change.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/flaky_test_history.rb', line 28 def policy_id @policy_id end |
#policy_meta ⇒ Object
Metadata about the policy that triggered this status change.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/flaky_test_history.rb', line 31 def @policy_meta end |
#status ⇒ Object
The test status at this point in history.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/flaky_test_history.rb', line 34 def status @status end |
#timestamp ⇒ Object
Unix timestamp in milliseconds when this status change occurred.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/flaky_test_history.rb', line 37 def @timestamp end |