Class: DatadogAPIClient::V2::FlakyTestsSearchFilter

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/flaky_tests_search_filter.rb

Overview

Search filter settings.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



42
43
44
# File 'lib/datadog_api_client/v2/models/flaky_tests_search_filter.rb', line 42

def additional_properties
  @additional_properties
end

#include_historyObject

Whether to include the status change history for each flaky test in the response. When set to true, each test will include a ‘history` array with chronological status changes. Defaults to false.



27
28
29
# File 'lib/datadog_api_client/v2/models/flaky_tests_search_filter.rb', line 27

def include_history
  @include_history
end

#queryObject

Search query following log syntax used to filter flaky tests, same as on Flaky Tests Management UI. The supported search keys are:

  • ‘flaky_test_state`

  • ‘flaky_test_category`

  • ‘@test.name`

  • ‘@test.suite`

  • ‘@test.module`

  • ‘@test.service`

  • ‘@git.repository.id_v2`

  • ‘@git.branch`

  • ‘@test.codeowners`

  • ‘env`



40
41
42
# File 'lib/datadog_api_client/v2/models/flaky_tests_search_filter.rb', line 40

def query
  @query
end