Class: DatadogAPIClient::V2::FleetAgentInfoDetailsV2
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetAgentInfoDetailsV2
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb
Overview
Detailed information about a Datadog Agent.
Instance Attribute Summary collapse
-
#active_ha_agent ⇒ Object
The currently active agent in the high-availability group.
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#agent_version ⇒ Object
The Datadog Agent version.
-
#api_key_name ⇒ Object
The API key name (if available and not redacted).
-
#api_key_uuid ⇒ Object
The API key UUID.
-
#cloud_provider ⇒ Object
The cloud provider where the agent is running.
-
#cluster_name ⇒ Object
Kubernetes cluster name (if applicable).
-
#config_id ⇒ Object
The configuration identifier applied to the agent.
-
#datadog_agent_key ⇒ Object
The unique agent key identifier.
-
#datadog_data_center ⇒ Object
The Datadog data center the agent reports to.
-
#ecs_fargate_cluster_name ⇒ Object
The ECS Fargate cluster name, if the agent runs in an ECS Fargate environment.
-
#ecs_fargate_task_arn ⇒ Object
The ECS Fargate task ARN, if the agent runs in an ECS Fargate environment.
-
#enabled_products ⇒ Object
Datadog products enabled on the agent.
-
#env ⇒ Object
Environments the agent is reporting from.
-
#first_seen_at ⇒ Object
Timestamp when the agent was first seen.
-
#ha_agent_hosts ⇒ Object
Hosts participating in the agent's high-availability group.
-
#ha_agent_state ⇒ Object
The high-availability state of the agent.
-
#hostname ⇒ Object
The hostname of the agent.
-
#hostname_aliases ⇒ Object
Alternative hostname list for the agent.
-
#install_method_installer_version ⇒ Object
The version of the installer used.
-
#install_method_tool ⇒ Object
The tool used to install the agent.
-
#ip_addresses ⇒ Object
IP addresses of the agent.
-
#is_single_step_instrumentation_enabled ⇒ Object
Whether single-step instrumentation is enabled.
-
#last_restart_at ⇒ Object
Timestamp of the last agent restart.
-
#os ⇒ Object
The operating system.
-
#os_version ⇒ Object
The operating system version.
-
#otel_collector_deployment_types ⇒ Object
OpenTelemetry collector deployment types associated with the agent.
-
#otel_collector_distributions ⇒ Object
OpenTelemetry collector distributions associated with the agent.
-
#otel_collector_versions ⇒ Object
List of OpenTelemetry collector versions (if applicable).
-
#otel_collectors ⇒ Object
OpenTelemetry collectors associated with the agent (if applicable).
-
#otel_resource_attributes ⇒ Object
OpenTelemetry resource attributes reported by the agent.
-
#pod_name ⇒ Object
Kubernetes pod name (if applicable).
-
#preferred_ha_active_agent ⇒ Object
The preferred active agent in the high-availability group.
-
#python_version ⇒ Object
The Python version used by the agent.
-
#region ⇒ Object
Regions where the agent is running.
-
#remote_agent_management ⇒ Object
Remote agent management status.
-
#remote_config_status ⇒ Object
Remote configuration status.
-
#services ⇒ Object
Services running on the agent.
-
#support_agent_upgrade ⇒ Object
Whether the agent supports remote agent upgrade.
-
#tags ⇒ Object
Tags associated with the agent.
-
#team ⇒ Object
Team associated with the agent.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#active_ha_agent ⇒ Object
The currently active agent in the high-availability group.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 25 def active_ha_agent @active_ha_agent end |
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
144 145 146 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 144 def additional_properties @additional_properties end |
#agent_version ⇒ Object
The Datadog Agent version.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 28 def agent_version @agent_version end |
#api_key_name ⇒ Object
The API key name (if available and not redacted).
31 32 33 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 31 def api_key_name @api_key_name end |
#api_key_uuid ⇒ Object
The API key UUID.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 34 def api_key_uuid @api_key_uuid end |
#cloud_provider ⇒ Object
The cloud provider where the agent is running.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 37 def cloud_provider @cloud_provider end |
#cluster_name ⇒ Object
Kubernetes cluster name (if applicable).
40 41 42 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 40 def cluster_name @cluster_name end |
#config_id ⇒ Object
The configuration identifier applied to the agent.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 43 def config_id @config_id end |
#datadog_agent_key ⇒ Object
The unique agent key identifier.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 46 def datadog_agent_key @datadog_agent_key end |
#datadog_data_center ⇒ Object
The Datadog data center the agent reports to.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 49 def datadog_data_center @datadog_data_center end |
#ecs_fargate_cluster_name ⇒ Object
The ECS Fargate cluster name, if the agent runs in an ECS Fargate environment.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 52 def ecs_fargate_cluster_name @ecs_fargate_cluster_name end |
#ecs_fargate_task_arn ⇒ Object
The ECS Fargate task ARN, if the agent runs in an ECS Fargate environment.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 55 def ecs_fargate_task_arn @ecs_fargate_task_arn end |
#enabled_products ⇒ Object
Datadog products enabled on the agent.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 58 def enabled_products @enabled_products end |
#env ⇒ Object
Environments the agent is reporting from.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 61 def env @env end |
#first_seen_at ⇒ Object
Timestamp when the agent was first seen.
64 65 66 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 64 def first_seen_at @first_seen_at end |
#ha_agent_hosts ⇒ Object
Hosts participating in the agent's high-availability group.
67 68 69 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 67 def ha_agent_hosts @ha_agent_hosts end |
#ha_agent_state ⇒ Object
The high-availability state of the agent.
70 71 72 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 70 def ha_agent_state @ha_agent_state end |
#hostname ⇒ Object
The hostname of the agent.
73 74 75 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 73 def hostname @hostname end |
#hostname_aliases ⇒ Object
Alternative hostname list for the agent.
76 77 78 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 76 def hostname_aliases @hostname_aliases end |
#install_method_installer_version ⇒ Object
The version of the installer used.
79 80 81 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 79 def install_method_installer_version @install_method_installer_version end |
#install_method_tool ⇒ Object
The tool used to install the agent.
82 83 84 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 82 def install_method_tool @install_method_tool end |
#ip_addresses ⇒ Object
IP addresses of the agent.
85 86 87 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 85 def ip_addresses @ip_addresses end |
#is_single_step_instrumentation_enabled ⇒ Object
Whether single-step instrumentation is enabled.
88 89 90 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 88 def is_single_step_instrumentation_enabled @is_single_step_instrumentation_enabled end |
#last_restart_at ⇒ Object
Timestamp of the last agent restart.
91 92 93 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 91 def last_restart_at @last_restart_at end |
#os ⇒ Object
The operating system.
94 95 96 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 94 def os @os end |
#os_version ⇒ Object
The operating system version.
97 98 99 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 97 def os_version @os_version end |
#otel_collector_deployment_types ⇒ Object
OpenTelemetry collector deployment types associated with the agent.
100 101 102 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 100 def otel_collector_deployment_types @otel_collector_deployment_types end |
#otel_collector_distributions ⇒ Object
OpenTelemetry collector distributions associated with the agent.
103 104 105 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 103 def otel_collector_distributions @otel_collector_distributions end |
#otel_collector_versions ⇒ Object
List of OpenTelemetry collector versions (if applicable).
106 107 108 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 106 def otel_collector_versions @otel_collector_versions end |
#otel_collectors ⇒ Object
OpenTelemetry collectors associated with the agent (if applicable).
109 110 111 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 109 def otel_collectors @otel_collectors end |
#otel_resource_attributes ⇒ Object
OpenTelemetry resource attributes reported by the agent.
112 113 114 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 112 def otel_resource_attributes @otel_resource_attributes end |
#pod_name ⇒ Object
Kubernetes pod name (if applicable).
115 116 117 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 115 def pod_name @pod_name end |
#preferred_ha_active_agent ⇒ Object
The preferred active agent in the high-availability group.
118 119 120 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 118 def preferred_ha_active_agent @preferred_ha_active_agent end |
#python_version ⇒ Object
The Python version used by the agent.
121 122 123 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 121 def python_version @python_version end |
#region ⇒ Object
Regions where the agent is running.
124 125 126 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 124 def region @region end |
#remote_agent_management ⇒ Object
Remote agent management status.
127 128 129 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 127 def remote_agent_management @remote_agent_management end |
#remote_config_status ⇒ Object
Remote configuration status.
130 131 132 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 130 def remote_config_status @remote_config_status end |
#services ⇒ Object
Services running on the agent.
133 134 135 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 133 def services @services end |
#support_agent_upgrade ⇒ Object
Whether the agent supports remote agent upgrade.
136 137 138 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 136 def support_agent_upgrade @support_agent_upgrade end |
#tags ⇒ Object
Tags associated with the agent.
139 140 141 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 139 def @tags end |
#team ⇒ Object
Team associated with the agent.
142 143 144 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_info_details_v2.rb', line 142 def team @team end |