Class: DatadogAPIClient::V2::FleetClusterAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb

Overview

Attributes of a Kubernetes cluster in the fleet.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



75
76
77
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 75

def additional_properties
  @additional_properties
end

#agent_versionsObject

Datadog Agent versions running in the cluster.



25
26
27
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 25

def agent_versions
  @agent_versions
end

#api_key_namesObject

API key names used by agents in the cluster.



28
29
30
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 28

def api_key_names
  @api_key_names
end

#api_key_uuidsObject

API key UUIDs used by agents in the cluster.



31
32
33
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 31

def api_key_uuids
  @api_key_uuids
end

#cloud_providersObject

Cloud providers hosting the cluster.



34
35
36
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 34

def cloud_providers
  @cloud_providers
end

#cluster_nameObject

The name of the Kubernetes cluster.



37
38
39
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 37

def cluster_name
  @cluster_name
end

#enabled_productsObject

Datadog products enabled in the cluster.



40
41
42
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 40

def enabled_products
  @enabled_products
end

#envsObject

Environments associated with the cluster.



43
44
45
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 43

def envs
  @envs
end

#first_seen_atObject

Timestamp when the cluster was first seen.



46
47
48
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 46

def first_seen_at
  @first_seen_at
end

#install_method_toolObject

The tool used to install agents in the cluster.



49
50
51
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 49

def install_method_tool
  @install_method_tool
end

#node_countObject

Total number of nodes in the cluster.



52
53
54
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 52

def node_count
  @node_count
end

#node_count_by_statusObject

Node counts grouped by status.



55
56
57
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 55

def node_count_by_status
  @node_count_by_status
end

#operating_systemsObject

Operating systems of nodes in the cluster.



58
59
60
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 58

def operating_systems
  @operating_systems
end

#otel_collector_distributionsObject

OpenTelemetry collector distributions in the cluster.



61
62
63
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 61

def otel_collector_distributions
  @otel_collector_distributions
end

#otel_collector_versionsObject

OpenTelemetry collector versions in the cluster.



64
65
66
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 64

def otel_collector_versions
  @otel_collector_versions
end

#pod_count_by_stateObject

Pod counts grouped by state.



67
68
69
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 67

def pod_count_by_state
  @pod_count_by_state
end

#servicesObject

Services running in the cluster.



70
71
72
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 70

def services
  @services
end

#teamsObject

Teams associated with the cluster.



73
74
75
# File 'lib/datadog_api_client/v2/models/fleet_cluster_attributes.rb', line 73

def teams
  @teams
end