Class: DatadogAPIClient::V2::FleetDeploymentConfigureV2DryRunAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetDeploymentConfigureV2DryRunAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_attributes.rb
Overview
Attributes of a configuration deployment dry-run response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#dry_run ⇒ Object
Validation result of a configuration deployment dry run.
-
#query ⇒ Object
Query used to filter and select target hosts for the deployment.
-
#total_hosts ⇒ Object
Total number of hosts targeted by this deployment.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_attributes.rb', line 33 def additional_properties @additional_properties end |
#dry_run ⇒ Object
Validation result of a configuration deployment dry run.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_attributes.rb', line 25 def dry_run @dry_run end |
#query ⇒ Object
Query used to filter and select target hosts for the deployment.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_attributes.rb', line 28 def query @query end |
#total_hosts ⇒ Object
Total number of hosts targeted by this deployment.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_attributes.rb', line 31 def total_hosts @total_hosts end |