Class: DatadogAPIClient::V2::FleetDeploymentConfigureV2DryRunResult

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_result.rb

Overview

Validation result of a configuration deployment dry run.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



34
35
36
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_result.rb', line 34

def additional_properties
  @additional_properties
end

#config_validatedObject

Whether the configuration passed schema validation.



25
26
27
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_result.rb', line 25

def config_validated
  @config_validated
end

#non_upgradable_by_reasonObject

Breakdown of ineligible host counts by reason. Only includes reasons with a non-zero count. Absent from the response when no targeted host is ineligible.



29
30
31
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_result.rb', line 29

def non_upgradable_by_reason
  @non_upgradable_by_reason
end

#non_upgradable_hostsObject

Number of targeted hosts that are not eligible to receive this configuration.



32
33
34
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_dry_run_result.rb', line 32

def non_upgradable_hosts
  @non_upgradable_hosts
end