Class: DatadogAPIClient::V2::FleetIntegrationDetailsV2
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetIntegrationDetailsV2
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb
Overview
Detailed information about a single integration.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#data_type ⇒ Object
Type of data collected, such as metrics or logs.
-
#error_messages ⇒ Object
Error messages if the integration has issues.
-
#init_config ⇒ Object
Initialization configuration (YAML format).
-
#instance_config ⇒ Object
Instance-specific configuration (YAML format).
-
#is_custom_check ⇒ Object
Whether this is a custom integration.
-
#is_default ⇒ Object
Whether this is a default integration instance.
-
#is_init ⇒ Object
Whether this integration configuration is an init config.
-
#log_config ⇒ Object
Log collection configuration (YAML format).
-
#name ⇒ Object
Name of the integration instance.
-
#pod_count ⇒ Object
Number of pods running this integration.
-
#source_index ⇒ Object
Index in the configuration file.
-
#source_path ⇒ Object
Path to the configuration file.
-
#type ⇒ Object
Integration type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
63 64 65 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 63 def additional_properties @additional_properties end |
#data_type ⇒ Object
Type of data collected, such as metrics or logs.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 25 def data_type @data_type end |
#error_messages ⇒ Object
Error messages if the integration has issues.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 28 def @error_messages end |
#init_config ⇒ Object
Initialization configuration (YAML format).
31 32 33 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 31 def init_config @init_config end |
#instance_config ⇒ Object
Instance-specific configuration (YAML format).
34 35 36 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 34 def instance_config @instance_config end |
#is_custom_check ⇒ Object
Whether this is a custom integration.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 37 def is_custom_check @is_custom_check end |
#is_default ⇒ Object
Whether this is a default integration instance.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 40 def is_default @is_default end |
#is_init ⇒ Object
Whether this integration configuration is an init config.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 43 def is_init @is_init end |
#log_config ⇒ Object
Log collection configuration (YAML format).
46 47 48 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 46 def log_config @log_config end |
#name ⇒ Object
Name of the integration instance.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 49 def name @name end |
#pod_count ⇒ Object
Number of pods running this integration. Absent from the response when the count is zero.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 52 def pod_count @pod_count end |
#source_index ⇒ Object
Index in the configuration file.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 55 def source_index @source_index end |
#source_path ⇒ Object
Path to the configuration file.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 58 def source_path @source_path end |
#type ⇒ Object
Integration type.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/fleet_integration_details_v2.rb', line 61 def type @type end |