Class: DatadogAPIClient::V2::FleetScheduleV2Attributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb

Overview

Attributes of a fleet schedule in the v2 API response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



70
71
72
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 70

def additional_properties
  @additional_properties
end

#created_atObject

RFC3339 timestamp when the schedule was created.



25
26
27
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 25

def created_at
  @created_at
end

#created_byObject

User handle of the person who created the schedule.



28
29
30
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 28

def created_by
  @created_by
end

#is_defaultObject

Whether this is the default schedule for the organization.



31
32
33
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 31

def is_default
  @is_default
end

#nameObject

Human-readable name for the schedule.



34
35
36
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 34

def name
  @name
end

#next_runObject

RFC3339 timestamp of the next scheduled maintenance window start time. Absent when the next run time cannot be computed.



38
39
40
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 38

def next_run
  @next_run
end

#notification_ruleObject

Notification configuration attached to a schedule.

Included when available. If the notification rule cannot be retrieved, this field is omitted and the schedule is still returned. If the notification rule is retrieved but its handles cannot be resolved, it is still included with an empty handles array.



45
46
47
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 45

def notification_rule
  @notification_rule
end

#queryObject

Query used to filter and select target hosts for scheduled deployments.



48
49
50
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 48

def query
  @query
end

#ruleObject

Defines the recurrence pattern for the schedule.



51
52
53
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 51

def rule
  @rule
end

#statusObject

The status of the schedule.

  • active: The schedule is active and will create deployments according to its recurrence rule.
  • inactive: The schedule is inactive and will not create any deployments.


56
57
58
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 56

def status
  @status
end

#updated_atObject

RFC3339 timestamp when the schedule was last updated.



59
60
61
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 59

def updated_at
  @updated_at
end

#updated_byObject

User handle of the person who last updated the schedule.



62
63
64
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 62

def updated_by
  @updated_by
end

#version_to_latestObject

Number of major versions behind the latest to target for upgrades.

  • 0: Always upgrade to the latest version.
  • 1: Upgrade to latest minus 1 major version.
  • 2: Upgrade to latest minus 2 major versions.


68
69
70
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_attributes.rb', line 68

def version_to_latest
  @version_to_latest
end