Class: DatadogAPIClient::V2::FleetScheduleV2NotificationRule

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/fleet_schedule_v2_notification_rule.rb

Overview

Notification configuration attached to a schedule.

Included when available. If the notification rule cannot be retrieved, this field is omitted and the schedule is still returned. If the notification rule is retrieved but its handles cannot be resolved, it is still included with an empty handles array.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



34
35
36
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_notification_rule.rb', line 34

def additional_properties
  @additional_properties
end

#handlesObject

Notification handles (for example, Slack channels or PagerDuty integrations).



29
30
31
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_notification_rule.rb', line 29

def handles
  @handles
end

#tagsObject

Tags associated with the notification rule.



32
33
34
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_notification_rule.rb', line 32

def tags
  @tags
end