Class: DatadogAPIClient::V2::FleetScheduleV2RecurrenceRule

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb

Overview

Defines the recurrence pattern for the schedule.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



42
43
44
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb', line 42

def additional_properties
  @additional_properties
end

#days_of_weekObject

Days of the week when the schedule triggers. Valid values are "Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun".



26
27
28
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb', line 26

def days_of_week
  @days_of_week
end

#intervalObject

Interval between schedule runs in weeks. 1 means the schedule runs every week on the specified days. Higher values repeat every N weeks.



30
31
32
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb', line 30

def interval
  @interval
end

#maintenance_window_durationObject

Duration of the maintenance window in minutes.



33
34
35
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb', line 33

def maintenance_window_duration
  @maintenance_window_duration
end

#start_maintenance_windowObject

Start time of the maintenance window in 24-hour clock format (HHMM). Deployments are triggered at this time on the specified days.



37
38
39
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb', line 37

def start_maintenance_window
  @start_maintenance_window
end

#timezoneObject

Timezone in IANA Time Zone Database format.



40
41
42
# File 'lib/datadog_api_client/v2/models/fleet_schedule_v2_recurrence_rule.rb', line 40

def timezone
  @timezone
end