Class: DatadogAPIClient::V2::GovernanceConfigAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_config_attributes.rb

Overview

The attributes of a Governance Console configuration.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



37
38
39
# File 'lib/datadog_api_client/v2/models/governance_config_attributes.rb', line 37

def additional_properties
  @additional_properties
end

#assignment_notifications_enabledObject

Whether notifications are sent to users when detections are assigned to them.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_config_attributes.rb', line 25

def assignment_notifications_enabled
  @assignment_notifications_enabled
end

#enabledObject

Whether the Governance Console is enabled for the organization.



28
29
30
# File 'lib/datadog_api_client/v2/models/governance_config_attributes.rb', line 28

def enabled
  @enabled
end

#usage_attribution_configuredObject

Whether usage attribution is configured for the organization.



31
32
33
# File 'lib/datadog_api_client/v2/models/governance_config_attributes.rb', line 31

def usage_attribution_configured
  @usage_attribution_configured
end

#xorg_insights_enabledObject

Whether the organization has opted in to sharing governance data with a managing org for cross-org insights.



35
36
37
# File 'lib/datadog_api_client/v2/models/governance_config_attributes.rb', line 35

def xorg_insights_enabled
  @xorg_insights_enabled
end