Class: DatadogAPIClient::V2::GovernanceConfigData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_config_data.rb

Overview

A Governance Console configuration resource.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



35
36
37
# File 'lib/datadog_api_client/v2/models/governance_config_data.rb', line 35

def additional_properties
  @additional_properties
end

#attributesObject

The attributes of a Governance Console configuration.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_config_data.rb', line 25

def attributes
  @attributes
end

#idObject

The unique identifier of the organization the Governance Console configuration applies to. May be the nil UUID (00000000-0000-0000-0000-000000000000) when the configuration is not tied to a specific organization record.



30
31
32
# File 'lib/datadog_api_client/v2/models/governance_config_data.rb', line 30

def id
  @id
end

#typeObject

Governance console config resource type.



33
34
35
# File 'lib/datadog_api_client/v2/models/governance_config_data.rb', line 33

def type
  @type
end