Class: DatadogAPIClient::V2::GovernanceControlAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_control_attributes.rb

Overview

The attributes of a governance control.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#active_detections_countObject

The number of active detections for the control.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 25

def active_detections_count
  @active_detections_count
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



84
85
86
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 84

def additional_properties
  @additional_properties
end

#categoryObject

The value driver the control is grouped under, such as security or cost.



28
29
30
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 28

def category
  @category
end

#created_atObject

The time the control configuration was created.



31
32
33
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 31

def created_at
  @created_at
end

#created_byObject

The UUID of the user who created the control configuration.



34
35
36
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 34

def created_by
  @created_by
end

#descriptionObject

A human-readable description of what the control detects.



37
38
39
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 37

def description
  @description
end

#detection_frequencyObject

How often detections are evaluated for the control.



40
41
42
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 40

def detection_frequency
  @detection_frequency
end

#detection_parametersObject

A free-form map of parameter names to their configured values.



43
44
45
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 43

def detection_parameters
  @detection_parameters
end

#insightsObject

The insight slugs associated with the control.



46
47
48
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 46

def insights
  @insights
end

#last_detection_atObject

The time of the most recent detection for the control. null when there are no detections.



49
50
51
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 49

def last_detection_at
  @last_detection_at
end

#mitigated_detections_countObject

The number of mitigated detections for the control.



52
53
54
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 52

def mitigated_detections_count
  @mitigated_detections_count
end

#mitigation_parametersObject

A free-form map of parameter names to their configured values.



55
56
57
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 55

def mitigation_parameters
  @mitigation_parameters
end

#mitigation_typeObject

The configured mitigation type for the control. Empty when not configured.



58
59
60
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 58

def mitigation_type
  @mitigation_type
end

#mitigationsObject

The mitigations available for a control.



61
62
63
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 61

def mitigations
  @mitigations
end

#nameObject

Human-readable name of the control.



64
65
66
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 64

def name
  @name
end

#priorityObject

The priority of the control, such as High.



67
68
69
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 67

def priority
  @priority
end

#productObject

The product the control belongs to.



70
71
72
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 70

def product
  @product
end

#resource_typeObject

The type of resource the control evaluates.



73
74
75
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 73

def resource_type
  @resource_type
end

#resource_type_display_nameObject

The human-readable name of the resource type.



76
77
78
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 76

def resource_type_display_name
  @resource_type_display_name
end

#supported_detection_parametersObject

An array of parameter definitions.



79
80
81
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 79

def supported_detection_parameters
  @supported_detection_parameters
end

#typeObject

The control type, such as Proactive or Detection.



82
83
84
# File 'lib/datadog_api_client/v2/models/governance_control_attributes.rb', line 82

def type
  @type
end