Class: DatadogAPIClient::V2::GovernanceControlDetectionUpdateData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_control_detection_update_data.rb

Overview

The data of a governance control detection update request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



30
31
32
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_data.rb', line 30

def additional_properties
  @additional_properties
end

#attributesObject

The attributes of a governance control detection that can be updated. Only the attributes present in the request are modified.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_data.rb', line 25

def attributes
  @attributes
end

#typeObject

Governance control detection resource type.



28
29
30
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_data.rb', line 28

def type
  @type
end