Class: DatadogAPIClient::V2::GovernanceControlDetectionUpdateState

Inherits:
Object
  • Object
show all
Includes:
BaseEnumModel
Defined in:
lib/datadog_api_client/v2/models/governance_control_detection_update_state.rb

Overview

The new state to set for the detection. Set to exception to acknowledge the detection and exclude it from active counts, or active to reopen it.

Constant Summary collapse

EXCEPTION =
"exception".freeze
ACTIVE =
"active".freeze

Method Summary

Methods included from BaseEnumModel

included