Class: DatadogAPIClient::V2::GovernanceControlMitigationDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::GovernanceControlMitigationDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb
Overview
The definition of a mitigation available for a control.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#description ⇒ Object
readonly
A human-readable description of the mitigation.
-
#execution_modes ⇒ Object
readonly
The execution modes the mitigation supports, such as
manualorautomatic. -
#id ⇒ Object
readonly
The unique identifier of the mitigation.
-
#permissions ⇒ Object
readonly
The permissions required to apply the mitigation.
-
#supported_parameters ⇒ Object
readonly
An array of parameter definitions.
-
#title ⇒ Object
readonly
A short, human-readable name for the mitigation.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 42 def additional_properties @additional_properties end |
#description ⇒ Object
A human-readable description of the mitigation.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 25 def description @description end |
#execution_modes ⇒ Object
The execution modes the mitigation supports, such as manual or automatic.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 28 def execution_modes @execution_modes end |
#id ⇒ Object
The unique identifier of the mitigation.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 31 def id @id end |
#permissions ⇒ Object
The permissions required to apply the mitigation.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 34 def @permissions end |
#supported_parameters ⇒ Object
An array of parameter definitions.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 37 def supported_parameters @supported_parameters end |
#title ⇒ Object
A short, human-readable name for the mitigation.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/governance_control_mitigation_definition.rb', line 40 def title @title end |