Class: DatadogAPIClient::V2::GovernanceControlUpdateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_control_update_attributes.rb

Overview

The attributes of a governance control that can be updated. Only the attributes present in the request are modified.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



36
37
38
# File 'lib/datadog_api_client/v2/models/governance_control_update_attributes.rb', line 36

def additional_properties
  @additional_properties
end

#detection_frequencyObject

How often detections should be evaluated for the control.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_control_update_attributes.rb', line 25

def detection_frequency
  @detection_frequency
end

#detection_parametersObject

A free-form map of parameter names to their configured values.



28
29
30
# File 'lib/datadog_api_client/v2/models/governance_control_update_attributes.rb', line 28

def detection_parameters
  @detection_parameters
end

#mitigation_parametersObject

A free-form map of parameter names to their configured values.



31
32
33
# File 'lib/datadog_api_client/v2/models/governance_control_update_attributes.rb', line 31

def mitigation_parameters
  @mitigation_parameters
end

#mitigation_typeObject

The mitigation type to configure for the control.



34
35
36
# File 'lib/datadog_api_client/v2/models/governance_control_update_attributes.rb', line 34

def mitigation_type
  @mitigation_type
end