Class: DatadogAPIClient::V2::GovernanceInsightQueryConfig

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_insight_query_config.rb

Overview

Query execution context for running insight queries directly.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



39
40
41
# File 'lib/datadog_api_client/v2/models/governance_insight_query_config.rb', line 39

def additional_properties
  @additional_properties
end

#chart_typeObject

The chart type used to render the insight.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_insight_query_config.rb', line 25

def chart_type
  @chart_type
end

#comparison_shiftObject

The window used for the previous value comparison; for example, week or month.



28
29
30
# File 'lib/datadog_api_client/v2/models/governance_insight_query_config.rb', line 28

def comparison_shift
  @comparison_shift
end

#default_valueObject

The default value to display when no data is available.



31
32
33
# File 'lib/datadog_api_client/v2/models/governance_insight_query_config.rb', line 31

def default_value
  @default_value
end

#directionalityObject

Whether an increase in the insight's value is good, bad, or neutral.



34
35
36
# File 'lib/datadog_api_client/v2/models/governance_insight_query_config.rb', line 34

def directionality
  @directionality
end

#effective_time_window_daysObject

The number of days the insight value is computed over.



37
38
39
# File 'lib/datadog_api_client/v2/models/governance_insight_query_config.rb', line 37

def effective_time_window_days
  @effective_time_window_days
end