Class: DatadogAPIClient::V2::GovernanceMitigationRequestAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/governance_mitigation_request_attributes.rb

Overview

The attributes of a governance mitigation request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



36
37
38
# File 'lib/datadog_api_client/v2/models/governance_mitigation_request_attributes.rb', line 36

def additional_properties
  @additional_properties
end

#detection_idsObject

The identifiers of the detections to mitigate in this request.



25
26
27
# File 'lib/datadog_api_client/v2/models/governance_mitigation_request_attributes.rb', line 25

def detection_ids
  @detection_ids
end

#detection_typeObject

The detection type whose detections should be mitigated.



28
29
30
# File 'lib/datadog_api_client/v2/models/governance_mitigation_request_attributes.rb', line 28

def detection_type
  @detection_type
end

#mitigation_parametersObject

A free-form map of parameter names to their configured values.



31
32
33
# File 'lib/datadog_api_client/v2/models/governance_mitigation_request_attributes.rb', line 31

def mitigation_parameters
  @mitigation_parameters
end

#mitigation_typeObject

The mitigation to apply to the selected detections. Defaults to the control's configured mitigation when omitted.



34
35
36
# File 'lib/datadog_api_client/v2/models/governance_mitigation_request_attributes.rb', line 34

def mitigation_type
  @mitigation_type
end