Class: DatadogAPIClient::V2::HistoricalJobQuery

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/historical_job_query.rb

Overview

Query for selecting logs analyzed by the historical job.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_filters ⇒ Object

Additional filters appended to the query at evaluation time.



25
26
27
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 25

def additional_filters
  @additional_filters
end

#additional_properties ⇒ Object

Returns the value of attribute additional_properties.



72
73
74
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 72

def additional_properties
  @additional_properties
end

#aggregation ⇒ Object

The aggregation type.



28
29
30
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 28

def aggregation
  @aggregation
end

#correlated_by_fields ⇒ Object

Fields used to correlate results across queries in sequence detection rules.



31
32
33
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 31

def correlated_by_fields
  @correlated_by_fields
end

#correlated_query_index ⇒ Object

Zero-based index of the query to correlate with in sequence detection rules. Up to 10 queries are supported, so valid values are 0 to 9.



34
35
36
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 34

def correlated_query_index
  @correlated_query_index
end

#custom_query_extension ⇒ Object

Custom query extension used to refine the base query.



37
38
39
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 37

def custom_query_extension
  @custom_query_extension
end

#data_source ⇒ Object

Source of events, either logs, audit trail, security signals, or Datadog events. app_sec_spans is deprecated in favor of spans.



40
41
42
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 40

def data_source
  @data_source
end

#dataset_ids ⇒ Object

IDs of reference datasets used by this query.



43
44
45
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 43

def dataset_ids
  @dataset_ids
end

#distinct_fields ⇒ Object

Field for which the cardinality is measured. Sent as an array.



46
47
48
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 46

def distinct_fields
  @distinct_fields
end

#group_by_fields ⇒ Object

Fields to group by.



49
50
51
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 49

def group_by_fields
  @group_by_fields
end

#has_optional_group_by_fields ⇒ Object

When false, events without a group-by value are ignored by the query. When true, events with missing group-by fields are processed with N/A, replacing the missing values.



52
53
54
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 52

def has_optional_group_by_fields
  @has_optional_group_by_fields
end

#index ⇒ Object

Index used to load the data for this query.



55
56
57
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 55

def index
  @index
end

#indexes ⇒ Object

Indexes used to load the data for this query. Mutually exclusive with index.



58
59
60
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 58

def indexes
  @indexes
end

#metrics ⇒ Object

Group of target fields to aggregate over when using the sum, max, geo data, or new value aggregations. The sum, max, and geo data aggregations only accept one value in this list, whereas the new value aggregation accepts up to five values.



61
62
63
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 61

def metrics
  @metrics
end

#name ⇒ Object

Name of the query.



64
65
66
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 64

def name
  @name
end

#query ⇒ Object

Query to run on logs.



67
68
69
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 67

def query
  @query
end

#query_language ⇒ Object

Language used to parse the query string.



70
71
72
# File 'lib/datadog_api_client/v2/models/historical_job_query.rb', line 70

def query_language
  @query_language
end