Class: DatadogAPIClient::V2::HourlyUsageAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/hourly_usage_attributes.rb

Overview

Attributes of hourly usage for a product family for an org for a time period.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#measurementsObject

List of the measured usage values for the product family for the org for the time period.



29
30
31
# File 'lib/datadog_api_client/v2/models/hourly_usage_attributes.rb', line 29

def measurements
  @measurements
end

#org_nameObject

The organization name.



32
33
34
# File 'lib/datadog_api_client/v2/models/hourly_usage_attributes.rb', line 32

def org_name
  @org_name
end

#product_familyObject

The product for which usage is being reported.



35
36
37
# File 'lib/datadog_api_client/v2/models/hourly_usage_attributes.rb', line 35

def product_family
  @product_family
end

#public_idObject

The organization public ID.



38
39
40
# File 'lib/datadog_api_client/v2/models/hourly_usage_attributes.rb', line 38

def public_id
  @public_id
end

#regionObject

The region of the Datadog instance that the organization belongs to.



41
42
43
# File 'lib/datadog_api_client/v2/models/hourly_usage_attributes.rb', line 41

def region
  @region
end

#timestampObject

Datetime in ISO-8601 format, UTC. The hour for the usage.



44
45
46
# File 'lib/datadog_api_client/v2/models/hourly_usage_attributes.rb', line 44

def timestamp
  @timestamp
end