Class: DatadogAPIClient::V2::IncidentCreateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/incident_create_attributes.rb

Overview

The incident’s attributes for a create request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#customer_impactedObject

A flag indicating whether the incident caused customer impact.



29
30
31
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 29

def customer_impacted
  @customer_impacted
end

#fieldsObject

A condensed view of the user-defined fields for which to create initial selections.



32
33
34
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 32

def fields
  @fields
end

#initial_cellsObject

An array of initial timeline cells to be placed at the beginning of the incident timeline.



35
36
37
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 35

def initial_cells
  @initial_cells
end

#notification_handlesObject

Notification handles that will be notified of the incident at creation.



38
39
40
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 38

def notification_handles
  @notification_handles
end

#titleObject

The title of the incident, which summarizes what happened.



41
42
43
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 41

def title
  @title
end