Class: DatadogAPIClient::V2::IncidentCreateData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentCreateData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_create_data.rb
Overview
Incident data for a create request.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
The incident’s attributes for a create request.
-
#relationships ⇒ Object
The relationships the incident will have with other resources once created.
-
#type ⇒ Object
readonly
Incident resource type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
The incident’s attributes for a create request.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/incident_create_data.rb', line 29 def attributes @attributes end |
#relationships ⇒ Object
The relationships the incident will have with other resources once created.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/incident_create_data.rb', line 32 def relationships @relationships end |
#type ⇒ Object
Incident resource type.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/incident_create_data.rb', line 35 def type @type end |