Class: DatadogAPIClient::V2::IncidentCreateOnCallPageDataAttributesRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentCreateOnCallPageDataAttributesRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb
Overview
Attributes for creating an on-call page from an incident.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#description ⇒ Object
The description of the page.
-
#role ⇒ Object
A reference to an incident role for a page.
-
#services ⇒ Object
List of affected services.
-
#tags ⇒ Object
List of tags for the page.
-
#target ⇒ Object
The target recipient for a page.
-
#title ⇒ Object
The title of the page.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 42 def additional_properties @additional_properties end |
#description ⇒ Object
The description of the page.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 25 def description @description end |
#role ⇒ Object
A reference to an incident role for a page.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 28 def role @role end |
#services ⇒ Object
List of affected services.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 31 def services @services end |
#tags ⇒ Object
List of tags for the page.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 34 def @tags end |
#target ⇒ Object
The target recipient for a page.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 37 def target @target end |
#title ⇒ Object
The title of the page.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/incident_create_on_call_page_data_attributes_request.rb', line 40 def title @title end |