Class: DatadogAPIClient::V2::IncidentIntegrationMetadataAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb

Overview

Incident integration metadata’s attributes for a create request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



46
47
48
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 46

def additional_properties
  @additional_properties
end

#createdObject

Timestamp when the incident todo was created.



25
26
27
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 25

def created
  @created
end

#incident_idObject

UUID of the incident this integration metadata is connected to.



28
29
30
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 28

def incident_id
  @incident_id
end

#integration_typeObject

A number indicating the type of integration this metadata is for. 1 indicates Slack; 7 indicates Microsoft Teams; 8 indicates Jira.



33
34
35
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 33

def integration_type
  @integration_type
end

#metadataObject

Incident integration metadata’s metadata attribute.



36
37
38
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 36

def 
  @metadata
end

#modifiedObject

Timestamp when the incident todo was last modified.



39
40
41
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 39

def modified
  @modified
end

#statusObject

A number indicating the status of this integration metadata. 0 indicates unknown; 1 indicates pending; 2 indicates complete; 3 indicates manually created; 4 indicates manually updated; 5 indicates failed.



44
45
46
# File 'lib/datadog_api_client/v2/models/incident_integration_metadata_attributes.rb', line 44

def status
  @status
end