Class: DatadogAPIClient::V2::IncidentOrgSettingsDataAttributesResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentOrgSettingsDataAttributesResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_org_settings_data_attributes_response.rb
Overview
Attributes of an incident org settings resource in a response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#created ⇒ Object
readonly
Timestamp when the settings were created.
-
#modified ⇒ Object
readonly
Timestamp when the settings were last modified.
-
#settings ⇒ Object
readonly
The settings configuration for an incident org settings resource.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/incident_org_settings_data_attributes_response.rb', line 33 def additional_properties @additional_properties end |
#created ⇒ Object
Timestamp when the settings were created.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/incident_org_settings_data_attributes_response.rb', line 25 def created @created end |
#modified ⇒ Object
Timestamp when the settings were last modified.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/incident_org_settings_data_attributes_response.rb', line 28 def modified @modified end |
#settings ⇒ Object
The settings configuration for an incident org settings resource.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/incident_org_settings_data_attributes_response.rb', line 31 def settings @settings end |