Class: DatadogAPIClient::V2::IncidentResponseAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/incident_response_attributes.rb

Overview

The incident’s attributes from a response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#createdObject

Timestamp when the incident was created.



29
30
31
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 29

def created
  @created
end

#customer_impact_durationObject

Length of the incident’s customer impact in seconds. Equals the difference between customer_impact_start and customer_impact_end.



33
34
35
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 33

def customer_impact_duration
  @customer_impact_duration
end

#customer_impact_endObject

Timestamp when customers were no longer impacted by the incident.



36
37
38
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 36

def customer_impact_end
  @customer_impact_end
end

#customer_impact_scopeObject

A summary of the impact customers experienced during the incident.



39
40
41
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 39

def customer_impact_scope
  @customer_impact_scope
end

#customer_impact_startObject

Timestamp when customers began being impacted by the incident.



42
43
44
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 42

def customer_impact_start
  @customer_impact_start
end

#customer_impactedObject

A flag indicating whether the incident caused customer impact.



45
46
47
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 45

def customer_impacted
  @customer_impacted
end

#detectedObject

Timestamp when the incident was detected.



48
49
50
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 48

def detected
  @detected
end

#fieldsObject

A condensed view of the user-defined fields attached to incidents.



51
52
53
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 51

def fields
  @fields
end

#modifiedObject

Timestamp when the incident was last modified.



54
55
56
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 54

def modified
  @modified
end

#notification_handlesObject

Notification handles that will be notified of the incident during update.



57
58
59
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 57

def notification_handles
  @notification_handles
end

#public_idObject

The monotonically increasing integer ID for the incident.



60
61
62
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 60

def public_id
  @public_id
end

#resolvedObject

Timestamp when the incident’s state was last changed from active or stable to resolved or completed.



63
64
65
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 63

def resolved
  @resolved
end

#time_to_detectObject

The amount of time in seconds to detect the incident. Equals the difference between customer_impact_start and detected.



67
68
69
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 67

def time_to_detect
  @time_to_detect
end

#time_to_internal_responseObject

The amount of time in seconds to call incident after detection. Equals the difference of detected and created.



70
71
72
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 70

def time_to_internal_response
  @time_to_internal_response
end

#time_to_repairObject

The amount of time in seconds to resolve customer impact after detecting the issue. Equals the difference between customer_impact_end and detected.



73
74
75
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 73

def time_to_repair
  @time_to_repair
end

#time_to_resolveObject

The amount of time in seconds to resolve the incident after it was created. Equals the difference between created and resolved.



76
77
78
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 76

def time_to_resolve
  @time_to_resolve
end

#titleObject

The title of the incident, which summarizes what happened.



79
80
81
# File 'lib/datadog_api_client/v2/models/incident_response_attributes.rb', line 79

def title
  @title
end