Class: DatadogAPIClient::V2::IncidentResponseMetaPagination

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/incident_response_meta_pagination.rb

Overview

Pagination properties.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#next_offsetObject

The index of the first element in the next page of results. Equal to page size added to the current offset.



29
30
31
# File 'lib/datadog_api_client/v2/models/incident_response_meta_pagination.rb', line 29

def next_offset
  @next_offset
end

#offsetObject

The index of the first element in the results.



32
33
34
# File 'lib/datadog_api_client/v2/models/incident_response_meta_pagination.rb', line 32

def offset
  @offset
end

#sizeObject

Maximum size of pages to return.



35
36
37
# File 'lib/datadog_api_client/v2/models/incident_response_meta_pagination.rb', line 35

def size
  @size
end