Class: DatadogAPIClient::V2::IncidentRuleDataAttributesRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentRuleDataAttributesRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb
Overview
Attributes for creating an incident rule.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#condition ⇒ Object
readonly
A query-based condition for an incident rule.
-
#condition_table_type ⇒ Object
readonly
The condition table type.
-
#conditions ⇒ Object
List of field-based conditions.
-
#enabled ⇒ Object
readonly
Whether the rule is enabled.
-
#execution_type ⇒ Object
readonly
The execution type of an incident rule.
-
#incident_type_uuid ⇒ Object
The UUID of the incident type this rule applies to.
-
#match_any_condition ⇒ Object
Whether any condition (OR logic) should match instead of all (AND logic).
-
#task_id ⇒ Object
readonly
The task ID for an incident rule.
-
#task_payload ⇒ Object
readonly
The JSON-encoded payload for the task.
-
#trigger ⇒ Object
The trigger event for an incident rule.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 54 def additional_properties @additional_properties end |
#condition ⇒ Object
A query-based condition for an incident rule.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 25 def condition @condition end |
#condition_table_type ⇒ Object
The condition table type. 1 = raw query.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 28 def condition_table_type @condition_table_type end |
#conditions ⇒ Object
List of field-based conditions.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 31 def conditions @conditions end |
#enabled ⇒ Object
Whether the rule is enabled.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 34 def enabled @enabled end |
#execution_type ⇒ Object
The execution type of an incident rule.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 37 def execution_type @execution_type end |
#incident_type_uuid ⇒ Object
The UUID of the incident type this rule applies to.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 40 def incident_type_uuid @incident_type_uuid end |
#match_any_condition ⇒ Object
Whether any condition (OR logic) should match instead of all (AND logic).
43 44 45 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 43 def match_any_condition @match_any_condition end |
#task_id ⇒ Object
The task ID for an incident rule.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 46 def task_id @task_id end |
#task_payload ⇒ Object
The JSON-encoded payload for the task.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 49 def task_payload @task_payload end |
#trigger ⇒ Object
The trigger event for an incident rule.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_request.rb', line 52 def trigger @trigger end |