Class: DatadogAPIClient::V2::IncidentRuleDataAttributesResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentRuleDataAttributesResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb
Overview
Attributes of an incident rule in a response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#condition ⇒ Object
A query-based condition for an incident rule.
-
#condition_table_type ⇒ Object
The condition table type.
-
#conditions ⇒ Object
List of field-based conditions.
-
#created ⇒ Object
Timestamp when the rule was created.
-
#created_by_uuid ⇒ Object
UUID of the user who created the rule.
-
#deleted ⇒ Object
Timestamp when the rule was deleted.
-
#enabled ⇒ Object
Whether the rule is enabled.
-
#execution_type ⇒ Object
The execution type of the rule.
-
#incident_settings_association_uuid ⇒ Object
The incident settings association UUID.
-
#match_any_condition ⇒ Object
Whether any condition should match.
-
#modified ⇒ Object
Timestamp when the rule was last modified.
-
#modified_by_uuid ⇒ Object
UUID of the user who last modified the rule.
-
#org_id ⇒ Object
The organization ID.
-
#task_id ⇒ Object
The task ID.
-
#task_payload ⇒ Object
The JSON-encoded task payload.
-
#trigger ⇒ Object
The trigger event for the rule.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
72 73 74 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 72 def additional_properties @additional_properties end |
#condition ⇒ Object
A query-based condition for an incident rule.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 25 def condition @condition end |
#condition_table_type ⇒ Object
The condition table type.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 28 def condition_table_type @condition_table_type end |
#conditions ⇒ Object
List of field-based conditions.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 31 def conditions @conditions end |
#created ⇒ Object
Timestamp when the rule was created.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 34 def created @created end |
#created_by_uuid ⇒ Object
UUID of the user who created the rule.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 37 def created_by_uuid @created_by_uuid end |
#deleted ⇒ Object
Timestamp when the rule was deleted.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 40 def deleted @deleted end |
#enabled ⇒ Object
Whether the rule is enabled.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 43 def enabled @enabled end |
#execution_type ⇒ Object
The execution type of the rule.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 46 def execution_type @execution_type end |
#incident_settings_association_uuid ⇒ Object
The incident settings association UUID.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 49 def incident_settings_association_uuid @incident_settings_association_uuid end |
#match_any_condition ⇒ Object
Whether any condition should match.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 52 def match_any_condition @match_any_condition end |
#modified ⇒ Object
Timestamp when the rule was last modified.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 55 def modified @modified end |
#modified_by_uuid ⇒ Object
UUID of the user who last modified the rule.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 58 def modified_by_uuid @modified_by_uuid end |
#org_id ⇒ Object
The organization ID.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 61 def org_id @org_id end |
#task_id ⇒ Object
The task ID.
64 65 66 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 64 def task_id @task_id end |
#task_payload ⇒ Object
The JSON-encoded task payload.
67 68 69 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 67 def task_payload @task_payload end |
#trigger ⇒ Object
The trigger event for the rule.
70 71 72 |
# File 'lib/datadog_api_client/v2/models/incident_rule_data_attributes_response.rb', line 70 def trigger @trigger end |