Class: DatadogAPIClient::V2::IncidentSearchResponseFieldFacetData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/incident_search_response_field_facet_data.rb

Overview

Facet value and number of occurrences for a property field of an incident.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#countObject

Count of the facet value appearing in search results.



29
30
31
# File 'lib/datadog_api_client/v2/models/incident_search_response_field_facet_data.rb', line 29

def count
  @count
end

#nameObject

The facet value appearing in search results.



32
33
34
# File 'lib/datadog_api_client/v2/models/incident_search_response_field_facet_data.rb', line 32

def name
  @name
end