Class: DatadogAPIClient::V2::IncidentSearchResponseUserFacetData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentSearchResponseUserFacetData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_search_response_user_facet_data.rb
Overview
Facet data for user attributes of an incident.
Instance Attribute Summary collapse
-
#count ⇒ Object
readonly
Count of the facet value appearing in search results.
-
#email ⇒ Object
Email of the user.
-
#handle ⇒ Object
Handle of the user.
-
#name ⇒ Object
Name of the user.
-
#uuid ⇒ Object
ID of the user.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#count ⇒ Object
Count of the facet value appearing in search results.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/incident_search_response_user_facet_data.rb', line 29 def count @count end |
#email ⇒ Object
Email of the user.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/incident_search_response_user_facet_data.rb', line 32 def email @email end |
#handle ⇒ Object
Handle of the user.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/incident_search_response_user_facet_data.rb', line 35 def handle @handle end |
#name ⇒ Object
Name of the user.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/incident_search_response_user_facet_data.rb', line 38 def name @name end |
#uuid ⇒ Object
ID of the user.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/incident_search_response_user_facet_data.rb', line 41 def uuid @uuid end |