Class: DatadogAPIClient::V2::IncidentsAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v2/api/incidents_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ IncidentsAPI

Returns a new instance of IncidentsAPI.



22
23
24
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#create_incident(body, opts = {}) ⇒ Object

Create an incident.



29
30
31
32
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 29

def create_incident(body, opts = {})
  data, _status_code, _headers = create_incident_with_http_info(body, opts)
  data
end

#create_incident_with_http_info(body, opts = {}) ⇒ Array<(IncidentResponse, Integer, Hash)>

Create an incident.

Create an incident.

Parameters:

  • body (IncidentCreateRequest)

    Incident payload.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(IncidentResponse, Integer, Hash)>)

    IncidentResponse data, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 41

def create_incident_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.create_incident".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.create_incident")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.create_incident"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.create_incident ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling IncidentsAPI.create_incident"
  end
  # resource path
  local_var_path = '/api/v2/incidents'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :create_incident,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#create_incident\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_incident(incident_id, opts = {}) ⇒ Object

Delete an existing incident.



102
103
104
105
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 102

def delete_incident(incident_id, opts = {})
  delete_incident_with_http_info(incident_id, opts)
  nil
end

#delete_incident_with_http_info(incident_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete an existing incident.

Deletes an existing incident from the users organization.

Parameters:

  • incident_id (String)

    The UUID of the incident.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 114

def delete_incident_with_http_info(incident_id, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.delete_incident".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.delete_incident")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.delete_incident"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.delete_incident ...'
  end
  # verify the required parameter 'incident_id' is set
  if @api_client.config.client_side_validation && incident_id.nil?
    fail ArgumentError, "Missing the required parameter 'incident_id' when calling IncidentsAPI.delete_incident"
  end
  # resource path
  local_var_path = '/api/v2/incidents/{incident_id}'.sub('{incident_id}', CGI.escape(incident_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :delete_incident,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#delete_incident\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_incident(incident_id, opts = {}) ⇒ Object

Get the details of an incident.



173
174
175
176
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 173

def get_incident(incident_id, opts = {})
  data, _status_code, _headers = get_incident_with_http_info(incident_id, opts)
  data
end

#get_incident_with_http_info(incident_id, opts = {}) ⇒ Array<(IncidentResponse, Integer, Hash)>

Get the details of an incident.

Get the details of an incident by incident_id.

Parameters:

  • incident_id (String)

    The UUID of the incident.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include (Array<IncidentRelatedObject>)

    Specifies which types of related objects should be included in the response.

Returns:

  • (Array<(IncidentResponse, Integer, Hash)>)

    IncidentResponse data, response status code and response headers



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 186

def get_incident_with_http_info(incident_id, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.get_incident".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.get_incident")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.get_incident"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.get_incident ...'
  end
  # verify the required parameter 'incident_id' is set
  if @api_client.config.client_side_validation && incident_id.nil?
    fail ArgumentError, "Missing the required parameter 'incident_id' when calling IncidentsAPI.get_incident"
  end
  # resource path
  local_var_path = '/api/v2/incidents/{incident_id}'.sub('{incident_id}', CGI.escape(incident_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :csv) if !opts[:'include'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :get_incident,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#get_incident\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_incident_attachments(incident_id, opts = {}) ⇒ Object

Get a list of attachments.



246
247
248
249
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 246

def list_incident_attachments(incident_id, opts = {})
  data, _status_code, _headers = list_incident_attachments_with_http_info(incident_id, opts)
  data
end

#list_incident_attachments_with_http_info(incident_id, opts = {}) ⇒ Array<(IncidentAttachmentsResponse, Integer, Hash)>

Get a list of attachments.

Get all attachments for a given incident.

Parameters:

  • incident_id (String)

    The UUID of the incident.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(IncidentAttachmentsResponse, Integer, Hash)>)

    IncidentAttachmentsResponse data, response status code and response headers



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 260

def list_incident_attachments_with_http_info(incident_id, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.list_incident_attachments".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.list_incident_attachments")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.list_incident_attachments"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.list_incident_attachments ...'
  end
  # verify the required parameter 'incident_id' is set
  if @api_client.config.client_side_validation && incident_id.nil?
    fail ArgumentError, "Missing the required parameter 'incident_id' when calling IncidentsAPI.list_incident_attachments"
  end
  # resource path
  local_var_path = '/api/v2/incidents/{incident_id}/attachments'.sub('{incident_id}', CGI.escape(incident_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :csv) if !opts[:'include'].nil?
  query_params[:'filter[attachment_type]'] = @api_client.build_collection_param(opts[:'filter_attachment_type'], :csv) if !opts[:'filter_attachment_type'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentAttachmentsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_incident_attachments,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#list_incident_attachments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_incidents(opts = {}) ⇒ Object

Get a list of incidents.



321
322
323
324
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 321

def list_incidents(opts = {})
  data, _status_code, _headers = list_incidents_with_http_info(opts)
  data
end

#list_incidents_with_http_info(opts = {}) ⇒ Array<(IncidentsResponse, Integer, Hash)>

Get a list of incidents.

Get all incidents for the user’s organization.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include (Array<IncidentRelatedObject>)

    Specifies which types of related objects should be included in the response.

  • :page_size (Integer)

    Size for a given page. The maximum allowed value is 5000.

  • :page_offset (Integer)

    Specific offset to use as the beginning of the returned page.

Returns:

  • (Array<(IncidentsResponse, Integer, Hash)>)

    IncidentsResponse data, response status code and response headers



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 335

def list_incidents_with_http_info(opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.list_incidents".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.list_incidents")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.list_incidents"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.list_incidents ...'
  end
  # resource path
  local_var_path = '/api/v2/incidents'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :csv) if !opts[:'include'].nil?
  query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'page[offset]'] = opts[:'page_offset'] if !opts[:'page_offset'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_incidents,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#list_incidents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_incidents_with_pagination(opts = {}) {|IncidentResponseData| ... } ⇒ Object

Get a list of incidents.

Provide a paginated version of #list_incidents, returning all items.

To use it you need to use a block: list_incidents_with_pagination { |item| p item }

Yields:



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 397

def list_incidents_with_pagination(opts = {})
    api_version = "V2"
    page_size = @api_client.get_attribute_from_path(opts, "page_size", 10)
    @api_client.set_attribute_from_path(api_version, opts, "page_size", Integer, page_size)
    while true do
        response = list_incidents(opts)
        @api_client.get_attribute_from_path(response, "data").each { |item| yield(item) }
        if @api_client.get_attribute_from_path(response, "data").length < page_size
          break
        end
        @api_client.set_attribute_from_path(api_version, opts, "page_offset", Integer, @api_client.get_attribute_from_path(opts, "page_offset", 0) + page_size)
    end
end

#search_incidents(query, opts = {}) ⇒ Object

Search for incidents.



414
415
416
417
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 414

def search_incidents(query, opts = {})
  data, _status_code, _headers = search_incidents_with_http_info(query, opts)
  data
end

#search_incidents_with_http_info(query, opts = {}) ⇒ Array<(IncidentSearchResponse, Integer, Hash)>

Search for incidents.

Search for incidents matching a certain query.

Parameters:

  • query (String)

    Specifies which incidents should be returned. After entering a search query in your [Incidents page], use the query parameter value in the URL of the page as the value for this parameter. The query can contain any number of incident facets joined by ANDs, along with multiple values for each of those facets joined by ‘OR`s, for instance: `query=“state:active AND severity:(SEV-2 OR SEV-1)”`. [1]: app.datadoghq.com/incidents

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(IncidentSearchResponse, Integer, Hash)>)

    IncidentSearchResponse data, response status code and response headers



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 428

def search_incidents_with_http_info(query, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.search_incidents".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.search_incidents")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.search_incidents"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.search_incidents ...'
  end
  allowable_values = ['users', 'attachments']
  if @api_client.config.client_side_validation && opts[:'include'] && !allowable_values.include?(opts[:'include'])
    fail ArgumentError, "invalid value for \"include\", must be one of #{allowable_values}"
  end
  # verify the required parameter 'query' is set
  if @api_client.config.client_side_validation && query.nil?
    fail ArgumentError, "Missing the required parameter 'query' when calling IncidentsAPI.search_incidents"
  end
  allowable_values = ['created', '-created']
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/v2/incidents/search'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'query'] = query
  query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentSearchResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :search_incidents,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#search_incidents\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_incident(incident_id, body, opts = {}) ⇒ Object

Update an existing incident.



498
499
500
501
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 498

def update_incident(incident_id, body, opts = {})
  data, _status_code, _headers = update_incident_with_http_info(incident_id, body, opts)
  data
end

#update_incident_attachments(incident_id, body, opts = {}) ⇒ Object

Create, update, and delete incident attachments.



578
579
580
581
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 578

def update_incident_attachments(incident_id, body, opts = {})
  data, _status_code, _headers = update_incident_attachments_with_http_info(incident_id, body, opts)
  data
end

#update_incident_attachments_with_http_info(incident_id, body, opts = {}) ⇒ Array<(IncidentAttachmentUpdateResponse, Integer, Hash)>

Create, update, and delete incident attachments.

The bulk update endpoint for creating, updating, and deleting attachments for a given incident.

Parameters:

  • incident_id (String)

    The UUID of the incident.

  • body (IncidentAttachmentUpdateRequest)

    Incident Attachment Payload.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 592

def update_incident_attachments_with_http_info(incident_id, body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.update_incident_attachments".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_incident_attachments")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_incident_attachments"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.update_incident_attachments ...'
  end
  # verify the required parameter 'incident_id' is set
  if @api_client.config.client_side_validation && incident_id.nil?
    fail ArgumentError, "Missing the required parameter 'incident_id' when calling IncidentsAPI.update_incident_attachments"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling IncidentsAPI.update_incident_attachments"
  end
  # resource path
  local_var_path = '/api/v2/incidents/{incident_id}/attachments'.sub('{incident_id}', CGI.escape(incident_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :csv) if !opts[:'include'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentAttachmentUpdateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_incident_attachments,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#update_incident_attachments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_incident_with_http_info(incident_id, body, opts = {}) ⇒ Array<(IncidentResponse, Integer, Hash)>

Update an existing incident.

Updates an incident. Provide only the attributes that should be updated as this request is a partial update.

Parameters:

  • incident_id (String)

    The UUID of the incident.

  • body (IncidentUpdateRequest)

    Incident Payload.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :include (Array<IncidentRelatedObject>)

    Specifies which types of related objects should be included in the response.

Returns:

  • (Array<(IncidentResponse, Integer, Hash)>)

    IncidentResponse data, response status code and response headers



512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/datadog_api_client/v2/api/incidents_api.rb', line 512

def update_incident_with_http_info(incident_id, body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.update_incident".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_incident")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_incident"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IncidentsAPI.update_incident ...'
  end
  # verify the required parameter 'incident_id' is set
  if @api_client.config.client_side_validation && incident_id.nil?
    fail ArgumentError, "Missing the required parameter 'incident_id' when calling IncidentsAPI.update_incident"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling IncidentsAPI.update_incident"
  end
  # resource path
  local_var_path = '/api/v2/incidents/{incident_id}'.sub('{incident_id}', CGI.escape(incident_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'include'] = @api_client.build_collection_param(opts[:'include'], :csv) if !opts[:'include'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'IncidentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :update_incident,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IncidentsAPI#update_incident\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end