Class: DatadogAPIClient::V2::IoCIndicatorDetailed

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb

Overview

An indicator of compromise with extended context from your environment.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_dataObject

Additional domain-specific context from threat intelligence sources.



25
26
27
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 25

def additional_data
  @additional_data
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



117
118
119
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 117

def additional_properties
  @additional_properties
end

#as_cidr_blockObject

Autonomous system CIDR block.



28
29
30
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 28

def as_cidr_block
  @as_cidr_block
end

#as_geoObject

Geographic location information for an IP indicator.



31
32
33
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 31

def as_geo
  @as_geo
end

#as_numberObject

Autonomous system number.



34
35
36
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 34

def as_number
  @as_number
end

#as_organizationObject

Autonomous system organization name.



37
38
39
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 37

def as_organization
  @as_organization
end

#as_typeObject

Autonomous system type.



40
41
42
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 40

def as_type
  @as_type
end

#benign_sourcesObject

Threat intelligence sources that flagged this indicator as benign.



43
44
45
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 43

def benign_sources
  @benign_sources
end

#categoriesObject

Threat categories associated with the indicator.



46
47
48
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 46

def categories
  @categories
end

#critical_assetsObject

Critical assets associated with this indicator.



49
50
51
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 49

def critical_assets
  @critical_assets
end

#first_seenObject

Timestamp when the indicator was first seen.



52
53
54
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 52

def first_seen
  @first_seen
end

#hostsObject

Hosts associated with this indicator.



55
56
57
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 55

def hosts
  @hosts
end

#idObject

Unique identifier for the indicator.



58
59
60
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 58

def id
  @id
end

#indicatorObject

The indicator value (for example, an IP address or domain).



61
62
63
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 61

def indicator
  @indicator
end

#indicator_typeObject

Type of indicator (for example, IP address or domain).



64
65
66
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 64

def indicator_type
  @indicator_type
end

#last_seenObject

Timestamp when the indicator was last seen.



67
68
69
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 67

def last_seen
  @last_seen
end

#log_matchesObject

Number of logs that matched this indicator.



70
71
72
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 70

def log_matches
  @log_matches
end

#log_sourcesObject

Log sources where this indicator was observed.



73
74
75
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 73

def log_sources
  @log_sources
end

#m_as_typeObject

Effect of a scoring factor on the indicator’s threat score.



76
77
78
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 76

def m_as_type
  @m_as_type
end

#m_persistenceObject

Effect of a scoring factor on the indicator’s threat score.



79
80
81
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 79

def m_persistence
  @m_persistence
end

#m_signalObject

Effect of a scoring factor on the indicator’s threat score.



82
83
84
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 82

def m_signal
  @m_signal
end

#m_sourcesObject

Effect of a scoring factor on the indicator’s threat score.



85
86
87
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 85

def m_sources
  @m_sources
end

#malicious_sourcesObject

Threat intelligence sources that flagged this indicator as malicious.



88
89
90
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 88

def malicious_sources
  @malicious_sources
end

#max_trust_scoreObject

Effect of a scoring factor on the indicator’s threat score.



91
92
93
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 91

def max_trust_score
  @max_trust_score
end

#scoreObject

Threat score for the indicator (0-100).



94
95
96
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 94

def score
  @score
end

#servicesObject

Services where this indicator was observed.



97
98
99
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 97

def services
  @services
end

#signal_matchesObject

Number of security signals that matched this indicator.



100
101
102
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 100

def signal_matches
  @signal_matches
end

#signal_severityObject

Breakdown of security signals by severity.



103
104
105
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 103

def signal_severity
  @signal_severity
end

#signal_tierObject

Signal tier level.



106
107
108
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 106

def signal_tier
  @signal_tier
end

#suspicious_sourcesObject

Threat intelligence sources that flagged this indicator as suspicious.



109
110
111
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 109

def suspicious_sources
  @suspicious_sources
end

#tagsObject

Tags associated with the indicator.



112
113
114
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 112

def tags
  @tags
end

#usersObject

Users associated with this indicator, grouped by category.



115
116
117
# File 'lib/datadog_api_client/v2/models/io_c_indicator_detailed.rb', line 115

def users
  @users
end