Class: DatadogAPIClient::V2::IoCTriageWriteResponseAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IoCTriageWriteResponseAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb
Overview
Attributes of a created or updated triage state.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#created_at ⇒ Object
Timestamp when the triage record was created.
-
#indicator ⇒ Object
The indicator value that was triaged.
-
#triage_state ⇒ Object
Current triage state of the indicator.
-
#triaged_at ⇒ Object
Timestamp when the triage state was set.
-
#triaged_by ⇒ Object
UUID of the user who set the triage state.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb', line 39 def additional_properties @additional_properties end |
#created_at ⇒ Object
Timestamp when the triage record was created.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb', line 25 def created_at @created_at end |
#indicator ⇒ Object
The indicator value that was triaged.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb', line 28 def indicator @indicator end |
#triage_state ⇒ Object
Current triage state of the indicator.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb', line 31 def triage_state @triage_state end |
#triaged_at ⇒ Object
Timestamp when the triage state was set.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb', line 34 def triaged_at @triaged_at end |
#triaged_by ⇒ Object
UUID of the user who set the triage state.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/io_c_triage_write_response_attributes.rb', line 37 def triaged_by @triaged_by end |