Class: DatadogAPIClient::V2::KeyManagementAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::KeyManagementAPI
- Defined in:
- lib/datadog_api_client/v2/api/key_management_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_api_key(body, opts = {}) ⇒ Object
Create an API key.
-
#create_api_key_with_http_info(body, opts = {}) ⇒ Array<(APIKeyResponse, Integer, Hash)>
Create an API key.
-
#create_current_user_application_key(body, opts = {}) ⇒ Object
Create an application key for current user.
-
#create_current_user_application_key_with_http_info(body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Create an application key for current user.
-
#create_personal_access_token(body, opts = {}) ⇒ Object
Create a personal access token.
-
#create_personal_access_token_with_http_info(body, opts = {}) ⇒ Array<(PersonalAccessTokenCreateResponse, Integer, Hash)>
Create a personal access token.
-
#delete_api_key(api_key_id, opts = {}) ⇒ Object
Delete an API key.
-
#delete_api_key_with_http_info(api_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an API key.
-
#delete_application_key(app_key_id, opts = {}) ⇒ Object
Delete an application key.
-
#delete_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an application key.
-
#delete_current_user_application_key(app_key_id, opts = {}) ⇒ Object
Delete an application key owned by current user.
-
#delete_current_user_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an application key owned by current user.
-
#get_api_key(api_key_id, opts = {}) ⇒ Object
Get API key.
-
#get_api_key_with_http_info(api_key_id, opts = {}) ⇒ Array<(APIKeyResponse, Integer, Hash)>
Get API key.
-
#get_application_key(app_key_id, opts = {}) ⇒ Object
Get an application key.
-
#get_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Get an application key.
-
#get_current_user_application_key(app_key_id, opts = {}) ⇒ Object
Get one application key owned by current user.
-
#get_current_user_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Get one application key owned by current user.
-
#get_personal_access_token(pat_id, opts = {}) ⇒ Object
Get a personal access token.
-
#get_personal_access_token_with_http_info(pat_id, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Get a personal access token.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ KeyManagementAPI
constructor
A new instance of KeyManagementAPI.
-
#list_api_keys(opts = {}) ⇒ Object
Get all API keys.
-
#list_api_keys_with_http_info(opts = {}) ⇒ Array<(APIKeysResponse, Integer, Hash)>
Get all API keys.
-
#list_application_keys(opts = {}) ⇒ Object
Get all application keys.
-
#list_application_keys_with_http_info(opts = {}) ⇒ Array<(ListApplicationKeysResponse, Integer, Hash)>
Get all application keys.
-
#list_current_user_application_keys(opts = {}) ⇒ Object
Get all application keys owned by current user.
-
#list_current_user_application_keys_with_http_info(opts = {}) ⇒ Array<(ListApplicationKeysResponse, Integer, Hash)>
Get all application keys owned by current user.
-
#list_personal_access_tokens(opts = {}) ⇒ Object
Get all personal access tokens.
-
#list_personal_access_tokens_with_http_info(opts = {}) ⇒ Array<(ListPersonalAccessTokensResponse, Integer, Hash)>
Get all personal access tokens.
-
#revoke_personal_access_token(pat_id, opts = {}) ⇒ Object
Revoke a personal access token.
-
#revoke_personal_access_token_with_http_info(pat_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke a personal access token.
-
#update_api_key(api_key_id, body, opts = {}) ⇒ Object
Edit an API key.
-
#update_api_key_with_http_info(api_key_id, body, opts = {}) ⇒ Array<(APIKeyResponse, Integer, Hash)>
Edit an API key.
-
#update_application_key(app_key_id, body, opts = {}) ⇒ Object
Edit an application key.
-
#update_application_key_with_http_info(app_key_id, body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Edit an application key.
-
#update_current_user_application_key(app_key_id, body, opts = {}) ⇒ Object
Edit an application key owned by current user.
-
#update_current_user_application_key_with_http_info(app_key_id, body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Edit an application key owned by current user.
-
#update_personal_access_token(pat_id, body, opts = {}) ⇒ Object
Update a personal access token.
-
#update_personal_access_token_with_http_info(pat_id, body, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Update a personal access token.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ KeyManagementAPI
Returns a new instance of KeyManagementAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#create_api_key(body, opts = {}) ⇒ Object
Create an API key.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 29 def create_api_key(body, opts = {}) data, _status_code, _headers = create_api_key_with_http_info(body, opts) data end |
#create_api_key_with_http_info(body, opts = {}) ⇒ Array<(APIKeyResponse, Integer, Hash)>
Create an API key.
Create an API key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 41 def create_api_key_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.create_api_key ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.create_api_key" end # resource path local_var_path = '/api/v2/api_keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'APIKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_api_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#create_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_current_user_application_key(body, opts = {}) ⇒ Object
Create an application key for current user.
96 97 98 99 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 96 def create_current_user_application_key(body, opts = {}) data, _status_code, _headers = create_current_user_application_key_with_http_info(body, opts) data end |
#create_current_user_application_key_with_http_info(body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Create an application key for current user.
Create an application key for current user
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 108 def create_current_user_application_key_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.create_current_user_application_key ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.create_current_user_application_key" end # resource path local_var_path = '/api/v2/current_user/application_keys' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_current_user_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#create_current_user_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_personal_access_token(body, opts = {}) ⇒ Object
Create a personal access token.
163 164 165 166 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 163 def create_personal_access_token(body, opts = {}) data, _status_code, _headers = create_personal_access_token_with_http_info(body, opts) data end |
#create_personal_access_token_with_http_info(body, opts = {}) ⇒ Array<(PersonalAccessTokenCreateResponse, Integer, Hash)>
Create a personal access token.
Create a personal access token for the current user.
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 175 def create_personal_access_token_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.create_personal_access_token ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.create_personal_access_token" end # resource path local_var_path = '/api/v2/personal_access_tokens' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'PersonalAccessTokenCreateResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_personal_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#create_personal_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_api_key(api_key_id, opts = {}) ⇒ Object
Delete an API key.
230 231 232 233 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 230 def delete_api_key(api_key_id, opts = {}) delete_api_key_with_http_info(api_key_id, opts) nil end |
#delete_api_key_with_http_info(api_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an API key.
Delete an API key.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 242 def delete_api_key_with_http_info(api_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.delete_api_key ...' end # verify the required parameter 'api_key_id' is set if @api_client.config.client_side_validation && api_key_id.nil? fail ArgumentError, "Missing the required parameter 'api_key_id' when calling KeyManagementAPI.delete_api_key" end # resource path local_var_path = '/api/v2/api_keys/{api_key_id}'.sub('{api_key_id}', CGI.escape(api_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :delete_api_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#delete_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_application_key(app_key_id, opts = {}) ⇒ Object
Delete an application key.
295 296 297 298 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 295 def delete_application_key(app_key_id, opts = {}) delete_application_key_with_http_info(app_key_id, opts) nil end |
#delete_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an application key.
Delete an application key
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 307 def delete_application_key_with_http_info(app_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.delete_application_key ...' end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling KeyManagementAPI.delete_application_key" end # resource path local_var_path = '/api/v2/application_keys/{app_key_id}'.sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :delete_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#delete_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_current_user_application_key(app_key_id, opts = {}) ⇒ Object
Delete an application key owned by current user.
360 361 362 363 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 360 def delete_current_user_application_key(app_key_id, opts = {}) delete_current_user_application_key_with_http_info(app_key_id, opts) nil end |
#delete_current_user_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an application key owned by current user.
Delete an application key owned by current user
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 372 def delete_current_user_application_key_with_http_info(app_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.delete_current_user_application_key ...' end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling KeyManagementAPI.delete_current_user_application_key" end # resource path local_var_path = '/api/v2/current_user/application_keys/{app_key_id}'.sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :delete_current_user_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#delete_current_user_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_api_key(api_key_id, opts = {}) ⇒ Object
Get API key.
425 426 427 428 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 425 def get_api_key(api_key_id, opts = {}) data, _status_code, _headers = get_api_key_with_http_info(api_key_id, opts) data end |
#get_api_key_with_http_info(api_key_id, opts = {}) ⇒ Array<(APIKeyResponse, Integer, Hash)>
Get API key.
Get an API key.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 438 def get_api_key_with_http_info(api_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.get_api_key ...' end # verify the required parameter 'api_key_id' is set if @api_client.config.client_side_validation && api_key_id.nil? fail ArgumentError, "Missing the required parameter 'api_key_id' when calling KeyManagementAPI.get_api_key" end # resource path local_var_path = '/api/v2/api_keys/{api_key_id}'.sub('{api_key_id}', CGI.escape(api_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'APIKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_api_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#get_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_application_key(app_key_id, opts = {}) ⇒ Object
Get an application key.
492 493 494 495 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 492 def get_application_key(app_key_id, opts = {}) data, _status_code, _headers = get_application_key_with_http_info(app_key_id, opts) data end |
#get_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Get an application key.
Get an application key for your org.
505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 505 def get_application_key_with_http_info(app_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.get_application_key ...' end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling KeyManagementAPI.get_application_key" end # resource path local_var_path = '/api/v2/application_keys/{app_key_id}'.sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#get_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_current_user_application_key(app_key_id, opts = {}) ⇒ Object
Get one application key owned by current user.
559 560 561 562 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 559 def get_current_user_application_key(app_key_id, opts = {}) data, _status_code, _headers = get_current_user_application_key_with_http_info(app_key_id, opts) data end |
#get_current_user_application_key_with_http_info(app_key_id, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Get one application key owned by current user.
Get an application key owned by current user. The ‘key` field is not returned for organizations in [One-Time Read mode](docs.datadoghq.com/account_management/api-app-keys/#one-time-read-mode).
572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 572 def get_current_user_application_key_with_http_info(app_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.get_current_user_application_key ...' end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling KeyManagementAPI.get_current_user_application_key" end # resource path local_var_path = '/api/v2/current_user/application_keys/{app_key_id}'.sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_current_user_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#get_current_user_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_personal_access_token(pat_id, opts = {}) ⇒ Object
Get a personal access token.
625 626 627 628 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 625 def get_personal_access_token(pat_id, opts = {}) data, _status_code, _headers = get_personal_access_token_with_http_info(pat_id, opts) data end |
#get_personal_access_token_with_http_info(pat_id, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Get a personal access token.
Get a specific personal access token by its UUID.
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 637 def get_personal_access_token_with_http_info(pat_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.get_personal_access_token ...' end # verify the required parameter 'pat_id' is set if @api_client.config.client_side_validation && pat_id.nil? fail ArgumentError, "Missing the required parameter 'pat_id' when calling KeyManagementAPI.get_personal_access_token" end # resource path local_var_path = '/api/v2/personal_access_tokens/{pat_id}'.sub('{pat_id}', CGI.escape(pat_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PersonalAccessTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_personal_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#get_personal_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_api_keys(opts = {}) ⇒ Object
Get all API keys.
690 691 692 693 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 690 def list_api_keys(opts = {}) data, _status_code, _headers = list_api_keys_with_http_info(opts) data end |
#list_api_keys_with_http_info(opts = {}) ⇒ Array<(APIKeysResponse, Integer, Hash)>
Get all API keys.
List all API keys available for your account.
712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 712 def list_api_keys_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.list_api_keys ...' end allowable_values = ['created_at', '-created_at', 'last4', '-last4', 'modified_at', '-modified_at', 'name', '-name'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/api_keys' # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'filter[created_at][start]'] = opts[:'filter_created_at_start'] if !opts[:'filter_created_at_start'].nil? query_params[:'filter[created_at][end]'] = opts[:'filter_created_at_end'] if !opts[:'filter_created_at_end'].nil? query_params[:'filter[modified_at][start]'] = opts[:'filter_modified_at_start'] if !opts[:'filter_modified_at_start'].nil? query_params[:'filter[modified_at][end]'] = opts[:'filter_modified_at_end'] if !opts[:'filter_modified_at_end'].nil? query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? query_params[:'filter[remote_config_read_enabled]'] = opts[:'filter_remote_config_read_enabled'] if !opts[:'filter_remote_config_read_enabled'].nil? query_params[:'filter[category]'] = opts[:'filter_category'] if !opts[:'filter_category'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'APIKeysResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_api_keys, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#list_api_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_application_keys(opts = {}) ⇒ Object
Get all application keys.
776 777 778 779 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 776 def list_application_keys(opts = {}) data, _status_code, _headers = list_application_keys_with_http_info(opts) data end |
#list_application_keys_with_http_info(opts = {}) ⇒ Array<(ListApplicationKeysResponse, Integer, Hash)>
Get all application keys.
List all application keys available for your org
794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 794 def list_application_keys_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.list_application_keys ...' end allowable_values = ['created_at', '-created_at', 'last4', '-last4', 'name', '-name'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/application_keys' # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'filter[created_at][start]'] = opts[:'filter_created_at_start'] if !opts[:'filter_created_at_start'].nil? query_params[:'filter[created_at][end]'] = opts[:'filter_created_at_end'] if !opts[:'filter_created_at_end'].nil? query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListApplicationKeysResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_application_keys, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#list_application_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_current_user_application_keys(opts = {}) ⇒ Object
Get all application keys owned by current user.
854 855 856 857 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 854 def list_current_user_application_keys(opts = {}) data, _status_code, _headers = list_current_user_application_keys_with_http_info(opts) data end |
#list_current_user_application_keys_with_http_info(opts = {}) ⇒ Array<(ListApplicationKeysResponse, Integer, Hash)>
Get all application keys owned by current user.
List all application keys available for current user
872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 872 def list_current_user_application_keys_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.list_current_user_application_keys ...' end allowable_values = ['created_at', '-created_at', 'last4', '-last4', 'name', '-name'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/current_user/application_keys' # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'filter[created_at][start]'] = opts[:'filter_created_at_start'] if !opts[:'filter_created_at_start'].nil? query_params[:'filter[created_at][end]'] = opts[:'filter_created_at_end'] if !opts[:'filter_created_at_end'].nil? query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListApplicationKeysResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_current_user_application_keys, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#list_current_user_application_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_personal_access_tokens(opts = {}) ⇒ Object
Get all personal access tokens.
932 933 934 935 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 932 def list_personal_access_tokens(opts = {}) data, _status_code, _headers = list_personal_access_tokens_with_http_info(opts) data end |
#list_personal_access_tokens_with_http_info(opts = {}) ⇒ Array<(ListPersonalAccessTokensResponse, Integer, Hash)>
Get all personal access tokens.
List all personal access tokens for the organization.
948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 948 def list_personal_access_tokens_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.list_personal_access_tokens ...' end allowable_values = ['name', '-name', 'created_at', '-created_at', 'expires_at', '-expires_at'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/personal_access_tokens' # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'filter[owner_uuid]'] = @api_client.build_collection_param(opts[:'filter_owner_uuid'], :multi) if !opts[:'filter_owner_uuid'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListPersonalAccessTokensResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_personal_access_tokens, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) [:query_string_normalizer] = HTTParty::Request::NON_RAILS_QUERY_STRING_NORMALIZER data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#list_personal_access_tokens\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_personal_access_token(pat_id, opts = {}) ⇒ Object
Revoke a personal access token.
1007 1008 1009 1010 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1007 def revoke_personal_access_token(pat_id, opts = {}) revoke_personal_access_token_with_http_info(pat_id, opts) nil end |
#revoke_personal_access_token_with_http_info(pat_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke a personal access token.
Revoke a specific personal access token.
1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1019 def revoke_personal_access_token_with_http_info(pat_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.revoke_personal_access_token ...' end # verify the required parameter 'pat_id' is set if @api_client.config.client_side_validation && pat_id.nil? fail ArgumentError, "Missing the required parameter 'pat_id' when calling KeyManagementAPI.revoke_personal_access_token" end # resource path local_var_path = '/api/v2/personal_access_tokens/{pat_id}'.sub('{pat_id}', CGI.escape(pat_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :revoke_personal_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#revoke_personal_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_api_key(api_key_id, body, opts = {}) ⇒ Object
Edit an API key.
1072 1073 1074 1075 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1072 def update_api_key(api_key_id, body, opts = {}) data, _status_code, _headers = update_api_key_with_http_info(api_key_id, body, opts) data end |
#update_api_key_with_http_info(api_key_id, body, opts = {}) ⇒ Array<(APIKeyResponse, Integer, Hash)>
Edit an API key.
Update an API key.
1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1085 def update_api_key_with_http_info(api_key_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.update_api_key ...' end # verify the required parameter 'api_key_id' is set if @api_client.config.client_side_validation && api_key_id.nil? fail ArgumentError, "Missing the required parameter 'api_key_id' when calling KeyManagementAPI.update_api_key" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.update_api_key" end # resource path local_var_path = '/api/v2/api_keys/{api_key_id}'.sub('{api_key_id}', CGI.escape(api_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'APIKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_api_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#update_api_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_application_key(app_key_id, body, opts = {}) ⇒ Object
Edit an application key.
1144 1145 1146 1147 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1144 def update_application_key(app_key_id, body, opts = {}) data, _status_code, _headers = update_application_key_with_http_info(app_key_id, body, opts) data end |
#update_application_key_with_http_info(app_key_id, body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Edit an application key.
Edit an application key
1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 1204 1205 1206 1207 1208 1209 1210 1211 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1157 def update_application_key_with_http_info(app_key_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.update_application_key ...' end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling KeyManagementAPI.update_application_key" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.update_application_key" end # resource path local_var_path = '/api/v2/application_keys/{app_key_id}'.sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#update_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_current_user_application_key(app_key_id, body, opts = {}) ⇒ Object
Edit an application key owned by current user.
1216 1217 1218 1219 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1216 def update_current_user_application_key(app_key_id, body, opts = {}) data, _status_code, _headers = update_current_user_application_key_with_http_info(app_key_id, body, opts) data end |
#update_current_user_application_key_with_http_info(app_key_id, body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Edit an application key owned by current user.
Edit an application key owned by current user. The ‘key` field is not returned for organizations in [One-Time Read mode](docs.datadoghq.com/account_management/api-app-keys/#one-time-read-mode).
1230 1231 1232 1233 1234 1235 1236 1237 1238 1239 1240 1241 1242 1243 1244 1245 1246 1247 1248 1249 1250 1251 1252 1253 1254 1255 1256 1257 1258 1259 1260 1261 1262 1263 1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 1275 1276 1277 1278 1279 1280 1281 1282 1283 1284 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1230 def update_current_user_application_key_with_http_info(app_key_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.update_current_user_application_key ...' end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling KeyManagementAPI.update_current_user_application_key" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.update_current_user_application_key" end # resource path local_var_path = '/api/v2/current_user/application_keys/{app_key_id}'.sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_current_user_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#update_current_user_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_personal_access_token(pat_id, body, opts = {}) ⇒ Object
Update a personal access token.
1289 1290 1291 1292 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1289 def update_personal_access_token(pat_id, body, opts = {}) data, _status_code, _headers = update_personal_access_token_with_http_info(pat_id, body, opts) data end |
#update_personal_access_token_with_http_info(pat_id, body, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Update a personal access token.
Update a specific personal access token.
1302 1303 1304 1305 1306 1307 1308 1309 1310 1311 1312 1313 1314 1315 1316 1317 1318 1319 1320 1321 1322 1323 1324 1325 1326 1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 |
# File 'lib/datadog_api_client/v2/api/key_management_api.rb', line 1302 def update_personal_access_token_with_http_info(pat_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: KeyManagementAPI.update_personal_access_token ...' end # verify the required parameter 'pat_id' is set if @api_client.config.client_side_validation && pat_id.nil? fail ArgumentError, "Missing the required parameter 'pat_id' when calling KeyManagementAPI.update_personal_access_token" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling KeyManagementAPI.update_personal_access_token" end # resource path local_var_path = '/api/v2/personal_access_tokens/{pat_id}'.sub('{pat_id}', CGI.escape(pat_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'PersonalAccessTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_personal_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: KeyManagementAPI#update_personal_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |