Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigAssessmentCriteria
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsCustomEvalConfigAssessmentCriteria
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_assessment_criteria.rb
Overview
Criteria used to assess the pass/fail result of a custom evaluator.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#max_threshold ⇒ Object
Maximum numeric threshold for a passing result.
-
#min_threshold ⇒ Object
Minimum numeric threshold for a passing result.
-
#pass_values ⇒ Object
Specific output values considered as a passing result.
-
#pass_when ⇒ Object
When true, a boolean output of true is treated as passing.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_assessment_criteria.rb', line 36 def additional_properties @additional_properties end |
#max_threshold ⇒ Object
Maximum numeric threshold for a passing result.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_assessment_criteria.rb', line 25 def max_threshold @max_threshold end |
#min_threshold ⇒ Object
Minimum numeric threshold for a passing result.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_assessment_criteria.rb', line 28 def min_threshold @min_threshold end |
#pass_values ⇒ Object
Specific output values considered as a passing result.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_assessment_criteria.rb', line 31 def pass_values @pass_values end |
#pass_when ⇒ Object
When true, a boolean output of true is treated as passing.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_assessment_criteria.rb', line 34 def pass_when @pass_when end |