Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb

Overview

Attributes of a custom LLM Observability evaluator configuration.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



51
52
53
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 51

def additional_properties
  @additional_properties
end

#categoryObject

Category of the evaluator.



25
26
27
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 25

def category
  @category
end

#created_atObject

Timestamp when the evaluator configuration was created.



28
29
30
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 28

def created_at
  @created_at
end

#created_byObject

A Datadog user associated with a custom evaluator configuration.



31
32
33
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 31

def created_by
  @created_by
end

#eval_nameObject

Name of the custom evaluator.



34
35
36
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 34

def eval_name
  @eval_name
end

#last_updated_byObject

A Datadog user associated with a custom evaluator configuration.



37
38
39
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 37

def last_updated_by
  @last_updated_by
end

#llm_judge_configObject

LLM judge configuration for a custom evaluator.



40
41
42
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 40

def llm_judge_config
  @llm_judge_config
end

#llm_providerObject

LLM provider configuration for a custom evaluator.



43
44
45
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 43

def llm_provider
  @llm_provider
end

#targetObject

Target application configuration for a custom evaluator.



46
47
48
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 46

def target
  @target
end

#updated_atObject

Timestamp when the evaluator configuration was last updated.



49
50
51
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 49

def updated_at
  @updated_at
end