Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigLLMJudgeConfig

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb

Overview

LLM judge configuration for a custom evaluator.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



54
55
56
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 54

def additional_properties
  @additional_properties
end

#assessment_criteriaObject

Criteria used to assess the pass/fail result of a custom evaluator.



25
26
27
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 25

def assessment_criteria
  @assessment_criteria
end

#context_queryObject

Query used to extract additional context for the evaluation.



28
29
30
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 28

def context_query
  @context_query
end

#inference_paramsObject

LLM inference parameters for a custom evaluator.



31
32
33
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 31

def inference_params
  @inference_params
end

#last_used_library_prompt_template_nameObject

Name of the last library prompt template used.



34
35
36
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 34

def last_used_library_prompt_template_name
  @last_used_library_prompt_template_name
end

#modified_library_prompt_templateObject

Whether the library prompt template was modified.



37
38
39
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 37

def modified_library_prompt_template
  @modified_library_prompt_template
end

#output_schemaObject

JSON schema describing the expected output format of the LLM judge.



40
41
42
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 40

def output_schema
  @output_schema
end

#parsing_typeObject

Output parsing type for a custom LLM judge evaluator.



43
44
45
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 43

def parsing_type
  @parsing_type
end

#prompt_templateObject

List of messages forming the LLM judge prompt template.



46
47
48
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 46

def prompt_template
  @prompt_template
end

#target_queryObject

Query used to extract the target value to evaluate.



49
50
51
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 49

def target_query
  @target_query
end

#user_specified_json_post_processing_functionObject

User-provided function applied to post-process the JSON output of the LLM judge.



52
53
54
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 52

def user_specified_json_post_processing_function
  @user_specified_json_post_processing_function
end