Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigPromptToolResult
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsCustomEvalConfigPromptToolResult
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_prompt_tool_result.rb
Overview
A tool call result within a prompt message.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#name ⇒ Object
Name of the tool that produced this result.
-
#result ⇒ Object
The result returned by the tool.
-
#tool_id ⇒ Object
Identifier of the tool call this result corresponds to.
-
#type ⇒ Object
Type of the tool result.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_prompt_tool_result.rb', line 36 def additional_properties @additional_properties end |
#name ⇒ Object
Name of the tool that produced this result.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_prompt_tool_result.rb', line 25 def name @name end |
#result ⇒ Object
The result returned by the tool.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_prompt_tool_result.rb', line 28 def result @result end |
#tool_id ⇒ Object
Identifier of the tool call this result corresponds to.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_prompt_tool_result.rb', line 31 def tool_id @tool_id end |
#type ⇒ Object
Type of the tool result.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_prompt_tool_result.rb', line 34 def type @type end |