Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigTarget
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsCustomEvalConfigTarget
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb
Overview
Target application configuration for a custom evaluator.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#application_name ⇒ Object
readonly
Name of the ML application this evaluator targets.
-
#enabled ⇒ Object
readonly
Whether the evaluator is active for the target application.
-
#eval_scope ⇒ Object
Scope at which to evaluate spans.
-
#filter ⇒ Object
Filter expression to select which spans to evaluate.
-
#root_spans_only ⇒ Object
When true, only root spans are evaluated.
-
#sampling_percentage ⇒ Object
Percentage of traces to evaluate.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 42 def additional_properties @additional_properties end |
#application_name ⇒ Object
Name of the ML application this evaluator targets.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 25 def application_name @application_name end |
#enabled ⇒ Object
Whether the evaluator is active for the target application.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 28 def enabled @enabled end |
#eval_scope ⇒ Object
Scope at which to evaluate spans.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 31 def eval_scope @eval_scope end |
#filter ⇒ Object
Filter expression to select which spans to evaluate.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 34 def filter @filter end |
#root_spans_only ⇒ Object
When true, only root spans are evaluated.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 37 def root_spans_only @root_spans_only end |
#sampling_percentage ⇒ Object
Percentage of traces to evaluate. Must be greater than 0 and at most 100.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_target.rb', line 40 def sampling_percentage @sampling_percentage end |