Class: DatadogAPIClient::V2::LLMObsPatternsClusteredPoint

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb

Overview

A single data point grouped into a topic.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



48
49
50
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 48

def additional_properties
  @additional_properties
end

#event_idObject

Identifier of the source event.



25
26
27
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 25

def event_id
  @event_id
end

#idObject

Unique identifier of the clustered point.



28
29
30
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 28

def id
  @id
end

#inputObject

Input text of the source span.



31
32
33
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 31

def input
  @input
end

#is_includedObject

Whether the point is included in the patterns dataset.



34
35
36
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 34

def is_included
  @is_included
end

#is_suggestedObject

Whether the point is suggested for inclusion in the patterns dataset.



37
38
39
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 37

def is_suggested
  @is_suggested
end

#session_idObject

Identifier of the source session.



40
41
42
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 40

def session_id
  @session_id
end

#span_idObject

Identifier of the source span.



43
44
45
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 43

def span_id
  @span_id
end

#topic_idObject

Identifier of the topic the point belongs to.



46
47
48
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 46

def topic_id
  @topic_id
end