Class: DatadogAPIClient::V2::LLMObsPatternsClusteredPointRef

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb

Overview

A clustered point attached inline to a topic. The metric fields are populated only when the request includes ‘include_metrics=true`.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



50
51
52
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 50

def additional_properties
  @additional_properties
end

#durationObject

Duration of the source span in nanoseconds. Included only when metrics are requested.



26
27
28
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 26

def duration
  @duration
end

#estimated_total_costObject

Estimated total cost of the source span. Included only when metrics are requested.



29
30
31
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 29

def estimated_total_cost
  @estimated_total_cost
end

#evaluationObject

Evaluation results for the source span keyed by evaluation name. Included only when metrics are requested.



33
34
35
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 33

def evaluation
  @evaluation
end

#input_tokensObject

Number of input tokens of the source span. Included only when metrics are requested.



36
37
38
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 36

def input_tokens
  @input_tokens
end

#output_tokensObject

Number of output tokens of the source span. Included only when metrics are requested.



39
40
41
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 39

def output_tokens
  @output_tokens
end

#span_idObject

Identifier of the source span.



42
43
44
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 42

def span_id
  @span_id
end

#statusObject

Status of the source span. Included only when metrics are requested.



45
46
47
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 45

def status
  @status
end

#total_tokensObject

Total number of tokens of the source span. Included only when metrics are requested.



48
49
50
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point_ref.rb', line 48

def total_tokens
  @total_tokens
end