Class: DatadogAPIClient::V2::LLMObsPatternsConfigAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsPatternsConfigAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb
Overview
Attributes of an LLM Observability patterns configuration.
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Integration account ID for a bring-your-own-model configuration.
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#created_at ⇒ Object
readonly
Timestamp when the configuration was created.
-
#evp_query ⇒ Object
readonly
Query that selects the spans the patterns run analyzes.
-
#hierarchy_depth ⇒ Object
readonly
Depth of the topic hierarchy to generate.
-
#integration_provider ⇒ Object
Integration provider for a bring-your-own-model configuration.
-
#model_name ⇒ Object
Model name for a bring-your-own-model configuration.
-
#name ⇒ Object
readonly
Name of the configuration.
-
#num_records ⇒ Object
readonly
Maximum number of records to process for the run.
-
#sampling_ratio ⇒ Object
readonly
Fraction of matching spans to sample for the run.
-
#scope ⇒ Object
readonly
Scope of the configuration.
-
#template ⇒ Object
Template used to guide topic generation.
-
#updated_at ⇒ Object
readonly
Timestamp when the configuration was last updated.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#account_id ⇒ Object
Integration account ID for a bring-your-own-model configuration.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 25 def account_id @account_id end |
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
60 61 62 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 60 def additional_properties @additional_properties end |
#created_at ⇒ Object
Timestamp when the configuration was created.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 28 def created_at @created_at end |
#evp_query ⇒ Object
Query that selects the spans the patterns run analyzes.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 31 def evp_query @evp_query end |
#hierarchy_depth ⇒ Object
Depth of the topic hierarchy to generate.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 34 def hierarchy_depth @hierarchy_depth end |
#integration_provider ⇒ Object
Integration provider for a bring-your-own-model configuration.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 37 def integration_provider @integration_provider end |
#model_name ⇒ Object
Model name for a bring-your-own-model configuration.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 40 def model_name @model_name end |
#name ⇒ Object
Name of the configuration.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 43 def name @name end |
#num_records ⇒ Object
Maximum number of records to process for the run.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 46 def num_records @num_records end |
#sampling_ratio ⇒ Object
Fraction of matching spans to sample for the run.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 49 def sampling_ratio @sampling_ratio end |
#scope ⇒ Object
Scope of the configuration.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 52 def scope @scope end |
#template ⇒ Object
Template used to guide topic generation.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 55 def template @template end |
#updated_at ⇒ Object
Timestamp when the configuration was last updated.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_config_attributes.rb', line 58 def updated_at @updated_at end |