Class: DatadogAPIClient::V2::LLMObsPatternsRunSummary
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsPatternsRunSummary
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb
Overview
Summary of an LLM Observability patterns run.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#completed_at ⇒ Object
Timestamp when the run completed.
-
#config_snapshot ⇒ Object
Snapshot of the configuration used for a patterns run.
-
#created_at ⇒ Object
readonly
Timestamp when the run was created.
-
#id ⇒ Object
readonly
Unique identifier of the run.
-
#status ⇒ Object
readonly
Status of the run.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb', line 39 def additional_properties @additional_properties end |
#completed_at ⇒ Object
Timestamp when the run completed. Null if the run has not completed.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb', line 25 def completed_at @completed_at end |
#config_snapshot ⇒ Object
Snapshot of the configuration used for a patterns run.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb', line 28 def config_snapshot @config_snapshot end |
#created_at ⇒ Object
Timestamp when the run was created.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb', line 31 def created_at @created_at end |
#id ⇒ Object
Unique identifier of the run.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb', line 34 def id @id end |
#status ⇒ Object
Status of the run.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_run_summary.rb', line 37 def status @status end |