Class: DatadogAPIClient::V2::LLMObsPatternsTopicsResponseAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsPatternsTopicsResponseAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb
Overview
Attributes of an LLM Observability patterns topics response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#completed_at ⇒ Object
Timestamp when the run completed.
-
#config_id ⇒ Object
readonly
Identifier of the configuration that produced the run.
-
#config_snapshot ⇒ Object
Snapshot of the configuration used for a patterns run.
-
#created_at ⇒ Object
readonly
Timestamp when the run was created.
-
#previous_run_id ⇒ Object
readonly
Identifier of the run that completed immediately before this one.
-
#run_id ⇒ Object
readonly
Identifier of the run that produced the topics.
-
#topics ⇒ Object
readonly
List of discovered topics.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 45 def additional_properties @additional_properties end |
#completed_at ⇒ Object
Timestamp when the run completed. Null if the run has not completed.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 25 def completed_at @completed_at end |
#config_id ⇒ Object
Identifier of the configuration that produced the run.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 28 def config_id @config_id end |
#config_snapshot ⇒ Object
Snapshot of the configuration used for a patterns run.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 31 def config_snapshot @config_snapshot end |
#created_at ⇒ Object
Timestamp when the run was created.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 34 def created_at @created_at end |
#previous_run_id ⇒ Object
Identifier of the run that completed immediately before this one. Empty if none.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 37 def previous_run_id @previous_run_id end |
#run_id ⇒ Object
Identifier of the run that produced the topics.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 40 def run_id @run_id end |
#topics ⇒ Object
List of discovered topics.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_response_attributes.rb', line 43 def topics @topics end |