Class: DatadogAPIClient::V2::LLMObsPatternsTopicsWithClusteredPointsResponseAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb

Overview

Attributes of an LLM Observability patterns topics-with-clustered-points response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



45
46
47
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 45

def additional_properties
  @additional_properties
end

#completed_atObject

Timestamp when the run completed. Null if the run has not completed.



25
26
27
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 25

def completed_at
  @completed_at
end

#config_idObject

Identifier of the configuration that produced the run.



28
29
30
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 28

def config_id
  @config_id
end

#config_snapshotObject

Snapshot of the configuration used for a patterns run.



31
32
33
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 31

def config_snapshot
  @config_snapshot
end

#created_atObject

Timestamp when the run was created.



34
35
36
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 34

def created_at
  @created_at
end

#previous_run_idObject

Identifier of the run that completed immediately before this one. Empty if none.



37
38
39
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 37

def previous_run_id
  @previous_run_id
end

#run_idObject

Identifier of the run that produced the topics.



40
41
42
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 40

def run_id
  @run_id
end

#topicsObject

List of discovered topics with their clustered points.



43
44
45
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_topics_with_clustered_points_response_attributes.rb', line 43

def topics
  @topics
end