Class: DatadogAPIClient::V2::Log

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/log.rb

Overview

Object description of a log after being processed and stored by Datadog.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#attributesObject

JSON object containing all log attributes and their associated values.



29
30
31
# File 'lib/datadog_api_client/v2/models/log.rb', line 29

def attributes
  @attributes
end

#idObject

Unique ID of the Log.



32
33
34
# File 'lib/datadog_api_client/v2/models/log.rb', line 32

def id
  @id
end

#typeObject

Type of the event.



35
36
37
# File 'lib/datadog_api_client/v2/models/log.rb', line 35

def type
  @type
end