Class: DatadogAPIClient::V2::LogAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/log_attributes.rb
Overview
JSON object containing all log attributes and their associated values.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
JSON object of attributes from your log.
-
#host ⇒ Object
Name of the machine from where the logs are being sent.
-
#message ⇒ Object
The message [reserved attribute](docs.datadoghq.com/logs/log_collection/#reserved-attributes) of your log.
-
#service ⇒ Object
The name of the application or service generating the log events.
-
#status ⇒ Object
Status of the message associated with your log.
-
#tags ⇒ Object
Array of tags associated with your log.
-
#timestamp ⇒ Object
Timestamp of your log.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
JSON object of attributes from your log.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 29 def attributes @attributes end |
#host ⇒ Object
Name of the machine from where the logs are being sent.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 32 def host @host end |
#message ⇒ Object
The message [reserved attribute](docs.datadoghq.com/logs/log_collection/#reserved-attributes) of your log. By default, Datadog ingests the value of the message attribute as the body of the log entry. That value is then highlighted and displayed in the Logstream, where it is indexed for full text search.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 37 def @message end |
#service ⇒ Object
The name of the application or service generating the log events. It is used to switch from Logs to APM, so make sure you define the same value when you use both products.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 42 def service @service end |
#status ⇒ Object
Status of the message associated with your log.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 45 def status @status end |
#tags ⇒ Object
Array of tags associated with your log.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 48 def @tags end |
#timestamp ⇒ Object
Timestamp of your log.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/log_attributes.rb', line 51 def @timestamp end |