Class: DatadogAPIClient::V2::LogsAggregateRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogsAggregateRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/logs_aggregate_request.rb
Overview
The object sent with the request to retrieve a list of logs from your organization.
Instance Attribute Summary collapse
-
#compute ⇒ Object
The list of metrics or timeseries to compute for the retrieved buckets.
-
#filter ⇒ Object
The search and filter query settings.
-
#group_by ⇒ Object
The rules for the group by.
-
#options ⇒ Object
Global query options that are used during the query.
-
#page ⇒ Object
Paging settings.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#compute ⇒ Object
The list of metrics or timeseries to compute for the retrieved buckets.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/logs_aggregate_request.rb', line 29 def compute @compute end |
#filter ⇒ Object
The search and filter query settings
32 33 34 |
# File 'lib/datadog_api_client/v2/models/logs_aggregate_request.rb', line 32 def filter @filter end |
#group_by ⇒ Object
The rules for the group by
35 36 37 |
# File 'lib/datadog_api_client/v2/models/logs_aggregate_request.rb', line 35 def group_by @group_by end |
#options ⇒ Object
Global query options that are used during the query. Note: You should only supply timezone or time offset but not both otherwise the query will fail.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/logs_aggregate_request.rb', line 39 def end |
#page ⇒ Object
Paging settings
42 43 44 |
# File 'lib/datadog_api_client/v2/models/logs_aggregate_request.rb', line 42 def page @page end |