Class: DatadogAPIClient::V2::LogsArchiveAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogsArchiveAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/logs_archive_attributes.rb
Overview
The attributes associated with the archive.
Instance Attribute Summary collapse
-
#destination ⇒ Object
An archive’s destination.
-
#include_tags ⇒ Object
To store the tags in the archive, set the value “true”.
-
#name ⇒ Object
readonly
The archive name.
-
#query ⇒ Object
readonly
The archive query/filter.
-
#rehydration_max_scan_size_in_gb ⇒ Object
Maximum scan size for rehydration from this archive.
-
#rehydration_tags ⇒ Object
An array of tags to add to rehydrated logs from an archive.
-
#state ⇒ Object
The state of the archive.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#destination ⇒ Object
An archive’s destination.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 29 def destination @destination end |
#include_tags ⇒ Object
To store the tags in the archive, set the value “true”. If it is set to “false”, the tags will be deleted when the logs are sent to the archive.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 33 def end |
#name ⇒ Object
The archive name.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 36 def name @name end |
#query ⇒ Object
The archive query/filter. Logs matching this query are included in the archive.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 39 def query @query end |
#rehydration_max_scan_size_in_gb ⇒ Object
Maximum scan size for rehydration from this archive.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 42 def rehydration_max_scan_size_in_gb @rehydration_max_scan_size_in_gb end |
#rehydration_tags ⇒ Object
An array of tags to add to rehydrated logs from an archive.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 45 def end |
#state ⇒ Object
The state of the archive.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/logs_archive_attributes.rb', line 48 def state @state end |