Class: DatadogAPIClient::V2::LogsArchiveCreateRequestAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogsArchiveCreateRequestAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb
Overview
The attributes associated with the archive.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#compression_method ⇒ Object
The type of compression for the archive.
-
#destination ⇒ Object
readonly
An archive’s destination.
-
#include_tags ⇒ Object
To store the tags in the archive, set the value “true”.
-
#name ⇒ Object
readonly
The archive name.
-
#query ⇒ Object
readonly
The archive query/filter.
-
#rehydration_max_scan_size_in_gb ⇒ Object
Maximum scan size for rehydration from this archive.
-
#rehydration_tags ⇒ Object
An array of tags to add to rehydrated logs from an archive.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 46 def additional_properties @additional_properties end |
#compression_method ⇒ Object
The type of compression for the archive.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 25 def compression_method @compression_method end |
#destination ⇒ Object
An archive’s destination.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 28 def destination @destination end |
#include_tags ⇒ Object
To store the tags in the archive, set the value “true”. If it is set to “false”, the tags will be deleted when the logs are sent to the archive.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 32 def @include_tags end |
#name ⇒ Object
The archive name.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 35 def name @name end |
#query ⇒ Object
The archive query/filter. Logs matching this query are included in the archive.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 38 def query @query end |
#rehydration_max_scan_size_in_gb ⇒ Object
Maximum scan size for rehydration from this archive.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 41 def rehydration_max_scan_size_in_gb @rehydration_max_scan_size_in_gb end |
#rehydration_tags ⇒ Object
An array of tags to add to rehydrated logs from an archive.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/logs_archive_create_request_attributes.rb', line 44 def @rehydration_tags end |