Class: DatadogAPIClient::V2::LogsGroupBy
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogsGroupBy
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/logs_group_by.rb
Overview
A group by rule
Instance Attribute Summary collapse
-
#facet ⇒ Object
readonly
The name of the facet to use (required).
-
#histogram ⇒ Object
Used to perform a histogram computation (only for measure facets).
-
#limit ⇒ Object
The maximum buckets to return for this group by.
-
#missing ⇒ Object
The value to use for logs that don’t have the facet used to group by.
-
#sort ⇒ Object
A sort rule.
-
#total ⇒ Object
A resulting object to put the given computes in over all the matching records.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#facet ⇒ Object
The name of the facet to use (required)
29 30 31 |
# File 'lib/datadog_api_client/v2/models/logs_group_by.rb', line 29 def facet @facet end |
#histogram ⇒ Object
Used to perform a histogram computation (only for measure facets). Note: At most 100 buckets are allowed, the number of buckets is (max - min)/interval.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/logs_group_by.rb', line 33 def histogram @histogram end |
#limit ⇒ Object
The maximum buckets to return for this group by
36 37 38 |
# File 'lib/datadog_api_client/v2/models/logs_group_by.rb', line 36 def limit @limit end |
#missing ⇒ Object
The value to use for logs that don’t have the facet used to group by
39 40 41 |
# File 'lib/datadog_api_client/v2/models/logs_group_by.rb', line 39 def missing @missing end |
#sort ⇒ Object
A sort rule
42 43 44 |
# File 'lib/datadog_api_client/v2/models/logs_group_by.rb', line 42 def sort @sort end |
#total ⇒ Object
A resulting object to put the given computes in over all the matching records.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/logs_group_by.rb', line 45 def total @total end |