Class: DatadogAPIClient::V2::LogsListRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogsListRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/logs_list_request.rb
Overview
The request for a logs list.
Instance Attribute Summary collapse
-
#filter ⇒ Object
The search and filter query settings.
-
#options ⇒ Object
Global query options that are used during the query.
-
#page ⇒ Object
Paging attributes for listing logs.
-
#sort ⇒ Object
Sort parameters when querying logs.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#filter ⇒ Object
The search and filter query settings
29 30 31 |
# File 'lib/datadog_api_client/v2/models/logs_list_request.rb', line 29 def filter @filter end |
#options ⇒ Object
Global query options that are used during the query. Note: You should only supply timezone or time offset but not both otherwise the query will fail.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/logs_list_request.rb', line 33 def @options end |
#page ⇒ Object
Paging attributes for listing logs.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/logs_list_request.rb', line 36 def page @page end |
#sort ⇒ Object
Sort parameters when querying logs.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/logs_list_request.rb', line 39 def sort @sort end |