Class: DatadogAPIClient::V2::LogsQueryFilter

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/logs_query_filter.rb

Overview

The search and filter query settings

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#fromObject

The minimum time for the requested logs, supports date math and regular timestamps (milliseconds).



29
30
31
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 29

def from
  @from
end

#indexesObject

For customers with multiple indexes, the indexes to search. Defaults to [‘*’] which means all indexes.



32
33
34
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 32

def indexes
  @indexes
end

#queryObject

The search query - following the log search syntax.



35
36
37
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 35

def query
  @query
end

#storage_tierObject

Specifies storage type as indexes or online-archives



38
39
40
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 38

def storage_tier
  @storage_tier
end

#toObject

The maximum time for the requested logs, supports date math and regular timestamps (milliseconds).



41
42
43
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 41

def to
  @to
end