Class: DatadogAPIClient::V2::MaintenanceTemplateDataAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb

Overview

The attributes of a maintenance template.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



48
49
50
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 48

def additional_properties
  @additional_properties
end

#completed_descriptionObject

The description shown when a maintenance created from this template is completed.



25
26
27
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 25

def completed_description
  @completed_description
end

#component_idsObject

The IDs of the components affected by a maintenance created from this template.



28
29
30
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 28

def component_ids
  @component_ids
end

#created_atObject

Timestamp of when the maintenance template was created.



31
32
33
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 31

def created_at
  @created_at
end

#in_progress_descriptionObject

The description shown while a maintenance created from this template is in progress.



34
35
36
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 34

def in_progress_description
  @in_progress_description
end

#maintenance_titleObject

The title used for a maintenance created from this template.



37
38
39
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 37

def maintenance_title
  @maintenance_title
end

#modified_atObject

Timestamp of when the maintenance template was last modified.



40
41
42
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 40

def modified_at
  @modified_at
end

#nameObject

The name of the maintenance template.



43
44
45
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 43

def name
  @name
end

#scheduled_descriptionObject

The description shown when a maintenance created from this template is scheduled.



46
47
48
# File 'lib/datadog_api_client/v2/models/maintenance_template_data_attributes.rb', line 46

def scheduled_description
  @scheduled_description
end