Class: DatadogAPIClient::V2::MetricBulkTagConfigStatusAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb

Overview

Optional attributes for the status of a bulk tag configuration request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#emailsObject

A list of account emails to notify when the configuration is applied.



29
30
31
# File 'lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb', line 29

def emails
  @emails
end

#statusObject

The status of the request.



32
33
34
# File 'lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb', line 32

def status
  @status
end

#tagsObject

A list of tag names to apply to the configuration.



35
36
37
# File 'lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb', line 35

def tags
  @tags
end