Class: DatadogAPIClient::V2::MetricTagConfiguration
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::MetricTagConfiguration
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/metric_tag_configuration.rb
Overview
Object for a single metric tag configuration.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
Object containing the definition of a metric tag configuration attributes.
-
#id ⇒ Object
The metric name for this resource.
-
#type ⇒ Object
The metric tag configuration resource type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
Object containing the definition of a metric tag configuration attributes.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration.rb', line 29 def attributes @attributes end |
#id ⇒ Object
The metric name for this resource.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration.rb', line 32 def id @id end |
#type ⇒ Object
The metric tag configuration resource type.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration.rb', line 35 def type @type end |