Class: DatadogAPIClient::V2::MetricTagConfigurationAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::MetricTagConfigurationAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb
Overview
Object containing the definition of a metric tag configuration attributes.
Instance Attribute Summary collapse
-
#aggregations ⇒ Object
A list of queryable aggregation combinations for a count, rate, or gauge metric.
-
#created_at ⇒ Object
Timestamp when the tag configuration was created.
-
#include_percentiles ⇒ Object
Toggle to include or exclude percentile aggregations for distribution metrics.
-
#metric_type ⇒ Object
The metric’s type.
-
#modified_at ⇒ Object
Timestamp when the tag configuration was last modified.
-
#tags ⇒ Object
List of tag keys on which to group.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#aggregations ⇒ Object
A list of queryable aggregation combinations for a count, rate, or gauge metric. By default, count and rate metrics require the (time: sum, space: sum) aggregation and Gauge metrics require the (time: avg, space: avg) aggregation. Additional time & space combinations are also available:
-
time: avg, space: avg
-
time: avg, space: max
-
time: avg, space: min
-
time: avg, space: sum
-
time: count, space: sum
-
time: max, space: max
-
time: min, space: min
-
time: sum, space: avg
-
time: sum, space: sum
Can only be applied to metrics that have a metric_type of count, rate, or gauge.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb', line 44 def aggregations @aggregations end |
#created_at ⇒ Object
Timestamp when the tag configuration was created.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb', line 47 def created_at @created_at end |
#include_percentiles ⇒ Object
Toggle to include or exclude percentile aggregations for distribution metrics. Only present when the metric_type is distribution.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb', line 51 def include_percentiles @include_percentiles end |
#metric_type ⇒ Object
The metric’s type.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb', line 54 def metric_type @metric_type end |
#modified_at ⇒ Object
Timestamp when the tag configuration was last modified.
57 58 59 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb', line 57 def modified_at @modified_at end |
#tags ⇒ Object
List of tag keys on which to group.
60 61 62 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_attributes.rb', line 60 def end |