Class: DatadogAPIClient::V2::MetricTagConfigurationCreateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::MetricTagConfigurationCreateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/metric_tag_configuration_create_attributes.rb
Overview
Object containing the definition of a metric tag configuration to be created.
Instance Attribute Summary collapse
-
#aggregations ⇒ Object
A list of queryable aggregation combinations for a count, rate, or gauge metric.
-
#include_percentiles ⇒ Object
Toggle to include/exclude percentiles for a distribution metric.
-
#metric_type ⇒ Object
readonly
The metric’s type.
-
#tags ⇒ Object
readonly
A list of tag keys that will be queryable for your metric.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#aggregations ⇒ Object
A list of queryable aggregation combinations for a count, rate, or gauge metric. By default, count and rate metrics require the (time: sum, space: sum) aggregation and Gauge metrics require the (time: avg, space: avg) aggregation. Additional time & space combinations are also available:
-
time: avg, space: avg
-
time: avg, space: max
-
time: avg, space: min
-
time: avg, space: sum
-
time: count, space: sum
-
time: max, space: max
-
time: min, space: min
-
time: sum, space: avg
-
time: sum, space: sum
Can only be applied to metrics that have a metric_type of count, rate, or gauge.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_create_attributes.rb', line 44 def aggregations @aggregations end |
#include_percentiles ⇒ Object
Toggle to include/exclude percentiles for a distribution metric. Defaults to false. Can only be applied to metrics that have a metric_type of distribution.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_create_attributes.rb', line 48 def include_percentiles @include_percentiles end |
#metric_type ⇒ Object
The metric’s type.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_create_attributes.rb', line 51 def metric_type @metric_type end |
#tags ⇒ Object
A list of tag keys that will be queryable for your metric.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/metric_tag_configuration_create_attributes.rb', line 54 def end |