Class: DatadogAPIClient::V2::ObservabilityPipelineAmazonS3Source
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ObservabilityPipelineAmazonS3Source
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb
Overview
The ‘amazon_s3` source ingests logs from an Amazon S3 bucket. It supports AWS authentication, TLS encryption, and configurable compression.
**Supported pipeline types:** logs
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#auth ⇒ Object
AWS authentication credentials used for accessing AWS services such as S3.
-
#compression ⇒ Object
Compression format for objects retrieved from the S3 bucket.
-
#id ⇒ Object
readonly
The unique identifier for this component.
-
#region ⇒ Object
readonly
AWS region where the S3 bucket resides.
-
#tls ⇒ Object
Configuration for enabling TLS encryption between the pipeline component and external services.
-
#type ⇒ Object
readonly
The source type.
-
#url_key ⇒ Object
Name of the environment variable or secret that holds the S3 bucket URL.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 49 def additional_properties @additional_properties end |
#auth ⇒ Object
AWS authentication credentials used for accessing AWS services such as S3. If omitted, the system’s default credentials are used (for example, the IAM role and environment variables).
29 30 31 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 29 def auth @auth end |
#compression ⇒ Object
Compression format for objects retrieved from the S3 bucket. Use ‘auto` to detect compression from the object’s Content-Encoding header or file extension.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 32 def compression @compression end |
#id ⇒ Object
The unique identifier for this component. Used in other parts of the pipeline to reference this component (for example, as the ‘input` to downstream components).
35 36 37 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 35 def id @id end |
#region ⇒ Object
AWS region where the S3 bucket resides.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 38 def region @region end |
#tls ⇒ Object
Configuration for enabling TLS encryption between the pipeline component and external services.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 41 def tls @tls end |
#type ⇒ Object
The source type. Always ‘amazon_s3`.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 44 def type @type end |
#url_key ⇒ Object
Name of the environment variable or secret that holds the S3 bucket URL.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_amazon_s3_source.rb', line 47 def url_key @url_key end |