Class: DatadogAPIClient::V2::ObservabilityPipelineConfig

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/observability_pipeline_config.rb

Overview

Specifies the pipeline’s configuration, including its sources, processors, and destinations.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



48
49
50
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 48

def additional_properties
  @additional_properties
end

#destinationsObject

A list of destination components where processed logs are sent.



25
26
27
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 25

def destinations
  @destinations
end

#pipeline_typeObject

The type of data being ingested. Defaults to ‘logs` if not specified.



28
29
30
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 28

def pipeline_type
  @pipeline_type
end

#processor_groupsObject

A list of processor groups that transform or enrich log data.



31
32
33
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 31

def processor_groups
  @processor_groups
end

#processorsObject

A list of processor groups that transform or enrich log data.

Deprecated: This field is deprecated, you should now use the processor_groups field.



36
37
38
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 36

def processors
  @processors
end

#sourcesObject

A list of configured data sources for the pipeline.



39
40
41
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 39

def sources
  @sources
end

#use_legacy_search_syntaxObject

Set to ‘true` to continue using the legacy search syntax while migrating filter queries. After migrating all queries to the new syntax, set to `false`. The legacy syntax is deprecated and will eventually be removed. Requires Observability Pipelines Worker 2.11 or later. Only applies to `logs` pipelines. This field is ignored for `metrics` pipelines. See [Upgrade Your Filter Queries to the New Search Syntax](docs.datadoghq.com/observability_pipelines/guide/upgrade_your_filter_queries_to_the_new_search_syntax/) for more information.



46
47
48
# File 'lib/datadog_api_client/v2/models/observability_pipeline_config.rb', line 46

def use_legacy_search_syntax
  @use_legacy_search_syntax
end