Class: DatadogAPIClient::V2::ObservabilityPipelineElasticsearchDestination

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb

Overview

The ‘elasticsearch` destination writes logs or metrics to an Elasticsearch cluster.

**Supported pipeline types:** logs, metrics

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



69
70
71
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 69

def additional_properties
  @additional_properties
end

#api_versionObject

The Elasticsearch API version to use. Set to ‘auto` to auto-detect.



27
28
29
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 27

def api_version
  @api_version
end

#authObject

Authentication settings for the Elasticsearch destination. When ‘strategy` is `basic`, use `username_key` and `password_key` to reference credentials stored in environment variables or secrets.



31
32
33
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 31

def auth
  @auth
end

#bufferObject

Configuration for buffer settings on destination components.



34
35
36
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 34

def buffer
  @buffer
end

#bulk_indexObject

The name of the index to write events to in Elasticsearch.



37
38
39
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 37

def bulk_index
  @bulk_index
end

#compressionObject

Compression configuration for the Elasticsearch destination.



40
41
42
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 40

def compression
  @compression
end

#data_streamObject

Configuration options for writing to Elasticsearch Data Streams instead of a fixed index.



43
44
45
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 43

def data_stream
  @data_stream
end

#endpoint_url_keyObject

Name of the environment variable or secret that holds the Elasticsearch endpoint URL.



46
47
48
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 46

def endpoint_url_key
  @endpoint_url_key
end

#idObject

The unique identifier for this component.



49
50
51
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 49

def id
  @id
end

#id_keyObject

The name of the field used as the document ID in Elasticsearch.



52
53
54
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 52

def id_key
  @id_key
end

#inputsObject

A list of component IDs whose output is used as the ‘input` for this component.



55
56
57
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 55

def inputs
  @inputs
end

#pipelineObject

The name of an Elasticsearch ingest pipeline to apply to events before indexing.



58
59
60
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 58

def pipeline
  @pipeline
end

#request_retry_partialObject

When ‘true`, retries failed partial bulk requests when some events in a batch fail while others succeed.



61
62
63
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 61

def request_retry_partial
  @request_retry_partial
end

#tlsObject

Configuration for enabling TLS encryption between the pipeline component and external services.



64
65
66
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 64

def tls
  @tls
end

#typeObject

The destination type. The value should always be ‘elasticsearch`.



67
68
69
# File 'lib/datadog_api_client/v2/models/observability_pipeline_elasticsearch_destination.rb', line 67

def type
  @type
end