Class: DatadogAPIClient::V2::ObservabilityPipelineQuotaProcessor

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb

Overview

The ‘quota` processor measures logging traffic for logs that match a specified filter. When the configured daily quota is met, the processor can drop or alert.

**Supported pipeline types:** logs

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



71
72
73
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 71

def additional_properties
  @additional_properties
end

#display_nameObject

The display name for a component.



27
28
29
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 27

def display_name
  @display_name
end

#drop_eventsObject

If set to ‘true`, logs that match the quota filter and are sent after the quota is exceeded are dropped. Logs that do not match the filter continue through the pipeline. Note: You can set either `drop_events` or `overflow_action`, but not both.



30
31
32
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 30

def drop_events
  @drop_events
end

#enabledObject

Indicates whether the processor is enabled.



33
34
35
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 33

def enabled
  @enabled
end

#idObject

The unique identifier for this component. Used in other parts of the pipeline to reference this component (for example, as the ‘input` to downstream components).



36
37
38
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 36

def id
  @id
end

#ignore_when_missing_partitionsObject

If ‘true`, the processor skips quota checks when partition fields are missing from the logs.



39
40
41
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 39

def ignore_when_missing_partitions
  @ignore_when_missing_partitions
end

#includeObject

A Datadog search query used to determine which logs this processor targets.



42
43
44
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 42

def include
  @include
end

#limitObject

The maximum amount of data or number of events allowed before the quota is enforced. Can be specified in bytes or events.



45
46
47
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 45

def limit
  @limit
end

#nameObject

Name of the quota.



48
49
50
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 48

def name
  @name
end

#overflow_actionObject

The action to take when the quota or bucket limit is exceeded. Options:

  • ‘drop`: Drop the event.

  • ‘no_action`: Let the event pass through.

  • ‘overflow_routing`: Route to an overflow destination.



54
55
56
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 54

def overflow_action
  @overflow_action
end

#overridesObject

A list of alternate quota rules that apply to specific sets of events, identified by matching field values. Each override can define a custom limit.



57
58
59
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 57

def overrides
  @overrides
end

#partition_fieldsObject

A list of fields used to segment log traffic for quota enforcement. Quotas are tracked independently by unique combinations of these field values.



60
61
62
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 60

def partition_fields
  @partition_fields
end

#too_many_buckets_actionObject

The action to take when the quota or bucket limit is exceeded. Options:

  • ‘drop`: Drop the event.

  • ‘no_action`: Let the event pass through.

  • ‘overflow_routing`: Route to an overflow destination.



66
67
68
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 66

def too_many_buckets_action
  @too_many_buckets_action
end

#typeObject

The processor type. The value should always be ‘quota`.



69
70
71
# File 'lib/datadog_api_client/v2/models/observability_pipeline_quota_processor.rb', line 69

def type
  @type
end