Class: DatadogAPIClient::V2::ObservabilityPipelineSplunkHecDestination

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb

Overview

The ‘splunk_hec` destination forwards logs to Splunk using the HTTP Event Collector (HEC).

**Supported pipeline types:** logs

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



63
64
65
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 63

def additional_properties
  @additional_properties
end

#auto_extract_timestampObject

If ‘true`, Splunk tries to extract timestamps from incoming log events. If `false`, Splunk assigns the time the event was received.



28
29
30
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 28

def auto_extract_timestamp
  @auto_extract_timestamp
end

#bufferObject

Configuration for buffer settings on destination components.



31
32
33
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 31

def buffer
  @buffer
end

#encodingObject

Encoding format for log events.



34
35
36
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 34

def encoding
  @encoding
end

#endpoint_url_keyObject

Name of the environment variable or secret that holds the Splunk HEC endpoint URL.



37
38
39
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 37

def endpoint_url_key
  @endpoint_url_key
end

#idObject

The unique identifier for this component. Used in other parts of the pipeline to reference this component (for example, as the ‘input` to downstream components).



40
41
42
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 40

def id
  @id
end

#indexObject

Optional name of the Splunk index where logs are written.



43
44
45
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 43

def index
  @index
end

#indexed_fieldsObject

List of log field names to send as indexed fields to Splunk HEC. Available only when ‘encoding` is `json`.



46
47
48
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 46

def indexed_fields
  @indexed_fields
end

#inputsObject

A list of component IDs whose output is used as the ‘input` for this component.



49
50
51
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 49

def inputs
  @inputs
end

#sourcetypeObject

The Splunk sourcetype to assign to log events.



52
53
54
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 52

def sourcetype
  @sourcetype
end

#token_keyObject

Name of the environment variable or secret that holds the Splunk HEC token.



55
56
57
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 55

def token_key
  @token_key
end

#token_strategyObject

Controls how the Splunk HEC token is supplied. Use ‘custom` to provide a token with `token_key`, or `from_source` to forward the token received from an upstream Splunk HEC source.



58
59
60
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 58

def token_strategy
  @token_strategy
end

#typeObject

The destination type. Always ‘splunk_hec`.



61
62
63
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_destination.rb', line 61

def type
  @type
end