Class: DatadogAPIClient::V2::ObservabilityPipelineSplunkHecSource
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ObservabilityPipelineSplunkHecSource
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb
Overview
The ‘splunk_hec` source implements the Splunk HTTP Event Collector (HEC) API.
**Supported pipeline types:** logs
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#address_key ⇒ Object
Name of the environment variable or secret that holds the listen address for the HEC API.
-
#id ⇒ Object
readonly
The unique identifier for this component.
-
#store_hec_token ⇒ Object
When ‘true`, the Splunk HEC token from the incoming request is stored in the event metadata.
-
#tls ⇒ Object
Configuration for enabling TLS encryption between the pipeline component and external services.
-
#type ⇒ Object
readonly
The source type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb', line 42 def additional_properties @additional_properties end |
#address_key ⇒ Object
Name of the environment variable or secret that holds the listen address for the HEC API.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb', line 27 def address_key @address_key end |
#id ⇒ Object
The unique identifier for this component. Used in other parts of the pipeline to reference this component (for example, as the ‘input` to downstream components).
30 31 32 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb', line 30 def id @id end |
#store_hec_token ⇒ Object
When ‘true`, the Splunk HEC token from the incoming request is stored in the event metadata. This allows downstream components to forward the token to other Splunk HEC destinations.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb', line 34 def store_hec_token @store_hec_token end |
#tls ⇒ Object
Configuration for enabling TLS encryption between the pipeline component and external services.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb', line 37 def tls @tls end |
#type ⇒ Object
The source type. Always ‘splunk_hec`.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/observability_pipeline_splunk_hec_source.rb', line 40 def type @type end |