Class: DatadogAPIClient::V2::OrgGroupPolicyAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/org_group_policy_attributes.rb

Overview

Attributes of an org group policy.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



39
40
41
# File 'lib/datadog_api_client/v2/models/org_group_policy_attributes.rb', line 39

def additional_properties
  @additional_properties
end

#contentObject

The policy content as key-value pairs.



25
26
27
# File 'lib/datadog_api_client/v2/models/org_group_policy_attributes.rb', line 25

def content
  @content
end

#enforcement_tierObject

The enforcement tier of the policy. ‘DEFAULT` means the policy is set but member orgs may mutate it. `ENFORCE` means the policy is strictly controlled and mutations are blocked for affected orgs. `DELEGATE` means each member org controls its own value.



28
29
30
# File 'lib/datadog_api_client/v2/models/org_group_policy_attributes.rb', line 28

def enforcement_tier
  @enforcement_tier
end

#modified_atObject

Timestamp when the policy was last modified.



31
32
33
# File 'lib/datadog_api_client/v2/models/org_group_policy_attributes.rb', line 31

def modified_at
  @modified_at
end

#policy_nameObject

The name of the policy.



34
35
36
# File 'lib/datadog_api_client/v2/models/org_group_policy_attributes.rb', line 34

def policy_name
  @policy_name
end

#policy_typeObject

The type of the policy. Only ‘org_config` is supported, indicating a policy backed by an organization configuration setting.



37
38
39
# File 'lib/datadog_api_client/v2/models/org_group_policy_attributes.rb', line 37

def policy_type
  @policy_type
end