Class: DatadogAPIClient::V2::OrgGroupPolicyEnforcementTier
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::OrgGroupPolicyEnforcementTier
- Includes:
- BaseEnumModel
- Defined in:
- lib/datadog_api_client/v2/models/org_group_policy_enforcement_tier.rb
Overview
The enforcement tier of the policy. OVERRIDE_ALLOWED means the policy is set but member orgs may mutate it. GROUP_MANAGED means the policy is strictly controlled and mutations are blocked for affected orgs. DELEGATE means each member org controls its own value. role policies only support GROUP_MANAGED and DELEGATE — OVERRIDE_ALLOWED is rejected for this policy type. Transitioning a role policy to DELEGATE (disabling it) is one-way — the policy cannot be transitioned back to GROUP_MANAGED afterward.
Constant Summary collapse
- OVERRIDE_ALLOWED =
"OVERRIDE_ALLOWED".freeze
- GROUP_MANAGED =
"GROUP_MANAGED".freeze
- DELEGATE =
"DELEGATE".freeze