Class: DatadogAPIClient::V2::OrgGroupPolicyPolicyType
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::OrgGroupPolicyPolicyType
- Includes:
- BaseEnumModel
- Defined in:
- lib/datadog_api_client/v2/models/org_group_policy_policy_type.rb
Overview
The type of the policy. org_config indicates a policy backed by an organization configuration setting. role indicates a policy backed by a Datadog custom role.
Constant Summary collapse
- ORG_CONFIG =
"org_config".freeze
- ROLE =
"role".freeze