Class: DatadogAPIClient::V2::OrgGroupPolicyUpdateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/org_group_policy_update_attributes.rb

Overview

Attributes for updating an org group policy.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



30
31
32
# File 'lib/datadog_api_client/v2/models/org_group_policy_update_attributes.rb', line 30

def additional_properties
  @additional_properties
end

#contentObject

The policy content as key-value pairs.



25
26
27
# File 'lib/datadog_api_client/v2/models/org_group_policy_update_attributes.rb', line 25

def content
  @content
end

#enforcement_tierObject

The enforcement tier of the policy. ‘DEFAULT` means the policy is set but member orgs may mutate it. `ENFORCE` means the policy is strictly controlled and mutations are blocked for affected orgs. `DELEGATE` means each member org controls its own value.



28
29
30
# File 'lib/datadog_api_client/v2/models/org_group_policy_update_attributes.rb', line 28

def enforcement_tier
  @enforcement_tier
end