Class: DatadogAPIClient::V2::OrganizationAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::OrganizationAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/organization_attributes.rb
Overview
Attributes of the organization.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Creation time of the organization.
-
#description ⇒ Object
Description of the organization.
-
#disabled ⇒ Object
Whether or not the organization is disabled.
-
#modified_at ⇒ Object
Time of last organization modification.
-
#name ⇒ Object
Name of the organization.
-
#public_id ⇒ Object
Public ID of the organization.
-
#sharing ⇒ Object
Sharing type of the organization.
-
#url ⇒ Object
URL of the site that this organization exists at.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#created_at ⇒ Object
Creation time of the organization.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 29 def created_at @created_at end |
#description ⇒ Object
Description of the organization.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 32 def description @description end |
#disabled ⇒ Object
Whether or not the organization is disabled.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 35 def disabled @disabled end |
#modified_at ⇒ Object
Time of last organization modification.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 38 def modified_at @modified_at end |
#name ⇒ Object
Name of the organization.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 41 def name @name end |
#public_id ⇒ Object
Public ID of the organization.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 44 def public_id @public_id end |
#sharing ⇒ Object
Sharing type of the organization.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 47 def sharing @sharing end |
#url ⇒ Object
URL of the site that this organization exists at.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/organization_attributes.rb', line 50 def url @url end |