Class: DatadogAPIClient::V2::PatchDegradationTemplateRequestDataAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::PatchDegradationTemplateRequestDataAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/patch_degradation_template_request_data_attributes.rb
Overview
The supported attributes for updating a degradation template.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#components_affected ⇒ Object
The components affected by a degradation created from this template.
-
#degradation_title ⇒ Object
The title used for a degradation created from this template.
-
#name ⇒ Object
The name of the degradation template.
-
#updates ⇒ Object
The pre-filled updates for a degradation created from this template.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/patch_degradation_template_request_data_attributes.rb', line 36 def additional_properties @additional_properties end |
#components_affected ⇒ Object
The components affected by a degradation created from this template.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/patch_degradation_template_request_data_attributes.rb', line 25 def components_affected @components_affected end |
#degradation_title ⇒ Object
The title used for a degradation created from this template.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/patch_degradation_template_request_data_attributes.rb', line 28 def degradation_title @degradation_title end |
#name ⇒ Object
The name of the degradation template.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/patch_degradation_template_request_data_attributes.rb', line 31 def name @name end |
#updates ⇒ Object
The pre-filled updates for a degradation created from this template.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/patch_degradation_template_request_data_attributes.rb', line 34 def updates @updates end |