Class: DatadogAPIClient::V2::PatchMaintenanceTemplateRequestDataAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::PatchMaintenanceTemplateRequestDataAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb
Overview
The supported attributes for updating a maintenance template.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#completed_description ⇒ Object
The description shown when a maintenance created from this template is completed.
-
#component_ids ⇒ Object
The IDs of the components affected by a maintenance created from this template.
-
#in_progress_description ⇒ Object
The description shown while a maintenance created from this template is in progress.
-
#maintenance_title ⇒ Object
The title used for a maintenance created from this template.
-
#name ⇒ Object
The name of the maintenance template.
-
#scheduled_description ⇒ Object
The description shown when a maintenance created from this template is scheduled.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 42 def additional_properties @additional_properties end |
#completed_description ⇒ Object
The description shown when a maintenance created from this template is completed.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 25 def completed_description @completed_description end |
#component_ids ⇒ Object
The IDs of the components affected by a maintenance created from this template.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 28 def component_ids @component_ids end |
#in_progress_description ⇒ Object
The description shown while a maintenance created from this template is in progress.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 31 def in_progress_description @in_progress_description end |
#maintenance_title ⇒ Object
The title used for a maintenance created from this template.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 34 def maintenance_title @maintenance_title end |
#name ⇒ Object
The name of the maintenance template.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 37 def name @name end |
#scheduled_description ⇒ Object
The description shown when a maintenance created from this template is scheduled.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/patch_maintenance_template_request_data_attributes.rb', line 40 def scheduled_description @scheduled_description end |