Class: DatadogAPIClient::V2::ProcessSummariesMetaPage

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/process_summaries_meta_page.rb

Overview

Paging attributes.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#afterObject

The cursor used to get the next results, if any. To make the next request, use the same parameters with the addition of the page[cursor].



30
31
32
# File 'lib/datadog_api_client/v2/models/process_summaries_meta_page.rb', line 30

def after
  @after
end

#sizeObject

Number of results returned.



33
34
35
# File 'lib/datadog_api_client/v2/models/process_summaries_meta_page.rb', line 33

def size
  @size
end