Class: DatadogAPIClient::V2::RUMOperationJourneyCompositeRule
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RUMOperationJourneyCompositeRule
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb
Overview
A composite rule combining several predicates. Used as an alternative to nodes on a journey
step when several conditions must be matched together, in any order or in a specific order.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#composite_rule_id ⇒ Object
The unique identifier of the composite rule.
-
#config_version ⇒ Object
A hash of the composite rule's configuration, computed by the server.
-
#kind ⇒ Object
readonly
The rule used to combine the composite rule's predicates.
-
#max_window_ms ⇒ Object
The maximum time window, in milliseconds, in which all predicates must match.
-
#predicates ⇒ Object
readonly
The list of predicates that must be matched by RUM events.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb', line 41 def additional_properties @additional_properties end |
#composite_rule_id ⇒ Object
The unique identifier of the composite rule. Generated by the server if omitted.
26 27 28 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb', line 26 def composite_rule_id @composite_rule_id end |
#config_version ⇒ Object
A hash of the composite rule's configuration, computed by the server.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb', line 29 def config_version @config_version end |
#kind ⇒ Object
The rule used to combine the composite rule's predicates. all_of requires every predicate
to match, in any order. in_order requires every predicate to match in the given order.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb', line 33 def kind @kind end |
#max_window_ms ⇒ Object
The maximum time window, in milliseconds, in which all predicates must match.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb', line 36 def max_window_ms @max_window_ms end |
#predicates ⇒ Object
The list of predicates that must be matched by RUM events.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule.rb', line 39 def predicates @predicates end |