Class: DatadogAPIClient::V2::RUMOperationJourneyCompositeRuleKind

Inherits:
Object
  • Object
show all
Includes:
BaseEnumModel
Defined in:
lib/datadog_api_client/v2/models/rum_operation_journey_composite_rule_kind.rb

Overview

The rule used to combine the composite rule's predicates. all_of requires every predicate to match, in any order. in_order requires every predicate to match in the given order.

Constant Summary collapse

ALL_OF =
"all_of".freeze
IN_ORDER =
"in_order".freeze

Method Summary

Methods included from BaseEnumModel

included