Class: DatadogAPIClient::V2::RUMOperationStrongLinkCreateRequestAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb

Overview

Attributes for creating a RUM operation strong link.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



47
48
49
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 47

def additional_properties
  @additional_properties
end

#application_idObject

The RUM application ID used when creating a stub operation from operation_name.



25
26
27
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 25

def application_id
  @application_id
end

#descriptionObject

A description of the strong link.



28
29
30
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 28

def description
  @description
end

#feature_idObject

The unique identifier of the feature to link.



31
32
33
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 31

def feature_id
  @feature_id
end

#operation_idObject

The unique identifier of the RUM operation to link. Either operation_id or operation_name is required.



35
36
37
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 35

def operation_id
  @operation_id
end

#operation_nameObject

The name of the RUM operation to link. Either operation_id or operation_name is required. If no operation with this name exists, a stub operation is created.



39
40
41
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 39

def operation_name
  @operation_name
end

#statusObject

The status of a RUM operation strong link.



42
43
44
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 42

def status
  @status
end

#tagsObject

A list of tags associated with the strong link.



45
46
47
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_create_request_attributes.rb', line 45

def tags
  @tags
end