Class: DatadogAPIClient::V2::RUMOperationStrongLinkResponseAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb

Overview

Attributes of a RUM operation strong link response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



45
46
47
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 45

def additional_properties
  @additional_properties
end

#created_atObject

The timestamp when the strong link was created.



25
26
27
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 25

def created_at
  @created_at
end

#descriptionObject

A description of the strong link.



28
29
30
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 28

def description
  @description
end

#feature_idObject

The unique identifier of the linked feature.



31
32
33
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 31

def feature_id
  @feature_id
end

#operation_idObject

The unique identifier of the linked RUM operation.



34
35
36
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 34

def operation_id
  @operation_id
end

#statusObject

The status of a RUM operation strong link.



37
38
39
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 37

def status
  @status
end

#tagsObject

A list of tags associated with the strong link.



40
41
42
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 40

def tags
  @tags
end

#updated_atObject

The timestamp when the strong link was last updated.



43
44
45
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 43

def updated_at
  @updated_at
end