Class: DatadogAPIClient::V2::RUMOperationStrongLinkResponseData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RUMOperationStrongLinkResponseData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_operation_strong_link_response_data.rb
Overview
The data object in a RUM operation strong link response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#attributes ⇒ Object
readonly
Attributes of a RUM operation strong link response.
-
#id ⇒ Object
readonly
The unique identifier of the strong link, formatted as
<operation_id>:<feature_id>. -
#type ⇒ Object
readonly
The JSON:API type for RUM operation strong link resources.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_data.rb', line 33 def additional_properties @additional_properties end |
#attributes ⇒ Object
Attributes of a RUM operation strong link response.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_data.rb', line 25 def attributes @attributes end |
#id ⇒ Object
The unique identifier of the strong link, formatted as <operation_id>:<feature_id>.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_data.rb', line 28 def id @id end |
#type ⇒ Object
The JSON:API type for RUM operation strong link resources.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_data.rb', line 31 def type @type end |