Class: DatadogAPIClient::V2::RUMOperationStrongLinksListResponseMeta
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RUMOperationStrongLinksListResponseMeta
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_operation_strong_links_list_response_meta.rb
Overview
Metadata for a list of RUM operation strong links.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#limit ⇒ Object
The pagination limit.
-
#offset ⇒ Object
The current offset.
-
#total ⇒ Object
The total number of strong links matching the request.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_links_list_response_meta.rb', line 33 def additional_properties @additional_properties end |
#limit ⇒ Object
The pagination limit.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_links_list_response_meta.rb', line 25 def limit @limit end |
#offset ⇒ Object
The current offset.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_links_list_response_meta.rb', line 28 def offset @offset end |
#total ⇒ Object
The total number of strong links matching the request.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_links_list_response_meta.rb', line 31 def total @total end |