Class: DatadogAPIClient::V2::RUMQueryFilter

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/rum_query_filter.rb

Overview

The search and filter query settings.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#fromObject

The minimum time for the requested events; supports date (in [ISO 8601](www.w3.org/TR/NOTE-datetime) format with full date, hours, minutes, and the Z UTC indicator - seconds and fractional seconds are optional), math, and regular timestamps (in milliseconds).



29
30
31
# File 'lib/datadog_api_client/v2/models/rum_query_filter.rb', line 29

def from
  @from
end

#queryObject

The search query following the RUM search syntax.



32
33
34
# File 'lib/datadog_api_client/v2/models/rum_query_filter.rb', line 32

def query
  @query
end

#toObject

The maximum time for the requested events; supports date (in [ISO 8601](www.w3.org/TR/NOTE-datetime) format with full date, hours, minutes, and the Z UTC indicator - seconds and fractional seconds are optional), math, and regular timestamps (in milliseconds).



35
36
37
# File 'lib/datadog_api_client/v2/models/rum_query_filter.rb', line 35

def to
  @to
end