Class: DatadogAPIClient::V2::RUMSearchEventsRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RUMSearchEventsRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_search_events_request.rb
Overview
The request for a RUM events list.
Instance Attribute Summary collapse
-
#filter ⇒ Object
The search and filter query settings.
-
#options ⇒ Object
Global query options that are used during the query.
-
#page ⇒ Object
Paging attributes for listing events.
-
#sort ⇒ Object
Sort parameters when querying events.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#filter ⇒ Object
The search and filter query settings.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/rum_search_events_request.rb', line 29 def filter @filter end |
#options ⇒ Object
Global query options that are used during the query. Note: Only supply timezone or time offset, not both. Otherwise, the query fails.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/rum_search_events_request.rb', line 33 def @options end |
#page ⇒ Object
Paging attributes for listing events.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/rum_search_events_request.rb', line 36 def page @page end |
#sort ⇒ Object
Sort parameters when querying events.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/rum_search_events_request.rb', line 39 def sort @sort end |