Class: DatadogAPIClient::V2::ReportScheduleIndexTemplateVariable
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ReportScheduleIndexTemplateVariable
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/report_schedule_index_template_variable.rb
Overview
Template variable metadata from a dashboard index.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#available_values ⇒ Object
Available values for the template variable.
-
#defaults ⇒ Object
Default values for the template variable.
-
#name ⇒ Object
The template variable name.
-
#prefix ⇒ Object
The tag prefix for the template variable, when available.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/report_schedule_index_template_variable.rb', line 36 def additional_properties @additional_properties end |
#available_values ⇒ Object
Available values for the template variable.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/report_schedule_index_template_variable.rb', line 25 def available_values @available_values end |
#defaults ⇒ Object
Default values for the template variable.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/report_schedule_index_template_variable.rb', line 28 def defaults @defaults end |
#name ⇒ Object
The template variable name.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/report_schedule_index_template_variable.rb', line 31 def name @name end |
#prefix ⇒ Object
The tag prefix for the template variable, when available.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/report_schedule_index_template_variable.rb', line 34 def prefix @prefix end |