Class: DatadogAPIClient::V2::ReportScheduleListResponsePagination
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ReportScheduleListResponsePagination
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb
Overview
Offset and limit pagination metadata for a report schedule list response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#first_offset ⇒ Object
The first offset.
-
#last_offset ⇒ Object
The last offset when the total count is known, or
nullif it is unavailable. -
#limit ⇒ Object
The maximum number of schedules returned.
-
#next_offset ⇒ Object
The next offset.
-
#offset ⇒ Object
The current offset.
-
#prev_offset ⇒ Object
The previous offset.
-
#total ⇒ Object
The total number of matching schedules.
-
#type ⇒ Object
The pagination type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 48 def additional_properties @additional_properties end |
#first_offset ⇒ Object
The first offset.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 25 def first_offset @first_offset end |
#last_offset ⇒ Object
The last offset when the total count is known, or null if it is unavailable.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 28 def last_offset @last_offset end |
#limit ⇒ Object
The maximum number of schedules returned.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 31 def limit @limit end |
#next_offset ⇒ Object
The next offset.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 34 def next_offset @next_offset end |
#offset ⇒ Object
The current offset.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 37 def offset @offset end |
#prev_offset ⇒ Object
The previous offset.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 40 def prev_offset @prev_offset end |
#total ⇒ Object
The total number of matching schedules.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 43 def total @total end |
#type ⇒ Object
The pagination type.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/report_schedule_list_response_pagination.rb', line 46 def type @type end |