Class: DatadogAPIClient::V2::ReportScheduleResourceAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/report_schedule_resource_attributes.rb

Overview

Attributes of an included report target resource.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



33
34
35
# File 'lib/datadog_api_client/v2/models/report_schedule_resource_attributes.rb', line 33

def additional_properties
  @additional_properties
end

#resource_typeObject

The type of dashboard resource the report schedule targets.



25
26
27
# File 'lib/datadog_api_client/v2/models/report_schedule_resource_attributes.rb', line 25

def resource_type
  @resource_type
end

#template_variablesObject

Template variable metadata from the dashboard resource, when available.



28
29
30
# File 'lib/datadog_api_client/v2/models/report_schedule_resource_attributes.rb', line 28

def template_variables
  @template_variables
end

#titleObject

The title of the dashboard or integration dashboard resource, when available.



31
32
33
# File 'lib/datadog_api_client/v2/models/report_schedule_resource_attributes.rb', line 31

def title
  @title
end