Class: DatadogAPIClient::V2::RolesAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v2/api/roles_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ RolesAPI

Returns a new instance of RolesAPI.



22
23
24
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#add_permission_to_role(role_id, body, opts = {}) ⇒ Object

Grant permission to a role.



29
30
31
32
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 29

def add_permission_to_role(role_id, body, opts = {})
  data, _status_code, _headers = add_permission_to_role_with_http_info(role_id, body, opts)
  data
end

#add_permission_to_role_with_http_info(role_id, body, opts = {}) ⇒ Array<(PermissionsResponse, Integer, Hash)>

Grant permission to a role.

Adds a permission to a role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • body (RelationshipToPermission)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PermissionsResponse, Integer, Hash)>)

    PermissionsResponse data, response status code and response headers



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 42

def add_permission_to_role_with_http_info(role_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.add_permission_to_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.add_permission_to_role"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.add_permission_to_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/permissions'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'PermissionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :add_permission_to_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#add_permission_to_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#add_user_to_role(role_id, body, opts = {}) ⇒ Object

Add a user to a role.



101
102
103
104
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 101

def add_user_to_role(role_id, body, opts = {})
  data, _status_code, _headers = add_user_to_role_with_http_info(role_id, body, opts)
  data
end

#add_user_to_role_with_http_info(role_id, body, opts = {}) ⇒ Array<(UsersResponse, Integer, Hash)>

Add a user to a role.

Adds a user to a role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • body (RelationshipToUser)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UsersResponse, Integer, Hash)>)

    UsersResponse data, response status code and response headers



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 114

def add_user_to_role_with_http_info(role_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.add_user_to_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.add_user_to_role"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.add_user_to_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/users'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UsersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :add_user_to_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#add_user_to_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#clone_role(role_id, body, opts = {}) ⇒ Object

Create a new role by cloning an existing role.



173
174
175
176
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 173

def clone_role(role_id, body, opts = {})
  data, _status_code, _headers = clone_role_with_http_info(role_id, body, opts)
  data
end

#clone_role_with_http_info(role_id, body, opts = {}) ⇒ Array<(RoleResponse, Integer, Hash)>

Create a new role by cloning an existing role.

Clone an existing role

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • body (RoleCloneRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RoleResponse, Integer, Hash)>)

    RoleResponse data, response status code and response headers



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 186

def clone_role_with_http_info(role_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.clone_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.clone_role"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.clone_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/clone'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'RoleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :clone_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#clone_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_role(body, opts = {}) ⇒ Object

Create role.



245
246
247
248
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 245

def create_role(body, opts = {})
  data, _status_code, _headers = create_role_with_http_info(body, opts)
  data
end

#create_role_with_http_info(body, opts = {}) ⇒ Array<(RoleCreateResponse, Integer, Hash)>

Create role.

Create a new role for your organization.

The following read permissions are automatically added to every new role, even if they are not included in the request:

  • Dashboards Read
  • Notebooks Read
  • Monitors Read
  • APM Read
  • Vulnerability Management Read
  • RUM Apps Read
  • Incidents Read
  • SLOs Read
  • CI Visibility Read
  • CD Visibility Read

Parameters:

Returns:

  • (Array<(RoleCreateResponse, Integer, Hash)>)

    RoleCreateResponse data, response status code and response headers



270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 270

def create_role_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.create_role ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.create_role"
  end
  # resource path
  local_var_path = '/api/v2/roles'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'RoleCreateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :create_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#create_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_role(role_id, opts = {}) ⇒ Object

Delete role.



325
326
327
328
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 325

def delete_role(role_id, opts = {})
  delete_role_with_http_info(role_id, opts)
  nil
end

#delete_role_with_http_info(role_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete role.

Disables a role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 337

def delete_role_with_http_info(role_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.delete_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.delete_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :delete_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#delete_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_role(role_id, opts = {}) ⇒ Object

Get a role.



390
391
392
393
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 390

def get_role(role_id, opts = {})
  data, _status_code, _headers = get_role_with_http_info(role_id, opts)
  data
end

#get_role_with_http_info(role_id, opts = {}) ⇒ Array<(RoleResponse, Integer, Hash)>

Get a role.

Get a role in the organization specified by the role’s role_id.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RoleResponse, Integer, Hash)>)

    RoleResponse data, response status code and response headers



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 402

def get_role_with_http_info(role_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.get_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.get_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RoleResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :get_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#get_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_permissions(opts = {}) ⇒ Object

List permissions.



455
456
457
458
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 455

def list_permissions(opts = {})
  data, _status_code, _headers = list_permissions_with_http_info(opts)
  data
end

#list_permissions_with_http_info(opts = {}) ⇒ Array<(PermissionsResponse, Integer, Hash)>

List permissions.

Returns a list of all permissions, including name, description, and ID.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PermissionsResponse, Integer, Hash)>)

    PermissionsResponse data, response status code and response headers



466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 466

def list_permissions_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.list_permissions ...'
  end
  # resource path
  local_var_path = '/api/v2/permissions'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PermissionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_permissions,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#list_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_role_permissions(role_id, opts = {}) ⇒ Object

List permissions for a role.



515
516
517
518
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 515

def list_role_permissions(role_id, opts = {})
  data, _status_code, _headers = list_role_permissions_with_http_info(role_id, opts)
  data
end

#list_role_permissions_with_http_info(role_id, opts = {}) ⇒ Array<(PermissionsResponse, Integer, Hash)>

List permissions for a role.

Returns a list of all permissions for a single role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PermissionsResponse, Integer, Hash)>)

    PermissionsResponse data, response status code and response headers



527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 527

def list_role_permissions_with_http_info(role_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.list_role_permissions ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.list_role_permissions"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/permissions'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PermissionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_role_permissions,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#list_role_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_role_templates(opts = {}) ⇒ Object

List role templates.



654
655
656
657
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 654

def list_role_templates(opts = {})
  data, _status_code, _headers = list_role_templates_with_http_info(opts)
  data
end

#list_role_templates_with_http_info(opts = {}) ⇒ Array<(RoleTemplateArray, Integer, Hash)>

List role templates.

List all role templates

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RoleTemplateArray, Integer, Hash)>)

    RoleTemplateArray data, response status code and response headers



665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 665

def list_role_templates_with_http_info(opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.list_role_templates".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.list_role_templates")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.list_role_templates"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.list_role_templates ...'
  end
  # resource path
  local_var_path = '/api/v2/roles/templates'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RoleTemplateArray'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_role_templates,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#list_role_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_role_users(role_id, opts = {}) ⇒ Object

Get all users of a role.



720
721
722
723
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 720

def list_role_users(role_id, opts = {})
  data, _status_code, _headers = list_role_users_with_http_info(role_id, opts)
  data
end

#list_role_users_with_http_info(role_id, opts = {}) ⇒ Array<(UsersResponse, Integer, Hash)>

Get all users of a role.

Gets all users of a role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page_size (Integer)

    Size for a given page. The maximum allowed value is 100.

  • :page_number (Integer)

    Specific page number to return.

  • :sort (String)

    User attribute to order results by. Sort order is ascending by default. Sort order is descending if the field is prefixed by a negative sign, for example sort=-name. Options: name, email, status.

  • :filter (String)

    Filter all users by the given string. Defaults to no filtering.

Returns:

  • (Array<(UsersResponse, Integer, Hash)>)

    UsersResponse data, response status code and response headers



736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 736

def list_role_users_with_http_info(role_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.list_role_users ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.list_role_users"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/users'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UsersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_role_users,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#list_role_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_roles(opts = {}) ⇒ Object

List roles.



580
581
582
583
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 580

def list_roles(opts = {})
  data, _status_code, _headers = list_roles_with_http_info(opts)
  data
end

#list_roles_with_http_info(opts = {}) ⇒ Array<(RolesResponse, Integer, Hash)>

List roles.

Returns all roles, including their names and their unique identifiers.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page_size (Integer)

    Size for a given page. The maximum allowed value is 100.

  • :page_number (Integer)

    Specific page number to return.

  • :sort (RolesSort)

    Sort roles depending on the given field. Sort order is ascending by default. Sort order is descending if the field is prefixed by a negative sign, for example: sort=-name.

  • :filter (String)

    Filter all roles by the given string.

  • :filter_id (String)

    Filter all roles by the given list of role IDs.

Returns:

  • (Array<(RolesResponse, Integer, Hash)>)

    RolesResponse data, response status code and response headers



596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 596

def list_roles_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.list_roles ...'
  end
  allowable_values = ['name', '-name', 'modified_at', '-modified_at', 'user_count', '-user_count']
  if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort'])
    fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/v2/roles'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'filter[id]'] = opts[:'filter_id'] if !opts[:'filter_id'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'RolesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_roles,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#list_roles\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_permission_from_role(role_id, body, opts = {}) ⇒ Object

Revoke permission.



793
794
795
796
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 793

def remove_permission_from_role(role_id, body, opts = {})
  data, _status_code, _headers = remove_permission_from_role_with_http_info(role_id, body, opts)
  data
end

#remove_permission_from_role_with_http_info(role_id, body, opts = {}) ⇒ Array<(PermissionsResponse, Integer, Hash)>

Revoke permission.

Removes a permission from a role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • body (RelationshipToPermission)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PermissionsResponse, Integer, Hash)>)

    PermissionsResponse data, response status code and response headers



806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 806

def remove_permission_from_role_with_http_info(role_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.remove_permission_from_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.remove_permission_from_role"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.remove_permission_from_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/permissions'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'PermissionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :remove_permission_from_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#remove_permission_from_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#remove_user_from_role(role_id, body, opts = {}) ⇒ Object

Remove a user from a role.



865
866
867
868
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 865

def remove_user_from_role(role_id, body, opts = {})
  data, _status_code, _headers = remove_user_from_role_with_http_info(role_id, body, opts)
  data
end

#remove_user_from_role_with_http_info(role_id, body, opts = {}) ⇒ Array<(UsersResponse, Integer, Hash)>

Remove a user from a role.

Removes a user from a role.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • body (RelationshipToUser)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UsersResponse, Integer, Hash)>)

    UsersResponse data, response status code and response headers



878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 878

def remove_user_from_role_with_http_info(role_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.remove_user_from_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.remove_user_from_role"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.remove_user_from_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}/users'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UsersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :remove_user_from_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#remove_user_from_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_role(role_id, body, opts = {}) ⇒ Object

Update a role.



937
938
939
940
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 937

def update_role(role_id, body, opts = {})
  data, _status_code, _headers = update_role_with_http_info(role_id, body, opts)
  data
end

#update_role_with_http_info(role_id, body, opts = {}) ⇒ Array<(RoleUpdateResponse, Integer, Hash)>

Update a role.

Edit a role. Can only be used with application keys belonging to administrators.

Parameters:

  • role_id (String)

    The unique identifier of the role.

  • body (RoleUpdateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(RoleUpdateResponse, Integer, Hash)>)

    RoleUpdateResponse data, response status code and response headers



950
951
952
953
954
955
956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
# File 'lib/datadog_api_client/v2/api/roles_api.rb', line 950

def update_role_with_http_info(role_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RolesAPI.update_role ...'
  end
  # verify the required parameter 'role_id' is set
  if @api_client.config.client_side_validation && role_id.nil?
    fail ArgumentError, "Missing the required parameter 'role_id' when calling RolesAPI.update_role"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling RolesAPI.update_role"
  end
  # resource path
  local_var_path = '/api/v2/roles/{role_id}'.sub('{role_id}', CGI.escape(role_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'RoleUpdateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :update_role,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RolesAPI#update_role\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end