Class: DatadogAPIClient::V2::RuleBasedViewComplianceFramework
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RuleBasedViewComplianceFramework
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb
Overview
Compliance framework mapping for a rule.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#control ⇒ Object
Identifier of the control inside the requirement.
-
#framework ⇒ Object
Handle of the compliance framework.
-
#is_default ⇒ Object
Whether the framework is a Datadog default framework.
-
#message ⇒ Object
Optional message describing the framework mapping for the rule.
-
#requirement ⇒ Object
Name of the requirement that contains the control.
-
#version ⇒ Object
Version of the compliance framework.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 42 def additional_properties @additional_properties end |
#control ⇒ Object
Identifier of the control inside the requirement.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 25 def control @control end |
#framework ⇒ Object
Handle of the compliance framework.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 28 def framework @framework end |
#is_default ⇒ Object
Whether the framework is a Datadog default framework. ‘true` indicates a Datadog framework and `false` indicates a custom framework.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 31 def is_default @is_default end |
#message ⇒ Object
Optional message describing the framework mapping for the rule.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 34 def @message end |
#requirement ⇒ Object
Name of the requirement that contains the control.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 37 def requirement @requirement end |
#version ⇒ Object
Version of the compliance framework.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_compliance_framework.rb', line 40 def version @version end |