Class: DatadogAPIClient::V2::RuleBasedViewRule

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/rule_based_view_rule.rb

Overview

A compliance rule along with its evaluation statistics and framework mappings.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



57
58
59
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 57

def additional_properties
  @additional_properties
end

#compliance_frameworksObject

List of compliance framework mappings associated with the rule.



25
26
27
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 25

def compliance_frameworks
  @compliance_frameworks
end

#enabledObject

Whether the rule is enabled.



28
29
30
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 28

def enabled
  @enabled
end

#idObject

Unique identifier of the rule.



31
32
33
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 31

def id
  @id
end

#nameObject

Human-readable name of the rule.



34
35
36
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 34

def name
  @name
end

#resource_attributesObject

List of resource attribute names exposed by the rule.



37
38
39
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 37

def resource_attributes
  @resource_attributes
end

#resource_categoryObject

Resource category targeted by the rule.



40
41
42
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 40

def resource_category
  @resource_category
end

#resource_typeObject

Resource type targeted by the rule.



43
44
45
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 43

def resource_type
  @resource_type
end

#statsObject

Counts of findings for the rule, grouped by their evaluation status.



46
47
48
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 46

def stats
  @stats
end

#statusObject

Severity associated with the rule (for example, ‘info`, `low`, `medium`, `high`, or `critical`).



49
50
51
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 49

def status
  @status
end

#tagsObject

List of tags attached to the rule.



52
53
54
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 52

def tags
  @tags
end

#typeObject

The category of the security rule.



55
56
57
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 55

def type
  @type
end