Class: DatadogAPIClient::V2::RumConfigAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/rum_config_attributes.rb

Overview

Attributes of the RUM configuration.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



51
52
53
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 51

def additional_properties
  @additional_properties
end

#disabledObject

Whether the RUM configuration is disabled for the organization.



25
26
27
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 25

def disabled
  @disabled
end

#enforced_application_tagsObject

Whether application tags are enforced for the RUM applications in the organization.



28
29
30
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 28

def enforced_application_tags
  @enforced_application_tags
end

#enforced_application_tags_updated_atObject

Timestamp of when the enforced application tags setting was last updated.



31
32
33
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 31

def enforced_application_tags_updated_at
  @enforced_application_tags_updated_at
end

#enforced_application_tags_updated_byObject

Handle of the user who last updated the enforced application tags setting.



34
35
36
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 34

def enforced_application_tags_updated_by
  @enforced_application_tags_updated_by
end

#ootb_metrics_versionObject

Version of the out-of-the-box metrics installed for the organization.



37
38
39
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 37

def ootb_metrics_version
  @ootb_metrics_version
end

#ootb_metrics_version_installed_atObject

Timestamp of when the out-of-the-box metrics version was installed.



40
41
42
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 40

def ootb_metrics_version_installed_at
  @ootb_metrics_version_installed_at
end

#retention_filters_enabledObject

Whether retention filters are enabled for the organization.



43
44
45
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 43

def retention_filters_enabled
  @retention_filters_enabled
end

#retention_filters_enabled_updated_atObject

Timestamp of when the retention filters setting was last updated.



46
47
48
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 46

def retention_filters_enabled_updated_at
  @retention_filters_enabled_updated_at
end

#retention_filters_enabled_updated_byObject

Handle of the user or job who last updated the retention filters setting.



49
50
51
# File 'lib/datadog_api_client/v2/models/rum_config_attributes.rb', line 49

def retention_filters_enabled_updated_by
  @retention_filters_enabled_updated_by
end