Class: DatadogAPIClient::V2::RumSdkConfigDynamicOption
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RumSdkConfigDynamicOption
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb
Overview
A dynamic configuration option that extracts a value at runtime using a specified strategy.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#attribute ⇒ Object
The element attribute to read.
-
#extractor ⇒ Object
A serialized regex used as an extractor in dynamic options.
-
#key ⇒ Object
The
localStoragekey to read. -
#name ⇒ Object
The cookie name to read.
-
#path ⇒ Object
The JavaScript path used to extract the value.
-
#rc_serialized_type ⇒ Object
readonly
The type identifier for a dynamic option.
-
#selector ⇒ Object
The CSS selector to read from the page.
-
#strategy ⇒ Object
readonly
The strategy used to extract the dynamic value.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 48 def additional_properties @additional_properties end |
#attribute ⇒ Object
The element attribute to read. Used when strategy is dom.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 25 def attribute @attribute end |
#extractor ⇒ Object
A serialized regex used as an extractor in dynamic options.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 28 def extractor @extractor end |
#key ⇒ Object
The localStorage key to read. Required when strategy is localStorage.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 31 def key @key end |
#name ⇒ Object
The cookie name to read. Required when strategy is cookie.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 34 def name @name end |
#path ⇒ Object
The JavaScript path used to extract the value. Required when strategy is js.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 37 def path @path end |
#rc_serialized_type ⇒ Object
The type identifier for a dynamic option. Always dynamic.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 40 def rc_serialized_type @rc_serialized_type end |
#selector ⇒ Object
The CSS selector to read from the page. Required when strategy is dom.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 43 def selector @selector end |
#strategy ⇒ Object
The strategy used to extract the dynamic value.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option.rb', line 46 def strategy @strategy end |