Class: DatadogAPIClient::V2::RumSdkConfigDynamicOptionPair
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RumSdkConfigDynamicOptionPair
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option_pair.rb
Overview
A key-value pair where the value is a dynamic configuration option.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#key ⇒ Object
readonly
The key name for this dynamic configuration pair.
-
#value ⇒ Object
readonly
A dynamic configuration option that extracts a value at runtime using a specified strategy.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option_pair.rb', line 30 def additional_properties @additional_properties end |
#key ⇒ Object
The key name for this dynamic configuration pair.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option_pair.rb', line 25 def key @key end |
#value ⇒ Object
A dynamic configuration option that extracts a value at runtime using a specified strategy.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_dynamic_option_pair.rb', line 28 def value @value end |