Class: DatadogAPIClient::V2::RumSdkConfigMeta
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RumSdkConfigMeta
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_sdk_config_meta.rb
Overview
Metadata associated with a RUM SDK configuration.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#updated_at ⇒ Object
readonly
The timestamp of the last update to this configuration.
-
#updated_by ⇒ Object
readonly
The handle of the user who last updated this configuration.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_meta.rb', line 30 def additional_properties @additional_properties end |
#updated_at ⇒ Object
The timestamp of the last update to this configuration.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_meta.rb', line 25 def updated_at @updated_at end |
#updated_by ⇒ Object
The handle of the user who last updated this configuration.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_meta.rb', line 28 def updated_by @updated_by end |