Class: DatadogAPIClient::V2::RumSdkConfigRumUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RumSdkConfigRumUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb
Overview
The RUM SDK settings to apply when updating a configuration.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#allowed_tracing_urls ⇒ Object
A list of URL configurations for distributed tracing.
-
#allowed_tracking_origins ⇒ Object
A list of origin patterns allowed for cross-origin session tracking.
-
#context ⇒ Object
A list of dynamic option key-value pairs.
-
#default_privacy_level ⇒ Object
readonly
The default privacy masking level applied to all RUM data.
-
#enable_privacy_for_action_name ⇒ Object
readonly
Whether to mask user-interaction action names for privacy.
-
#env ⇒ Object
The environment tag for the RUM application.
-
#service ⇒ Object
The service name tag for the RUM application.
-
#session_replay_sample_rate ⇒ Object
readonly
The percentage of collected sessions for which a replay is captured (0–100).
-
#session_sample_rate ⇒ Object
readonly
The percentage of user sessions to collect (0–100).
-
#trace_sample_rate ⇒ Object
readonly
The percentage of requests to forward as APM traces (0–100).
-
#track_session_across_subdomains ⇒ Object
Whether to share a session across subdomains of the same site.
-
#user ⇒ Object
A list of dynamic option key-value pairs.
-
#version ⇒ Object
A dynamic configuration option that extracts a value at runtime using a specified strategy.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
63 64 65 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 63 def additional_properties @additional_properties end |
#allowed_tracing_urls ⇒ Object
A list of URL configurations for distributed tracing.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 25 def allowed_tracing_urls @allowed_tracing_urls end |
#allowed_tracking_origins ⇒ Object
A list of origin patterns allowed for cross-origin session tracking.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 28 def allowed_tracking_origins @allowed_tracking_origins end |
#context ⇒ Object
A list of dynamic option key-value pairs.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 31 def context @context end |
#default_privacy_level ⇒ Object
The default privacy masking level applied to all RUM data.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 34 def default_privacy_level @default_privacy_level end |
#enable_privacy_for_action_name ⇒ Object
Whether to mask user-interaction action names for privacy.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 37 def enable_privacy_for_action_name @enable_privacy_for_action_name end |
#env ⇒ Object
The environment tag for the RUM application.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 40 def env @env end |
#service ⇒ Object
The service name tag for the RUM application.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 43 def service @service end |
#session_replay_sample_rate ⇒ Object
The percentage of collected sessions for which a replay is captured (0–100).
46 47 48 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 46 def session_replay_sample_rate @session_replay_sample_rate end |
#session_sample_rate ⇒ Object
The percentage of user sessions to collect (0–100).
49 50 51 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 49 def session_sample_rate @session_sample_rate end |
#trace_sample_rate ⇒ Object
The percentage of requests to forward as APM traces (0–100).
52 53 54 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 52 def trace_sample_rate @trace_sample_rate end |
#track_session_across_subdomains ⇒ Object
Whether to share a session across subdomains of the same site.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 55 def track_session_across_subdomains @track_session_across_subdomains end |
#user ⇒ Object
A list of dynamic option key-value pairs.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 58 def user @user end |
#version ⇒ Object
A dynamic configuration option that extracts a value at runtime using a specified strategy.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/rum_sdk_config_rum_update_attributes.rb', line 61 def version @version end |