Class: DatadogAPIClient::V2::SecurityFilterCreateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityFilterCreateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_filter_create_attributes.rb
Overview
Object containing the attributes of the security filter to be created.
Instance Attribute Summary collapse
-
#exclusion_filters ⇒ Object
readonly
Exclusion filters to exclude some logs from the security filter.
-
#filtered_data_type ⇒ Object
readonly
The filtered data type.
-
#is_enabled ⇒ Object
readonly
Whether the security filter is enabled.
-
#name ⇒ Object
readonly
The name of the security filter.
-
#query ⇒ Object
readonly
The query of the security filter.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#exclusion_filters ⇒ Object
Exclusion filters to exclude some logs from the security filter.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/security_filter_create_attributes.rb', line 29 def exclusion_filters @exclusion_filters end |
#filtered_data_type ⇒ Object
The filtered data type.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/security_filter_create_attributes.rb', line 32 def filtered_data_type @filtered_data_type end |
#is_enabled ⇒ Object
Whether the security filter is enabled.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/security_filter_create_attributes.rb', line 35 def is_enabled @is_enabled end |
#name ⇒ Object
The name of the security filter.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/security_filter_create_attributes.rb', line 38 def name @name end |
#query ⇒ Object
The query of the security filter.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/security_filter_create_attributes.rb', line 41 def query @query end |