Class: DatadogAPIClient::V2::SecurityFilterUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityFilterUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_filter_update_attributes.rb
Overview
The security filters properties to be updated.
Instance Attribute Summary collapse
-
#exclusion_filters ⇒ Object
Exclusion filters to exclude some logs from the security filter.
-
#filtered_data_type ⇒ Object
The filtered data type.
-
#is_enabled ⇒ Object
Whether the security filter is enabled.
-
#name ⇒ Object
The name of the security filter.
-
#query ⇒ Object
The query of the security filter.
-
#version ⇒ Object
readonly
The version of the security filter to update.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#exclusion_filters ⇒ Object
Exclusion filters to exclude some logs from the security filter.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/security_filter_update_attributes.rb', line 29 def exclusion_filters @exclusion_filters end |
#filtered_data_type ⇒ Object
The filtered data type.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/security_filter_update_attributes.rb', line 32 def filtered_data_type @filtered_data_type end |
#is_enabled ⇒ Object
Whether the security filter is enabled.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/security_filter_update_attributes.rb', line 35 def is_enabled @is_enabled end |
#name ⇒ Object
The name of the security filter.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/security_filter_update_attributes.rb', line 38 def name @name end |
#query ⇒ Object
The query of the security filter.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/security_filter_update_attributes.rb', line 41 def query @query end |
#version ⇒ Object
The version of the security filter to update.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/security_filter_update_attributes.rb', line 44 def version @version end |