Class: DatadogAPIClient::V2::SecurityMonitoringContentPackStateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb

Overview

Attributes of a content pack state

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



46
47
48
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 46

def additional_properties
  @additional_properties
end

#cloud_siem_index_incorrectObject

Whether the cloud SIEM index configuration is incorrect (only applies to certain pricing models)



25
26
27
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 25

def cloud_siem_index_incorrect
  @cloud_siem_index_incorrect
end

#cp_activationObject

The activation status of a content pack.



28
29
30
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 28

def cp_activation
  @cp_activation
end

#filters_configured_for_logsObject

Whether filters (Security Filters or Index Query depending on the pricing model) are present and correctly configured to route logs into Cloud SIEM.



32
33
34
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 32

def filters_configured_for_logs
  @filters_configured_for_logs
end

#integration_installed_statusObject

The installation status of the related integration.



35
36
37
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 35

def integration_installed_status
  @integration_installed_status
end

#logs_last_collectedObject

Timestamp bucket indicating when logs were last collected.



38
39
40
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 38

def logs_last_collected
  @logs_last_collected
end

#logs_seen_from_any_indexObject

Whether logs for this content pack have been seen in any Datadog index within the last 72 hours.



41
42
43
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 41

def logs_seen_from_any_index
  @logs_seen_from_any_index
end

#stateObject

The current operational status of a content pack.



44
45
46
# File 'lib/datadog_api_client/v2/models/security_monitoring_content_pack_state_attributes.rb', line 44

def state
  @state
end