Class: DatadogAPIClient::V2::SecurityMonitoringRuleCase
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringRuleCase
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_rule_case.rb
Overview
Case when signal is generated.
Instance Attribute Summary collapse
-
#condition ⇒ Object
A rule case contains logical operations (‘>`,`>=`, `&&`, `||`) to determine if a signal should be generated based on the event counts in the previously defined queries.
-
#name ⇒ Object
Name of the case.
-
#notifications ⇒ Object
Notification targets for each rule case.
-
#status ⇒ Object
Severity of the Security Signal.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#condition ⇒ Object
A rule case contains logical operations (‘>`,`>=`, `&&`, `||`) to determine if a signal should be generated based on the event counts in the previously defined queries.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_rule_case.rb', line 30 def condition @condition end |
#name ⇒ Object
Name of the case.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_rule_case.rb', line 33 def name @name end |
#notifications ⇒ Object
Notification targets for each rule case.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_rule_case.rb', line 36 def notifications @notifications end |
#status ⇒ Object
Severity of the Security Signal.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_rule_case.rb', line 39 def status @status end |