Class: DatadogAPIClient::V2::SecurityMonitoringSignal
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringSignal
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_signal.rb
Overview
Object description of a security signal.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
The object containing all signal attributes and their associated values.
-
#id ⇒ Object
The unique ID of the security signal.
-
#type ⇒ Object
The type of event.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
The object containing all signal attributes and their associated values.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal.rb', line 30 def attributes @attributes end |
#id ⇒ Object
The unique ID of the security signal.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal.rb', line 33 def id @id end |
#type ⇒ Object
The type of event.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal.rb', line 36 def type @type end |