Class: DatadogAPIClient::V2::SecurityMonitoringSignalStateUpdateData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringSignalStateUpdateData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_signal_state_update_data.rb
Overview
Data containing the patch for changing the state of a signal.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
readonly
Attributes describing the change of state of a security signal.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
Attributes describing the change of state of a security signal.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal_state_update_data.rb', line 29 def attributes @attributes end |