Class: DatadogAPIClient::V2::SecurityMonitoringSignalUpdateData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringSignalUpdateData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_signal_update_data.rb
Overview
Data containing the triage state or assignee update for a security signal.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#attributes ⇒ Object
readonly
Attributes for updating the triage state or assignee of a security signal.
-
#type ⇒ Object
The type of event.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal_update_data.rb', line 30 def additional_properties @additional_properties end |
#attributes ⇒ Object
Attributes for updating the triage state or assignee of a security signal.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal_update_data.rb', line 25 def attributes @attributes end |
#type ⇒ Object
The type of event.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_signal_update_data.rb', line 28 def type @type end |