Class: DatadogAPIClient::V2::SecurityMonitoringStandardRuleCreatePayload
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringStandardRuleCreatePayload
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb
Overview
Create a new rule.
Instance Attribute Summary collapse
-
#cases ⇒ Object
readonly
Cases for generating signals.
-
#filters ⇒ Object
Additional queries to filter matched events before they are processed.
-
#has_extended_title ⇒ Object
Whether the notifications include the triggering group-by values in their title.
-
#is_enabled ⇒ Object
readonly
Whether the rule is enabled.
-
#message ⇒ Object
readonly
Message for generated signals.
-
#name ⇒ Object
readonly
The name of the rule.
-
#options ⇒ Object
readonly
Options on rules.
-
#queries ⇒ Object
readonly
Queries for selecting logs which are part of the rule.
-
#tags ⇒ Object
Tags for generated signals.
-
#type ⇒ Object
The rule type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#cases ⇒ Object
Cases for generating signals.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 29 def cases @cases end |
#filters ⇒ Object
Additional queries to filter matched events before they are processed.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 32 def filters @filters end |
#has_extended_title ⇒ Object
Whether the notifications include the triggering group-by values in their title.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 35 def has_extended_title @has_extended_title end |
#is_enabled ⇒ Object
Whether the rule is enabled.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 38 def is_enabled @is_enabled end |
#message ⇒ Object
Message for generated signals.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 41 def end |
#name ⇒ Object
The name of the rule.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 44 def name @name end |
#options ⇒ Object
Options on rules.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 47 def end |
#queries ⇒ Object
Queries for selecting logs which are part of the rule.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 50 def queries @queries end |
#tags ⇒ Object
Tags for generated signals.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 53 def end |
#type ⇒ Object
The rule type.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_create_payload.rb', line 56 def type @type end |