Class: DatadogAPIClient::V2::SecurityMonitoringStandardRuleQuery
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringStandardRuleQuery
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb
Overview
Query for matching rule.
Instance Attribute Summary collapse
-
#aggregation ⇒ Object
The aggregation type.
-
#distinct_fields ⇒ Object
Field for which the cardinality is measured.
-
#group_by_fields ⇒ Object
Fields to group by.
-
#metric ⇒ Object
(Deprecated) The target field to aggregate over when using the sum or max aggregations.
-
#metrics ⇒ Object
Group of target fields to aggregate over when using the sum, max, geo data, or new value aggregations.
-
#name ⇒ Object
Name of the query.
-
#query ⇒ Object
readonly
Query to run on logs.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#aggregation ⇒ Object
The aggregation type.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 29 def aggregation @aggregation end |
#distinct_fields ⇒ Object
Field for which the cardinality is measured. Sent as an array.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 32 def distinct_fields @distinct_fields end |
#group_by_fields ⇒ Object
Fields to group by.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 35 def group_by_fields @group_by_fields end |
#metric ⇒ Object
(Deprecated) The target field to aggregate over when using the sum or max aggregations. metrics field should be used instead.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 39 def metric @metric end |
#metrics ⇒ Object
Group of target fields to aggregate over when using the sum, max, geo data, or new value aggregations. The sum, max, and geo data aggregations only accept one value in this list, whereas the new value aggregation accepts up to five values.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 42 def metrics @metrics end |
#name ⇒ Object
Name of the query.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 45 def name @name end |
#query ⇒ Object
Query to run on logs.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_query.rb', line 48 def query @query end |