Class: DatadogAPIClient::V2::SecurityMonitoringStandardRuleResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SecurityMonitoringStandardRuleResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb
Overview
Rule.
Instance Attribute Summary collapse
-
#cases ⇒ Object
Cases for generating signals.
-
#compliance_signal_options ⇒ Object
How to generate compliance signals.
-
#created_at ⇒ Object
When the rule was created, timestamp in milliseconds.
-
#creation_author_id ⇒ Object
User ID of the user who created the rule.
-
#deprecation_date ⇒ Object
When the rule will be deprecated, timestamp in milliseconds.
-
#filters ⇒ Object
Additional queries to filter matched events before they are processed.
-
#has_extended_title ⇒ Object
Whether the notifications include the triggering group-by values in their title.
-
#id ⇒ Object
The ID of the rule.
-
#is_default ⇒ Object
Whether the rule is included by default.
-
#is_deleted ⇒ Object
Whether the rule has been deleted.
-
#is_enabled ⇒ Object
Whether the rule is enabled.
-
#message ⇒ Object
Message for generated signals.
-
#name ⇒ Object
The name of the rule.
-
#options ⇒ Object
Options on rules.
-
#queries ⇒ Object
Queries for selecting logs which are part of the rule.
-
#tags ⇒ Object
Tags for generated signals.
-
#type ⇒ Object
The rule type.
-
#update_author_id ⇒ Object
User ID of the user who updated the rule.
-
#version ⇒ Object
The version of the rule.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#cases ⇒ Object
Cases for generating signals.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 29 def cases @cases end |
#compliance_signal_options ⇒ Object
How to generate compliance signals. Useful for cloud_configuration rules only.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 32 def @compliance_signal_options end |
#created_at ⇒ Object
When the rule was created, timestamp in milliseconds.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 35 def created_at @created_at end |
#creation_author_id ⇒ Object
User ID of the user who created the rule.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 38 def @creation_author_id end |
#deprecation_date ⇒ Object
When the rule will be deprecated, timestamp in milliseconds.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 41 def deprecation_date @deprecation_date end |
#filters ⇒ Object
Additional queries to filter matched events before they are processed.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 44 def filters @filters end |
#has_extended_title ⇒ Object
Whether the notifications include the triggering group-by values in their title.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 47 def has_extended_title @has_extended_title end |
#id ⇒ Object
The ID of the rule.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 50 def id @id end |
#is_default ⇒ Object
Whether the rule is included by default.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 53 def is_default @is_default end |
#is_deleted ⇒ Object
Whether the rule has been deleted.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 56 def is_deleted @is_deleted end |
#is_enabled ⇒ Object
Whether the rule is enabled.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 59 def is_enabled @is_enabled end |
#message ⇒ Object
Message for generated signals.
62 63 64 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 62 def @message end |
#name ⇒ Object
The name of the rule.
65 66 67 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 65 def name @name end |
#options ⇒ Object
Options on rules.
68 69 70 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 68 def @options end |
#queries ⇒ Object
Queries for selecting logs which are part of the rule.
71 72 73 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 71 def queries @queries end |
#tags ⇒ Object
Tags for generated signals.
74 75 76 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 74 def @tags end |
#type ⇒ Object
The rule type.
77 78 79 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 77 def type @type end |
#update_author_id ⇒ Object
User ID of the user who updated the rule.
80 81 82 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 80 def @update_author_id end |
#version ⇒ Object
The version of the rule.
83 84 85 |
# File 'lib/datadog_api_client/v2/models/security_monitoring_standard_rule_response.rb', line 83 def version @version end |