Class: DatadogAPIClient::V2::SensitiveDataScannerMeta

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/sensitive_data_scanner_meta.rb

Overview

Meta response containing information about the API.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#count_limitObject

Maximum number of scanning rules allowed for the org.



29
30
31
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_meta.rb', line 29

def count_limit
  @count_limit
end

#group_count_limitObject

Maximum number of scanning groups allowed for the org.



32
33
34
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_meta.rb', line 32

def group_count_limit
  @group_count_limit
end

#has_highlight_enabledObject

Whether or not scanned events are highlighted in Logs or RUM for the org.



35
36
37
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_meta.rb', line 35

def has_highlight_enabled
  @has_highlight_enabled
end

#is_pci_compliantObject

Whether or not the org is compliant to the payment card industry standard.



38
39
40
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_meta.rb', line 38

def is_pci_compliant
  @is_pci_compliant
end

#versionObject

Version of the API.



41
42
43
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_meta.rb', line 41

def version
  @version
end