Class: DatadogAPIClient::V2::SensitiveDataScannerRuleAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb

Overview

Attributes of the Sensitive Data Scanner rule.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#descriptionObject

Description of the rule.



29
30
31
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 29

def description
  @description
end

#excluded_namespacesObject

Attributes excluded from the scan. If namespaces is provided, it has to be a sub-path of the namespaces array.



32
33
34
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 32

def excluded_namespaces
  @excluded_namespaces
end

#is_enabledObject

Whether or not the rule is enabled.



35
36
37
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 35

def is_enabled
  @is_enabled
end

#nameObject

Name of the rule.



38
39
40
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 38

def name
  @name
end

#namespacesObject

Attributes included in the scan. If namespaces is empty or missing, all attributes except excluded_namespaces are scanned. If both are missing the whole event is scanned.



42
43
44
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 42

def namespaces
  @namespaces
end

#patternObject

Not included if there is a relationship to a standard pattern.



45
46
47
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 45

def pattern
  @pattern
end

#tagsObject

List of tags.



48
49
50
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 48

def tags
  @tags
end

#text_replacementObject

Object describing how the scanned event will be replaced.



51
52
53
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 51

def text_replacement
  @text_replacement
end