Class: DatadogAPIClient::V2::ServiceDefinitionV2
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ServiceDefinitionV2
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/service_definition_v2.rb
Overview
Service definition V2 for providing service metadata and integrations.
Instance Attribute Summary collapse
-
#contacts ⇒ Object
A list of contacts related to the services.
-
#dd_service ⇒ Object
readonly
Unique identifier of the service.
-
#dd_team ⇒ Object
Experimental feature.
-
#docs ⇒ Object
A list of documentation related to the services.
-
#extensions ⇒ Object
Extensions to V2 schema.
-
#integrations ⇒ Object
Third party integrations that Datadog supports.
-
#links ⇒ Object
A list of links related to the services.
-
#repos ⇒ Object
A list of code repositories related to the services.
-
#schema_version ⇒ Object
readonly
Schema version being used.
-
#tags ⇒ Object
A set of custom tags.
-
#team ⇒ Object
Team that owns the service.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#contacts ⇒ Object
A list of contacts related to the services.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 29 def contacts @contacts end |
#dd_service ⇒ Object
Unique identifier of the service. Must be unique across all services and is used to match with a service in Datadog.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 32 def dd_service @dd_service end |
#dd_team ⇒ Object
Experimental feature. A Team handle that matches a Team in the Datadog Teams product.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 35 def dd_team @dd_team end |
#docs ⇒ Object
A list of documentation related to the services.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 38 def docs @docs end |
#extensions ⇒ Object
Extensions to V2 schema.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 41 def extensions @extensions end |
#integrations ⇒ Object
Third party integrations that Datadog supports.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 44 def integrations @integrations end |
#links ⇒ Object
A list of links related to the services.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 47 def links @links end |
#repos ⇒ Object
A list of code repositories related to the services.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 50 def repos @repos end |
#schema_version ⇒ Object
Schema version being used.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 53 def schema_version @schema_version end |
#tags ⇒ Object
A set of custom tags.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 56 def @tags end |
#team ⇒ Object
Team that owns the service.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/service_definition_v2.rb', line 59 def team @team end |