Class: DatadogAPIClient::V2::Step

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/step.rb

Overview

A Step is a sub-component of a workflow. Each Step performs an action.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#action_idObject

The unique identifier of an action.



25
26
27
# File 'lib/datadog_api_client/v2/models/step.rb', line 25

def action_id
  @action_id
end

#additional_propertiesObject

Returns the value of attribute additional_properties.



52
53
54
# File 'lib/datadog_api_client/v2/models/step.rb', line 52

def additional_properties
  @additional_properties
end

#completion_gateObject

Used to create conditions before running subsequent actions.



28
29
30
# File 'lib/datadog_api_client/v2/models/step.rb', line 28

def completion_gate
  @completion_gate
end

#connection_labelObject

The unique identifier of a connection defined in the spec.



31
32
33
# File 'lib/datadog_api_client/v2/models/step.rb', line 31

def connection_label
  @connection_label
end

#displayObject

The position of a step on the workflow canvas. Omit display from every step to use automatic layout, or provide it for every step to preserve a manual layout.



35
36
37
# File 'lib/datadog_api_client/v2/models/step.rb', line 35

def display
  @display
end

#error_handlersObject

The Step errorHandlers.



38
39
40
# File 'lib/datadog_api_client/v2/models/step.rb', line 38

def error_handlers
  @error_handlers
end

#nameObject

Name of the step.



41
42
43
# File 'lib/datadog_api_client/v2/models/step.rb', line 41

def name
  @name
end

#outbound_edgesObject

A list of subsequent actions to run. This list is empty for a terminal step.



44
45
46
# File 'lib/datadog_api_client/v2/models/step.rb', line 44

def outbound_edges
  @outbound_edges
end

#parametersObject

A list of inputs for an action.



47
48
49
# File 'lib/datadog_api_client/v2/models/step.rb', line 47

def parameters
  @parameters
end

#readiness_gateObject

Used to merge multiple branches into a single branch.



50
51
52
# File 'lib/datadog_api_client/v2/models/step.rb', line 50

def readiness_gate
  @readiness_gate
end