Class: DatadogAPIClient::V2::StepDisplay

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/step_display.rb

Overview

The position of a step on the workflow canvas. Omit display from every step to use automatic layout, or provide it for every step to preserve a manual layout.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



28
29
30
# File 'lib/datadog_api_client/v2/models/step_display.rb', line 28

def additional_properties
  @additional_properties
end

#boundsObject

The definition of StepDisplayBounds object.



26
27
28
# File 'lib/datadog_api_client/v2/models/step_display.rb', line 26

def bounds
  @bounds
end