Class: DatadogAPIClient::V2::SyntheticsDowntimeWeekdayPosition

Inherits:
Object
  • Object
show all
Includes:
BaseEnumModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_downtime_weekday_position.rb

Overview

The position of a weekday within a month for a monthly Synthetics downtime recurrence. ‘1` through `4` select the first through fourth occurrence of the weekday in the month, and `-1` selects the last occurrence.

Constant Summary collapse

FIRST =
1.freeze
SECOND =
2.freeze
THIRD =
3.freeze
FOURTH =
4.freeze
LAST =
-1.freeze

Method Summary

Methods included from BaseEnumModel

included