Class: DatadogAPIClient::V2::SyntheticsFastTestResultDetail

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb

Overview

Detailed result data for the fast test run. The exact shape of nested fields (‘request`, `response`, `assertions`, etc.) depends on the test subtype.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



82
83
84
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 82

def additional_properties
  @additional_properties
end

#assertionsObject

Results of each assertion evaluated during the test.



26
27
28
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 26

def assertions
  @assertions
end

#call_typeObject

gRPC call type (for example, ‘unary`, `healthCheck`, or `reflection`).



29
30
31
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 29

def call_type
  @call_type
end

#certObject

SSL/TLS certificate information returned from an SSL test.



32
33
34
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 32

def cert
  @cert
end

#durationObject

Total duration of the test in milliseconds.



35
36
37
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 35

def duration
  @duration
end

#failureObject

Details about the failure of a Synthetic test.



38
39
40
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 38

def failure
  @failure
end

#finished_atObject

Unix timestamp (ms) of when the test finished.



41
42
43
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 41

def finished_at
  @finished_at
end

#idObject

The result ID. Set to the fast test UUID because no persistent result ID exists for fast tests.



44
45
46
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 44

def id
  @id
end

#is_fast_retryObject

Whether this result is from an automatic fast retry.



47
48
49
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 47

def is_fast_retry
  @is_fast_retry
end

#requestObject

Details of the outgoing request made during the test execution.



50
51
52
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 50

def request
  @request
end

#resolved_ipObject

IP address resolved for the target host.



53
54
55
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 53

def resolved_ip
  @resolved_ip
end

#responseObject

Details of the response received during the test execution.



56
57
58
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 56

def response
  @response
end

#run_typeObject

The type of run for a Synthetic test result.



59
60
61
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 59

def run_type
  @run_type
end

#started_atObject

Unix timestamp (ms) of when the test started.



62
63
64
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 62

def started_at
  @started_at
end

#statusObject

Status of the test result (‘passed` or `failed`).



65
66
67
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 65

def status
  @status
end

#stepsObject

Step results for multistep API tests.



68
69
70
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 68

def steps
  @steps
end

#timingsObject

Timing breakdown of the test request phases (for example, DNS, TCP, TLS, first byte).



71
72
73
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 71

def timings
  @timings
end

#tracerouteObject

Traceroute hop results, present for ICMP and TCP tests.



74
75
76
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 74

def traceroute
  @traceroute
end

#triggered_atObject

Unix timestamp (ms) of when the test was triggered.



77
78
79
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 77

def triggered_at
  @triggered_at
end

#tunnelObject

Whether the test was run through a Synthetics tunnel.



80
81
82
# File 'lib/datadog_api_client/v2/models/synthetics_fast_test_result_detail.rb', line 80

def tunnel
  @tunnel
end