Class: DatadogAPIClient::V2::SyntheticsTestResultAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb

Overview

Attributes of a Synthetic test result.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



48
49
50
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 48

def additional_properties
  @additional_properties
end

#batchObject

Batch information for the test result.



25
26
27
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 25

def batch
  @batch
end

#ciObject

CI information associated with the test result.



28
29
30
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 28

def ci
  @ci
end

#deviceObject

Device information for the test result (browser and mobile tests).



31
32
33
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 31

def device
  @device
end

#gitObject

Git information associated with the test result.



34
35
36
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 34

def git
  @git
end

#locationObject

Location information for a Synthetic test result.



37
38
39
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 37

def location
  @location
end

#resultObject

Full result details for a Synthetic test execution.



40
41
42
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 40

def result
  @result
end

#test_sub_typeObject

Subtype of the Synthetic test that produced this result.



43
44
45
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 43

def test_sub_type
  @test_sub_type
end

#test_typeObject

Type of the Synthetic test that produced this result.



46
47
48
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_attributes.rb', line 46

def test_type
  @test_type
end