Class: DatadogAPIClient::V2::SyntheticsTestResultDetail

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb

Overview

Full result details for a Synthetic test execution.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



147
148
149
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 147

def additional_properties
  @additional_properties
end

#assertionsObject

Assertion results produced by the test.



25
26
27
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 25

def assertions
  @assertions
end

#bucket_keysObject

Storage bucket keys for artifacts produced during a step or test.



28
29
30
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 28

def bucket_keys
  @bucket_keys
end

#call_typeObject

gRPC call type (for example, ‘unary`, `healthCheck`, or `reflection`).



31
32
33
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 31

def call_type
  @call_type
end

#certObject

SSL/TLS certificate information returned from an SSL test.



34
35
36
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 34

def cert
  @cert
end

#compressed_json_descriptorObject

Compressed JSON descriptor for the test (internal format).



37
38
39
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 37

def compressed_json_descriptor
  @compressed_json_descriptor
end

#compressed_stepsObject

Compressed representation of the test steps (internal format).



40
41
42
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 40

def compressed_steps
  @compressed_steps
end

#connection_outcomeObject

Outcome of the connection attempt (for example, ‘established`, `refused`).



43
44
45
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 43

def connection_outcome
  @connection_outcome
end

#dns_resolutionObject

DNS resolution details recorded during the test execution.



46
47
48
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 46

def dns_resolution
  @dns_resolution
end

#durationObject

Duration of the test execution (in milliseconds).



49
50
51
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 49

def duration
  @duration
end

#exited_on_step_successObject

Whether the test exited early because a step marked with ‘exitIfSucceed` passed.



52
53
54
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 52

def exited_on_step_success
  @exited_on_step_success
end

#failureObject

Details about the failure of a Synthetic test.



55
56
57
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 55

def failure
  @failure
end

#finished_atObject

Timestamp of when the test finished (in milliseconds).



58
59
60
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 58

def finished_at
  @finished_at
end

#handshakeObject

Handshake request and response for protocol-level tests.



61
62
63
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 61

def handshake
  @handshake
end

#idObject

The unique identifier for this result.



64
65
66
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 64

def id
  @id
end

#initial_idObject

The initial result ID before any retries.



67
68
69
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 67

def initial_id
  @initial_id
end

#is_fast_retryObject

Whether this result is from a fast retry.



70
71
72
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 70

def is_fast_retry
  @is_fast_retry
end

#is_last_retryObject

Whether this result is from the last retry.



73
74
75
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 73

def is_last_retry
  @is_last_retry
end

#netpathObject

Network Path test result capturing the path between source and destination.



76
77
78
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 76

def netpath
  @netpath
end

#netstatsObject

Aggregated network statistics from the test execution.



79
80
81
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 79

def netstats
  @netstats
end

#ocspObject

OCSP response received while validating a certificate.



82
83
84
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 82

def ocsp
  @ocsp
end

#pingObject

A network probe result, used for traceroute hops and ping summaries.



85
86
87
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 85

def ping
  @ping
end

#received_email_countObject

Number of emails received during the test (email tests).



88
89
90
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 88

def received_email_count
  @received_email_count
end

#received_messageObject

Message received from the target (for WebSocket/TCP/UDP tests).



91
92
93
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 91

def received_message
  @received_message
end

#requestObject

Details of the outgoing request made during the test execution.



94
95
96
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 94

def request
  @request
end

#resolved_ipObject

IP address resolved for the target host.



97
98
99
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 97

def resolved_ip
  @resolved_ip
end

#responseObject

Details of the response received during the test execution.



100
101
102
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 100

def response
  @response
end

#run_typeObject

The type of run for a Synthetic test result.



103
104
105
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 103

def run_type
  @run_type
end

#sent_messageObject

Message sent to the target (for WebSocket/TCP/UDP tests).



106
107
108
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 106

def sent_message
  @sent_message
end

#start_urlObject

Start URL for the test (browser tests).



109
110
111
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 109

def start_url
  @start_url
end

#started_atObject

Timestamp of when the test started (in milliseconds).



112
113
114
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 112

def started_at
  @started_at
end

#statusObject

Status of a Synthetic test result.



115
116
117
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 115

def status
  @status
end

#stepsObject

Step results (for browser, mobile, and multistep API tests).



118
119
120
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 118

def steps
  @steps
end

#time_to_interactiveObject

Time to interactive in milliseconds (browser tests).



121
122
123
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 121

def time_to_interactive
  @time_to_interactive
end

#timingsObject

Timing breakdown of the test request phases (for example, DNS, TCP, TLS, first byte).



124
125
126
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 124

def timings
  @timings
end

#traceObject

Trace identifiers associated with a Synthetic test result.



127
128
129
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 127

def trace
  @trace
end

#tracerouteObject

Traceroute hop results (for network tests).



130
131
132
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 130

def traceroute
  @traceroute
end

#triggered_atObject

Timestamp of when the test was triggered (in milliseconds).



133
134
135
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 133

def triggered_at
  @triggered_at
end

#tunnelObject

Whether the test was executed through a tunnel.



136
137
138
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 136

def tunnel
  @tunnel
end

#turnsObject

Turns executed by a goal-based browser test.



139
140
141
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 139

def turns
  @turns
end

#unhealthyObject

Whether the test runner was unhealthy at the time of execution.



142
143
144
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 142

def unhealthy
  @unhealthy
end

#variablesObject

Variables captured during a test step.



145
146
147
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_detail.rb', line 145

def variables
  @variables
end