Class: DatadogAPIClient::V2::SyntheticsTestResultGit
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultGit
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_git.rb
Overview
Git information associated with the test result.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#branch ⇒ Object
Git branch name.
-
#commit ⇒ Object
Details of the Git commit associated with the test result.
-
#repository_url ⇒ Object
Git repository URL.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_git.rb', line 33 def additional_properties @additional_properties end |
#branch ⇒ Object
Git branch name.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_git.rb', line 25 def branch @branch end |
#commit ⇒ Object
Details of the Git commit associated with the test result.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_git.rb', line 28 def commit @commit end |
#repository_url ⇒ Object
Git repository URL.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_git.rb', line 31 def repository_url @repository_url end |