Class: DatadogAPIClient::V2::SyntheticsTestResultHandshake

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_test_result_handshake.rb

Overview

Handshake request and response for protocol-level tests.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



30
31
32
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_handshake.rb', line 30

def additional_properties
  @additional_properties
end

#requestObject

Details of the outgoing request made during the test execution.



25
26
27
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_handshake.rb', line 25

def request
  @request
end

#responseObject

Details of the response received during the test execution.



28
29
30
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_handshake.rb', line 28

def response
  @response
end