Class: DatadogAPIClient::V2::SyntheticsTestResultNetstats
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultNetstats
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb
Overview
Aggregated network statistics from the test execution.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#hops ⇒ Object
Statistics about the number of hops for a network test.
-
#jitter ⇒ Object
Network jitter in milliseconds.
-
#latency ⇒ Object
Latency statistics for a network probe.
-
#packet_loss_percentage ⇒ Object
Percentage of probe packets lost.
-
#packets_received ⇒ Object
Number of probe packets received.
-
#packets_sent ⇒ Object
Number of probe packets sent.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 42 def additional_properties @additional_properties end |
#hops ⇒ Object
Statistics about the number of hops for a network test.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 25 def hops @hops end |
#jitter ⇒ Object
Network jitter in milliseconds.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 28 def jitter @jitter end |
#latency ⇒ Object
Latency statistics for a network probe.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 31 def latency @latency end |
#packet_loss_percentage ⇒ Object
Percentage of probe packets lost.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 34 def packet_loss_percentage @packet_loss_percentage end |
#packets_received ⇒ Object
Number of probe packets received.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 37 def packets_received @packets_received end |
#packets_sent ⇒ Object
Number of probe packets sent.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_netstats.rb', line 40 def packets_sent @packets_sent end |