Class: DatadogAPIClient::V2::SyntheticsTestResultRequestInfo

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb

Overview

Details of the outgoing request made during the test execution.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



87
88
89
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 87

def additional_properties
  @additional_properties
end

#allow_insecureObject

Whether insecure certificates are allowed for this request.



25
26
27
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 25

def allow_insecure
  @allow_insecure
end

#bodyObject

Body sent with the request.



28
29
30
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 28

def body
  @body
end

#call_typeObject

gRPC call type (for example, ‘unary`, `healthCheck`, or `reflection`).



31
32
33
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 31

def call_type
  @call_type
end

#destination_serviceObject

Destination service for a Network Path test.



34
35
36
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 34

def destination_service
  @destination_service
end

#dns_serverObject

DNS server used to resolve the target host.



37
38
39
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 37

def dns_server
  @dns_server
end

#dns_server_portObject

Port of the DNS server used for resolution.



40
41
42
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 40

def dns_server_port
  @dns_server_port
end

#e2e_queriesObject

Number of end-to-end probe queries issued.



43
44
45
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 43

def e2e_queries
  @e2e_queries
end

#filesObject

Files attached to the request.



46
47
48
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 46

def files
  @files
end

#headersObject

Headers sent with the request.



49
50
51
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 49

def headers
  @headers
end

#hostObject

Host targeted by the request.



52
53
54
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 52

def host
  @host
end

#max_ttlObject

Maximum TTL for network probe packets.



55
56
57
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 55

def max_ttl
  @max_ttl
end

#messageObject

Message sent with the request (for WebSocket/TCP/UDP tests).



58
59
60
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 58

def message
  @message
end

#methodObject

HTTP method used for the request.



61
62
63
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 61

def method
  @method
end

#no_saving_response_bodyObject

Whether the response body was not saved.



64
65
66
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 64

def no_saving_response_body
  @no_saving_response_body
end

#portObject

Port targeted by the request. Can be a number or a string variable reference.



67
68
69
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 67

def port
  @port
end

#serviceObject

Service name targeted by the request (for gRPC tests).



70
71
72
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 70

def service
  @service
end

#source_serviceObject

Source service for a Network Path test.



73
74
75
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 73

def source_service
  @source_service
end

#timeoutObject

Request timeout in milliseconds.



76
77
78
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 76

def timeout
  @timeout
end

#tool_nameObject

Name of the MCP tool called (MCP tests only).



79
80
81
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 79

def tool_name
  @tool_name
end

#traceroute_queriesObject

Number of traceroute probe queries issued.



82
83
84
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 82

def traceroute_queries
  @traceroute_queries
end

#urlObject

URL targeted by the request.



85
86
87
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 85

def url
  @url
end