Class: DatadogAPIClient::V2::SyntheticsTestResultStep

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/synthetics_test_result_step.rb

Overview

A step result from a browser, mobile, or multistep API test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



153
154
155
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 153

def additional_properties
  @additional_properties
end

#allow_failureObject

Whether the test continues when this step fails.



25
26
27
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 25

def allow_failure
  @allow_failure
end

#api_testObject

Inner API test definition for browser ‘runApiTest` steps.



28
29
30
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 28

def api_test
  @api_test
end

#assertion_resultObject

Assertion result for a browser or mobile step.



31
32
33
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 31

def assertion_result
  @assertion_result
end

#assertionsObject

Assertion results produced by the step.



34
35
36
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 34

def assertions
  @assertions
end

#blocked_requests_urlsObject

URLs of requests blocked during the step.



37
38
39
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 37

def blocked_requests_urls
  @blocked_requests_urls
end

#boundsObject

Bounding box of an element on the page.



40
41
42
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 40

def bounds
  @bounds
end

#browser_errorsObject

Browser errors captured during the step.



43
44
45
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 43

def browser_errors
  @browser_errors
end

#bucket_keysObject

Storage bucket keys for artifacts produced during a step or test.



46
47
48
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 46

def bucket_keys
  @bucket_keys
end

#cdn_resourcesObject

CDN resources encountered during the step.



49
50
51
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 49

def cdn_resources
  @cdn_resources
end

#click_typeObject

Click type performed in a browser step.



52
53
54
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 52

def click_type
  @click_type
end

#compressed_json_descriptorObject

Compressed JSON descriptor for the step (internal format).



55
56
57
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 55

def compressed_json_descriptor
  @compressed_json_descriptor
end

#configObject

Request configuration executed by this step (API test steps).



58
59
60
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 58

def config
  @config
end

#descriptionObject

Human-readable description of the step.



61
62
63
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 61

def description
  @description
end

#durationObject

Duration of the step in milliseconds.



64
65
66
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 64

def duration
  @duration
end

#element_descriptionObject

Description of the element interacted with by the step.



67
68
69
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 67

def element_description
  @element_description
end

#element_updatesObject

Element locator updates produced during a step.



70
71
72
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 70

def element_updates
  @element_updates
end

#extracted_valueObject

A variable used or extracted during a test.



73
74
75
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 73

def extracted_value
  @extracted_value
end

#failureObject

Details about the failure of a Synthetic test.



76
77
78
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 76

def failure
  @failure
end

#http_resultsObject

HTTP results produced by an MCP step.



79
80
81
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 79

def http_results
  @http_results
end

#idObject

Identifier of the step.



82
83
84
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 82

def id
  @id
end

#is_criticalObject

Whether this step is critical for the test outcome.



85
86
87
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 85

def is_critical
  @is_critical
end

#javascript_custom_assertion_codeObject

Whether the step uses a custom JavaScript assertion.



88
89
90
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 88

def javascript_custom_assertion_code
  @javascript_custom_assertion_code
end

#locate_element_durationObject

Time taken to locate the element in milliseconds.



91
92
93
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 91

def locate_element_duration
  @locate_element_duration
end

#nameObject

Name of the step.



94
95
96
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 94

def name
  @name
end

#requestObject

Details of the outgoing request made during the test execution.



97
98
99
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 97

def request
  @request
end

#responseObject

Details of the response received during the test execution.



100
101
102
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 100

def response
  @response
end

#retriesObject

Retry results for the step.



103
104
105
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 103

def retries
  @retries
end

#retry_countObject

Number of times this step was retried.



106
107
108
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 106

def retry_count
  @retry_count
end

#rum_contextObject

RUM application context associated with a step or sub-test.



109
110
111
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 109

def rum_context
  @rum_context
end

#started_atObject

Unix timestamp (ms) of when the step started.



112
113
114
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 112

def started_at
  @started_at
end

#statusObject

Status of the step (for example, ‘passed`, `failed`).



115
116
117
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 115

def status
  @status
end

#sub_stepObject

Information about a sub-step in a nested test execution.



118
119
120
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 118

def sub_step
  @sub_step
end

#sub_testObject

Information about a sub-test played from a parent browser test.



121
122
123
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 121

def sub_test
  @sub_test
end

#subtypeObject

Subtype of the step.



124
125
126
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 124

def subtype
  @subtype
end

#tabsObject

Browser tabs involved in the step.



127
128
129
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 127

def tabs
  @tabs
end

#timingsObject

Timing breakdown of the step execution.



130
131
132
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 130

def timings
  @timings
end

#tunnelObject

Whether the step was executed through a Synthetics tunnel.



133
134
135
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 133

def tunnel
  @tunnel
end

#typeObject

Type of the step (for example, ‘click`, `assertElementContent`, `runApiTest`).



136
137
138
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 136

def type
  @type
end

#urlObject

URL associated with the step (for navigation steps).



139
140
141
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 139

def url
  @url
end

#valueObject

Step value. Its type depends on the step type.



142
143
144
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 142

def value
  @value
end

#variablesObject

Variables captured during a test step.



145
146
147
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 145

def variables
  @variables
end

#vitals_metricsObject

Web vitals metrics captured during the step.



148
149
150
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 148

def vitals_metrics
  @vitals_metrics
end

#warningsObject

Warnings emitted during the step.



151
152
153
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_step.rb', line 151

def warnings
  @warnings
end