Class: DatadogAPIClient::V2::SyntheticsTestResultTurn
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultTurn
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb
Overview
A turn in a goal-based browser test, grouping steps and reasoning.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#bucket_keys ⇒ Object
Storage bucket keys for artifacts produced during a step or test.
-
#name ⇒ Object
Name of the turn.
-
#reasoning ⇒ Object
Agent reasoning produced for this turn.
-
#status ⇒ Object
Status of the turn (for example, ‘passed`, `failed`).
-
#steps ⇒ Object
Steps executed during the turn.
-
#turn_finished_at ⇒ Object
Unix timestamp (ms) of when the turn finished.
-
#turn_started_at ⇒ Object
Unix timestamp (ms) of when the turn started.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 45 def additional_properties @additional_properties end |
#bucket_keys ⇒ Object
Storage bucket keys for artifacts produced during a step or test.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 25 def bucket_keys @bucket_keys end |
#name ⇒ Object
Name of the turn.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 28 def name @name end |
#reasoning ⇒ Object
Agent reasoning produced for this turn.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 31 def reasoning @reasoning end |
#status ⇒ Object
Status of the turn (for example, ‘passed`, `failed`).
34 35 36 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 34 def status @status end |
#steps ⇒ Object
Steps executed during the turn.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 37 def steps @steps end |
#turn_finished_at ⇒ Object
Unix timestamp (ms) of when the turn finished.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 40 def turn_finished_at @turn_finished_at end |
#turn_started_at ⇒ Object
Unix timestamp (ms) of when the turn started.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn.rb', line 43 def turn_started_at @turn_started_at end |