Class: DatadogAPIClient::V2::SyntheticsTestResultTurnStep
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultTurnStep
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_turn_step.rb
Overview
A step executed during a goal-based browser test turn.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#bucket_keys ⇒ Object
Storage bucket keys for artifacts produced during a step or test.
-
#config ⇒ Object
Browser step configuration for this turn step.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn_step.rb', line 30 def additional_properties @additional_properties end |
#bucket_keys ⇒ Object
Storage bucket keys for artifacts produced during a step or test.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn_step.rb', line 25 def bucket_keys @bucket_keys end |
#config ⇒ Object
Browser step configuration for this turn step.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_turn_step.rb', line 28 def config @config end |