Class: DatadogAPIClient::V2::TagPolicyUpdateData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::TagPolicyUpdateData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/tag_policy_update_data.rb
Overview
Data object for updating a tag policy.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#attributes ⇒ Object
Mutable attributes of a tag policy.
-
#id ⇒ Object
readonly
The unique identifier of the tag policy being updated.
-
#type ⇒ Object
readonly
JSON:API resource type for a tag policy.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_data.rb', line 34 def additional_properties @additional_properties end |
#attributes ⇒ Object
Mutable attributes of a tag policy. Each field is optional; omitting a field leaves its current value unchanged. The ‘source` of a policy cannot be changed.
26 27 28 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_data.rb', line 26 def attributes @attributes end |
#id ⇒ Object
The unique identifier of the tag policy being updated.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_data.rb', line 29 def id @id end |
#type ⇒ Object
JSON:API resource type for a tag policy.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_data.rb', line 32 def type @type end |