Class: DatadogAPIClient::V2::TimeseriesResponseAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/timeseries_response_attributes.rb

Overview

The object describing a timeseries response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#seriesObject

Array of response series. The index here corresponds to the index in the formulas or queries array from the request.



29
30
31
# File 'lib/datadog_api_client/v2/models/timeseries_response_attributes.rb', line 29

def series
  @series
end

#timesObject

Array of times, 1-1 match with individual values arrays.



32
33
34
# File 'lib/datadog_api_client/v2/models/timeseries_response_attributes.rb', line 32

def times
  @times
end

#valuesObject

Array of value-arrays. The index here corresponds to the index in the formulas or queries array from the request.



35
36
37
# File 'lib/datadog_api_client/v2/models/timeseries_response_attributes.rb', line 35

def values
  @values
end