Class: DatadogAPIClient::V2::TimeseriesResponseSeries
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::TimeseriesResponseSeries
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/timeseries_response_series.rb
Instance Attribute Summary collapse
-
#group_tags ⇒ Object
List of tags that apply to a single response value.
-
#query_index ⇒ Object
readonly
The index of the query in the “formulas” array (or “queries” array if no “formulas” was specified).
-
#unit ⇒ Object
Detailed information about the unit.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#group_tags ⇒ Object
List of tags that apply to a single response value.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/timeseries_response_series.rb', line 29 def @group_tags end |
#query_index ⇒ Object
The index of the query in the “formulas” array (or “queries” array if no “formulas” was specified).
32 33 34 |
# File 'lib/datadog_api_client/v2/models/timeseries_response_series.rb', line 32 def query_index @query_index end |
#unit ⇒ Object
Detailed information about the unit. The first element describes the “primary unit” (for example, bytes in ‘bytes per second`). The second element describes the “per unit” (for example, second in `bytes per second`). If the second element is not present, the API returns null.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/timeseries_response_series.rb', line 38 def unit @unit end |