Class: DatadogAPIClient::V2::UpsertCloudInventorySyncConfigRequestAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::UpsertCloudInventorySyncConfigRequestAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_attributes.rb
Overview
Settings for the cloud provider specified in ‘data.id`. Include only the matching provider object (`aws`, `gcp`, or `azure`).
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#aws ⇒ Object
AWS settings for the S3 bucket Storage Management reads inventory reports from.
-
#azure ⇒ Object
Azure settings for the storage account and container with inventory data.
-
#gcp ⇒ Object
GCP settings for buckets involved in inventory reporting.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_attributes.rb', line 33 def additional_properties @additional_properties end |
#aws ⇒ Object
AWS settings for the S3 bucket Storage Management reads inventory reports from.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_attributes.rb', line 25 def aws @aws end |
#azure ⇒ Object
Azure settings for the storage account and container with inventory data.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_attributes.rb', line 28 def azure @azure end |
#gcp ⇒ Object
GCP settings for buckets involved in inventory reporting.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_attributes.rb', line 31 def gcp @gcp end |