Class: DatadogAPIClient::V2::UpsertCloudInventorySyncConfigRequestData

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb

Overview

Storage Management configuration data for the create or update request.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



33
34
35
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 33

def additional_properties
  @additional_properties
end

#attributesObject

Settings for the cloud provider specified in ‘data.id`. Include only the matching provider object (`aws`, `gcp`, or `azure`).



25
26
27
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 25

def attributes
  @attributes
end

#idObject

Cloud provider for this sync configuration (‘aws`, `gcp`, or `azure`). For requests, must match the provider block supplied under `attributes`.



28
29
30
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 28

def id
  @id
end

#typeObject

Always ‘cloud_provider`.



31
32
33
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 31

def type
  @type
end