Class: DatadogAPIClient::V2::UsageAttributesObject
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::UsageAttributesObject
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/usage_attributes_object.rb
Overview
Usage attributes data.
Instance Attribute Summary collapse
-
#org_name ⇒ Object
The organization name.
-
#product_family ⇒ Object
The product for which usage is being reported.
-
#public_id ⇒ Object
The organization public ID.
-
#timeseries ⇒ Object
List of usage data reported for each requested hour.
-
#usage_type ⇒ Object
Usage type that is being measured.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#org_name ⇒ Object
The organization name.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/usage_attributes_object.rb', line 29 def org_name @org_name end |
#product_family ⇒ Object
The product for which usage is being reported.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/usage_attributes_object.rb', line 32 def product_family @product_family end |
#public_id ⇒ Object
The organization public ID.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/usage_attributes_object.rb', line 35 def public_id @public_id end |
#timeseries ⇒ Object
List of usage data reported for each requested hour.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/usage_attributes_object.rb', line 38 def timeseries @timeseries end |
#usage_type ⇒ Object
Usage type that is being measured.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/usage_attributes_object.rb', line 41 def usage_type @usage_type end |