Class: DatadogAPIClient::V2::UserUpdateAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/user_update_attributes.rb

Overview

Attributes of the edited user.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



39
40
41
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 39

def additional_properties
  @additional_properties
end

#disabledObject

When set to ‘true`, the user is deactivated and can no longer log in. When `false`, the user is active.



26
27
28
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 26

def disabled
  @disabled
end

#emailObject

The email address of the user, used for login and notifications. Must be a valid email format.



30
31
32
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 30

def email
  @email
end

#nameObject

The full display name of the user as shown in the Datadog UI. Maximum 55 characters, cannot contain ‘<` or `>`.



34
35
36
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 34

def name
  @name
end

#titleObject

The job title of the user (for example, “Senior Engineer” or “Product Manager”).



37
38
39
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 37

def title
  @title
end