Class: DatadogAPIClient::V2::UsersAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v2/api/users_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ UsersAPI

Returns a new instance of UsersAPI.



22
23
24
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#anonymize_users(body, opts = {}) ⇒ Object

Anonymize users.



29
30
31
32
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 29

def anonymize_users(body, opts = {})
  data, _status_code, _headers = anonymize_users_with_http_info(body, opts)
  data
end

#anonymize_users_with_http_info(body, opts = {}) ⇒ Array<(AnonymizeUsersResponse, Integer, Hash)>

Anonymize users.

Anonymize a list of users, removing their personal data. This operation is irreversible. Requires the ‘user_access_manage` permission.

Parameters:

Returns:

  • (Array<(AnonymizeUsersResponse, Integer, Hash)>)

    AnonymizeUsersResponse data, response status code and response headers



42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 42

def anonymize_users_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.anonymize_users".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.anonymize_users")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.anonymize_users"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.anonymize_users ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling UsersAPI.anonymize_users"
  end
  # resource path
  local_var_path = '/api/v2/anonymize_users'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'AnonymizeUsersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :anonymize_users,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Put, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#anonymize_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_user(body, opts = {}) ⇒ Object

Create a user.



103
104
105
106
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 103

def create_user(body, opts = {})
  data, _status_code, _headers = create_user_with_http_info(body, opts)
  data
end

#create_user_with_http_info(body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>

Create a user.

Create a user for your organization.

Parameters:

Returns:

  • (Array<(UserResponse, Integer, Hash)>)

    UserResponse data, response status code and response headers



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 115

def create_user_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.create_user ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling UsersAPI.create_user"
  end
  # resource path
  local_var_path = '/api/v2/users'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UserResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :create_user,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#create_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_user_invitations(user_id, opts = {}) ⇒ Object

Delete a pending user’s invitations.



170
171
172
173
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 170

def delete_user_invitations(user_id, opts = {})
  delete_user_invitations_with_http_info(user_id, opts)
  nil
end

#delete_user_invitations_with_http_info(user_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a pending user’s invitations.

Cancel all pending invitations for a specified user. Requires the ‘user_access_invite` permission.

Parameters:

  • user_id (UUID)

    The UUID of the user whose pending invitations should be canceled.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 183

def delete_user_invitations_with_http_info(user_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.delete_user_invitations ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersAPI.delete_user_invitations"
  end
  # resource path
  local_var_path = '/api/v2/users/{user_id}/invitations'.sub('{user_id}', CGI.escape(user_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :delete_user_invitations,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#delete_user_invitations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#disable_user(user_id, opts = {}) ⇒ Object

Disable a user.



236
237
238
239
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 236

def disable_user(user_id, opts = {})
  disable_user_with_http_info(user_id, opts)
  nil
end

#disable_user_with_http_info(user_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Disable a user.

Disable a user. Can only be used with an application key belonging to an administrator user.

Parameters:

  • user_id (String)

    The ID of the user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 249

def disable_user_with_http_info(user_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.disable_user ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersAPI.disable_user"
  end
  # resource path
  local_var_path = '/api/v2/users/{user_id}'.sub('{user_id}', CGI.escape(user_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :disable_user,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#disable_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_current_user(opts = {}) ⇒ Object

Get current user.



302
303
304
305
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 302

def get_current_user(opts = {})
  data, _status_code, _headers = get_current_user_with_http_info(opts)
  data
end

#get_current_user_with_http_info(opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>

Get current user.

Get the user associated with the current authentication context. The response includes the user’s profile attributes (name, email, handle, status, MFA state), along with related resources: the user’s organization, assigned roles with their granted permissions, and team-scoped roles. No additional permissions are required beyond valid authentication.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserResponse, Integer, Hash)>)

    UserResponse data, response status code and response headers



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 317

def get_current_user_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.get_current_user ...'
  end
  # resource path
  local_var_path = '/api/v2/current_user'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :get_current_user,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#get_current_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_invitation(user_invitation_uuid, opts = {}) ⇒ Object

Get a user invitation.



366
367
368
369
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 366

def get_invitation(user_invitation_uuid, opts = {})
  data, _status_code, _headers = get_invitation_with_http_info(user_invitation_uuid, opts)
  data
end

#get_invitation_with_http_info(user_invitation_uuid, opts = {}) ⇒ Array<(UserInvitationResponse, Integer, Hash)>

Get a user invitation.

Returns a single user invitation by its UUID.

Parameters:

  • user_invitation_uuid (String)

    The UUID of the user invitation.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserInvitationResponse, Integer, Hash)>)

    UserInvitationResponse data, response status code and response headers



378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 378

def get_invitation_with_http_info(user_invitation_uuid, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.get_invitation ...'
  end
  # verify the required parameter 'user_invitation_uuid' is set
  if @api_client.config.client_side_validation && user_invitation_uuid.nil?
    fail ArgumentError, "Missing the required parameter 'user_invitation_uuid' when calling UsersAPI.get_invitation"
  end
  # resource path
  local_var_path = '/api/v2/user_invitations/{user_invitation_uuid}'.sub('{user_invitation_uuid}', CGI.escape(user_invitation_uuid.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserInvitationResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :get_invitation,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#get_invitation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_user(user_id, opts = {}) ⇒ Object

Get user details.



431
432
433
434
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 431

def get_user(user_id, opts = {})
  data, _status_code, _headers = get_user_with_http_info(user_id, opts)
  data
end

#get_user_with_http_info(user_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>

Get user details.

Get a user in the organization specified by the user’s ‘user_id`.

Parameters:

  • user_id (String)

    The ID of the user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserResponse, Integer, Hash)>)

    UserResponse data, response status code and response headers



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 443

def get_user_with_http_info(user_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.get_user ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersAPI.get_user"
  end
  # resource path
  local_var_path = '/api/v2/users/{user_id}'.sub('{user_id}', CGI.escape(user_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :get_user,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_user_organizations(user_id, opts = {}) ⇒ Object

Get a user organization.



496
497
498
499
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 496

def list_user_organizations(user_id, opts = {})
  data, _status_code, _headers = list_user_organizations_with_http_info(user_id, opts)
  data
end

#list_user_organizations_with_http_info(user_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>

Get a user organization.

Get a user organization. Returns the user information and all organizations joined by this user.

Parameters:

  • user_id (String)

    The ID of the user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserResponse, Integer, Hash)>)

    UserResponse data, response status code and response headers



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 509

def list_user_organizations_with_http_info(user_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.list_user_organizations ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersAPI.list_user_organizations"
  end
  # resource path
  local_var_path = '/api/v2/users/{user_id}/orgs'.sub('{user_id}', CGI.escape(user_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UserResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_user_organizations,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#list_user_organizations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_user_permissions(user_id, opts = {}) ⇒ Object

Get a user permissions.



562
563
564
565
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 562

def list_user_permissions(user_id, opts = {})
  data, _status_code, _headers = list_user_permissions_with_http_info(user_id, opts)
  data
end

#list_user_permissions_with_http_info(user_id, opts = {}) ⇒ Array<(PermissionsResponse, Integer, Hash)>

Get a user permissions.

Get a user permission set. Returns a list of the user’s permissions granted by the associated user’s roles.

Parameters:

  • user_id (String)

    The ID of the user.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(PermissionsResponse, Integer, Hash)>)

    PermissionsResponse data, response status code and response headers



575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 575

def list_user_permissions_with_http_info(user_id, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.list_user_permissions ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersAPI.list_user_permissions"
  end
  # resource path
  local_var_path = '/api/v2/users/{user_id}/permissions'.sub('{user_id}', CGI.escape(user_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PermissionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_user_permissions,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#list_user_permissions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_users(opts = {}) ⇒ Object

List all users.



628
629
630
631
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 628

def list_users(opts = {})
  data, _status_code, _headers = list_users_with_http_info(opts)
  data
end

#list_users_with_http_info(opts = {}) ⇒ Array<(UsersResponse, Integer, Hash)>

List all users.

Get the list of all users in the organization. This list includes all users even if they are deactivated or unverified.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :page_size (Integer)

    Size for a given page. The maximum allowed value is 100.

  • :page_number (Integer)

    Specific page number to return.

  • :sort (String)

    User attribute to order results by. Sort order is ascending by default. Sort order is descending if the field is prefixed by a negative sign, for example ‘sort=-name`. Options: `name`, `modified_at`, `user_count`.

  • :sort_dir (QuerySortOrder)

    Direction of sort. Options: ‘asc`, `desc`.

  • :filter (String)

    Filter all users by the given string. Defaults to no filtering.

  • :filter_status (String)

    Filter on status attribute. Comma separated list, with possible values ‘Active`, `Pending`, and `Disabled`. Defaults to no filtering.

Returns:

  • (Array<(UsersResponse, Integer, Hash)>)

    UsersResponse data, response status code and response headers



646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 646

def list_users_with_http_info(opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.list_users ...'
  end
  allowable_values = ['asc', 'desc']
  if @api_client.config.client_side_validation && opts[:'sort_dir'] && !allowable_values.include?(opts[:'sort_dir'])
    fail ArgumentError, "invalid value for \"sort_dir\", must be one of #{allowable_values}"
  end
  # resource path
  local_var_path = '/api/v2/users'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'sort_dir'] = opts[:'sort_dir'] if !opts[:'sort_dir'].nil?
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'filter[status]'] = opts[:'filter_status'] if !opts[:'filter_status'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'UsersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :list_users,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#list_users\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_users_with_pagination(opts = {}) {|User| ... } ⇒ Object

List all users.

Provide a paginated version of #list_users, returning all items.

To use it you need to use a block: list_users_with_pagination { |item| p item }

Yields:

  • (User)

    Paginated items



709
710
711
712
713
714
715
716
717
718
719
720
721
722
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 709

def list_users_with_pagination(opts = {})
    api_version = "V2"
    page_size = @api_client.get_attribute_from_path(opts, "page_size", 10)
    @api_client.set_attribute_from_path(api_version, opts, "page_size", Integer, page_size)
    @api_client.set_attribute_from_path(api_version, opts, "page_number", Integer, 0)
    while true do
        response = list_users(opts)
        @api_client.get_attribute_from_path(response, "data").each { |item| yield(item) }
        if @api_client.get_attribute_from_path(response, "data").length < page_size
          break
        end
        @api_client.set_attribute_from_path(api_version, opts, "page_number", Integer, @api_client.get_attribute_from_path(opts, "page_number", 0) + 1)
    end
end

#send_invitations(body, opts = {}) ⇒ Object

Send invitation emails.



727
728
729
730
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 727

def send_invitations(body, opts = {})
  data, _status_code, _headers = send_invitations_with_http_info(body, opts)
  data
end

#send_invitations_with_http_info(body, opts = {}) ⇒ Array<(UserInvitationsResponse, Integer, Hash)>

Send invitation emails.

Sends emails to one or more users inviting them to join the organization.

Parameters:

Returns:

  • (Array<(UserInvitationsResponse, Integer, Hash)>)

    UserInvitationsResponse data, response status code and response headers



739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 739

def send_invitations_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.send_invitations ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling UsersAPI.send_invitations"
  end
  # resource path
  local_var_path = '/api/v2/user_invitations'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UserInvitationsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :send_invitations,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#send_invitations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_current_user(body, opts = {}) ⇒ Object

Update current user.



794
795
796
797
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 794

def update_current_user(body, opts = {})
  data, _status_code, _headers = update_current_user_with_http_info(body, opts)
  data
end

#update_current_user_with_http_info(body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>

Update current user.

Edit the profile of the currently authenticated user. Updatable fields include ‘name`, `title`, `email`, and `disabled` status. The `id` field in the request body must match the authenticated user’s UUID; a mismatch returns a 422 error. Email address changes are recorded in the audit trail. Requires the ‘user_self_profile_write` permission.

Parameters:

Returns:

  • (Array<(UserResponse, Integer, Hash)>)

    UserResponse data, response status code and response headers



810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 810

def update_current_user_with_http_info(body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.update_current_user ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling UsersAPI.update_current_user"
  end
  # resource path
  local_var_path = '/api/v2/current_user'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UserResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth]

  new_options = opts.merge(
    :operation => :update_current_user,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#update_current_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_user(user_id, body, opts = {}) ⇒ Object

Update a user.



865
866
867
868
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 865

def update_user(user_id, body, opts = {})
  data, _status_code, _headers = update_user_with_http_info(user_id, body, opts)
  data
end

#update_user_with_http_info(user_id, body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>

Update a user.

Edit a user. Can only be used with an application key belonging to an administrator user.

Parameters:

  • user_id (String)

    The ID of the user.

  • body (UserUpdateRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(UserResponse, Integer, Hash)>)

    UserResponse data, response status code and response headers



879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
# File 'lib/datadog_api_client/v2/api/users_api.rb', line 879

def update_user_with_http_info(user_id, body, opts = {})

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: UsersAPI.update_user ...'
  end
  # verify the required parameter 'user_id' is set
  if @api_client.config.client_side_validation && user_id.nil?
    fail ArgumentError, "Missing the required parameter 'user_id' when calling UsersAPI.update_user"
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling UsersAPI.update_user"
  end
  # resource path
  local_var_path = '/api/v2/users/{user_id}'.sub('{user_id}', CGI.escape(user_id.to_s).gsub('%2F', '/'))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UserResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :update_user,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: UsersAPI#update_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end