Class: DatadogAPIClient::V2::ViewershipHistorySessionDataAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/viewership_history_session_data_attributes.rb

Overview

Attributes of a viewership history session entry, capturing when it was last watched and the associated event data.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



36
37
38
# File 'lib/datadog_api_client/v2/models/viewership_history_session_data_attributes.rb', line 36

def additional_properties
  @additional_properties
end

#event_idObject

Unique identifier of the RUM event associated with the watched session.



25
26
27
# File 'lib/datadog_api_client/v2/models/viewership_history_session_data_attributes.rb', line 25

def event_id
  @event_id
end

#last_watched_atObject

Timestamp when the session was last watched by the user.



28
29
30
# File 'lib/datadog_api_client/v2/models/viewership_history_session_data_attributes.rb', line 28

def last_watched_at
  @last_watched_at
end

#session_eventObject

Raw event data associated with the replay session.



31
32
33
# File 'lib/datadog_api_client/v2/models/viewership_history_session_data_attributes.rb', line 31

def session_event
  @session_event
end

#trackObject

Replay track identifier indicating which recording track the session belongs to.



34
35
36
# File 'lib/datadog_api_client/v2/models/viewership_history_session_data_attributes.rb', line 34

def track
  @track
end