Class: DatadogAPIClient::V2::WidgetAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/widget_attributes.rb

Overview

Attributes of a widget resource.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



43
44
45
# File 'lib/datadog_api_client/v2/models/widget_attributes.rb', line 43

def additional_properties
  @additional_properties
end

#created_atObject

ISO 8601 timestamp of when the widget was created.



25
26
27
# File 'lib/datadog_api_client/v2/models/widget_attributes.rb', line 25

def created_at
  @created_at
end

#definitionObject

The definition of a widget, including its type and configuration.



28
29
30
# File 'lib/datadog_api_client/v2/models/widget_attributes.rb', line 28

def definition
  @definition
end

#is_favoritedObject

Whether the current user has favorited this widget. Populated on get, batch_get, update, and search responses; create responses always return ‘false` because a widget can only be favorited after it exists. Favoriting itself is performed through the shared favorites API, not this service.



35
36
37
# File 'lib/datadog_api_client/v2/models/widget_attributes.rb', line 35

def is_favorited
  @is_favorited
end

#modified_atObject

ISO 8601 timestamp of when the widget was last modified.



38
39
40
# File 'lib/datadog_api_client/v2/models/widget_attributes.rb', line 38

def modified_at
  @modified_at
end

#tagsObject

User-defined tags for organizing widgets.



41
42
43
# File 'lib/datadog_api_client/v2/models/widget_attributes.rb', line 41

def tags
  @tags
end