Class: DatadogAPIClient::V2::WorkflowListItemAttributes

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb

Overview

Attributes of a workflow returned in a list response.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#additional_propertiesObject

Returns the value of attribute additional_properties.



45
46
47
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 45

def additional_properties
  @additional_properties
end

#created_atObject

When the workflow was created.



25
26
27
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 25

def created_at
  @created_at
end

#descriptionObject

Description of the workflow.



28
29
30
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 28

def description
  @description
end

#nameObject

Name of the workflow.



31
32
33
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 31

def name
  @name
end

#publishedObject

Whether the workflow is published. Unpublished workflows can only be run manually. Automatic triggers such as Schedule do not fire until the workflow is published.



34
35
36
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 34

def published
  @published
end

#specObject

The spec defines what the workflow does.



37
38
39
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 37

def spec
  @spec
end

#tagsObject

Tags of the workflow.



40
41
42
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 40

def tags
  @tags
end

#updated_atObject

When the workflow was last updated.



43
44
45
# File 'lib/datadog_api_client/v2/models/workflow_list_item_attributes.rb', line 43

def updated_at
  @updated_at
end