Class: DatadogAPIClient::V1::AlertGraphWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::AlertGraphWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb
Overview
Alert graphs are timeseries graphs showing the current status of any monitor defined on your system.
Instance Attribute Summary collapse
-
#alert_id ⇒ Object
readonly
ID of the alert to use in the widget.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
The title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the alert graph widget.
-
#viz_type ⇒ Object
readonly
Whether to display the Alert Graph as a timeseries or a top list.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#alert_id ⇒ Object
ID of the alert to use in the widget.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 29 def alert_id @alert_id end |
#time ⇒ Object
Time setting for the widget.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 32 def time @time end |
#title ⇒ Object
The title of the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 35 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 38 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 41 def title_size @title_size end |
#type ⇒ Object
Type of the alert graph widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 44 def type @type end |
#viz_type ⇒ Object
Whether to display the Alert Graph as a timeseries or a top list.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/alert_graph_widget_definition.rb', line 47 def viz_type @viz_type end |