Class: DatadogAPIClient::V1::AlertValueWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::AlertValueWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/alert_value_widget_definition.rb
Overview
Alert values are query values showing the current value of the metric in any monitor defined on your system.
Instance Attribute Summary collapse
-
#alert_id ⇒ Object
readonly
ID of the alert to use in the widget.
-
#precision ⇒ Object
Number of decimal to show.
-
#text_align ⇒ Object
How to align the text on the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of value in the widget.
-
#type ⇒ Object
readonly
Type of the alert value widget.
-
#unit ⇒ Object
Unit to display with the value.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#alert_id ⇒ Object
ID of the alert to use in the widget.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 29 def alert_id @alert_id end |
#precision ⇒ Object
Number of decimal to show. If not defined, will use the raw value.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 32 def precision @precision end |
#text_align ⇒ Object
How to align the text on the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 35 def text_align @text_align end |
#title ⇒ Object
Title of the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 38 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 41 def title_align @title_align end |
#title_size ⇒ Object
Size of value in the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 44 def title_size @title_size end |
#type ⇒ Object
Type of the alert value widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 47 def type @type end |
#unit ⇒ Object
Unit to display with the value.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/alert_value_widget_definition.rb', line 50 def unit @unit end |