Class: DatadogAPIClient::V1::ChangeWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ChangeWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/change_widget_definition.rb
Overview
The Change graph shows you the change in a value over the time period chosen.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#requests ⇒ Object
readonly
Array of one request object to display in the widget.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the change widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 29 def custom_links @custom_links end |
#requests ⇒ Object
Array of one request object to display in the widget.
See the dedicated [Request JSON schema documentation](docs.datadoghq.com/dashboards/graphing_json/request_json)
to learn how to build the `REQUEST_SCHEMA`.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 35 def requests @requests end |
#time ⇒ Object
Time setting for the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 38 def time @time end |
#title ⇒ Object
Title of the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 41 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 44 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 47 def title_size @title_size end |
#type ⇒ Object
Type of the change widget.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/change_widget_definition.rb', line 50 def type @type end |