Class: DatadogAPIClient::V1::Dashboard
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::Dashboard
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/dashboard.rb
Overview
A dashboard is Datadog’s tool for visually tracking, analyzing, and displaying key performance metrics, which enable you to monitor the health of your infrastructure.
Instance Attribute Summary collapse
-
#author_handle ⇒ Object
Identifier of the dashboard author.
-
#author_name ⇒ Object
Name of the dashboard author.
-
#created_at ⇒ Object
Creation date of the dashboard.
-
#description ⇒ Object
Description of the dashboard.
-
#id ⇒ Object
ID of the dashboard.
-
#is_read_only ⇒ Object
Whether this dashboard is read-only.
-
#layout_type ⇒ Object
readonly
Layout type of the dashboard.
-
#modified_at ⇒ Object
Modification date of the dashboard.
-
#notify_list ⇒ Object
List of handles of users to notify when changes are made to this dashboard.
-
#reflow_type ⇒ Object
Reflow type for a **new dashboard layout** dashboard.
-
#restricted_roles ⇒ Object
A list of role identifiers.
-
#template_variable_presets ⇒ Object
Array of template variables saved views.
-
#template_variables ⇒ Object
List of template variables for this dashboard.
-
#title ⇒ Object
readonly
Title of the dashboard.
-
#url ⇒ Object
The URL of the dashboard.
-
#widgets ⇒ Object
readonly
List of widgets to display on the dashboard.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#author_handle ⇒ Object
Identifier of the dashboard author.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 30 def end |
#author_name ⇒ Object
Name of the dashboard author.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 33 def end |
#created_at ⇒ Object
Creation date of the dashboard.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 36 def created_at @created_at end |
#description ⇒ Object
Description of the dashboard.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 39 def description @description end |
#id ⇒ Object
ID of the dashboard.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 42 def id @id end |
#is_read_only ⇒ Object
Whether this dashboard is read-only. If True, only the author and admins can make changes to it. Prefer using restricted_roles to manage write authorization.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 45 def is_read_only @is_read_only end |
#layout_type ⇒ Object
Layout type of the dashboard.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 48 def layout_type @layout_type end |
#modified_at ⇒ Object
Modification date of the dashboard.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 51 def modified_at @modified_at end |
#notify_list ⇒ Object
List of handles of users to notify when changes are made to this dashboard.
54 55 56 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 54 def notify_list @notify_list end |
#reflow_type ⇒ Object
Reflow type for a **new dashboard layout** dashboard. Set this only when layout type is ‘ordered’. If set to ‘fixed’, the dashboard expects all widgets to have a layout, and if it’s set to ‘auto’, widgets should not have layouts.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 59 def reflow_type @reflow_type end |
#restricted_roles ⇒ Object
A list of role identifiers. Only the author and users associated with at least one of these roles can edit this dashboard.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 62 def restricted_roles @restricted_roles end |
#template_variable_presets ⇒ Object
Array of template variables saved views.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 65 def template_variable_presets @template_variable_presets end |
#template_variables ⇒ Object
List of template variables for this dashboard.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 68 def template_variables @template_variables end |
#title ⇒ Object
Title of the dashboard.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 71 def title @title end |
#url ⇒ Object
The URL of the dashboard.
74 75 76 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 74 def url @url end |
#widgets ⇒ Object
List of widgets to display on the dashboard.
77 78 79 |
# File 'lib/datadog_api_client/v1/models/dashboard.rb', line 77 def end |