Class: DatadogAPIClient::V1::DashboardsAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::DashboardsAPI
- Defined in:
- lib/datadog_api_client/v1/api/dashboards_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_dashboard(body, opts = {}) ⇒ Object
Create a new dashboard.
-
#create_dashboard_with_http_info(body, opts = {}) ⇒ Array<(Dashboard, Integer, Hash)>
Create a new dashboard.
-
#delete_dashboard(dashboard_id, opts = {}) ⇒ Object
Delete a dashboard.
-
#delete_dashboard_with_http_info(dashboard_id, opts = {}) ⇒ Array<(DashboardDeleteResponse, Integer, Hash)>
Delete a dashboard.
-
#delete_dashboards(body, opts = {}) ⇒ Object
Delete dashboards.
-
#delete_dashboards_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete dashboards.
-
#get_dashboard(dashboard_id, opts = {}) ⇒ Object
Get a dashboard.
-
#get_dashboard_with_http_info(dashboard_id, opts = {}) ⇒ Array<(Dashboard, Integer, Hash)>
Get a dashboard.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ DashboardsAPI
constructor
A new instance of DashboardsAPI.
-
#list_dashboards(opts = {}) ⇒ Object
Get all dashboards.
-
#list_dashboards_with_http_info(opts = {}) ⇒ Array<(DashboardSummary, Integer, Hash)>
Get all dashboards.
-
#restore_dashboards(body, opts = {}) ⇒ Object
Restore deleted dashboards.
-
#restore_dashboards_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Restore deleted dashboards.
-
#update_dashboard(dashboard_id, body, opts = {}) ⇒ Object
Update a dashboard.
-
#update_dashboard_with_http_info(dashboard_id, body, opts = {}) ⇒ Array<(Dashboard, Integer, Hash)>
Update a dashboard.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ DashboardsAPI
Returns a new instance of DashboardsAPI.
22 23 24 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#create_dashboard(body, opts = {}) ⇒ Object
Create a new dashboard.
29 30 31 32 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 29 def create_dashboard(body, opts = {}) data, _status_code, _headers = create_dashboard_with_http_info(body, opts) data end |
#create_dashboard_with_http_info(body, opts = {}) ⇒ Array<(Dashboard, Integer, Hash)>
Create a new dashboard.
Create a dashboard using the specified options. When defining queries in your widgets, take note of which queries should have the ‘as_count()` or `as_rate()` modifiers appended. Refer to the following [documentation](docs.datadoghq.com/developers/metrics/type_modifiers/?tab=count#in-application-modifiers) for more information on these modifiers.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 42 def create_dashboard_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.create_dashboard ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling DashboardsAPI.create_dashboard" end # resource path local_var_path = '/api/v1/dashboard' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'Dashboard' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :create_dashboard, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#create_dashboard\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_dashboard(dashboard_id, opts = {}) ⇒ Object
Delete a dashboard.
97 98 99 100 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 97 def delete_dashboard(dashboard_id, opts = {}) data, _status_code, _headers = delete_dashboard_with_http_info(dashboard_id, opts) data end |
#delete_dashboard_with_http_info(dashboard_id, opts = {}) ⇒ Array<(DashboardDeleteResponse, Integer, Hash)>
Delete a dashboard.
Delete a dashboard using the specified ID.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 109 def delete_dashboard_with_http_info(dashboard_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.delete_dashboard ...' end # verify the required parameter 'dashboard_id' is set if @api_client.config.client_side_validation && dashboard_id.nil? fail ArgumentError, "Missing the required parameter 'dashboard_id' when calling DashboardsAPI.delete_dashboard" end # resource path local_var_path = '/api/v1/dashboard/{dashboard_id}'.sub('{dashboard_id}', CGI.escape(dashboard_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DashboardDeleteResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :delete_dashboard, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#delete_dashboard\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_dashboards(body, opts = {}) ⇒ Object
Delete dashboards.
162 163 164 165 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 162 def delete_dashboards(body, opts = {}) delete_dashboards_with_http_info(body, opts) nil end |
#delete_dashboards_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete dashboards.
Delete dashboards using the specified IDs. If there are any failures, no dashboards will be deleted (partial success is not allowed).
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 174 def delete_dashboards_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.delete_dashboards ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling DashboardsAPI.delete_dashboards" end # resource path local_var_path = '/api/v1/dashboard' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :delete_dashboards, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#delete_dashboards\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_dashboard(dashboard_id, opts = {}) ⇒ Object
Get a dashboard.
229 230 231 232 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 229 def get_dashboard(dashboard_id, opts = {}) data, _status_code, _headers = get_dashboard_with_http_info(dashboard_id, opts) data end |
#get_dashboard_with_http_info(dashboard_id, opts = {}) ⇒ Array<(Dashboard, Integer, Hash)>
Get a dashboard.
Get a dashboard using the specified ID.
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 241 def get_dashboard_with_http_info(dashboard_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.get_dashboard ...' end # verify the required parameter 'dashboard_id' is set if @api_client.config.client_side_validation && dashboard_id.nil? fail ArgumentError, "Missing the required parameter 'dashboard_id' when calling DashboardsAPI.get_dashboard" end # resource path local_var_path = '/api/v1/dashboard/{dashboard_id}'.sub('{dashboard_id}', CGI.escape(dashboard_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Dashboard' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :get_dashboard, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#get_dashboard\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_dashboards(opts = {}) ⇒ Object
Get all dashboards.
294 295 296 297 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 294 def list_dashboards(opts = {}) data, _status_code, _headers = list_dashboards_with_http_info(opts) data end |
#list_dashboards_with_http_info(opts = {}) ⇒ Array<(DashboardSummary, Integer, Hash)>
Get all dashboards.
Get all dashboards.
Note: This query will only return custom created or cloned dashboards. This query will not return preset dashboards.
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 310 def list_dashboards_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.list_dashboards ...' end # resource path local_var_path = '/api/v1/dashboard' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[shared]'] = opts[:'filter_shared'] if !opts[:'filter_shared'].nil? query_params[:'filter[deleted]'] = opts[:'filter_deleted'] if !opts[:'filter_deleted'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'DashboardSummary' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :list_dashboards, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#list_dashboards\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#restore_dashboards(body, opts = {}) ⇒ Object
Restore deleted dashboards.
361 362 363 364 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 361 def restore_dashboards(body, opts = {}) restore_dashboards_with_http_info(body, opts) nil end |
#restore_dashboards_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Restore deleted dashboards.
Restore dashboards using the specified IDs. If there are any failures, no dashboards will be restored (partial success is not allowed).
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 373 def restore_dashboards_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.restore_dashboards ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling DashboardsAPI.restore_dashboards" end # resource path local_var_path = '/api/v1/dashboard' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :restore_dashboards, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#restore_dashboards\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_dashboard(dashboard_id, body, opts = {}) ⇒ Object
Update a dashboard.
428 429 430 431 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 428 def update_dashboard(dashboard_id, body, opts = {}) data, _status_code, _headers = update_dashboard_with_http_info(dashboard_id, body, opts) data end |
#update_dashboard_with_http_info(dashboard_id, body, opts = {}) ⇒ Array<(Dashboard, Integer, Hash)>
Update a dashboard.
Update a dashboard using the specified ID.
441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/datadog_api_client/v1/api/dashboards_api.rb', line 441 def update_dashboard_with_http_info(dashboard_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: DashboardsAPI.update_dashboard ...' end # verify the required parameter 'dashboard_id' is set if @api_client.config.client_side_validation && dashboard_id.nil? fail ArgumentError, "Missing the required parameter 'dashboard_id' when calling DashboardsAPI.update_dashboard" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling DashboardsAPI.update_dashboard" end # resource path local_var_path = '/api/v1/dashboard/{dashboard_id}'.sub('{dashboard_id}', CGI.escape(dashboard_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'Dashboard' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :update_dashboard, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V1" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Put, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: DashboardsAPI#update_dashboard\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |