Class: DatadogAPIClient::V1::Event
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::Event
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/event.rb
Overview
Object representing an event.
Instance Attribute Summary collapse
-
#alert_type ⇒ Object
If an alert event is enabled, set its type.
-
#date_happened ⇒ Object
POSIX timestamp of the event.
-
#device_name ⇒ Object
A device name.
-
#host ⇒ Object
Host name to associate with the event.
-
#id ⇒ Object
Integer ID of the event.
-
#id_str ⇒ Object
Handling IDs as large 64-bit numbers can cause loss of accuracy issues with some programming languages.
-
#payload ⇒ Object
Payload of the event.
-
#priority ⇒ Object
The priority of the event.
-
#source_type_name ⇒ Object
The type of event being posted.
-
#tags ⇒ Object
A list of tags to apply to the event.
-
#text ⇒ Object
readonly
The body of the event.
-
#title ⇒ Object
The event title.
-
#url ⇒ Object
URL of the event.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#alert_type ⇒ Object
If an alert event is enabled, set its type. For example, error, warning, info, success, user_update, recommendation, and snapshot.
31 32 33 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 31 def alert_type @alert_type end |
#date_happened ⇒ Object
POSIX timestamp of the event. Must be sent as an integer (that is no quotes). Limited to events no older than 18 hours.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 35 def date_happened @date_happened end |
#device_name ⇒ Object
A device name.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 38 def device_name @device_name end |
#host ⇒ Object
Host name to associate with the event. Any tags associated with the host are also applied to this event.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 42 def host @host end |
#id ⇒ Object
Integer ID of the event.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 45 def id @id end |
#id_str ⇒ Object
Handling IDs as large 64-bit numbers can cause loss of accuracy issues with some programming languages. Instead, use the string representation of the Event ID to avoid losing accuracy.
49 50 51 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 49 def id_str @id_str end |
#payload ⇒ Object
Payload of the event.
52 53 54 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 52 def payload @payload end |
#priority ⇒ Object
The priority of the event. For example, normal or low.
55 56 57 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 55 def priority @priority end |
#source_type_name ⇒ Object
The type of event being posted. Option examples include nagios, hudson, jenkins, my_apps, chef, puppet, git, bitbucket, etc. The list of standard source attribute values [available here](docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value).
59 60 61 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 59 def source_type_name @source_type_name end |
#tags ⇒ Object
A list of tags to apply to the event.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 62 def end |
#text ⇒ Object
The body of the event. Limited to 4000 characters. The text supports markdown. To use markdown in the event text, start the text block with ‘%%% n` and end the text block with `n %%%`. Use msg_text with the Datadog Ruby library.
67 68 69 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 67 def text @text end |
#title ⇒ Object
The event title.
70 71 72 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 70 def title @title end |
#url ⇒ Object
URL of the event.
73 74 75 |
# File 'lib/datadog_api_client/v1/models/event.rb', line 73 def url @url end |