Class: DatadogAPIClient::V1::FunnelWidgetDefinition

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/funnel_widget_definition.rb

Overview

The funnel visualization displays a funnel of user sessions that maps a sequence of view navigation and user interaction in your application.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#requestsObject

Request payload used to query items.



29
30
31
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 29

def requests
  @requests
end

#timeObject

Time setting for the widget.



32
33
34
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 32

def time
  @time
end

#titleObject

The title of the widget.



35
36
37
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 35

def title
  @title
end

#title_alignObject

How to align the text on the widget.



38
39
40
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 38

def title_align
  @title_align
end

#title_sizeObject

The size of the title.



41
42
43
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 41

def title_size
  @title_size
end

#typeObject

Type of funnel widget.



44
45
46
# File 'lib/datadog_api_client/v1/models/funnel_widget_definition.rb', line 44

def type
  @type
end