Class: DatadogAPIClient::V1::GeomapWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::GeomapWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/geomap_widget_definition.rb
Overview
This visualization displays a series of values by country on a world map.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
A list of custom links.
-
#requests ⇒ Object
readonly
Array of one request object to display in the widget.
-
#style ⇒ Object
readonly
The style to apply to the widget.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
The title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
The size of the title.
-
#type ⇒ Object
readonly
Type of the geomap widget.
-
#view ⇒ Object
readonly
The view of the world that the map should render.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
A list of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 29 def custom_links @custom_links end |
#requests ⇒ Object
Array of one request object to display in the widget. The request must contain a group-by tag whose value is a country ISO code.
See the [Request JSON schema documentation](docs.datadoghq.com/dashboards/graphing_json/request_json) for information about building the REQUEST_SCHEMA.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 35 def requests @requests end |
#style ⇒ Object
The style to apply to the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 38 def style @style end |
#time ⇒ Object
Time setting for the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 41 def time @time end |
#title ⇒ Object
The title of your widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 44 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 47 def title_align @title_align end |
#title_size ⇒ Object
The size of the title.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 50 def title_size @title_size end |
#type ⇒ Object
Type of the geomap widget.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 53 def type @type end |
#view ⇒ Object
The view of the world that the map should render.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/geomap_widget_definition.rb', line 56 def view @view end |