Class: DatadogAPIClient::V1::GroupWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::GroupWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/group_widget_definition.rb
Overview
The groups widget allows you to keep similar graphs together on your timeboard. Each group has a custom header, can hold one to many graphs, and is collapsible.
Instance Attribute Summary collapse
-
#background_color ⇒ Object
Background color of the group title.
-
#banner_img ⇒ Object
URL of image to display as a banner for the group.
-
#layout_type ⇒ Object
readonly
Layout type of the group.
-
#show_title ⇒ Object
Whether to show the title or not.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#type ⇒ Object
readonly
Type of the group widget.
-
#widgets ⇒ Object
readonly
List of widget groups.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#background_color ⇒ Object
Background color of the group title.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 29 def background_color @background_color end |
#banner_img ⇒ Object
URL of image to display as a banner for the group.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 32 def end |
#layout_type ⇒ Object
Layout type of the group.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 35 def layout_type @layout_type end |
#show_title ⇒ Object
Whether to show the title or not.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 38 def show_title @show_title end |
#title ⇒ Object
Title of the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 41 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 44 def title_align @title_align end |
#type ⇒ Object
Type of the group widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 47 def type @type end |
#widgets ⇒ Object
List of widget groups.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/group_widget_definition.rb', line 50 def end |