Class: DatadogAPIClient::V1::Host
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::Host
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/host.rb
Overview
Object representing a host.
Instance Attribute Summary collapse
-
#aliases ⇒ Object
Host aliases collected by Datadog.
-
#apps ⇒ Object
The Datadog integrations reporting metrics for the host.
-
#aws_name ⇒ Object
AWS name of your host.
-
#host_name ⇒ Object
The host name.
-
#id ⇒ Object
The host ID.
-
#is_muted ⇒ Object
If a host is muted or unmuted.
-
#last_reported_time ⇒ Object
Last time the host reported a metric data point.
-
#meta ⇒ Object
Metadata associated with your host.
-
#metrics ⇒ Object
Host Metrics collected.
-
#mute_timeout ⇒ Object
Timeout of the mute applied to your host.
-
#name ⇒ Object
The host name.
-
#sources ⇒ Object
Source or cloud provider associated with your host.
-
#tags_by_source ⇒ Object
List of tags for each source (AWS, Datadog Agent, Chef..).
-
#up ⇒ Object
Displays UP when the expected metrics are received and displays ‘???` if no metrics are received.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#aliases ⇒ Object
Host aliases collected by Datadog.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 29 def aliases @aliases end |
#apps ⇒ Object
The Datadog integrations reporting metrics for the host.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 32 def apps @apps end |
#aws_name ⇒ Object
AWS name of your host.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 35 def aws_name @aws_name end |
#host_name ⇒ Object
The host name.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 38 def host_name @host_name end |
#id ⇒ Object
The host ID.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 41 def id @id end |
#is_muted ⇒ Object
If a host is muted or unmuted.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 44 def is_muted @is_muted end |
#last_reported_time ⇒ Object
Last time the host reported a metric data point.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 47 def last_reported_time @last_reported_time end |
#meta ⇒ Object
Metadata associated with your host.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 50 def end |
#metrics ⇒ Object
Host Metrics collected.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 53 def metrics @metrics end |
#mute_timeout ⇒ Object
Timeout of the mute applied to your host.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 56 def mute_timeout @mute_timeout end |
#name ⇒ Object
The host name.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 59 def name @name end |
#sources ⇒ Object
Source or cloud provider associated with your host.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 62 def sources @sources end |
#tags_by_source ⇒ Object
List of tags for each source (AWS, Datadog Agent, Chef..).
65 66 67 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 65 def end |
#up ⇒ Object
Displays UP when the expected metrics are received and displays ‘???` if no metrics are received.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/host.rb', line 68 def up @up end |