Class: DatadogAPIClient::V1::HostMapWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::HostMapWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/host_map_widget_definition.rb
Overview
The host map widget graphs any metric across your hosts using the same visualization available from the main Host Map page.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#group ⇒ Object
List of tag prefixes to group by.
-
#no_group_hosts ⇒ Object
Whether to show the hosts that don’t fit in a group.
-
#no_metric_hosts ⇒ Object
Whether to show the hosts with no metrics.
-
#node_type ⇒ Object
Which type of node to use in the map.
-
#notes ⇒ Object
Notes on the title.
-
#requests ⇒ Object
readonly
List of definitions.
-
#scope ⇒ Object
List of tags used to filter the map.
-
#style ⇒ Object
The style to apply to the widget.
-
#title ⇒ Object
Title of the widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the host map widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 29 def custom_links @custom_links end |
#group ⇒ Object
List of tag prefixes to group by.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 32 def group @group end |
#no_group_hosts ⇒ Object
Whether to show the hosts that don’t fit in a group.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 35 def no_group_hosts @no_group_hosts end |
#no_metric_hosts ⇒ Object
Whether to show the hosts with no metrics.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 38 def no_metric_hosts @no_metric_hosts end |
#node_type ⇒ Object
Which type of node to use in the map.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 41 def node_type @node_type end |
#notes ⇒ Object
Notes on the title.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 44 def notes @notes end |
#requests ⇒ Object
List of definitions.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 47 def requests @requests end |
#scope ⇒ Object
List of tags used to filter the map.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 50 def scope @scope end |
#style ⇒ Object
The style to apply to the widget.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 53 def style @style end |
#title ⇒ Object
Title of the widget.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 56 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 59 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 62 def title_size @title_size end |
#type ⇒ Object
Type of the host map widget.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/host_map_widget_definition.rb', line 65 def type @type end |