Class: DatadogAPIClient::V1::HostMuteResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::HostMuteResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/host_mute_response.rb
Overview
Response with the list of muted host for your organization.
Instance Attribute Summary collapse
-
#_end ⇒ Object
POSIX timestamp in seconds when the host is unmuted.
-
#action ⇒ Object
Action applied to the hosts.
-
#hostname ⇒ Object
The host name.
-
#message ⇒ Object
Message associated with the mute.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#_end ⇒ Object
POSIX timestamp in seconds when the host is unmuted.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 32 def _end @_end end |
#action ⇒ Object
Action applied to the hosts.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 29 def action @action end |
#hostname ⇒ Object
The host name.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 35 def hostname @hostname end |
#message ⇒ Object
Message associated with the mute.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/host_mute_response.rb', line 38 def @message end |