Class: DatadogAPIClient::V1::HourlyUsageAttributionBody
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::HourlyUsageAttributionBody
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb
Overview
The usage for one set of tags for one hour.
Instance Attribute Summary collapse
-
#hour ⇒ Object
The hour for the usage.
-
#org_name ⇒ Object
The name of the organization.
-
#public_id ⇒ Object
The organization public ID.
-
#tag_config_source ⇒ Object
The source of the usage attribution tag configuration and the selected tags in the format of ‘<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>`.
-
#tags ⇒ Object
Tag keys and values.
-
#total_usage_sum ⇒ Object
Total product usage for the given tags within the hour.
-
#updated_at ⇒ Object
Shows the most recent hour in the current month for all organizations where usages are calculated.
-
#usage_type ⇒ Object
Supported products for hourly usage attribution requests.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#hour ⇒ Object
The hour for the usage.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 29 def hour @hour end |
#org_name ⇒ Object
The name of the organization.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 32 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 35 def public_id @public_id end |
#tag_config_source ⇒ Object
The source of the usage attribution tag configuration and the selected tags in the format of ‘<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>`.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 38 def tag_config_source @tag_config_source end |
#tags ⇒ Object
Tag keys and values.
A null value here means that the requested tag breakdown cannot be applied because it does not match the [tags configured for usage attribution](docs.datadoghq.com/account_management/billing/usage_attribution/#getting-started). In this scenario the API returns the total usage, not broken down by tags.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 45 def @tags end |
#total_usage_sum ⇒ Object
Total product usage for the given tags within the hour.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 48 def total_usage_sum @total_usage_sum end |
#updated_at ⇒ Object
Shows the most recent hour in the current month for all organizations where usages are calculated.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 51 def updated_at @updated_at end |
#usage_type ⇒ Object
Supported products for hourly usage attribution requests.
54 55 56 |
# File 'lib/datadog_api_client/v1/models/hourly_usage_attribution_body.rb', line 54 def usage_type @usage_type end |