Class: DatadogAPIClient::V1::IFrameWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::IFrameWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/i_frame_widget_definition.rb
Overview
The iframe widget allows you to embed a portion of any other web page on your dashboard. Only available on FREE layout dashboards.
Instance Attribute Summary collapse
-
#type ⇒ Object
readonly
Type of the iframe widget.
-
#url ⇒ Object
readonly
URL of the iframe.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#type ⇒ Object
Type of the iframe widget.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/i_frame_widget_definition.rb', line 29 def type @type end |
#url ⇒ Object
URL of the iframe.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/i_frame_widget_definition.rb', line 32 def url @url end |