Class: DatadogAPIClient::V1::LogsByRetention
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsByRetention
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_by_retention.rb
Overview
Object containing logs usage data broken down by retention period.
Instance Attribute Summary collapse
-
#orgs ⇒ Object
Indexed logs usage summary for each organization for each retention period with usage.
-
#usage ⇒ Object
Aggregated index logs usage for each retention period with usage.
-
#usage_by_month ⇒ Object
Object containing a summary of indexed logs usage by retention period for a single month.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#orgs ⇒ Object
Indexed logs usage summary for each organization for each retention period with usage.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/logs_by_retention.rb', line 29 def orgs @orgs end |
#usage ⇒ Object
Aggregated index logs usage for each retention period with usage.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/logs_by_retention.rb', line 32 def usage @usage end |
#usage_by_month ⇒ Object
Object containing a summary of indexed logs usage by retention period for a single month.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/logs_by_retention.rb', line 35 def usage_by_month @usage_by_month end |