Class: DatadogAPIClient::V1::LogsByRetentionMonthlyUsage
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsByRetentionMonthlyUsage
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_by_retention_monthly_usage.rb
Overview
Object containing a summary of indexed logs usage by retention period for a single month.
Instance Attribute Summary collapse
-
#date ⇒ Object
The month for the usage.
-
#usage ⇒ Object
Indexed logs usage for each active retention for the month.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#date ⇒ Object
The month for the usage.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/logs_by_retention_monthly_usage.rb', line 29 def date @date end |
#usage ⇒ Object
Indexed logs usage for each active retention for the month.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/logs_by_retention_monthly_usage.rb', line 32 def usage @usage end |