Class: DatadogAPIClient::V1::LogsGrokParserRules
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsGrokParserRules
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_grok_parser_rules.rb
Overview
Set of rules for the grok parser.
Instance Attribute Summary collapse
-
#match_rules ⇒ Object
readonly
List of match rules for the grok parser, separated by a new line.
-
#support_rules ⇒ Object
List of support rules for the grok parser, separated by a new line.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#match_rules ⇒ Object
List of match rules for the grok parser, separated by a new line.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/logs_grok_parser_rules.rb', line 29 def match_rules @match_rules end |
#support_rules ⇒ Object
List of support rules for the grok parser, separated by a new line.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/logs_grok_parser_rules.rb', line 32 def support_rules @support_rules end |