Class: DatadogAPIClient::V1::LogsIndexUpdateRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsIndexUpdateRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_index_update_request.rb
Overview
Object for updating a Datadog Log index.
Instance Attribute Summary collapse
-
#daily_limit ⇒ Object
The number of log events you can send in this index per day before you are rate-limited.
-
#disable_daily_limit ⇒ Object
If true, sets the
daily_limitvalue to null and the index is not limited on a daily basis (any specifieddaily_limitvalue in the request is ignored). -
#exclusion_filters ⇒ Object
An array of exclusion objects.
-
#filter ⇒ Object
readonly
Filter for logs.
-
#num_retention_days ⇒ Object
The number of days before logs are deleted from this index.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#daily_limit ⇒ Object
The number of log events you can send in this index per day before you are rate-limited.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/logs_index_update_request.rb', line 29 def daily_limit @daily_limit end |
#disable_daily_limit ⇒ Object
If true, sets the daily_limit value to null and the index is not limited on a daily basis (any specified daily_limit value in the request is ignored). If false or omitted, the index’s current daily_limit is maintained.
34 35 36 |
# File 'lib/datadog_api_client/v1/models/logs_index_update_request.rb', line 34 def disable_daily_limit @disable_daily_limit end |
#exclusion_filters ⇒ Object
An array of exclusion objects. The logs are tested against the query of each filter, following the order of the array. Only the first matching active exclusion matters, others (if any) are ignored.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/logs_index_update_request.rb', line 39 def exclusion_filters @exclusion_filters end |
#filter ⇒ Object
Filter for logs.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/logs_index_update_request.rb', line 42 def filter @filter end |
#num_retention_days ⇒ Object
The number of days before logs are deleted from this index. Available values depend on retention plans specified in your organization’s contract/subscriptions.
Note: Changing the retention for an index adjusts the length of retention for all logs already in this index. It may also affect billing.
49 50 51 |
# File 'lib/datadog_api_client/v1/models/logs_index_update_request.rb', line 49 def num_retention_days @num_retention_days end |