Class: DatadogAPIClient::V1::LogsListRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsListRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_list_request.rb
Overview
Object to send with the request to retrieve a list of logs from your Organization.
Instance Attribute Summary collapse
-
#index ⇒ Object
The log index on which the request is performed.
-
#limit ⇒ Object
readonly
Number of logs return in the response.
-
#query ⇒ Object
The search query - following the log search syntax.
-
#sort ⇒ Object
Time-ascending
ascor time-descendingdescresults. -
#start_at ⇒ Object
Hash identifier of the first log to return in the list, available in a log
idattribute. -
#time ⇒ Object
readonly
Timeframe to retrieve the log from.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#index ⇒ Object
The log index on which the request is performed. For multi-index organizations, the default is all live indexes. Historical indexes of rehydrated logs must be specified.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/logs_list_request.rb', line 30 def index @index end |
#limit ⇒ Object
Number of logs return in the response.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/logs_list_request.rb', line 33 def limit @limit end |
#query ⇒ Object
The search query - following the log search syntax.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/logs_list_request.rb', line 36 def query @query end |
#sort ⇒ Object
Time-ascending asc or time-descending desc results.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/logs_list_request.rb', line 39 def sort @sort end |
#start_at ⇒ Object
Hash identifier of the first log to return in the list, available in a log id attribute. This parameter is used for the pagination feature.
Note: This parameter is ignored if the corresponding log is out of the scope of the specified time window.
46 47 48 |
# File 'lib/datadog_api_client/v1/models/logs_list_request.rb', line 46 def start_at @start_at end |
#time ⇒ Object
Timeframe to retrieve the log from.
49 50 51 |
# File 'lib/datadog_api_client/v1/models/logs_list_request.rb', line 49 def time @time end |