Class: DatadogAPIClient::V1::LogsMessageRemapper
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsMessageRemapper
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_message_remapper.rb
Overview
The message is a key attribute in Datadog. It is displayed in the message column of the Log Explorer and you can do full string search on it. Use this Processor to define one or more attributes as the official log message.
Note: If multiple log message remapper processors can be applied to a given log, only the first one (according to the pipeline order) is taken into account.
Instance Attribute Summary collapse
-
#is_enabled ⇒ Object
Whether or not the processor is enabled.
-
#name ⇒ Object
Name of the processor.
-
#sources ⇒ Object
readonly
Array of source attributes.
-
#type ⇒ Object
readonly
Type of logs message remapper.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#is_enabled ⇒ Object
Whether or not the processor is enabled.
34 35 36 |
# File 'lib/datadog_api_client/v1/models/logs_message_remapper.rb', line 34 def is_enabled @is_enabled end |
#name ⇒ Object
Name of the processor.
37 38 39 |
# File 'lib/datadog_api_client/v1/models/logs_message_remapper.rb', line 37 def name @name end |
#sources ⇒ Object
Array of source attributes.
40 41 42 |
# File 'lib/datadog_api_client/v1/models/logs_message_remapper.rb', line 40 def sources @sources end |
#type ⇒ Object
Type of logs message remapper.
43 44 45 |
# File 'lib/datadog_api_client/v1/models/logs_message_remapper.rb', line 43 def type @type end |