Class: DatadogAPIClient::V1::LogsPipeline
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsPipeline
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_pipeline.rb
Overview
Pipelines and processors operate on incoming logs, parsing and transforming them into structured attributes for easier querying.
Note: These endpoints are only available for admin users. Make sure to use an application key created by an admin.
Instance Attribute Summary collapse
-
#filter ⇒ Object
Filter for logs.
-
#id ⇒ Object
ID of the pipeline.
-
#is_enabled ⇒ Object
Whether or not the pipeline is enabled.
-
#is_read_only ⇒ Object
Whether or not the pipeline can be edited.
-
#name ⇒ Object
readonly
Name of the pipeline.
-
#processors ⇒ Object
Ordered list of processors in this pipeline.
-
#type ⇒ Object
Type of pipeline.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#filter ⇒ Object
Filter for logs.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 33 def filter @filter end |
#id ⇒ Object
ID of the pipeline.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 36 def id @id end |
#is_enabled ⇒ Object
Whether or not the pipeline is enabled.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 39 def is_enabled @is_enabled end |
#is_read_only ⇒ Object
Whether or not the pipeline can be edited.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 42 def is_read_only @is_read_only end |
#name ⇒ Object
Name of the pipeline.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 45 def name @name end |
#processors ⇒ Object
Ordered list of processors in this pipeline.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 48 def processors @processors end |
#type ⇒ Object
Type of pipeline.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/logs_pipeline.rb', line 51 def type @type end |