Class: DatadogAPIClient::V1::LogsServiceRemapper
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsServiceRemapper
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_service_remapper.rb
Overview
Use this processor if you want to assign one or more attributes as the official service.
Note: If multiple service remapper processors can be applied to a given log, only the first one (according to the pipeline order) is taken into account.
Instance Attribute Summary collapse
-
#is_enabled ⇒ Object
Whether or not the processor is enabled.
-
#name ⇒ Object
Name of the processor.
-
#sources ⇒ Object
readonly
Array of source attributes.
-
#type ⇒ Object
readonly
Type of logs service remapper.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#is_enabled ⇒ Object
Whether or not the processor is enabled.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 32 def is_enabled @is_enabled end |
#name ⇒ Object
Name of the processor.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 35 def name @name end |
#sources ⇒ Object
Array of source attributes.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 38 def sources @sources end |
#type ⇒ Object
Type of logs service remapper.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/logs_service_remapper.rb', line 41 def type @type end |