Class: DatadogAPIClient::V1::LogsStringBuilderProcessor
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsStringBuilderProcessor
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_string_builder_processor.rb
Overview
Use the string builder processor to add a new attribute (without spaces or special characters) to a log with the result of the provided template. This enables aggregation of different attributes or raw strings into a single attribute.
The template is defined by both raw text and blocks with the syntax ‘%attribute_path`.
Notes:
-
The processor only accepts attributes with values or an array of values in the blocks.
-
If an attribute cannot be used (object or array of object), it is replaced by an empty string or the entire operation is skipped depending on your selection.
-
If the target attribute already exists, it is overwritten by the result of the template.
-
Results of the template cannot exceed 256 characters.
Instance Attribute Summary collapse
-
#is_enabled ⇒ Object
Whether or not the processor is enabled.
-
#is_replace_missing ⇒ Object
If true, it replaces all missing attributes of
templateby an empty string. -
#name ⇒ Object
Name of the processor.
-
#target ⇒ Object
readonly
The name of the attribute that contains the result of the template.
-
#template ⇒ Object
readonly
A formula with one or more attributes and raw text.
-
#type ⇒ Object
readonly
Type of logs string builder processor.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#is_enabled ⇒ Object
Whether or not the processor is enabled.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/logs_string_builder_processor.rb', line 41 def is_enabled @is_enabled end |
#is_replace_missing ⇒ Object
If true, it replaces all missing attributes of template by an empty string. If false (default), skips the operation for missing attributes.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/logs_string_builder_processor.rb', line 45 def is_replace_missing @is_replace_missing end |
#name ⇒ Object
Name of the processor.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/logs_string_builder_processor.rb', line 48 def name @name end |
#target ⇒ Object
The name of the attribute that contains the result of the template.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/logs_string_builder_processor.rb', line 51 def target @target end |
#template ⇒ Object
A formula with one or more attributes and raw text.
54 55 56 |
# File 'lib/datadog_api_client/v1/models/logs_string_builder_processor.rb', line 54 def template @template end |
#type ⇒ Object
Type of logs string builder processor.
57 58 59 |
# File 'lib/datadog_api_client/v1/models/logs_string_builder_processor.rb', line 57 def type @type end |