Class: DatadogAPIClient::V1::LogsUserAgentParser
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::LogsUserAgentParser
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/logs_user_agent_parser.rb
Overview
The User-Agent parser takes a User-Agent attribute and extracts the OS, browser, device, and other user data. It recognizes major bots like the Google Bot, Yahoo Slurp, and Bing.
Instance Attribute Summary collapse
-
#is_enabled ⇒ Object
Whether or not the processor is enabled.
-
#is_encoded ⇒ Object
Define if the source attribute is URL encoded or not.
-
#name ⇒ Object
Name of the processor.
-
#sources ⇒ Object
readonly
Array of source attributes.
-
#target ⇒ Object
readonly
Name of the parent attribute that contains all the extracted details from the
sources. -
#type ⇒ Object
readonly
Type of logs User-Agent parser.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#is_enabled ⇒ Object
Whether or not the processor is enabled.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 30 def is_enabled @is_enabled end |
#is_encoded ⇒ Object
Define if the source attribute is URL encoded or not.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 33 def is_encoded @is_encoded end |
#name ⇒ Object
Name of the processor.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 36 def name @name end |
#sources ⇒ Object
Array of source attributes.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 39 def sources @sources end |
#target ⇒ Object
Name of the parent attribute that contains all the extracted details from the sources.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 42 def target @target end |
#type ⇒ Object
Type of logs User-Agent parser.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/logs_user_agent_parser.rb', line 45 def type @type end |