Class: DatadogAPIClient::V1::MetricMetadata
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MetricMetadata
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/metric_metadata.rb
Overview
Object with all metric related metadata.
Instance Attribute Summary collapse
-
#description ⇒ Object
Metric description.
-
#integration ⇒ Object
Name of the integration that sent the metric if applicable.
-
#per_unit ⇒ Object
Per unit of the metric such as
secondin ‘bytes per second`. -
#short_name ⇒ Object
A more human-readable and abbreviated version of the metric name.
-
#statsd_interval ⇒ Object
StatsD flush interval of the metric in seconds if applicable.
-
#type ⇒ Object
Metric type such as
gaugeorrate. -
#unit ⇒ Object
Primary unit of the metric such as
byteoroperation.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#description ⇒ Object
Metric description.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 29 def description @description end |
#integration ⇒ Object
Name of the integration that sent the metric if applicable.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 32 def integration @integration end |
#per_unit ⇒ Object
Per unit of the metric such as second in ‘bytes per second`.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 35 def per_unit @per_unit end |
#short_name ⇒ Object
A more human-readable and abbreviated version of the metric name.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 38 def short_name @short_name end |
#statsd_interval ⇒ Object
StatsD flush interval of the metric in seconds if applicable.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 41 def statsd_interval @statsd_interval end |
#type ⇒ Object
Metric type such as gauge or rate.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 44 def type @type end |
#unit ⇒ Object
Primary unit of the metric such as byte or operation.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/metric_metadata.rb', line 47 def unit @unit end |