Class: DatadogAPIClient::V1::MetricsQueryUnit
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::MetricsQueryUnit
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/metrics_query_unit.rb
Overview
Object containing the metric unit family, scale factor, name, and short name.
Instance Attribute Summary collapse
-
#family ⇒ Object
Unit family, allows for conversion between units of the same family, for scaling.
-
#name ⇒ Object
Unit name.
-
#plural ⇒ Object
Plural form of the unit name.
-
#scale_factor ⇒ Object
Factor for scaling between units of the same family.
-
#short_name ⇒ Object
Abbreviation of the unit.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#family ⇒ Object
Unit family, allows for conversion between units of the same family, for scaling.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 29 def family @family end |
#name ⇒ Object
Unit name
32 33 34 |
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 32 def name @name end |
#plural ⇒ Object
Plural form of the unit name.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 35 def plural @plural end |
#scale_factor ⇒ Object
Factor for scaling between units of the same family.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 38 def scale_factor @scale_factor end |
#short_name ⇒ Object
Abbreviation of the unit.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/metrics_query_unit.rb', line 41 def short_name @short_name end |