Class: DatadogAPIClient::V1::NotebookToplistCellAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::NotebookToplistCellAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/notebook_toplist_cell_attributes.rb
Overview
The attributes of a notebook toplist cell.
Instance Attribute Summary collapse
-
#definition ⇒ Object
readonly
The top list visualization enables you to display a list of Tag value like hostname or service with the most or least of any metric value, such as highest consumers of CPU, hosts with the least disk space, etc.
-
#graph_size ⇒ Object
The size of the graph.
-
#split_by ⇒ Object
Object describing how to split the graph to display multiple visualizations per request.
-
#time ⇒ Object
Timeframe for the notebook cell.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#definition ⇒ Object
The top list visualization enables you to display a list of Tag value like hostname or service with the most or least of any metric value, such as highest consumers of CPU, hosts with the least disk space, etc.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/notebook_toplist_cell_attributes.rb', line 29 def definition @definition end |
#graph_size ⇒ Object
The size of the graph.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/notebook_toplist_cell_attributes.rb', line 32 def graph_size @graph_size end |
#split_by ⇒ Object
Object describing how to split the graph to display multiple visualizations per request.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/notebook_toplist_cell_attributes.rb', line 35 def split_by @split_by end |
#time ⇒ Object
Timeframe for the notebook cell. When ‘null’, the notebook global time is used.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/notebook_toplist_cell_attributes.rb', line 38 def time @time end |