Class: DatadogAPIClient::V1::QueryValueWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::QueryValueWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/query_value_widget_definition.rb
Overview
Query values display the current value of a given metric, APM, or log query.
Instance Attribute Summary collapse
-
#autoscale ⇒ Object
Whether to use auto-scaling or not.
-
#custom_links ⇒ Object
List of custom links.
-
#custom_unit ⇒ Object
Display a unit of your choice on the widget.
-
#precision ⇒ Object
Number of decimals to show.
-
#requests ⇒ Object
readonly
Widget definition.
-
#text_align ⇒ Object
How to align the text on the widget.
-
#time ⇒ Object
Time setting for the widget.
-
#timeseries_background ⇒ Object
Set a timeseries on the widget background.
-
#title ⇒ Object
Title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the query value widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#autoscale ⇒ Object
Whether to use auto-scaling or not.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 29 def autoscale @autoscale end |
#custom_links ⇒ Object
List of custom links.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 32 def custom_links @custom_links end |
#custom_unit ⇒ Object
Display a unit of your choice on the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 35 def custom_unit @custom_unit end |
#precision ⇒ Object
Number of decimals to show. If not defined, the widget uses the raw value.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 38 def precision @precision end |
#requests ⇒ Object
Widget definition.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 41 def requests @requests end |
#text_align ⇒ Object
How to align the text on the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 44 def text_align @text_align end |
#time ⇒ Object
Time setting for the widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 47 def time @time end |
#timeseries_background ⇒ Object
Set a timeseries on the widget background.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 50 def timeseries_background @timeseries_background end |
#title ⇒ Object
Title of your widget.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 53 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 56 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 59 def title_size @title_size end |
#type ⇒ Object
Type of the query value widget.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/query_value_widget_definition.rb', line 62 def type @type end |