Class: DatadogAPIClient::V1::SLOCorrectionResponseAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SLOCorrectionResponseAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb
Overview
The attribute object associated with the SLO correction.
Instance Attribute Summary collapse
-
#_end ⇒ Object
Ending time of the correction in epoch seconds.
-
#category ⇒ Object
Category the SLO correction belongs to.
-
#created_at ⇒ Object
The epoch timestamp of when the correction was created at.
-
#creator ⇒ Object
Object describing the creator of the shared element.
-
#description ⇒ Object
Description of the correction being made.
-
#duration ⇒ Object
Length of time (in seconds) for a specified
rrulerecurring SLO correction. -
#modified_at ⇒ Object
The epoch timestamp of when the correction was modified at.
-
#modifier ⇒ Object
Modifier of the object.
-
#rrule ⇒ Object
The recurrence rules as defined in the iCalendar RFC 5545.
-
#slo_id ⇒ Object
ID of the SLO that this correction applies to.
-
#start ⇒ Object
Starting time of the correction in epoch seconds.
-
#timezone ⇒ Object
The timezone to display in the UI for the correction times (defaults to “UTC”).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#_end ⇒ Object
Ending time of the correction in epoch seconds.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 44 def _end @_end end |
#category ⇒ Object
Category the SLO correction belongs to.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 29 def category @category end |
#created_at ⇒ Object
The epoch timestamp of when the correction was created at.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 32 def created_at @created_at end |
#creator ⇒ Object
Object describing the creator of the shared element.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 35 def creator @creator end |
#description ⇒ Object
Description of the correction being made.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 38 def description @description end |
#duration ⇒ Object
Length of time (in seconds) for a specified rrule recurring SLO correction.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 41 def duration @duration end |
#modified_at ⇒ Object
The epoch timestamp of when the correction was modified at.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 47 def modified_at @modified_at end |
#modifier ⇒ Object
Modifier of the object.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 50 def modifier @modifier end |
#rrule ⇒ Object
The recurrence rules as defined in the iCalendar RFC 5545. The supported rules for SLO corrections are FREQ, INTERVAL, COUNT, and UNTIL.
54 55 56 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 54 def rrule @rrule end |
#slo_id ⇒ Object
ID of the SLO that this correction applies to.
57 58 59 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 57 def slo_id @slo_id end |
#start ⇒ Object
Starting time of the correction in epoch seconds.
60 61 62 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 60 def start @start end |
#timezone ⇒ Object
The timezone to display in the UI for the correction times (defaults to “UTC”).
63 64 65 |
# File 'lib/datadog_api_client/v1/models/slo_correction_response_attributes.rb', line 63 def timezone @timezone end |