Class: DatadogAPIClient::V1::SLOListResponseMetadataPage
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SLOListResponseMetadataPage
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/slo_list_response_metadata_page.rb
Overview
The object containing information about the pages of the list of SLOs.
Instance Attribute Summary collapse
-
#total_count ⇒ Object
The total number of resources that could be retrieved ignoring the parameters and filters in the request.
-
#total_filtered_count ⇒ Object
The total number of resources that match the parameters and filters in the request.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#total_count ⇒ Object
The total number of resources that could be retrieved ignoring the parameters and filters in the request.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/slo_list_response_metadata_page.rb', line 29 def total_count @total_count end |
#total_filtered_count ⇒ Object
The total number of resources that match the parameters and filters in the request. This attribute can be used by a client to determine the total number of pages.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/slo_list_response_metadata_page.rb', line 32 def total_filtered_count @total_filtered_count end |