Class: DatadogAPIClient::V1::ScatterPlotWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ScatterPlotWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb
Overview
The scatter plot visualization allows you to graph a chosen scope over two different metrics with their respective aggregation.
Instance Attribute Summary collapse
-
#color_by_groups ⇒ Object
List of groups used for colors.
-
#custom_links ⇒ Object
List of custom links.
-
#requests ⇒ Object
readonly
Widget definition.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the scatter plot widget.
-
#xaxis ⇒ Object
Axis controls for the widget.
-
#yaxis ⇒ Object
Axis controls for the widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#color_by_groups ⇒ Object
List of groups used for colors.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 29 def color_by_groups @color_by_groups end |
#custom_links ⇒ Object
List of custom links.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 32 def custom_links @custom_links end |
#requests ⇒ Object
Widget definition.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 35 def requests @requests end |
#time ⇒ Object
Time setting for the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 38 def time @time end |
#title ⇒ Object
Title of your widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 41 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 44 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 47 def title_size @title_size end |
#type ⇒ Object
Type of the scatter plot widget.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 50 def type @type end |
#xaxis ⇒ Object
Axis controls for the widget.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 53 def xaxis @xaxis end |
#yaxis ⇒ Object
Axis controls for the widget.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/scatter_plot_widget_definition.rb', line 56 def yaxis @yaxis end |