Class: DatadogAPIClient::V1::Series
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::Series
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/series.rb
Overview
A metric to submit to Datadog. See [Datadog metrics](docs.datadoghq.com/developers/metrics/#custom-metrics-properties).
Instance Attribute Summary collapse
-
#host ⇒ Object
The name of the host that produced the metric.
-
#interval ⇒ Object
If the type of the metric is rate or count, define the corresponding interval.
-
#metric ⇒ Object
readonly
The name of the timeseries.
-
#points ⇒ Object
readonly
Points relating to a metric.
-
#tags ⇒ Object
A list of tags associated with the metric.
-
#type ⇒ Object
The type of the metric.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#host ⇒ Object
The name of the host that produced the metric.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/series.rb', line 30 def host @host end |
#interval ⇒ Object
If the type of the metric is rate or count, define the corresponding interval.
33 34 35 |
# File 'lib/datadog_api_client/v1/models/series.rb', line 33 def interval @interval end |
#metric ⇒ Object
The name of the timeseries.
36 37 38 |
# File 'lib/datadog_api_client/v1/models/series.rb', line 36 def metric @metric end |
#points ⇒ Object
Points relating to a metric. All points must be tuples with timestamp and a scalar value (cannot be a string). Timestamps should be in POSIX time in seconds, and cannot be more than ten minutes in the future or more than one hour in the past.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/series.rb', line 39 def points @points end |
#tags ⇒ Object
A list of tags associated with the metric.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/series.rb', line 42 def @tags end |
#type ⇒ Object
The type of the metric. Valid types are “”,count, gauge, and rate.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/series.rb', line 45 def type @type end |