Class: DatadogAPIClient::V1::SignalStateUpdateRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SignalStateUpdateRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/signal_state_update_request.rb
Overview
Attributes describing the change of state for a given state.
Instance Attribute Summary collapse
-
#archive_comment ⇒ Object
Optional comment to explain why a signal is being archived.
-
#archive_reason ⇒ Object
Reason why a signal has been archived.
-
#state ⇒ Object
readonly
The new triage state of the signal.
-
#version ⇒ Object
Version of the updated signal.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#archive_comment ⇒ Object
Optional comment to explain why a signal is being archived.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 29 def archive_comment @archive_comment end |
#archive_reason ⇒ Object
Reason why a signal has been archived.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 32 def archive_reason @archive_reason end |
#state ⇒ Object
The new triage state of the signal.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 35 def state @state end |
#version ⇒ Object
Version of the updated signal. If server side version is higher, update will be rejected.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/signal_state_update_request.rb', line 38 def version @version end |