Class: DatadogAPIClient::V1::SyntheticsAPIStep
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsAPIStep
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_api_step.rb
Overview
The steps used in a Synthetics multistep API test.
Instance Attribute Summary collapse
-
#_retry ⇒ Object
Object describing the retry strategy to apply to a Synthetic test.
-
#allow_failure ⇒ Object
Determines whether or not to continue with test if this step fails.
-
#assertions ⇒ Object
readonly
Array of assertions used for the test.
-
#extracted_values ⇒ Object
Array of values to parse and save as variables from the response.
-
#is_critical ⇒ Object
Determines whether or not to consider the entire test as failed if this step fails.
-
#name ⇒ Object
readonly
The name of the step.
-
#request ⇒ Object
readonly
Object describing the Synthetic test request.
-
#subtype ⇒ Object
readonly
The subtype of the Synthetic multistep API test step, currently only supporting
http.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#_retry ⇒ Object
Object describing the retry strategy to apply to a Synthetic test.
48 49 50 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 48 def _retry @_retry end |
#allow_failure ⇒ Object
Determines whether or not to continue with test if this step fails.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 29 def allow_failure @allow_failure end |
#assertions ⇒ Object
Array of assertions used for the test.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 32 def assertions @assertions end |
#extracted_values ⇒ Object
Array of values to parse and save as variables from the response.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 35 def extracted_values @extracted_values end |
#is_critical ⇒ Object
Determines whether or not to consider the entire test as failed if this step fails. Can be used only if allowFailure is true.
39 40 41 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 39 def is_critical @is_critical end |
#name ⇒ Object
The name of the step.
42 43 44 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 42 def name @name end |
#request ⇒ Object
Object describing the Synthetic test request.
45 46 47 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 45 def request @request end |
#subtype ⇒ Object
The subtype of the Synthetic multistep API test step, currently only supporting http.
51 52 53 |
# File 'lib/datadog_api_client/v1/models/synthetics_api_step.rb', line 51 def subtype @subtype end |