Class: DatadogAPIClient::V1::SyntheticsBatchResult
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsBatchResult
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_batch_result.rb
Overview
Object with the results of a Synthetics batch.
Instance Attribute Summary collapse
-
#device ⇒ Object
The device ID.
-
#duration ⇒ Object
Total duration in millisecond of the test.
-
#execution_rule ⇒ Object
Execution rule for a Synthetics test.
-
#location ⇒ Object
Name of the location.
-
#result_id ⇒ Object
The ID of the result to get.
-
#retries ⇒ Object
Number of times this result has been retried.
-
#status ⇒ Object
Determines whether or not the batch has passed, failed, or is in progress.
-
#test_name ⇒ Object
Name of the test.
-
#test_public_id ⇒ Object
The public ID of the Synthetic test.
-
#test_type ⇒ Object
Type of the Synthetic test, either
apiorbrowser.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#device ⇒ Object
The device ID.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 29 def device @device end |
#duration ⇒ Object
Total duration in millisecond of the test.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 32 def duration @duration end |
#execution_rule ⇒ Object
Execution rule for a Synthetics test.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 35 def execution_rule @execution_rule end |
#location ⇒ Object
Name of the location.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 38 def location @location end |
#result_id ⇒ Object
The ID of the result to get.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 41 def result_id @result_id end |
#retries ⇒ Object
Number of times this result has been retried.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 44 def retries @retries end |
#status ⇒ Object
Determines whether or not the batch has passed, failed, or is in progress.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 47 def status @status end |
#test_name ⇒ Object
Name of the test.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 50 def test_name @test_name end |
#test_public_id ⇒ Object
The public ID of the Synthetic test.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 53 def test_public_id @test_public_id end |
#test_type ⇒ Object
Type of the Synthetic test, either api or browser.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/synthetics_batch_result.rb', line 56 def test_type @test_type end |