Class: DatadogAPIClient::V1::SyntheticsBrowserTestResultShort
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsBrowserTestResultShort
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb
Overview
Object with the results of a single Synthetic browser test.
Instance Attribute Summary collapse
-
#check_time ⇒ Object
Last time the browser test was performed.
-
#probe_dc ⇒ Object
Location from which the Browser test was performed.
-
#result ⇒ Object
Object with the result of the last browser test run.
-
#result_id ⇒ Object
ID of the browser test result.
-
#status ⇒ Object
The status of your Synthetic monitor.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#check_time ⇒ Object
Last time the browser test was performed.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 29 def check_time @check_time end |
#probe_dc ⇒ Object
Location from which the Browser test was performed.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 32 def probe_dc @probe_dc end |
#result ⇒ Object
Object with the result of the last browser test run.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 35 def result @result end |
#result_id ⇒ Object
ID of the browser test result.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 38 def result_id @result_id end |
#status ⇒ Object
The status of your Synthetic monitor.
-
Ofor not triggered -
1for triggered -
2for no data
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_browser_test_result_short.rb', line 44 def status @status end |