Class: DatadogAPIClient::V1::SyntheticsGlobalVariableParseTestOptions
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsGlobalVariableParseTestOptions
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_global_variable_parse_test_options.rb
Overview
Parser options to use for retrieving a Synthetics global variable from a Synthetics Test. Used in conjunction with parse_test_public_id.
Instance Attribute Summary collapse
-
#field ⇒ Object
When type is
http_header, name of the header to use to extract the value. -
#local_variable_name ⇒ Object
When type is
local_variable, name of the local variable to use to extract the value. -
#parser ⇒ Object
Details of the parser to use for the global variable.
-
#type ⇒ Object
readonly
Property of the Synthetics Test Response to use for a Synthetics global variable.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#field ⇒ Object
When type is http_header, name of the header to use to extract the value.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_parse_test_options.rb', line 29 def field @field end |
#local_variable_name ⇒ Object
When type is local_variable, name of the local variable to use to extract the value.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_parse_test_options.rb', line 32 def local_variable_name @local_variable_name end |
#parser ⇒ Object
Details of the parser to use for the global variable.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_parse_test_options.rb', line 35 def parser @parser end |
#type ⇒ Object
Property of the Synthetics Test Response to use for a Synthetics global variable.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_global_variable_parse_test_options.rb', line 38 def type @type end |