Class: DatadogAPIClient::V1::SyntheticsParsingOptions
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsParsingOptions
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_parsing_options.rb
Overview
Parsing options for variables to extract.
Instance Attribute Summary collapse
-
#field ⇒ Object
When type is
http_header, name of the header to use to extract the value. -
#name ⇒ Object
Name of the variable to extract.
-
#parser ⇒ Object
Details of the parser to use for the global variable.
-
#type ⇒ Object
Property of the Synthetics Test Response to use for a Synthetics global variable.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#field ⇒ Object
When type is http_header, name of the header to use to extract the value.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_parsing_options.rb', line 29 def field @field end |
#name ⇒ Object
Name of the variable to extract.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_parsing_options.rb', line 32 def name @name end |
#parser ⇒ Object
Details of the parser to use for the global variable.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_parsing_options.rb', line 35 def parser @parser end |
#type ⇒ Object
Property of the Synthetics Test Response to use for a Synthetics global variable.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_parsing_options.rb', line 38 def type @type end |