Class: DatadogAPIClient::V1::SyntheticsStep
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsStep
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_step.rb
Overview
The steps used in a Synthetics browser test.
Instance Attribute Summary collapse
-
#allow_failure ⇒ Object
A boolean set to allow this step to fail.
-
#is_critical ⇒ Object
A boolean to use in addition to
allowFailureto determine if the test should be marked as failed when the step fails. -
#name ⇒ Object
The name of the step.
-
#no_screenshot ⇒ Object
A boolean set to not take a screenshot for the step.
-
#params ⇒ Object
The parameters of the step.
-
#timeout ⇒ Object
The time before declaring a step failed.
-
#type ⇒ Object
Step type used in your Synthetic test.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#allow_failure ⇒ Object
A boolean set to allow this step to fail.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 29 def allow_failure @allow_failure end |
#is_critical ⇒ Object
A boolean to use in addition to allowFailure to determine if the test should be marked as failed when the step fails.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 32 def is_critical @is_critical end |
#name ⇒ Object
The name of the step.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 35 def name @name end |
#no_screenshot ⇒ Object
A boolean set to not take a screenshot for the step.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 38 def no_screenshot @no_screenshot end |
#params ⇒ Object
The parameters of the step.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 41 def params @params end |
#timeout ⇒ Object
The time before declaring a step failed.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 44 def timeout @timeout end |
#type ⇒ Object
Step type used in your Synthetic test.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/synthetics_step.rb', line 47 def type @type end |