Class: DatadogAPIClient::V1::SyntheticsStepDetail
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsStepDetail
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_step_detail.rb
Overview
Object describing a step for a Synthetic test.
Instance Attribute Summary collapse
-
#browser_errors ⇒ Object
Array of errors collected for a browser test.
-
#check_type ⇒ Object
Type of assertion to apply in an API test.
-
#description ⇒ Object
Description of the test.
-
#duration ⇒ Object
Total duration in millisecond of the test.
-
#error ⇒ Object
Error returned by the test.
-
#playing_tab ⇒ Object
Navigate between different tabs for your browser test.
-
#screenshot_bucket_key ⇒ Object
Whether or not screenshots where collected by the test.
-
#skipped ⇒ Object
Whether or not to skip this step.
-
#snapshot_bucket_key ⇒ Object
Whether or not snapshots where collected by the test.
-
#step_id ⇒ Object
The step ID.
-
#sub_test_step_details ⇒ Object
If this steps include a sub-test.
-
#time_to_interactive ⇒ Object
Time before starting the step.
-
#type ⇒ Object
Step type used in your Synthetic test.
-
#url ⇒ Object
URL to perform the step against.
-
#value ⇒ Object
Value for the step.
-
#vitals_metrics ⇒ Object
Array of Core Web Vitals metrics for the step.
-
#warnings ⇒ Object
Warning collected that didn’t failed the step.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#browser_errors ⇒ Object
Array of errors collected for a browser test.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 29 def browser_errors @browser_errors end |
#check_type ⇒ Object
Type of assertion to apply in an API test.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 32 def check_type @check_type end |
#description ⇒ Object
Description of the test.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 35 def description @description end |
#duration ⇒ Object
Total duration in millisecond of the test.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 38 def duration @duration end |
#error ⇒ Object
Error returned by the test.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 41 def error @error end |
#playing_tab ⇒ Object
Navigate between different tabs for your browser test.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 44 def end |
#screenshot_bucket_key ⇒ Object
Whether or not screenshots where collected by the test.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 47 def screenshot_bucket_key @screenshot_bucket_key end |
#skipped ⇒ Object
Whether or not to skip this step.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 50 def skipped @skipped end |
#snapshot_bucket_key ⇒ Object
Whether or not snapshots where collected by the test.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 53 def snapshot_bucket_key @snapshot_bucket_key end |
#step_id ⇒ Object
The step ID.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 56 def step_id @step_id end |
#sub_test_step_details ⇒ Object
If this steps include a sub-test. [Subtests documentation](docs.datadoghq.com/synthetics/browser_tests/advanced_options/#subtests).
60 61 62 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 60 def sub_test_step_details @sub_test_step_details end |
#time_to_interactive ⇒ Object
Time before starting the step.
63 64 65 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 63 def time_to_interactive @time_to_interactive end |
#type ⇒ Object
Step type used in your Synthetic test.
66 67 68 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 66 def type @type end |
#url ⇒ Object
URL to perform the step against.
69 70 71 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 69 def url @url end |
#value ⇒ Object
Value for the step.
72 73 74 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 72 def value @value end |
#vitals_metrics ⇒ Object
Array of Core Web Vitals metrics for the step.
75 76 77 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 75 def vitals_metrics @vitals_metrics end |
#warnings ⇒ Object
Warning collected that didn’t failed the step.
78 79 80 |
# File 'lib/datadog_api_client/v1/models/synthetics_step_detail.rb', line 78 def warnings @warnings end |