Class: DatadogAPIClient::V1::SyntheticsTestOptions

Inherits:
Object
  • Object
show all
Includes:
BaseGenericModel
Defined in:
lib/datadog_api_client/v1/models/synthetics_test_options.rb

Overview

Object describing the extra options for a Synthetic test.

Instance Attribute Summary collapse

Method Summary

Methods included from BaseGenericModel

included

Instance Attribute Details

#_retryObject

Object describing the retry strategy to apply to a Synthetic test.



86
87
88
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 86

def _retry
  @_retry
end

#accept_self_signedObject

For SSL test, whether or not the test should allow self signed certificates.



30
31
32
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 30

def accept_self_signed
  @accept_self_signed
end

#allow_insecureObject

Allows loading insecure content for an HTTP request in an API test.



33
34
35
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 33

def allow_insecure
  @allow_insecure
end

#check_certificate_revocationObject

For SSL test, whether or not the test should fail on revoked certificate in stapled OCSP.



36
37
38
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 36

def check_certificate_revocation
  @check_certificate_revocation
end

#ciObject

CI/CD options for a Synthetic test.



39
40
41
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 39

def ci
  @ci
end

#device_idsObject

For browser test, array with the different device IDs used to run the test.



42
43
44
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 42

def device_ids
  @device_ids
end

#disable_corsObject

Whether or not to disable CORS mechanism.



45
46
47
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 45

def disable_cors
  @disable_cors
end

#disable_cspObject

Disable Content Security Policy for browser tests.



48
49
50
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 48

def disable_csp
  @disable_csp
end

#follow_redirectsObject

For API HTTP test, whether or not the test should follow redirects.



51
52
53
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 51

def follow_redirects
  @follow_redirects
end

#http_versionObject

HTTP version to use for a Synthetic test.



54
55
56
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 54

def http_version
  @http_version
end

#ignore_server_certificate_errorObject

Ignore server certificate error for browser tests.



57
58
59
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 57

def ignore_server_certificate_error
  @ignore_server_certificate_error
end

#initial_navigation_timeoutObject

Timeout before declaring the initial step as failed (in seconds) for browser tests.



60
61
62
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 60

def initial_navigation_timeout
  @initial_navigation_timeout
end

#min_failure_durationObject

Minimum amount of time in failure required to trigger an alert.



63
64
65
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 63

def min_failure_duration
  @min_failure_duration
end

#min_location_failedObject

Minimum number of locations in failure required to trigger an alert.



67
68
69
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 67

def min_location_failed
  @min_location_failed
end

#monitor_nameObject

The monitor name is used for the alert title as well as for all monitor dashboard widgets and SLOs.



70
71
72
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 70

def monitor_name
  @monitor_name
end

#monitor_optionsObject

Object containing the options for a Synthetic test as a monitor (for example, renotification).



74
75
76
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 74

def monitor_options
  @monitor_options
end

#monitor_priorityObject

Integer from 1 (high) to 5 (low) indicating alert severity.



77
78
79
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 77

def monitor_priority
  @monitor_priority
end

#no_screenshotObject

Prevents saving screenshots of the steps.



80
81
82
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 80

def no_screenshot
  @no_screenshot
end

#restricted_rolesObject

A list of role identifiers that can be pulled from the Roles API, for restricting read and write access.



83
84
85
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 83

def restricted_roles
  @restricted_roles
end

#rum_settingsObject

The RUM data collection settings for the Synthetic browser test. Note: There are 3 ways to format RUM settings:

‘{ isEnabled: false }` RUM data is not collected.

‘{ isEnabled: true }` RUM data is collected from the Synthetic test’s default application.

‘{ isEnabled: true, applicationId: “xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx”, clientTokenId: 12345 }` RUM data is collected using the specified application.



99
100
101
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 99

def rum_settings
  @rum_settings
end

#schedulingObject

Object containing timeframes and timezone used for advanced scheduling.



102
103
104
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 102

def scheduling
  @scheduling
end

#tick_everyObject

The frequency at which to run the Synthetic test (in seconds).



105
106
107
# File 'lib/datadog_api_client/v1/models/synthetics_test_options.rb', line 105

def tick_every
  @tick_every
end