Class: DatadogAPIClient::V1::SyntheticsTestOptionsSchedulingTimeframe
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::SyntheticsTestOptionsSchedulingTimeframe
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/synthetics_test_options_scheduling_timeframe.rb
Overview
Object describing a timeframe.
Instance Attribute Summary collapse
-
#day ⇒ Object
readonly
Number representing the day of the week.
-
#from ⇒ Object
The hour of the day on which scheduling starts.
-
#to ⇒ Object
The hour of the day on which scheduling ends.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#day ⇒ Object
Number representing the day of the week.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options_scheduling_timeframe.rb', line 29 def day @day end |
#from ⇒ Object
The hour of the day on which scheduling starts.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options_scheduling_timeframe.rb', line 32 def from @from end |
#to ⇒ Object
The hour of the day on which scheduling ends.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/synthetics_test_options_scheduling_timeframe.rb', line 35 def to @to end |