Class: DatadogAPIClient::V1::TableWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::TableWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/table_widget_definition.rb
Overview
The table visualization is available on timeboards and screenboards. It displays columns of metrics grouped by tag key.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#has_search_bar ⇒ Object
Controls the display of the search bar.
-
#requests ⇒ Object
readonly
Widget definition.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the table widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 29 def custom_links @custom_links end |
#has_search_bar ⇒ Object
Controls the display of the search bar.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 32 def @has_search_bar end |
#requests ⇒ Object
Widget definition.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 35 def requests @requests end |
#time ⇒ Object
Time setting for the widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 38 def time @time end |
#title ⇒ Object
Title of your widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 41 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 44 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 47 def title_size @title_size end |
#type ⇒ Object
Type of the table widget.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/table_widget_definition.rb', line 50 def type @type end |