Class: DatadogAPIClient::V1::ToplistWidgetDefinition
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::ToplistWidgetDefinition
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/toplist_widget_definition.rb
Overview
The top list visualization enables you to display a list of Tag value like hostname or service with the most or least of any metric value, such as highest consumers of CPU, hosts with the least disk space, etc.
Instance Attribute Summary collapse
-
#custom_links ⇒ Object
List of custom links.
-
#requests ⇒ Object
readonly
List of top list widget requests.
-
#time ⇒ Object
Time setting for the widget.
-
#title ⇒ Object
Title of your widget.
-
#title_align ⇒ Object
How to align the text on the widget.
-
#title_size ⇒ Object
Size of the title.
-
#type ⇒ Object
readonly
Type of the top list widget.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#custom_links ⇒ Object
List of custom links.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 29 def custom_links @custom_links end |
#requests ⇒ Object
List of top list widget requests.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 32 def requests @requests end |
#time ⇒ Object
Time setting for the widget.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 35 def time @time end |
#title ⇒ Object
Title of your widget.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 38 def title @title end |
#title_align ⇒ Object
How to align the text on the widget.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 41 def title_align @title_align end |
#title_size ⇒ Object
Size of the title.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 44 def title_size @title_size end |
#type ⇒ Object
Type of the top list widget.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/toplist_widget_definition.rb', line 47 def type @type end |