Class: DatadogAPIClient::V1::UsageCIVisibilityHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageCIVisibilityHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb
Overview
CI visibility usage in a given hour.
Instance Attribute Summary collapse
-
#ci_pipeline_indexed_spans ⇒ Object
The number of spans for pipelines in the queried hour.
-
#ci_test_indexed_spans ⇒ Object
The number of spans for tests in the queried hour.
-
#ci_visibility_pipeline_committers ⇒ Object
Shows the total count of all active Git committers for Pipelines in the current month.
-
#ci_visibility_test_committers ⇒ Object
The total count of all active Git committers for tests in the current month.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#ci_pipeline_indexed_spans ⇒ Object
The number of spans for pipelines in the queried hour.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 29 def ci_pipeline_indexed_spans @ci_pipeline_indexed_spans end |
#ci_test_indexed_spans ⇒ Object
The number of spans for tests in the queried hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 32 def ci_test_indexed_spans @ci_test_indexed_spans end |
#ci_visibility_pipeline_committers ⇒ Object
Shows the total count of all active Git committers for Pipelines in the current month. A committer is active if they commit at least 3 times in a given month.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 35 def ci_visibility_pipeline_committers @ci_visibility_pipeline_committers end |
#ci_visibility_test_committers ⇒ Object
The total count of all active Git committers for tests in the current month. A committer is active if they commit at least 3 times in a given month.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 38 def ci_visibility_test_committers @ci_visibility_test_committers end |
#org_name ⇒ Object
The organization name.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 41 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_ci_visibility_hour.rb', line 44 def public_id @public_id end |