Class: DatadogAPIClient::V1::UsageCloudSecurityPostureManagementHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageCloudSecurityPostureManagementHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb
Overview
Cloud Security Posture Management usage for a given organization for a given hour.
Instance Attribute Summary collapse
-
#aas_host_count ⇒ Object
The number of Cloud Security Posture Management Azure app services hosts during a given hour.
-
#aws_host_count ⇒ Object
The number of Cloud Security Posture Management AWS hosts during a given hour.
-
#azure_host_count ⇒ Object
The number of Cloud Security Posture Management Azure hosts during a given hour.
-
#compliance_host_count ⇒ Object
The number of Cloud Security Posture Management hosts during a given hour.
-
#container_count ⇒ Object
The total number of Cloud Security Posture Management containers during a given hour.
-
#gcp_host_count ⇒ Object
The number of Cloud Security Posture Management GCP hosts during a given hour.
-
#host_count ⇒ Object
The total number of Cloud Security Posture Management hosts during a given hour.
-
#hour ⇒ Object
The hour for the usage.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#aas_host_count ⇒ Object
The number of Cloud Security Posture Management Azure app services hosts during a given hour.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 29 def aas_host_count @aas_host_count end |
#aws_host_count ⇒ Object
The number of Cloud Security Posture Management AWS hosts during a given hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 32 def aws_host_count @aws_host_count end |
#azure_host_count ⇒ Object
The number of Cloud Security Posture Management Azure hosts during a given hour.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 35 def azure_host_count @azure_host_count end |
#compliance_host_count ⇒ Object
The number of Cloud Security Posture Management hosts during a given hour.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 38 def compliance_host_count @compliance_host_count end |
#container_count ⇒ Object
The total number of Cloud Security Posture Management containers during a given hour.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 41 def container_count @container_count end |
#gcp_host_count ⇒ Object
The number of Cloud Security Posture Management GCP hosts during a given hour.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 44 def gcp_host_count @gcp_host_count end |
#host_count ⇒ Object
The total number of Cloud Security Posture Management hosts during a given hour.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 47 def host_count @host_count end |
#hour ⇒ Object
The hour for the usage.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 50 def hour @hour end |
#org_name ⇒ Object
The organization name.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 53 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/usage_cloud_security_posture_management_hour.rb', line 56 def public_id @public_id end |