Class: DatadogAPIClient::V1::UsageDBMHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageDBMHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_dbm_hour.rb
Overview
Database Monitoring usage for a given organization for a given hour.
Instance Attribute Summary collapse
-
#dbm_host_count ⇒ Object
The total number of Database Monitoring host hours from the start of the given hour’s month until the given hour.
-
#dbm_queries_count ⇒ Object
The total number of normalized Database Monitoring queries from the start of the given hour’s month until the given hour.
-
#hour ⇒ Object
The hour for the usage.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#dbm_host_count ⇒ Object
The total number of Database Monitoring host hours from the start of the given hour’s month until the given hour.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_dbm_hour.rb', line 29 def dbm_host_count @dbm_host_count end |
#dbm_queries_count ⇒ Object
The total number of normalized Database Monitoring queries from the start of the given hour’s month until the given hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_dbm_hour.rb', line 32 def dbm_queries_count @dbm_queries_count end |
#hour ⇒ Object
The hour for the usage.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_dbm_hour.rb', line 35 def hour @hour end |
#org_name ⇒ Object
The organization name.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_dbm_hour.rb', line 38 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_dbm_hour.rb', line 41 def public_id @public_id end |