Class: DatadogAPIClient::V1::UsageHostHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageHostHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_host_hour.rb
Overview
Number of hosts/containers recorded for each hour for a given organization.
Instance Attribute Summary collapse
-
#agent_host_count ⇒ Object
Contains the total number of infrastructure hosts reporting during a given hour that were running the Datadog Agent.
-
#alibaba_host_count ⇒ Object
Contains the total number of hosts that reported through Alibaba integration (and were NOT running the Datadog Agent).
-
#apm_azure_app_service_host_count ⇒ Object
Contains the total number of Azure App Services hosts using APM.
-
#apm_host_count ⇒ Object
Shows the total number of hosts using APM during the hour, these are counted as billable (except during trial periods).
-
#aws_host_count ⇒ Object
Contains the total number of hosts that reported through the AWS integration (and were NOT running the Datadog Agent).
-
#azure_host_count ⇒ Object
Contains the total number of hosts that reported through Azure integration (and were NOT running the Datadog Agent).
-
#container_count ⇒ Object
Shows the total number of containers reported by the Docker integration during the hour.
-
#gcp_host_count ⇒ Object
Contains the total number of hosts that reported through the Google Cloud integration (and were NOT running the Datadog Agent).
-
#heroku_host_count ⇒ Object
Contains the total number of Heroku dynos reported by the Datadog Agent.
-
#host_count ⇒ Object
Contains the total number of billable infrastructure hosts reporting during a given hour.
-
#hour ⇒ Object
The hour for the usage.
-
#infra_azure_app_service ⇒ Object
Contains the total number of hosts that reported through the Azure App Services integration (and were NOT running the Datadog Agent).
-
#opentelemetry_apm_host_count ⇒ Object
Contains the total number of hosts using APM reported by Datadog exporter for the OpenTelemetry Collector.
-
#opentelemetry_host_count ⇒ Object
Contains the total number of hosts reported by Datadog exporter for the OpenTelemetry Collector.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
-
#vsphere_host_count ⇒ Object
Contains the total number of hosts that reported through vSphere integration (and were NOT running the Datadog Agent).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#agent_host_count ⇒ Object
Contains the total number of infrastructure hosts reporting during a given hour that were running the Datadog Agent.
30 31 32 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 30 def agent_host_count @agent_host_count end |
#alibaba_host_count ⇒ Object
Contains the total number of hosts that reported through Alibaba integration (and were NOT running the Datadog Agent).
34 35 36 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 34 def alibaba_host_count @alibaba_host_count end |
#apm_azure_app_service_host_count ⇒ Object
Contains the total number of Azure App Services hosts using APM.
37 38 39 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 37 def apm_azure_app_service_host_count @apm_azure_app_service_host_count end |
#apm_host_count ⇒ Object
Shows the total number of hosts using APM during the hour, these are counted as billable (except during trial periods).
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 41 def apm_host_count @apm_host_count end |
#aws_host_count ⇒ Object
Contains the total number of hosts that reported through the AWS integration (and were NOT running the Datadog Agent).
45 46 47 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 45 def aws_host_count @aws_host_count end |
#azure_host_count ⇒ Object
Contains the total number of hosts that reported through Azure integration (and were NOT running the Datadog Agent).
49 50 51 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 49 def azure_host_count @azure_host_count end |
#container_count ⇒ Object
Shows the total number of containers reported by the Docker integration during the hour.
52 53 54 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 52 def container_count @container_count end |
#gcp_host_count ⇒ Object
Contains the total number of hosts that reported through the Google Cloud integration (and were NOT running the Datadog Agent).
56 57 58 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 56 def gcp_host_count @gcp_host_count end |
#heroku_host_count ⇒ Object
Contains the total number of Heroku dynos reported by the Datadog Agent.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 59 def heroku_host_count @heroku_host_count end |
#host_count ⇒ Object
Contains the total number of billable infrastructure hosts reporting during a given hour. This is the sum of agent_host_count, aws_host_count, and gcp_host_count.
63 64 65 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 63 def host_count @host_count end |
#hour ⇒ Object
The hour for the usage.
66 67 68 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 66 def hour @hour end |
#infra_azure_app_service ⇒ Object
Contains the total number of hosts that reported through the Azure App Services integration (and were NOT running the Datadog Agent).
70 71 72 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 70 def infra_azure_app_service @infra_azure_app_service end |
#opentelemetry_apm_host_count ⇒ Object
Contains the total number of hosts using APM reported by Datadog exporter for the OpenTelemetry Collector.
73 74 75 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 73 def opentelemetry_apm_host_count @opentelemetry_apm_host_count end |
#opentelemetry_host_count ⇒ Object
Contains the total number of hosts reported by Datadog exporter for the OpenTelemetry Collector.
76 77 78 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 76 def opentelemetry_host_count @opentelemetry_host_count end |
#org_name ⇒ Object
The organization name.
79 80 81 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 79 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
82 83 84 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 82 def public_id @public_id end |
#vsphere_host_count ⇒ Object
Contains the total number of hosts that reported through vSphere integration (and were NOT running the Datadog Agent).
86 87 88 |
# File 'lib/datadog_api_client/v1/models/usage_host_hour.rb', line 86 def vsphere_host_count @vsphere_host_count end |