Class: DatadogAPIClient::V1::UsageIngestedSpansHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageIngestedSpansHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_ingested_spans_hour.rb
Overview
Ingested spans usage for a given organization for a given hour.
Instance Attribute Summary collapse
-
#hour ⇒ Object
The hour for the usage.
-
#ingested_events_bytes ⇒ Object
Contains the total number of bytes ingested for APM spans during a given hour.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#hour ⇒ Object
The hour for the usage.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_ingested_spans_hour.rb', line 29 def hour @hour end |
#ingested_events_bytes ⇒ Object
Contains the total number of bytes ingested for APM spans during a given hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_ingested_spans_hour.rb', line 32 def ingested_events_bytes @ingested_events_bytes end |
#org_name ⇒ Object
The organization name.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_ingested_spans_hour.rb', line 35 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_ingested_spans_hour.rb', line 38 def public_id @public_id end |