Class: DatadogAPIClient::V1::UsageLogsByRetentionResponse
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageLogsByRetentionResponse
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_logs_by_retention_response.rb
Overview
Response containing the indexed logs usage broken down by retention period for an organization during a given hour.
Instance Attribute Summary collapse
-
#usage ⇒ Object
Get hourly usage for indexed logs by retention period.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#usage ⇒ Object
Get hourly usage for indexed logs by retention period.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_logs_by_retention_response.rb', line 29 def usage @usage end |