Class: DatadogAPIClient::V1::UsageSDSHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageSDSHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_sds_hour.rb
Overview
Sensitive Data Scanner usage for a given organization for a given hour.
Instance Attribute Summary collapse
-
#apm_scanned_bytes ⇒ Object
The total number of bytes scanned of APM usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
-
#events_scanned_bytes ⇒ Object
The total number of bytes scanned of Events usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
-
#hour ⇒ Object
The hour for the usage.
-
#logs_scanned_bytes ⇒ Object
The total number of bytes scanned of logs usage by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
-
#rum_scanned_bytes ⇒ Object
The total number of bytes scanned of RUM usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
-
#total_scanned_bytes ⇒ Object
The total number of bytes scanned across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#apm_scanned_bytes ⇒ Object
The total number of bytes scanned of APM usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 29 def apm_scanned_bytes @apm_scanned_bytes end |
#events_scanned_bytes ⇒ Object
The total number of bytes scanned of Events usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 32 def events_scanned_bytes @events_scanned_bytes end |
#hour ⇒ Object
The hour for the usage.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 35 def hour @hour end |
#logs_scanned_bytes ⇒ Object
The total number of bytes scanned of logs usage by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 38 def logs_scanned_bytes @logs_scanned_bytes end |
#org_name ⇒ Object
The organization name.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 41 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 44 def public_id @public_id end |
#rum_scanned_bytes ⇒ Object
The total number of bytes scanned of RUM usage across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 47 def rum_scanned_bytes @rum_scanned_bytes end |
#total_scanned_bytes ⇒ Object
The total number of bytes scanned across all usage types by the Sensitive Data Scanner from the start of the given hour’s month until the given hour.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/usage_sds_hour.rb', line 50 def total_scanned_bytes @total_scanned_bytes end |