Class: DatadogAPIClient::V1::UsageSpecifiedCustomReportsAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageSpecifiedCustomReportsAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb
Overview
The response containing attributes for specified custom reports.
Instance Attribute Summary collapse
-
#computed_on ⇒ Object
The date the specified custom report was computed.
-
#end_date ⇒ Object
The ending date of specified custom report.
-
#location ⇒ Object
A downloadable file for the specified custom reporting file.
-
#size ⇒ Object
size.
-
#start_date ⇒ Object
The starting date of specified custom report.
-
#tags ⇒ Object
A list of tags to apply to specified custom reports.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#computed_on ⇒ Object
The date the specified custom report was computed.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb', line 29 def computed_on @computed_on end |
#end_date ⇒ Object
The ending date of specified custom report.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb', line 32 def end_date @end_date end |
#location ⇒ Object
A downloadable file for the specified custom reporting file.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb', line 35 def location @location end |
#size ⇒ Object
size
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb', line 38 def size @size end |
#start_date ⇒ Object
The starting date of specified custom report.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb', line 41 def start_date @start_date end |
#tags ⇒ Object
A list of tags to apply to specified custom reports.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_specified_custom_reports_attributes.rb', line 44 def @tags end |