Class: DatadogAPIClient::V1::UsageSummaryDate
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageSummaryDate
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_summary_date.rb
Overview
Response with hourly report of all data billed by Datadog all organizations.
Instance Attribute Summary collapse
-
#agent_host_top99p ⇒ Object
Shows the 99th percentile of all agent hosts over all hours in the current date for all organizations.
-
#apm_azure_app_service_host_top99p ⇒ Object
Shows the 99th percentile of all Azure app services using APM over all hours in the current date all organizations.
-
#apm_fargate_count_avg ⇒ Object
Shows the average of all APM ECS Fargate tasks over all hours in the current date for all organizations.
-
#apm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct APM hosts over all hours in the current date for all organizations.
-
#appsec_fargate_count_avg ⇒ Object
Shows the average of all Application Security Monitoring ECS Fargate tasks over all hours in the current date for all organizations.
-
#audit_logs_lines_indexed_sum ⇒ Object
Shows the sum of audit logs lines indexed over all hours in the current date for all organizations.
-
#avg_profiled_fargate_tasks ⇒ Object
The average profiled task count for Fargate Profiling.
-
#aws_host_top99p ⇒ Object
Shows the 99th percentile of all AWS hosts over all hours in the current date for all organizations.
-
#aws_lambda_func_count ⇒ Object
Shows the average of the number of functions that executed 1 or more times each hour in the current date for all organizations.
-
#aws_lambda_invocations_sum ⇒ Object
Shows the sum of all AWS Lambda invocations over all hours in the current date for all organizations.
-
#azure_app_service_top99p ⇒ Object
Shows the 99th percentile of all Azure app services over all hours in the current date for all organizations.
-
#billable_ingested_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for all organizations.
-
#browser_rum_lite_session_count_sum ⇒ Object
Shows the sum of all browser lite sessions over all hours in the current date for all organizations.
-
#browser_rum_replay_session_count_sum ⇒ Object
Shows the sum of all browser replay sessions over all hours in the current date for all organizations.
-
#browser_rum_units_sum ⇒ Object
Shows the sum of all browser RUM units over all hours in the current date for all organizations.
-
#ci_pipeline_indexed_spans_sum ⇒ Object
Shows the sum of all CI pipeline indexed spans over all hours in the current month for all organizations.
-
#ci_test_indexed_spans_sum ⇒ Object
Shows the sum of all CI test indexed spans over all hours in the current month for all organizations.
-
#ci_visibility_pipeline_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility pipeline committers over all hours in the current month for all organizations.
-
#ci_visibility_test_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility test committers over all hours in the current month for all organizations.
-
#cloud_cost_management_host_count_avg ⇒ Object
Host count average of Cloud Cost Management for the given date and given organization.
-
#container_avg ⇒ Object
Shows the average of all distinct containers over all hours in the current date for all organizations.
-
#container_excl_agent_avg ⇒ Object
Shows the average of containers without the Datadog Agent over all hours in the current date for all organizations.
-
#container_hwm ⇒ Object
Shows the high-water mark of all distinct containers over all hours in the current date for all organizations.
-
#cspm_aas_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure app services hosts over all hours in the current date for all organizations.
-
#cspm_aws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management AWS hosts over all hours in the current date for all organizations.
-
#cspm_azure_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure hosts over all hours in the current date for all organizations.
-
#cspm_container_avg ⇒ Object
Shows the average number of Cloud Security Posture Management containers over all hours in the current date for all organizations.
-
#cspm_container_hwm ⇒ Object
Shows the high-water mark of Cloud Security Posture Management containers over all hours in the current date for all organizations.
-
#cspm_gcp_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management GCP hosts over all hours in the current date for all organizations.
-
#cspm_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management hosts over all hours in the current date for all organizations.
-
#custom_ts_avg ⇒ Object
Shows the average number of distinct custom metrics over all hours in the current date for all organizations.
-
#cws_container_count_avg ⇒ Object
Shows the average of all distinct Cloud Workload Security containers over all hours in the current date for all organizations.
-
#cws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Workload Security hosts over all hours in the current date for all organizations.
-
#date ⇒ Object
The date for the usage.
-
#dbm_host_top99p ⇒ Object
Shows the 99th percentile of all Database Monitoring hosts over all hours in the current date for all organizations.
-
#dbm_queries_count_avg ⇒ Object
Shows the average of all normalized Database Monitoring queries over all hours in the current date for all organizations.
-
#fargate_tasks_count_avg ⇒ Object
Shows the high-watermark of all Fargate tasks over all hours in the current date for all organizations.
-
#fargate_tasks_count_hwm ⇒ Object
Shows the average of all Fargate tasks over all hours in the current date for all organizations.
-
#gcp_host_top99p ⇒ Object
Shows the 99th percentile of all GCP hosts over all hours in the current date for all organizations.
-
#heroku_host_top99p ⇒ Object
Shows the 99th percentile of all Heroku dynos over all hours in the current date for all organizations.
-
#incident_management_monthly_active_users_hwm ⇒ Object
Shows the high-water mark of incident management monthly active users over all hours in the current date for all organizations.
-
#indexed_events_count_sum ⇒ Object
Shows the sum of all log events indexed over all hours in the current date for all organizations.
-
#infra_host_top99p ⇒ Object
Shows the 99th percentile of all distinct infrastructure hosts over all hours in the current date for all organizations.
-
#ingested_events_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for all organizations.
-
#iot_device_sum ⇒ Object
Shows the sum of all IoT devices over all hours in the current date for all organizations.
-
#iot_device_top99p ⇒ Object
Shows the 99th percentile of all IoT devices over all hours in the current date all organizations.
-
#mobile_rum_lite_session_count_sum ⇒ Object
Shows the sum of all mobile lite sessions over all hours in the current date for all organizations.
-
#mobile_rum_session_count_android_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on Android over all hours in the current date for all organizations.
-
#mobile_rum_session_count_ios_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on iOS over all hours in the current date for all organizations.
-
#mobile_rum_session_count_reactnative_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on React Native over all hours in the current date for all organizations.
-
#mobile_rum_session_count_sum ⇒ Object
Shows the sum of all mobile RUM Sessions over all hours in the current date for all organizations.
-
#mobile_rum_units_sum ⇒ Object
Shows the sum of all mobile RUM units over all hours in the current date for all organizations.
-
#netflow_indexed_events_count_sum ⇒ Object
Shows the sum of all Network flows indexed over all hours in the current date for all organizations.
-
#npm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct Networks hosts over all hours in the current date for all organizations.
-
#observability_pipelines_bytes_processed_sum ⇒ Object
Sum of all observability pipelines bytes processed over all hours in the current date for the given org.
-
#online_archive_events_count_sum ⇒ Object
Sum of all online archived events over all hours in the current date for all organizations.
-
#opentelemetry_apm_host_top99p ⇒ Object
Shows the 99th percentile of APM hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for all organizations.
-
#opentelemetry_host_top99p ⇒ Object
Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for all organizations.
-
#orgs ⇒ Object
Organizations associated with a user.
-
#profiling_host_top99p ⇒ Object
Shows the 99th percentile of all profiled hosts over all hours in the current date for all organizations.
-
#rum_browser_and_mobile_session_count ⇒ Object
Shows the sum of all mobile sessions and all browser lite and legacy sessions over all hours in the current month for all organizations.
-
#rum_session_count_sum ⇒ Object
Shows the sum of all browser RUM Lite Sessions over all hours in the current date for all organizations.
-
#rum_total_session_count_sum ⇒ Object
Shows the sum of RUM Sessions (browser and mobile) over all hours in the current date for all organizations.
-
#rum_units_sum ⇒ Object
Shows the sum of all browser and mobile RUM units over all hours in the current date for all organizations.
-
#sds_apm_scanned_bytes_sum ⇒ Object
Sum of all APM bytes scanned with sensitive data scanner over all hours in the current date for all organizations.
-
#sds_events_scanned_bytes_sum ⇒ Object
Sum of all event stream events bytes scanned with sensitive data scanner over all hours in the current date for all organizations.
-
#sds_logs_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned of logs usage by the Sensitive Data Scanner over all hours in the current month for all organizations.
-
#sds_rum_scanned_bytes_sum ⇒ Object
Sum of all RUM bytes scanned with sensitive data scanner over all hours in the current date for all organizations.
-
#sds_total_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned across all usage types by the Sensitive Data Scanner over all hours in the current month for all organizations.
-
#synthetics_browser_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic browser tests over all hours in the current date for all organizations.
-
#synthetics_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic API tests over all hours in the current date for all organizations.
-
#synthetics_parallel_testing_max_slots_hwm ⇒ Object
Shows the high-water mark of used synthetics parallel testing slots over all hours in the current date for all organizations.
-
#trace_search_indexed_events_count_sum ⇒ Object
Shows the sum of all Indexed Spans indexed over all hours in the current date for all organizations.
-
#twol_ingested_events_bytes_sum ⇒ Object
Shows the sum of all ingested APM span bytes over all hours in the current date for all organizations.
-
#vsphere_host_top99p ⇒ Object
Shows the 99th percentile of all vSphere hosts over all hours in the current date for all organizations.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#agent_host_top99p ⇒ Object
Shows the 99th percentile of all agent hosts over all hours in the current date for all organizations.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 29 def agent_host_top99p @agent_host_top99p end |
#apm_azure_app_service_host_top99p ⇒ Object
Shows the 99th percentile of all Azure app services using APM over all hours in the current date all organizations.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 32 def apm_azure_app_service_host_top99p @apm_azure_app_service_host_top99p end |
#apm_fargate_count_avg ⇒ Object
Shows the average of all APM ECS Fargate tasks over all hours in the current date for all organizations.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 35 def apm_fargate_count_avg @apm_fargate_count_avg end |
#apm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct APM hosts over all hours in the current date for all organizations.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 38 def apm_host_top99p @apm_host_top99p end |
#appsec_fargate_count_avg ⇒ Object
Shows the average of all Application Security Monitoring ECS Fargate tasks over all hours in the current date for all organizations.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 41 def appsec_fargate_count_avg @appsec_fargate_count_avg end |
#audit_logs_lines_indexed_sum ⇒ Object
Shows the sum of audit logs lines indexed over all hours in the current date for all organizations.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 44 def audit_logs_lines_indexed_sum @audit_logs_lines_indexed_sum end |
#avg_profiled_fargate_tasks ⇒ Object
The average profiled task count for Fargate Profiling.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 47 def avg_profiled_fargate_tasks @avg_profiled_fargate_tasks end |
#aws_host_top99p ⇒ Object
Shows the 99th percentile of all AWS hosts over all hours in the current date for all organizations.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 50 def aws_host_top99p @aws_host_top99p end |
#aws_lambda_func_count ⇒ Object
Shows the average of the number of functions that executed 1 or more times each hour in the current date for all organizations.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 53 def aws_lambda_func_count @aws_lambda_func_count end |
#aws_lambda_invocations_sum ⇒ Object
Shows the sum of all AWS Lambda invocations over all hours in the current date for all organizations.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 56 def aws_lambda_invocations_sum @aws_lambda_invocations_sum end |
#azure_app_service_top99p ⇒ Object
Shows the 99th percentile of all Azure app services over all hours in the current date for all organizations.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 59 def azure_app_service_top99p @azure_app_service_top99p end |
#billable_ingested_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for all organizations.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 62 def billable_ingested_bytes_sum @billable_ingested_bytes_sum end |
#browser_rum_lite_session_count_sum ⇒ Object
Shows the sum of all browser lite sessions over all hours in the current date for all organizations.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 65 def browser_rum_lite_session_count_sum @browser_rum_lite_session_count_sum end |
#browser_rum_replay_session_count_sum ⇒ Object
Shows the sum of all browser replay sessions over all hours in the current date for all organizations.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 68 def browser_rum_replay_session_count_sum @browser_rum_replay_session_count_sum end |
#browser_rum_units_sum ⇒ Object
Shows the sum of all browser RUM units over all hours in the current date for all organizations.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 71 def browser_rum_units_sum @browser_rum_units_sum end |
#ci_pipeline_indexed_spans_sum ⇒ Object
Shows the sum of all CI pipeline indexed spans over all hours in the current month for all organizations.
74 75 76 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 74 def ci_pipeline_indexed_spans_sum @ci_pipeline_indexed_spans_sum end |
#ci_test_indexed_spans_sum ⇒ Object
Shows the sum of all CI test indexed spans over all hours in the current month for all organizations.
77 78 79 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 77 def ci_test_indexed_spans_sum @ci_test_indexed_spans_sum end |
#ci_visibility_pipeline_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility pipeline committers over all hours in the current month for all organizations.
80 81 82 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 80 def ci_visibility_pipeline_committers_hwm @ci_visibility_pipeline_committers_hwm end |
#ci_visibility_test_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility test committers over all hours in the current month for all organizations.
83 84 85 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 83 def ci_visibility_test_committers_hwm @ci_visibility_test_committers_hwm end |
#cloud_cost_management_host_count_avg ⇒ Object
Host count average of Cloud Cost Management for the given date and given organization.
86 87 88 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 86 def cloud_cost_management_host_count_avg @cloud_cost_management_host_count_avg end |
#container_avg ⇒ Object
Shows the average of all distinct containers over all hours in the current date for all organizations.
89 90 91 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 89 def container_avg @container_avg end |
#container_excl_agent_avg ⇒ Object
Shows the average of containers without the Datadog Agent over all hours in the current date for all organizations.
92 93 94 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 92 def container_excl_agent_avg @container_excl_agent_avg end |
#container_hwm ⇒ Object
Shows the high-water mark of all distinct containers over all hours in the current date for all organizations.
95 96 97 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 95 def container_hwm @container_hwm end |
#cspm_aas_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure app services hosts over all hours in the current date for all organizations.
98 99 100 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 98 def cspm_aas_host_top99p @cspm_aas_host_top99p end |
#cspm_aws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management AWS hosts over all hours in the current date for all organizations.
101 102 103 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 101 def cspm_aws_host_top99p @cspm_aws_host_top99p end |
#cspm_azure_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure hosts over all hours in the current date for all organizations.
104 105 106 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 104 def cspm_azure_host_top99p @cspm_azure_host_top99p end |
#cspm_container_avg ⇒ Object
Shows the average number of Cloud Security Posture Management containers over all hours in the current date for all organizations.
107 108 109 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 107 def cspm_container_avg @cspm_container_avg end |
#cspm_container_hwm ⇒ Object
Shows the high-water mark of Cloud Security Posture Management containers over all hours in the current date for all organizations.
110 111 112 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 110 def cspm_container_hwm @cspm_container_hwm end |
#cspm_gcp_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management GCP hosts over all hours in the current date for all organizations.
113 114 115 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 113 def cspm_gcp_host_top99p @cspm_gcp_host_top99p end |
#cspm_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management hosts over all hours in the current date for all organizations.
116 117 118 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 116 def cspm_host_top99p @cspm_host_top99p end |
#custom_ts_avg ⇒ Object
Shows the average number of distinct custom metrics over all hours in the current date for all organizations.
119 120 121 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 119 def custom_ts_avg @custom_ts_avg end |
#cws_container_count_avg ⇒ Object
Shows the average of all distinct Cloud Workload Security containers over all hours in the current date for all organizations.
122 123 124 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 122 def cws_container_count_avg @cws_container_count_avg end |
#cws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Workload Security hosts over all hours in the current date for all organizations.
125 126 127 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 125 def cws_host_top99p @cws_host_top99p end |
#date ⇒ Object
The date for the usage.
128 129 130 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 128 def date @date end |
#dbm_host_top99p ⇒ Object
Shows the 99th percentile of all Database Monitoring hosts over all hours in the current date for all organizations.
131 132 133 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 131 def dbm_host_top99p @dbm_host_top99p end |
#dbm_queries_count_avg ⇒ Object
Shows the average of all normalized Database Monitoring queries over all hours in the current date for all organizations.
134 135 136 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 134 def dbm_queries_count_avg @dbm_queries_count_avg end |
#fargate_tasks_count_avg ⇒ Object
Shows the high-watermark of all Fargate tasks over all hours in the current date for all organizations.
137 138 139 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 137 def fargate_tasks_count_avg @fargate_tasks_count_avg end |
#fargate_tasks_count_hwm ⇒ Object
Shows the average of all Fargate tasks over all hours in the current date for all organizations.
140 141 142 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 140 def fargate_tasks_count_hwm @fargate_tasks_count_hwm end |
#gcp_host_top99p ⇒ Object
Shows the 99th percentile of all GCP hosts over all hours in the current date for all organizations.
143 144 145 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 143 def gcp_host_top99p @gcp_host_top99p end |
#heroku_host_top99p ⇒ Object
Shows the 99th percentile of all Heroku dynos over all hours in the current date for all organizations.
146 147 148 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 146 def heroku_host_top99p @heroku_host_top99p end |
#incident_management_monthly_active_users_hwm ⇒ Object
Shows the high-water mark of incident management monthly active users over all hours in the current date for all organizations.
149 150 151 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 149 def incident_management_monthly_active_users_hwm @incident_management_monthly_active_users_hwm end |
#indexed_events_count_sum ⇒ Object
Shows the sum of all log events indexed over all hours in the current date for all organizations.
152 153 154 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 152 def indexed_events_count_sum @indexed_events_count_sum end |
#infra_host_top99p ⇒ Object
Shows the 99th percentile of all distinct infrastructure hosts over all hours in the current date for all organizations.
155 156 157 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 155 def infra_host_top99p @infra_host_top99p end |
#ingested_events_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for all organizations.
158 159 160 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 158 def ingested_events_bytes_sum @ingested_events_bytes_sum end |
#iot_device_sum ⇒ Object
Shows the sum of all IoT devices over all hours in the current date for all organizations.
161 162 163 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 161 def iot_device_sum @iot_device_sum end |
#iot_device_top99p ⇒ Object
Shows the 99th percentile of all IoT devices over all hours in the current date all organizations.
164 165 166 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 164 def iot_device_top99p @iot_device_top99p end |
#mobile_rum_lite_session_count_sum ⇒ Object
Shows the sum of all mobile lite sessions over all hours in the current date for all organizations.
167 168 169 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 167 def mobile_rum_lite_session_count_sum @mobile_rum_lite_session_count_sum end |
#mobile_rum_session_count_android_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on Android over all hours in the current date for all organizations.
170 171 172 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 170 def mobile_rum_session_count_android_sum @mobile_rum_session_count_android_sum end |
#mobile_rum_session_count_ios_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on iOS over all hours in the current date for all organizations.
173 174 175 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 173 def mobile_rum_session_count_ios_sum @mobile_rum_session_count_ios_sum end |
#mobile_rum_session_count_reactnative_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on React Native over all hours in the current date for all organizations.
176 177 178 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 176 def mobile_rum_session_count_reactnative_sum @mobile_rum_session_count_reactnative_sum end |
#mobile_rum_session_count_sum ⇒ Object
Shows the sum of all mobile RUM Sessions over all hours in the current date for all organizations
179 180 181 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 179 def mobile_rum_session_count_sum @mobile_rum_session_count_sum end |
#mobile_rum_units_sum ⇒ Object
Shows the sum of all mobile RUM units over all hours in the current date for all organizations.
182 183 184 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 182 def mobile_rum_units_sum @mobile_rum_units_sum end |
#netflow_indexed_events_count_sum ⇒ Object
Shows the sum of all Network flows indexed over all hours in the current date for all organizations.
185 186 187 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 185 def netflow_indexed_events_count_sum @netflow_indexed_events_count_sum end |
#npm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct Networks hosts over all hours in the current date for all organizations.
188 189 190 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 188 def npm_host_top99p @npm_host_top99p end |
#observability_pipelines_bytes_processed_sum ⇒ Object
Sum of all observability pipelines bytes processed over all hours in the current date for the given org.
191 192 193 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 191 def observability_pipelines_bytes_processed_sum @observability_pipelines_bytes_processed_sum end |
#online_archive_events_count_sum ⇒ Object
Sum of all online archived events over all hours in the current date for all organizations.
194 195 196 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 194 def online_archive_events_count_sum @online_archive_events_count_sum end |
#opentelemetry_apm_host_top99p ⇒ Object
Shows the 99th percentile of APM hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for all organizations.
197 198 199 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 197 def opentelemetry_apm_host_top99p @opentelemetry_apm_host_top99p end |
#opentelemetry_host_top99p ⇒ Object
Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for all organizations.
200 201 202 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 200 def opentelemetry_host_top99p @opentelemetry_host_top99p end |
#orgs ⇒ Object
Organizations associated with a user.
203 204 205 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 203 def orgs @orgs end |
#profiling_host_top99p ⇒ Object
Shows the 99th percentile of all profiled hosts over all hours in the current date for all organizations.
206 207 208 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 206 def profiling_host_top99p @profiling_host_top99p end |
#rum_browser_and_mobile_session_count ⇒ Object
Shows the sum of all mobile sessions and all browser lite and legacy sessions over all hours in the current month for all organizations.
209 210 211 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 209 def rum_browser_and_mobile_session_count @rum_browser_and_mobile_session_count end |
#rum_session_count_sum ⇒ Object
Shows the sum of all browser RUM Lite Sessions over all hours in the current date for all organizations
212 213 214 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 212 def rum_session_count_sum @rum_session_count_sum end |
#rum_total_session_count_sum ⇒ Object
Shows the sum of RUM Sessions (browser and mobile) over all hours in the current date for all organizations.
215 216 217 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 215 def rum_total_session_count_sum @rum_total_session_count_sum end |
#rum_units_sum ⇒ Object
Shows the sum of all browser and mobile RUM units over all hours in the current date for all organizations.
218 219 220 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 218 def rum_units_sum @rum_units_sum end |
#sds_apm_scanned_bytes_sum ⇒ Object
Sum of all APM bytes scanned with sensitive data scanner over all hours in the current date for all organizations.
221 222 223 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 221 def sds_apm_scanned_bytes_sum @sds_apm_scanned_bytes_sum end |
#sds_events_scanned_bytes_sum ⇒ Object
Sum of all event stream events bytes scanned with sensitive data scanner over all hours in the current date for all organizations.
224 225 226 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 224 def sds_events_scanned_bytes_sum @sds_events_scanned_bytes_sum end |
#sds_logs_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned of logs usage by the Sensitive Data Scanner over all hours in the current month for all organizations.
227 228 229 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 227 def sds_logs_scanned_bytes_sum @sds_logs_scanned_bytes_sum end |
#sds_rum_scanned_bytes_sum ⇒ Object
Sum of all RUM bytes scanned with sensitive data scanner over all hours in the current date for all organizations.
230 231 232 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 230 def sds_rum_scanned_bytes_sum @sds_rum_scanned_bytes_sum end |
#sds_total_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned across all usage types by the Sensitive Data Scanner over all hours in the current month for all organizations.
233 234 235 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 233 def sds_total_scanned_bytes_sum @sds_total_scanned_bytes_sum end |
#synthetics_browser_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic browser tests over all hours in the current date for all organizations.
236 237 238 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 236 def synthetics_browser_check_calls_count_sum @synthetics_browser_check_calls_count_sum end |
#synthetics_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic API tests over all hours in the current date for all organizations.
239 240 241 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 239 def synthetics_check_calls_count_sum @synthetics_check_calls_count_sum end |
#synthetics_parallel_testing_max_slots_hwm ⇒ Object
Shows the high-water mark of used synthetics parallel testing slots over all hours in the current date for all organizations.
242 243 244 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 242 def synthetics_parallel_testing_max_slots_hwm @synthetics_parallel_testing_max_slots_hwm end |
#trace_search_indexed_events_count_sum ⇒ Object
Shows the sum of all Indexed Spans indexed over all hours in the current date for all organizations.
245 246 247 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 245 def trace_search_indexed_events_count_sum @trace_search_indexed_events_count_sum end |
#twol_ingested_events_bytes_sum ⇒ Object
Shows the sum of all ingested APM span bytes over all hours in the current date for all organizations.
248 249 250 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 248 def twol_ingested_events_bytes_sum @twol_ingested_events_bytes_sum end |
#vsphere_host_top99p ⇒ Object
Shows the 99th percentile of all vSphere hosts over all hours in the current date for all organizations.
251 252 253 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date.rb', line 251 def vsphere_host_top99p @vsphere_host_top99p end |