Class: DatadogAPIClient::V1::UsageSummaryDateOrg
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageSummaryDateOrg
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_summary_date_org.rb
Overview
Global hourly report of all data billed by Datadog for a given organization.
Instance Attribute Summary collapse
-
#agent_host_top99p ⇒ Object
Shows the 99th percentile of all agent hosts over all hours in the current date for the given org.
-
#apm_azure_app_service_host_top99p ⇒ Object
Shows the 99th percentile of all Azure app services using APM over all hours in the current date for the given org.
-
#apm_fargate_count_avg ⇒ Object
Shows the average of all APM ECS Fargate tasks over all hours in the current months for the given org.
-
#apm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct APM hosts over all hours in the current date for the given org.
-
#appsec_fargate_count_avg ⇒ Object
Shows the average of all Application Security Monitoring ECS Fargate tasks over all hours in the current months for the given org.
-
#audit_logs_lines_indexed_sum ⇒ Object
Shows the sum of all audit logs lines indexed over all hours in the current date for the given org.
-
#avg_profiled_fargate_tasks ⇒ Object
The average profiled task count for Fargate Profiling.
-
#aws_host_top99p ⇒ Object
Shows the 99th percentile of all AWS hosts over all hours in the current date for the given org.
-
#aws_lambda_func_count ⇒ Object
Shows the sum of all AWS Lambda invocations over all hours in the current date for the given org.
-
#aws_lambda_invocations_sum ⇒ Object
Shows the sum of all AWS Lambda invocations over all hours in the current date for the given org.
-
#azure_app_service_top99p ⇒ Object
Shows the 99th percentile of all Azure app services over all hours in the current date for the given org.
-
#billable_ingested_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for the given org.
-
#browser_rum_lite_session_count_sum ⇒ Object
Shows the sum of all browser lite sessions over all hours in the current date for the given org.
-
#browser_rum_replay_session_count_sum ⇒ Object
Shows the sum of all browser replay sessions over all hours in the current date for the given org.
-
#browser_rum_units_sum ⇒ Object
Shows the sum of all browser RUM units over all hours in the current date for the given org.
-
#ci_pipeline_indexed_spans_sum ⇒ Object
Shows the sum of all CI pipeline indexed spans over all hours in the current date for the given org.
-
#ci_test_indexed_spans_sum ⇒ Object
Shows the sum of all CI test indexed spans over all hours in the current date for the given org.
-
#ci_visibility_pipeline_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility pipeline committers over all hours in the current date for the given org.
-
#ci_visibility_test_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility test committers over all hours in the current date for the given org.
-
#cloud_cost_management_host_count_avg ⇒ Object
Host count average of Cloud Cost Management for the given date and given org.
-
#container_avg ⇒ Object
Shows the average of all distinct containers over all hours in the current date for the given org.
-
#container_excl_agent_avg ⇒ Object
Shows the average of containers without the Datadog Agent over all hours in the current date for the given organization.
-
#container_hwm ⇒ Object
Shows the high-water mark of all distinct containers over all hours in the current date for the given org.
-
#cspm_aas_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure app services hosts over all hours in the current date for the given org.
-
#cspm_aws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management AWS hosts over all hours in the current date for the given org.
-
#cspm_azure_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure hosts over all hours in the current date for the given org.
-
#cspm_container_avg ⇒ Object
Shows the average number of Cloud Security Posture Management containers over all hours in the current date for the given org.
-
#cspm_container_hwm ⇒ Object
Shows the high-water mark of Cloud Security Posture Management containers over all hours in the current date for the given org.
-
#cspm_gcp_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management GCP hosts over all hours in the current date for the given org.
-
#cspm_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management hosts over all hours in the current date for the given org.
-
#custom_ts_avg ⇒ Object
Shows the average number of distinct custom metrics over all hours in the current date for the given org.
-
#cws_container_count_avg ⇒ Object
Shows the average of all distinct Cloud Workload Security containers over all hours in the current date for the given org.
-
#cws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Workload Security hosts over all hours in the current date for the given org.
-
#dbm_host_top99p_sum ⇒ Object
Shows the 99th percentile of all Database Monitoring hosts over all hours in the current month for the given org.
-
#dbm_queries_avg_sum ⇒ Object
Shows the average of all distinct Database Monitoring normalized queries over all hours in the current month for the given org.
-
#fargate_tasks_count_avg ⇒ Object
The average task count for Fargate.
-
#fargate_tasks_count_hwm ⇒ Object
Shows the high-water mark of all Fargate tasks over all hours in the current date for the given org.
-
#gcp_host_top99p ⇒ Object
Shows the 99th percentile of all GCP hosts over all hours in the current date for the given org.
-
#heroku_host_top99p ⇒ Object
Shows the 99th percentile of all Heroku dynos over all hours in the current date for the given org.
-
#id ⇒ Object
The organization id.
-
#incident_management_monthly_active_users_hwm ⇒ Object
Shows the high-water mark of incident management monthly active users over all hours in the current date for the given org.
-
#indexed_events_count_sum ⇒ Object
Shows the sum of all log events indexed over all hours in the current date for the given org.
-
#infra_host_top99p ⇒ Object
Shows the 99th percentile of all distinct infrastructure hosts over all hours in the current date for the given org.
-
#ingested_events_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for the given org.
-
#iot_device_agg_sum ⇒ Object
Shows the sum of all IoT devices over all hours in the current date for the given org.
-
#iot_device_top99p_sum ⇒ Object
Shows the 99th percentile of all IoT devices over all hours in the current date for the given org.
-
#mobile_rum_lite_session_count_sum ⇒ Object
Shows the sum of all mobile lite sessions over all hours in the current date for the given org.
-
#mobile_rum_session_count_android_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on Android over all hours in the current date for the given org.
-
#mobile_rum_session_count_ios_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on iOS over all hours in the current date for the given org.
-
#mobile_rum_session_count_reactnative_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on React Native over all hours in the current date for the given org.
-
#mobile_rum_session_count_sum ⇒ Object
Shows the sum of all mobile RUM Sessions over all hours in the current date for the given org.
-
#mobile_rum_units_sum ⇒ Object
Shows the sum of all mobile RUM units over all hours in the current date for the given org.
-
#name ⇒ Object
The organization name.
-
#netflow_indexed_events_count_sum ⇒ Object
Shows the sum of all Network flows indexed over all hours in the current date for the given org.
-
#npm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct Networks hosts over all hours in the current date for the given org.
-
#observability_pipelines_bytes_processed_sum ⇒ Object
Sum of all observability pipelines bytes processed over all hours in the current date for the given org.
-
#online_archive_events_count_sum ⇒ Object
Sum of all online archived events over all hours in the current date for the given org.
-
#opentelemetry_apm_host_top99p ⇒ Object
Shows the 99th percentile of APM hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for the given org.
-
#opentelemetry_host_top99p ⇒ Object
Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for the given org.
-
#profiling_host_top99p ⇒ Object
Shows the 99th percentile of all profiled hosts over all hours in the current date for the given org.
-
#public_id ⇒ Object
The organization public id.
-
#region ⇒ Object
The region of the organization.
-
#rum_browser_and_mobile_session_count ⇒ Object
Shows the sum of all mobile sessions and all browser lite and legacy sessions over all hours in the current date for the given org.
-
#rum_session_count_sum ⇒ Object
Shows the sum of all browser RUM Lite Sessions over all hours in the current date for the given org.
-
#rum_total_session_count_sum ⇒ Object
Shows the sum of RUM Sessions (browser and mobile) over all hours in the current date for the given org.
-
#rum_units_sum ⇒ Object
Shows the sum of all browser and mobile RUM units over all hours in the current date for the given org.
-
#sds_apm_scanned_bytes_sum ⇒ Object
Sum of all APM bytes scanned with sensitive data scanner over all hours in the current date for the given org.
-
#sds_events_scanned_bytes_sum ⇒ Object
Sum of all event stream events bytes scanned with sensitive data scanner over all hours in the current date for the given org.
-
#sds_logs_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned of logs usage by the Sensitive Data Scanner over all hours in the current month for the given org.
-
#sds_rum_scanned_bytes_sum ⇒ Object
Sum of all RUM bytes scanned with sensitive data scanner over all hours in the current date for the given org.
-
#sds_total_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned across all usage types by the Sensitive Data Scanner over all hours in the current month for the given org.
-
#synthetics_browser_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic browser tests over all hours in the current date for the given org.
-
#synthetics_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic API tests over all hours in the current date for the given org.
-
#synthetics_parallel_testing_max_slots_hwm ⇒ Object
Shows the high-water mark of used synthetics parallel testing slots over all hours in the current date for the given org.
-
#trace_search_indexed_events_count_sum ⇒ Object
Shows the sum of all Indexed Spans indexed over all hours in the current date for the given org.
-
#twol_ingested_events_bytes_sum ⇒ Object
Shows the sum of all ingested APM span bytes over all hours in the current date for the given org.
-
#vsphere_host_top99p ⇒ Object
Shows the 99th percentile of all vSphere hosts over all hours in the current date for the given org.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#agent_host_top99p ⇒ Object
Shows the 99th percentile of all agent hosts over all hours in the current date for the given org.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 29 def agent_host_top99p @agent_host_top99p end |
#apm_azure_app_service_host_top99p ⇒ Object
Shows the 99th percentile of all Azure app services using APM over all hours in the current date for the given org.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 32 def apm_azure_app_service_host_top99p @apm_azure_app_service_host_top99p end |
#apm_fargate_count_avg ⇒ Object
Shows the average of all APM ECS Fargate tasks over all hours in the current months for the given org.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 35 def apm_fargate_count_avg @apm_fargate_count_avg end |
#apm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct APM hosts over all hours in the current date for the given org.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 38 def apm_host_top99p @apm_host_top99p end |
#appsec_fargate_count_avg ⇒ Object
Shows the average of all Application Security Monitoring ECS Fargate tasks over all hours in the current months for the given org.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 41 def appsec_fargate_count_avg @appsec_fargate_count_avg end |
#audit_logs_lines_indexed_sum ⇒ Object
Shows the sum of all audit logs lines indexed over all hours in the current date for the given org.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 44 def audit_logs_lines_indexed_sum @audit_logs_lines_indexed_sum end |
#avg_profiled_fargate_tasks ⇒ Object
The average profiled task count for Fargate Profiling.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 47 def avg_profiled_fargate_tasks @avg_profiled_fargate_tasks end |
#aws_host_top99p ⇒ Object
Shows the 99th percentile of all AWS hosts over all hours in the current date for the given org.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 50 def aws_host_top99p @aws_host_top99p end |
#aws_lambda_func_count ⇒ Object
Shows the sum of all AWS Lambda invocations over all hours in the current date for the given org.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 53 def aws_lambda_func_count @aws_lambda_func_count end |
#aws_lambda_invocations_sum ⇒ Object
Shows the sum of all AWS Lambda invocations over all hours in the current date for the given org.
56 57 58 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 56 def aws_lambda_invocations_sum @aws_lambda_invocations_sum end |
#azure_app_service_top99p ⇒ Object
Shows the 99th percentile of all Azure app services over all hours in the current date for the given org.
59 60 61 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 59 def azure_app_service_top99p @azure_app_service_top99p end |
#billable_ingested_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for the given org.
62 63 64 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 62 def billable_ingested_bytes_sum @billable_ingested_bytes_sum end |
#browser_rum_lite_session_count_sum ⇒ Object
Shows the sum of all browser lite sessions over all hours in the current date for the given org.
65 66 67 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 65 def browser_rum_lite_session_count_sum @browser_rum_lite_session_count_sum end |
#browser_rum_replay_session_count_sum ⇒ Object
Shows the sum of all browser replay sessions over all hours in the current date for the given org.
68 69 70 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 68 def browser_rum_replay_session_count_sum @browser_rum_replay_session_count_sum end |
#browser_rum_units_sum ⇒ Object
Shows the sum of all browser RUM units over all hours in the current date for the given org.
71 72 73 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 71 def browser_rum_units_sum @browser_rum_units_sum end |
#ci_pipeline_indexed_spans_sum ⇒ Object
Shows the sum of all CI pipeline indexed spans over all hours in the current date for the given org.
74 75 76 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 74 def ci_pipeline_indexed_spans_sum @ci_pipeline_indexed_spans_sum end |
#ci_test_indexed_spans_sum ⇒ Object
Shows the sum of all CI test indexed spans over all hours in the current date for the given org.
77 78 79 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 77 def ci_test_indexed_spans_sum @ci_test_indexed_spans_sum end |
#ci_visibility_pipeline_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility pipeline committers over all hours in the current date for the given org.
80 81 82 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 80 def ci_visibility_pipeline_committers_hwm @ci_visibility_pipeline_committers_hwm end |
#ci_visibility_test_committers_hwm ⇒ Object
Shows the high-water mark of all CI visibility test committers over all hours in the current date for the given org.
83 84 85 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 83 def ci_visibility_test_committers_hwm @ci_visibility_test_committers_hwm end |
#cloud_cost_management_host_count_avg ⇒ Object
Host count average of Cloud Cost Management for the given date and given org.
86 87 88 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 86 def cloud_cost_management_host_count_avg @cloud_cost_management_host_count_avg end |
#container_avg ⇒ Object
Shows the average of all distinct containers over all hours in the current date for the given org.
89 90 91 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 89 def container_avg @container_avg end |
#container_excl_agent_avg ⇒ Object
Shows the average of containers without the Datadog Agent over all hours in the current date for the given organization.
92 93 94 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 92 def container_excl_agent_avg @container_excl_agent_avg end |
#container_hwm ⇒ Object
Shows the high-water mark of all distinct containers over all hours in the current date for the given org.
95 96 97 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 95 def container_hwm @container_hwm end |
#cspm_aas_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure app services hosts over all hours in the current date for the given org.
98 99 100 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 98 def cspm_aas_host_top99p @cspm_aas_host_top99p end |
#cspm_aws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management AWS hosts over all hours in the current date for the given org.
101 102 103 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 101 def cspm_aws_host_top99p @cspm_aws_host_top99p end |
#cspm_azure_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management Azure hosts over all hours in the current date for the given org.
104 105 106 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 104 def cspm_azure_host_top99p @cspm_azure_host_top99p end |
#cspm_container_avg ⇒ Object
Shows the average number of Cloud Security Posture Management containers over all hours in the current date for the given org.
107 108 109 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 107 def cspm_container_avg @cspm_container_avg end |
#cspm_container_hwm ⇒ Object
Shows the high-water mark of Cloud Security Posture Management containers over all hours in the current date for the given org.
110 111 112 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 110 def cspm_container_hwm @cspm_container_hwm end |
#cspm_gcp_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management GCP hosts over all hours in the current date for the given org.
113 114 115 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 113 def cspm_gcp_host_top99p @cspm_gcp_host_top99p end |
#cspm_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Security Posture Management hosts over all hours in the current date for the given org.
116 117 118 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 116 def cspm_host_top99p @cspm_host_top99p end |
#custom_ts_avg ⇒ Object
Shows the average number of distinct custom metrics over all hours in the current date for the given org.
119 120 121 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 119 def custom_ts_avg @custom_ts_avg end |
#cws_container_count_avg ⇒ Object
Shows the average of all distinct Cloud Workload Security containers over all hours in the current date for the given org.
122 123 124 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 122 def cws_container_count_avg @cws_container_count_avg end |
#cws_host_top99p ⇒ Object
Shows the 99th percentile of all Cloud Workload Security hosts over all hours in the current date for the given org.
125 126 127 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 125 def cws_host_top99p @cws_host_top99p end |
#dbm_host_top99p_sum ⇒ Object
Shows the 99th percentile of all Database Monitoring hosts over all hours in the current month for the given org.
128 129 130 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 128 def dbm_host_top99p_sum @dbm_host_top99p_sum end |
#dbm_queries_avg_sum ⇒ Object
Shows the average of all distinct Database Monitoring normalized queries over all hours in the current month for the given org.
131 132 133 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 131 def dbm_queries_avg_sum @dbm_queries_avg_sum end |
#fargate_tasks_count_avg ⇒ Object
The average task count for Fargate.
134 135 136 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 134 def fargate_tasks_count_avg @fargate_tasks_count_avg end |
#fargate_tasks_count_hwm ⇒ Object
Shows the high-water mark of all Fargate tasks over all hours in the current date for the given org.
137 138 139 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 137 def fargate_tasks_count_hwm @fargate_tasks_count_hwm end |
#gcp_host_top99p ⇒ Object
Shows the 99th percentile of all GCP hosts over all hours in the current date for the given org.
140 141 142 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 140 def gcp_host_top99p @gcp_host_top99p end |
#heroku_host_top99p ⇒ Object
Shows the 99th percentile of all Heroku dynos over all hours in the current date for the given org.
143 144 145 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 143 def heroku_host_top99p @heroku_host_top99p end |
#id ⇒ Object
The organization id.
146 147 148 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 146 def id @id end |
#incident_management_monthly_active_users_hwm ⇒ Object
Shows the high-water mark of incident management monthly active users over all hours in the current date for the given org.
149 150 151 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 149 def incident_management_monthly_active_users_hwm @incident_management_monthly_active_users_hwm end |
#indexed_events_count_sum ⇒ Object
Shows the sum of all log events indexed over all hours in the current date for the given org.
152 153 154 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 152 def indexed_events_count_sum @indexed_events_count_sum end |
#infra_host_top99p ⇒ Object
Shows the 99th percentile of all distinct infrastructure hosts over all hours in the current date for the given org.
155 156 157 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 155 def infra_host_top99p @infra_host_top99p end |
#ingested_events_bytes_sum ⇒ Object
Shows the sum of all log bytes ingested over all hours in the current date for the given org.
158 159 160 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 158 def ingested_events_bytes_sum @ingested_events_bytes_sum end |
#iot_device_agg_sum ⇒ Object
Shows the sum of all IoT devices over all hours in the current date for the given org.
161 162 163 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 161 def iot_device_agg_sum @iot_device_agg_sum end |
#iot_device_top99p_sum ⇒ Object
Shows the 99th percentile of all IoT devices over all hours in the current date for the given org.
164 165 166 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 164 def iot_device_top99p_sum @iot_device_top99p_sum end |
#mobile_rum_lite_session_count_sum ⇒ Object
Shows the sum of all mobile lite sessions over all hours in the current date for the given org.
167 168 169 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 167 def mobile_rum_lite_session_count_sum @mobile_rum_lite_session_count_sum end |
#mobile_rum_session_count_android_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on Android over all hours in the current date for the given org.
170 171 172 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 170 def mobile_rum_session_count_android_sum @mobile_rum_session_count_android_sum end |
#mobile_rum_session_count_ios_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on iOS over all hours in the current date for the given org.
173 174 175 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 173 def mobile_rum_session_count_ios_sum @mobile_rum_session_count_ios_sum end |
#mobile_rum_session_count_reactnative_sum ⇒ Object
Shows the sum of all mobile RUM Sessions on React Native over all hours in the current date for the given org.
176 177 178 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 176 def mobile_rum_session_count_reactnative_sum @mobile_rum_session_count_reactnative_sum end |
#mobile_rum_session_count_sum ⇒ Object
Shows the sum of all mobile RUM Sessions over all hours in the current date for the given org.
179 180 181 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 179 def mobile_rum_session_count_sum @mobile_rum_session_count_sum end |
#mobile_rum_units_sum ⇒ Object
Shows the sum of all mobile RUM units over all hours in the current date for the given org.
182 183 184 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 182 def mobile_rum_units_sum @mobile_rum_units_sum end |
#name ⇒ Object
The organization name.
185 186 187 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 185 def name @name end |
#netflow_indexed_events_count_sum ⇒ Object
Shows the sum of all Network flows indexed over all hours in the current date for the given org.
188 189 190 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 188 def netflow_indexed_events_count_sum @netflow_indexed_events_count_sum end |
#npm_host_top99p ⇒ Object
Shows the 99th percentile of all distinct Networks hosts over all hours in the current date for the given org.
191 192 193 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 191 def npm_host_top99p @npm_host_top99p end |
#observability_pipelines_bytes_processed_sum ⇒ Object
Sum of all observability pipelines bytes processed over all hours in the current date for the given org.
194 195 196 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 194 def observability_pipelines_bytes_processed_sum @observability_pipelines_bytes_processed_sum end |
#online_archive_events_count_sum ⇒ Object
Sum of all online archived events over all hours in the current date for the given org.
197 198 199 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 197 def online_archive_events_count_sum @online_archive_events_count_sum end |
#opentelemetry_apm_host_top99p ⇒ Object
Shows the 99th percentile of APM hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for the given org.
200 201 202 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 200 def opentelemetry_apm_host_top99p @opentelemetry_apm_host_top99p end |
#opentelemetry_host_top99p ⇒ Object
Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current date for the given org.
203 204 205 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 203 def opentelemetry_host_top99p @opentelemetry_host_top99p end |
#profiling_host_top99p ⇒ Object
Shows the 99th percentile of all profiled hosts over all hours in the current date for the given org.
206 207 208 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 206 def profiling_host_top99p @profiling_host_top99p end |
#public_id ⇒ Object
The organization public id.
209 210 211 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 209 def public_id @public_id end |
#region ⇒ Object
The region of the organization.
212 213 214 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 212 def region @region end |
#rum_browser_and_mobile_session_count ⇒ Object
Shows the sum of all mobile sessions and all browser lite and legacy sessions over all hours in the current date for the given org.
215 216 217 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 215 def rum_browser_and_mobile_session_count @rum_browser_and_mobile_session_count end |
#rum_session_count_sum ⇒ Object
Shows the sum of all browser RUM Lite Sessions over all hours in the current date for the given org.
218 219 220 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 218 def rum_session_count_sum @rum_session_count_sum end |
#rum_total_session_count_sum ⇒ Object
Shows the sum of RUM Sessions (browser and mobile) over all hours in the current date for the given org.
221 222 223 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 221 def rum_total_session_count_sum @rum_total_session_count_sum end |
#rum_units_sum ⇒ Object
Shows the sum of all browser and mobile RUM units over all hours in the current date for the given org.
224 225 226 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 224 def rum_units_sum @rum_units_sum end |
#sds_apm_scanned_bytes_sum ⇒ Object
Sum of all APM bytes scanned with sensitive data scanner over all hours in the current date for the given org.
227 228 229 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 227 def sds_apm_scanned_bytes_sum @sds_apm_scanned_bytes_sum end |
#sds_events_scanned_bytes_sum ⇒ Object
Sum of all event stream events bytes scanned with sensitive data scanner over all hours in the current date for the given org.
230 231 232 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 230 def sds_events_scanned_bytes_sum @sds_events_scanned_bytes_sum end |
#sds_logs_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned of logs usage by the Sensitive Data Scanner over all hours in the current month for the given org.
233 234 235 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 233 def sds_logs_scanned_bytes_sum @sds_logs_scanned_bytes_sum end |
#sds_rum_scanned_bytes_sum ⇒ Object
Sum of all RUM bytes scanned with sensitive data scanner over all hours in the current date for the given org.
236 237 238 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 236 def sds_rum_scanned_bytes_sum @sds_rum_scanned_bytes_sum end |
#sds_total_scanned_bytes_sum ⇒ Object
Shows the sum of all bytes scanned across all usage types by the Sensitive Data Scanner over all hours in the current month for the given org.
239 240 241 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 239 def sds_total_scanned_bytes_sum @sds_total_scanned_bytes_sum end |
#synthetics_browser_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic browser tests over all hours in the current date for the given org.
242 243 244 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 242 def synthetics_browser_check_calls_count_sum @synthetics_browser_check_calls_count_sum end |
#synthetics_check_calls_count_sum ⇒ Object
Shows the sum of all Synthetic API tests over all hours in the current date for the given org.
245 246 247 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 245 def synthetics_check_calls_count_sum @synthetics_check_calls_count_sum end |
#synthetics_parallel_testing_max_slots_hwm ⇒ Object
Shows the high-water mark of used synthetics parallel testing slots over all hours in the current date for the given org.
248 249 250 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 248 def synthetics_parallel_testing_max_slots_hwm @synthetics_parallel_testing_max_slots_hwm end |
#trace_search_indexed_events_count_sum ⇒ Object
Shows the sum of all Indexed Spans indexed over all hours in the current date for the given org.
251 252 253 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 251 def trace_search_indexed_events_count_sum @trace_search_indexed_events_count_sum end |
#twol_ingested_events_bytes_sum ⇒ Object
Shows the sum of all ingested APM span bytes over all hours in the current date for the given org.
254 255 256 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 254 def twol_ingested_events_bytes_sum @twol_ingested_events_bytes_sum end |
#vsphere_host_top99p ⇒ Object
Shows the 99th percentile of all vSphere hosts over all hours in the current date for the given org.
257 258 259 |
# File 'lib/datadog_api_client/v1/models/usage_summary_date_org.rb', line 257 def vsphere_host_top99p @vsphere_host_top99p end |