Class: DatadogAPIClient::V1::UsageTimeseriesHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageTimeseriesHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_timeseries_hour.rb
Overview
The hourly usage of timeseries.
Instance Attribute Summary collapse
-
#hour ⇒ Object
The hour for the usage.
-
#num_custom_input_timeseries ⇒ Object
Contains the number of custom metrics that are inputs for aggregations (metric configured is custom).
-
#num_custom_output_timeseries ⇒ Object
Contains the number of custom metrics that are outputs for aggregations (metric configured is custom).
-
#num_custom_timeseries ⇒ Object
Contains sum of non-aggregation custom metrics and custom metrics that are outputs for aggregations.
-
#org_name ⇒ Object
The organization name.
-
#public_id ⇒ Object
The organization public ID.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#hour ⇒ Object
The hour for the usage.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_timeseries_hour.rb', line 29 def hour @hour end |
#num_custom_input_timeseries ⇒ Object
Contains the number of custom metrics that are inputs for aggregations (metric configured is custom).
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_timeseries_hour.rb', line 32 def num_custom_input_timeseries @num_custom_input_timeseries end |
#num_custom_output_timeseries ⇒ Object
Contains the number of custom metrics that are outputs for aggregations (metric configured is custom).
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_timeseries_hour.rb', line 35 def num_custom_output_timeseries @num_custom_output_timeseries end |
#num_custom_timeseries ⇒ Object
Contains sum of non-aggregation custom metrics and custom metrics that are outputs for aggregations.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_timeseries_hour.rb', line 38 def num_custom_timeseries @num_custom_timeseries end |
#org_name ⇒ Object
The organization name.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/usage_timeseries_hour.rb', line 41 def org_name @org_name end |
#public_id ⇒ Object
The organization public ID.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/usage_timeseries_hour.rb', line 44 def public_id @public_id end |