Class: DatadogAPIClient::V1::UsageTopAvgMetricsHour
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::UsageTopAvgMetricsHour
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/usage_top_avg_metrics_hour.rb
Overview
Number of hourly recorded custom metrics for a given organization.
Instance Attribute Summary collapse
-
#avg_metric_hour ⇒ Object
Average number of timeseries per hour in which the metric occurs.
-
#max_metric_hour ⇒ Object
Maximum number of timeseries per hour in which the metric occurs.
-
#metric_category ⇒ Object
Contains the metric category.
-
#metric_name ⇒ Object
Contains the custom metric name.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#avg_metric_hour ⇒ Object
Average number of timeseries per hour in which the metric occurs.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_hour.rb', line 29 def avg_metric_hour @avg_metric_hour end |
#max_metric_hour ⇒ Object
Maximum number of timeseries per hour in which the metric occurs.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_hour.rb', line 32 def max_metric_hour @max_metric_hour end |
#metric_category ⇒ Object
Contains the metric category.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_hour.rb', line 35 def metric_category @metric_category end |
#metric_name ⇒ Object
Contains the custom metric name.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/usage_top_avg_metrics_hour.rb', line 38 def metric_name @metric_name end |