Class: DatadogAPIClient::V1::WidgetConditionalFormat
- Inherits:
-
Object
- Object
- DatadogAPIClient::V1::WidgetConditionalFormat
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v1/models/widget_conditional_format.rb
Overview
Define a conditional format for the widget.
Instance Attribute Summary collapse
-
#comparator ⇒ Object
readonly
Comparator to apply.
-
#custom_bg_color ⇒ Object
Color palette to apply to the background, same values available as palette.
-
#custom_fg_color ⇒ Object
Color palette to apply to the foreground, same values available as palette.
-
#hide_value ⇒ Object
True hides values.
-
#image_url ⇒ Object
Displays an image as the background.
-
#metric ⇒ Object
Metric from the request to correlate this conditional format with.
-
#palette ⇒ Object
readonly
Color palette to apply.
-
#timeframe ⇒ Object
Defines the displayed timeframe.
-
#value ⇒ Object
readonly
Value for the comparator.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#comparator ⇒ Object
Comparator to apply.
29 30 31 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 29 def comparator @comparator end |
#custom_bg_color ⇒ Object
Color palette to apply to the background, same values available as palette.
32 33 34 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 32 def custom_bg_color @custom_bg_color end |
#custom_fg_color ⇒ Object
Color palette to apply to the foreground, same values available as palette.
35 36 37 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 35 def custom_fg_color @custom_fg_color end |
#hide_value ⇒ Object
True hides values.
38 39 40 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 38 def hide_value @hide_value end |
#image_url ⇒ Object
Displays an image as the background.
41 42 43 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 41 def image_url @image_url end |
#metric ⇒ Object
Metric from the request to correlate this conditional format with.
44 45 46 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 44 def metric @metric end |
#palette ⇒ Object
Color palette to apply.
47 48 49 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 47 def palette @palette end |
#timeframe ⇒ Object
Defines the displayed timeframe.
50 51 52 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 50 def timeframe @timeframe end |
#value ⇒ Object
Value for the comparator.
53 54 55 |
# File 'lib/datadog_api_client/v1/models/widget_conditional_format.rb', line 53 def value @value end |