Class: DatadogAPIClient::V2::AgentTrigger
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::AgentTrigger
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/agent_trigger.rb
Overview
Trigger a workflow from an agent via the MCP execute tool. Workflow can be executed from Bits Chat, Bits Agent Builder, Claude Code, Codex, Cursor, and any other coding agent using the Datadog MCP.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#rate_limit ⇒ Object
Defines a rate limit for a trigger.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/agent_trigger.rb', line 27 def additional_properties @additional_properties end |
#rate_limit ⇒ Object
Defines a rate limit for a trigger.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/agent_trigger.rb', line 25 def rate_limit @rate_limit end |