Class: DatadogAPIClient::V2::ApmResourceStatsQuery
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ApmResourceStatsQuery
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/apm_resource_stats_query.rb
Overview
A query for APM resource statistics such as latency, error rate, and hit count, grouped by resource name.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#data_source ⇒ Object
readonly
A data source for APM resource statistics queries.
-
#env ⇒ Object
readonly
The environment to query.
-
#group_by ⇒ Object
Tag keys to group results by.
-
#name ⇒ Object
readonly
The variable name for use in formulas.
-
#operation_name ⇒ Object
The APM operation name.
-
#primary_tag_name ⇒ Object
Name of the second primary tag used within APM.
-
#primary_tag_value ⇒ Object
Value of the second primary tag by which to filter APM data.
-
#resource_name ⇒ Object
The resource name to filter by.
-
#service ⇒ Object
readonly
The service name to filter by.
-
#stat ⇒ Object
readonly
The APM resource statistic to query.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 54 def additional_properties @additional_properties end |
#data_source ⇒ Object
A data source for APM resource statistics queries.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 25 def data_source @data_source end |
#env ⇒ Object
The environment to query.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 28 def env @env end |
#group_by ⇒ Object
Tag keys to group results by.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 31 def group_by @group_by end |
#name ⇒ Object
The variable name for use in formulas.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 34 def name @name end |
#operation_name ⇒ Object
The APM operation name.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 37 def operation_name @operation_name end |
#primary_tag_name ⇒ Object
Name of the second primary tag used within APM. Required when ‘primary_tag_value` is specified. See docs.datadoghq.com/tracing/guide/setting_primary_tags_to_scope/#add-a-second-primary-tag-in-datadog
40 41 42 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 40 def primary_tag_name @primary_tag_name end |
#primary_tag_value ⇒ Object
Value of the second primary tag by which to filter APM data. ‘primary_tag_name` must also be specified.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 43 def primary_tag_value @primary_tag_value end |
#resource_name ⇒ Object
The resource name to filter by.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 46 def resource_name @resource_name end |
#service ⇒ Object
The service name to filter by.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 49 def service @service end |
#stat ⇒ Object
The APM resource statistic to query.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/apm_resource_stats_query.rb', line 52 def stat @stat end |