Class: DatadogAPIClient::V2::CIAppEventAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CIAppEventAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/ci_app_event_attributes.rb
Overview
JSON object containing all event attributes and their associated values.
Instance Attribute Summary collapse
-
#attributes ⇒ Object
JSON object of attributes from CI Visibility events.
-
#service ⇒ Object
The name of the application or service generating CI Visibility events.
-
#tags ⇒ Object
Array of tags associated with your event.
-
#timestamp ⇒ Object
Timestamp of your event.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#attributes ⇒ Object
JSON object of attributes from CI Visibility events.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 29 def attributes @attributes end |
#service ⇒ Object
The name of the application or service generating CI Visibility events. It is used to switch from CI Visibility to APM, so make sure you define the same value when you use both products.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 34 def service @service end |
#tags ⇒ Object
Array of tags associated with your event.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 37 def end |
#timestamp ⇒ Object
Timestamp of your event.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/ci_app_event_attributes.rb', line 40 def end |