Class: DatadogAPIClient::V2::CIAppPipelineEventInProgressJob
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CIAppPipelineEventInProgressJob
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb
Overview
Details of a running CI job.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#dependencies ⇒ Object
A list of job IDs that this job depends on.
-
#error ⇒ Object
Contains information of the CI error.
-
#git ⇒ Object
If pipelines are triggered due to actions to a Git repository, then all payloads must contain this.
-
#id ⇒ Object
readonly
The UUID for the job.
-
#level ⇒ Object
readonly
Used to distinguish between pipelines, stages, jobs, and steps.
-
#metrics ⇒ Object
A list of user-defined metrics.
-
#name ⇒ Object
readonly
The name for the job.
-
#node ⇒ Object
Contains information of the host running the pipeline, stage, job, or step.
-
#parameters ⇒ Object
A map of key-value parameters or environment variables that were defined for the pipeline.
-
#pipeline_name ⇒ Object
readonly
The parent pipeline name.
-
#pipeline_unique_id ⇒ Object
readonly
The parent pipeline UUID.
-
#queue_time ⇒ Object
readonly
The queue time in milliseconds, if applicable.
-
#stage_id ⇒ Object
The parent stage UUID (if applicable).
-
#stage_name ⇒ Object
The parent stage name (if applicable).
-
#start ⇒ Object
readonly
Time when the job run instance started (it should not include any queue time).
-
#status ⇒ Object
readonly
The in-progress status of the job.
-
#tags ⇒ Object
A list of user-defined tags.
-
#url ⇒ Object
readonly
The URL to look at the job in the CI provider UI.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
80 81 82 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 80 def additional_properties @additional_properties end |
#dependencies ⇒ Object
A list of job IDs that this job depends on.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 25 def dependencies @dependencies end |
#error ⇒ Object
Contains information of the CI error.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 28 def error @error end |
#git ⇒ Object
If pipelines are triggered due to actions to a Git repository, then all payloads must contain this.
Note that either tag or branch has to be provided, but not both.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 32 def git @git end |
#id ⇒ Object
The UUID for the job. It must match the ID of the corresponding finished job.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 35 def id @id end |
#level ⇒ Object
Used to distinguish between pipelines, stages, jobs, and steps.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 38 def level @level end |
#metrics ⇒ Object
A list of user-defined metrics. The metrics must follow the key:value pattern and the value must be numeric.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 41 def metrics @metrics end |
#name ⇒ Object
The name for the job.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 44 def name @name end |
#node ⇒ Object
Contains information of the host running the pipeline, stage, job, or step.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 47 def node @node end |
#parameters ⇒ Object
A map of key-value parameters or environment variables that were defined for the pipeline.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 50 def parameters @parameters end |
#pipeline_name ⇒ Object
The parent pipeline name.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 53 def pipeline_name @pipeline_name end |
#pipeline_unique_id ⇒ Object
The parent pipeline UUID.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 56 def pipeline_unique_id @pipeline_unique_id end |
#queue_time ⇒ Object
The queue time in milliseconds, if applicable.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 59 def queue_time @queue_time end |
#stage_id ⇒ Object
The parent stage UUID (if applicable).
62 63 64 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 62 def stage_id @stage_id end |
#stage_name ⇒ Object
The parent stage name (if applicable).
65 66 67 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 65 def stage_name @stage_name end |
#start ⇒ Object
Time when the job run instance started (it should not include any queue time). The time format must be RFC3339.
69 70 71 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 69 def start @start end |
#status ⇒ Object
The in-progress status of the job.
72 73 74 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 72 def status @status end |
#tags ⇒ Object
A list of user-defined tags. The tags must follow the key:value pattern.
75 76 77 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 75 def @tags end |
#url ⇒ Object
The URL to look at the job in the CI provider UI.
78 79 80 |
# File 'lib/datadog_api_client/v2/models/ci_app_pipeline_event_in_progress_job.rb', line 78 def url @url end |