Class: DatadogAPIClient::V2::CloudWorkloadSecurityAgentRuleAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CloudWorkloadSecurityAgentRuleAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb
Overview
A Cloud Workload Security Agent rule returned by the API.
Instance Attribute Summary collapse
-
#category ⇒ Object
The category of the Agent rule.
-
#creation_date ⇒ Object
When the Agent rule was created, timestamp in milliseconds.
-
#creator ⇒ Object
The attributes of the user who created the Agent rule.
-
#default_rule ⇒ Object
Whether the rule is included by default.
-
#description ⇒ Object
The description of the Agent rule.
-
#enabled ⇒ Object
Whether the Agent rule is enabled.
-
#expression ⇒ Object
The SECL expression of the Agent rule.
-
#name ⇒ Object
The name of the Agent rule.
-
#updated_at ⇒ Object
When the Agent rule was last updated, timestamp in milliseconds.
-
#updater ⇒ Object
The attributes of the user who last updated the Agent rule.
-
#version ⇒ Object
The version of the Agent rule.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#category ⇒ Object
The category of the Agent rule.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 29 def category @category end |
#creation_date ⇒ Object
When the Agent rule was created, timestamp in milliseconds.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 32 def creation_date @creation_date end |
#creator ⇒ Object
The attributes of the user who created the Agent rule.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 35 def creator @creator end |
#default_rule ⇒ Object
Whether the rule is included by default.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 38 def default_rule @default_rule end |
#description ⇒ Object
The description of the Agent rule.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 41 def description @description end |
#enabled ⇒ Object
Whether the Agent rule is enabled.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 44 def enabled @enabled end |
#expression ⇒ Object
The SECL expression of the Agent rule.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 47 def expression @expression end |
#name ⇒ Object
The name of the Agent rule.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 50 def name @name end |
#updated_at ⇒ Object
When the Agent rule was last updated, timestamp in milliseconds.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 53 def updated_at @updated_at end |
#updater ⇒ Object
The attributes of the user who last updated the Agent rule.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 56 def updater @updater end |
#version ⇒ Object
The version of the Agent rule.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/cloud_workload_security_agent_rule_attributes.rb', line 59 def version @version end |