Class: DatadogAPIClient::V2::ComplianceAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ComplianceAPI
- Defined in:
- lib/datadog_api_client/v2/api/compliance_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_rule_based_view(to, opts = {}) ⇒ Object
Get the rule-based view of compliance findings.
-
#get_rule_based_view_with_http_info(to, opts = {}) ⇒ Array<(RuleBasedViewResponse, Integer, Hash)>
Get the rule-based view of compliance findings.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ ComplianceAPI
constructor
A new instance of ComplianceAPI.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ ComplianceAPI
Returns a new instance of ComplianceAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/compliance_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/compliance_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#get_rule_based_view(to, opts = {}) ⇒ Object
Get the rule-based view of compliance findings.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/compliance_api.rb', line 29 def get_rule_based_view(to, opts = {}) data, _status_code, _headers = get_rule_based_view_with_http_info(to, opts) data end |
#get_rule_based_view_with_http_info(to, opts = {}) ⇒ Array<(RuleBasedViewResponse, Integer, Hash)>
Get the rule-based view of compliance findings.
Get an aggregated view of compliance rules with their pass, fail, and muted finding counts. Supports filtering by compliance framework, framework version, and additional query filters.
48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/datadog_api_client/v2/api/compliance_api.rb', line 48 def get_rule_based_view_with_http_info(to, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.get_rule_based_view".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.get_rule_based_view") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.get_rule_based_view")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ComplianceAPI.get_rule_based_view ...' end # verify the required parameter 'to' is set if @api_client.config.client_side_validation && to.nil? fail ArgumentError, "Missing the required parameter 'to' when calling ComplianceAPI.get_rule_based_view" end # resource path local_var_path = '/api/v2/compliance_findings/rule_based_view' # query parameters query_params = opts[:query_params] || {} query_params[:'to'] = to query_params[:'framework'] = opts[:'framework'] if !opts[:'framework'].nil? query_params[:'version'] = opts[:'version'] if !opts[:'version'].nil? query_params[:'query_findings_without_framework_version'] = opts[:'query_findings_without_framework_version'] if !opts[:'query_findings_without_framework_version'].nil? query_params[:'include_rules_without_findings'] = opts[:'include_rules_without_findings'] if !opts[:'include_rules_without_findings'].nil? query_params[:'is_custom'] = opts[:'is_custom'] if !opts[:'is_custom'].nil? query_params[:'query'] = opts[:'query'] if !opts[:'query'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RuleBasedViewResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :get_rule_based_view, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ComplianceAPI#get_rule_based_view\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |