Class: DatadogAPIClient::V2::ControlNotificationEventSetting
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ControlNotificationEventSetting
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/control_notification_event_setting.rb
Overview
The notification settings for a single event type on a control.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#enabled ⇒ Object
readonly
Whether notifications are enabled for this event type.
-
#event_type ⇒ Object
readonly
The event type the notification settings apply to, such as
new_detection. -
#targets ⇒ Object
readonly
The destinations that receive notifications for an event type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 33 def additional_properties @additional_properties end |
#enabled ⇒ Object
Whether notifications are enabled for this event type.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 25 def enabled @enabled end |
#event_type ⇒ Object
The event type the notification settings apply to, such as new_detection.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 28 def event_type @event_type end |
#targets ⇒ Object
The destinations that receive notifications for an event type.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/control_notification_event_setting.rb', line 31 def targets @targets end |