Class: DatadogAPIClient::V2::CostAnomaly
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CostAnomaly
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cost_anomaly.rb
Overview
A single detected Cloud Cost Management anomaly.
Instance Attribute Summary collapse
-
#actual_cost ⇒ Object
readonly
Actual cost incurred during the anomaly window.
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#anomalous_cost_change ⇒ Object
readonly
Anomalous cost change relative to the expected baseline.
-
#anomaly_end ⇒ Object
readonly
Anomaly end timestamp in Unix milliseconds.
-
#anomaly_start ⇒ Object
readonly
Anomaly start timestamp in Unix milliseconds.
-
#correlated_tags ⇒ Object
Map of correlated tag keys to the list of correlated tag values.
-
#dimensions ⇒ Object
readonly
Map of cost dimension keys to their values for the anomaly grouping.
-
#dismissal ⇒ Object
Resolution metadata for an anomaly that has been dismissed.
-
#max_cost ⇒ Object
readonly
Maximum cost observed during the anomaly window.
-
#provider ⇒ Object
readonly
Cloud or SaaS provider associated with the anomaly (for example ‘aws`, `gcp`, `azure`).
-
#query ⇒ Object
readonly
The metrics query that detected the anomaly.
-
#uuid ⇒ Object
readonly
The unique identifier of the anomaly.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#actual_cost ⇒ Object
Actual cost incurred during the anomaly window.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 25 def actual_cost @actual_cost end |
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
57 58 59 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 57 def additional_properties @additional_properties end |
#anomalous_cost_change ⇒ Object
Anomalous cost change relative to the expected baseline.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 28 def anomalous_cost_change @anomalous_cost_change end |
#anomaly_end ⇒ Object
Anomaly end timestamp in Unix milliseconds.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 31 def anomaly_end @anomaly_end end |
#anomaly_start ⇒ Object
Anomaly start timestamp in Unix milliseconds.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 34 def anomaly_start @anomaly_start end |
#correlated_tags ⇒ Object
Map of correlated tag keys to the list of correlated tag values.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 37 def @correlated_tags end |
#dimensions ⇒ Object
Map of cost dimension keys to their values for the anomaly grouping.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 40 def dimensions @dimensions end |
#dismissal ⇒ Object
Resolution metadata for an anomaly that has been dismissed.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 43 def dismissal @dismissal end |
#max_cost ⇒ Object
Maximum cost observed during the anomaly window.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 46 def max_cost @max_cost end |
#provider ⇒ Object
Cloud or SaaS provider associated with the anomaly (for example ‘aws`, `gcp`, `azure`).
49 50 51 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 49 def provider @provider end |
#query ⇒ Object
The metrics query that detected the anomaly.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 52 def query @query end |
#uuid ⇒ Object
The unique identifier of the anomaly.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/cost_anomaly.rb', line 55 def uuid @uuid end |