Class: DatadogAPIClient::V2::CostTagDescription
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CostTagDescription
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cost_tag_description.rb
Overview
A Cloud Cost Management tag key description, either cross-cloud or scoped to a single cloud provider.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#attributes ⇒ Object
readonly
Human-readable description and metadata attached to a Cloud Cost Management tag key, optionally scoped to a single cloud provider.
-
#id ⇒ Object
readonly
Stable identifier of the tag description.
-
#type ⇒ Object
readonly
Type of the Cloud Cost Management tag description resource.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description.rb', line 33 def additional_properties @additional_properties end |
#attributes ⇒ Object
Human-readable description and metadata attached to a Cloud Cost Management tag key, optionally scoped to a single cloud provider.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description.rb', line 25 def attributes @attributes end |
#id ⇒ Object
Stable identifier of the tag description. Equals the tag key when the description is the cross-cloud default; encodes both the cloud and the tag key when the description is cloud-specific.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description.rb', line 28 def id @id end |
#type ⇒ Object
Type of the Cloud Cost Management tag description resource.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description.rb', line 31 def type @type end |