Class: DatadogAPIClient::V2::CostTagDescriptionAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CostTagDescriptionAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb
Overview
Human-readable description and metadata attached to a Cloud Cost Management tag key, optionally scoped to a single cloud provider.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#cloud ⇒ Object
readonly
Cloud provider this description applies to (for example, ‘aws`).
-
#created_at ⇒ Object
readonly
Timestamp when the description was created, in RFC 3339 format.
-
#description ⇒ Object
readonly
The human-readable description for the tag key.
-
#source ⇒ Object
readonly
Origin of the description.
-
#tag_key ⇒ Object
readonly
The tag key this description applies to.
-
#updated_at ⇒ Object
readonly
Timestamp when the description was last updated, in RFC 3339 format.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 42 def additional_properties @additional_properties end |
#cloud ⇒ Object
Cloud provider this description applies to (for example, ‘aws`). Empty when the description is the cross-cloud default for the tag key.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 25 def cloud @cloud end |
#created_at ⇒ Object
Timestamp when the description was created, in RFC 3339 format.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 28 def created_at @created_at end |
#description ⇒ Object
The human-readable description for the tag key.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 31 def description @description end |
#source ⇒ Object
Origin of the description. ‘human` indicates the description was written by a user, `ai_generated` was produced by AI, and `datadog` is a default supplied by Datadog.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 34 def source @source end |
#tag_key ⇒ Object
The tag key this description applies to.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 37 def tag_key @tag_key end |
#updated_at ⇒ Object
Timestamp when the description was last updated, in RFC 3339 format.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/cost_tag_description_attributes.rb', line 40 def updated_at @updated_at end |