Class: DatadogAPIClient::V2::CustomDestinationResponseForwardDestinationSplunk
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::CustomDestinationResponseForwardDestinationSplunk
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/custom_destination_response_forward_destination_splunk.rb
Overview
The Splunk HTTP Event Collector (HEC) destination.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#endpoint ⇒ Object
readonly
The destination for which logs will be forwarded to.
-
#sourcetype ⇒ Object
The Splunk sourcetype for the events sent to this Splunk destination.
-
#type ⇒ Object
readonly
Type of the Splunk HTTP Event Collector (HEC) destination.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/custom_destination_response_forward_destination_splunk.rb', line 39 def additional_properties @additional_properties end |
#endpoint ⇒ Object
The destination for which logs will be forwarded to. Must have HTTPS scheme and forwarding back to Datadog is not allowed.
26 27 28 |
# File 'lib/datadog_api_client/v2/models/custom_destination_response_forward_destination_splunk.rb', line 26 def endpoint @endpoint end |
#sourcetype ⇒ Object
The Splunk sourcetype for the events sent to this Splunk destination.
If the field is absent from the request and no sourcetype has been previously set on this destination, the default sourcetype ‘_json` is used. On update, if the field is absent from the request but a sourcetype was previously set, the previous value is kept. If set to `null`, the sourcetype field is omitted from the forwarded event entirely. Otherwise, the provided string value is used as the sourcetype.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/custom_destination_response_forward_destination_splunk.rb', line 34 def sourcetype @sourcetype end |
#type ⇒ Object
Type of the Splunk HTTP Event Collector (HEC) destination.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/custom_destination_response_forward_destination_splunk.rb', line 37 def type @type end |