Class: DatadogAPIClient::V2::DORADeploymentPatchByVersionRequestAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DORADeploymentPatchByVersionRequestAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb
Overview
Attributes for patching a DORA deployment event identified by service, environment, and version.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#change_failure ⇒ Object
readonly
Indicates whether the deployment resulted in a change failure.
-
#env ⇒ Object
readonly
The environment the deployment was performed in.
-
#remediation ⇒ Object
Remediation details for the deployment.
-
#service ⇒ Object
readonly
The name of the service that was deployed.
-
#version ⇒ Object
readonly
The version deployed.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb', line 39 def additional_properties @additional_properties end |
#change_failure ⇒ Object
Indicates whether the deployment resulted in a change failure.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb', line 25 def change_failure @change_failure end |
#env ⇒ Object
The environment the deployment was performed in.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb', line 28 def env @env end |
#remediation ⇒ Object
Remediation details for the deployment. Optional, but required to calculate failed deployment recovery time. Specify either id or version to identify the remediation deployment, but not both.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb', line 31 def remediation @remediation end |
#service ⇒ Object
The name of the service that was deployed.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb', line 34 def service @service end |
#version ⇒ Object
The version deployed. This can be seen in the Service Catalog or in the APM Deployment Tracking.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_by_version_request_attributes.rb', line 37 def version @version end |