Class: DatadogAPIClient::V2::DORADeploymentPatchRemediation
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DORADeploymentPatchRemediation
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/dora_deployment_patch_remediation.rb
Overview
Remediation details for the deployment. Optional, but required to calculate failed deployment recovery time. Specify either id or version to identify the remediation deployment, but not both.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#id ⇒ Object
The ID of the remediation deployment.
-
#type ⇒ Object
The type of remediation action taken.
-
#version ⇒ Object
The version of the remediation deployment, matched against the same service and environment as the failed deployment.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_remediation.rb', line 33 def additional_properties @additional_properties end |
#id ⇒ Object
The ID of the remediation deployment. Use this or version to identify the remediation deployment, but not both.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_remediation.rb', line 25 def id @id end |
#type ⇒ Object
The type of remediation action taken. Required when the failed deployment must be linked to a remediation deployment.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_remediation.rb', line 28 def type @type end |
#version ⇒ Object
The version of the remediation deployment, matched against the same service and environment as the failed deployment. Use this or id to identify the remediation deployment, but not both.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/dora_deployment_patch_remediation.rb', line 31 def version @version end |