Class: DatadogAPIClient::V2::DashboardListUpdateItemsRequest
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DashboardListUpdateItemsRequest
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/dashboard_list_update_items_request.rb
Overview
Request containing the list of dashboards to update to.
Instance Attribute Summary collapse
-
#dashboards ⇒ Object
List of dashboards to update the dashboard list to.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#dashboards ⇒ Object
List of dashboards to update the dashboard list to.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/dashboard_list_update_items_request.rb', line 29 def dashboards @dashboards end |