Class: DatadogAPIClient::V2::DeploymentGatesEvaluationConfiguration
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DeploymentGatesEvaluationConfiguration
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/deployment_gates_evaluation_configuration.rb
Overview
Inline rule definitions for a deployment gate evaluation. When provided, rules are evaluated directly from this configuration instead of using the preconfigured gate rules. At least one rule is required.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#dry_run ⇒ Object
Gate-level dry run.
-
#rules ⇒ Object
readonly
The list of rules to evaluate.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_configuration.rb', line 32 def additional_properties @additional_properties end |
#dry_run ⇒ Object
Gate-level dry run. When enabled, the rules are evaluated normally but the gate always returns ‘pass`. The real result is visible in the Datadog UI.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_configuration.rb', line 27 def dry_run @dry_run end |
#rules ⇒ Object
The list of rules to evaluate. At least one rule is required.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_configuration.rb', line 30 def rules @rules end |