Class: DatadogAPIClient::V2::DeploymentGatesEvaluationRequestAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::DeploymentGatesEvaluationRequestAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb
Overview
Attributes for a deployment gate evaluation request. When ‘configuration` is provided, rules are evaluated inline from that configuration. When omitted, rules are resolved from the preconfigured gate for the given service and environment.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#configuration ⇒ Object
Inline rule definitions for a deployment gate evaluation.
-
#env ⇒ Object
readonly
The environment of the deployment.
-
#identifier ⇒ Object
The identifier of the deployment gate.
-
#primary_tag ⇒ Object
A primary tag to scope APM Faulty Deployment Detection rules.
-
#service ⇒ Object
readonly
The service being deployed.
-
#version ⇒ Object
The version of the deployment.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 46 def additional_properties @additional_properties end |
#configuration ⇒ Object
Inline rule definitions for a deployment gate evaluation. When provided, rules are evaluated directly from this configuration instead of using the preconfigured gate rules. At least one rule is required.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 29 def configuration @configuration end |
#env ⇒ Object
The environment of the deployment.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 32 def env @env end |
#identifier ⇒ Object
The identifier of the deployment gate. Defaults to “default”.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 35 def identifier @identifier end |
#primary_tag ⇒ Object
A primary tag to scope APM Faulty Deployment Detection rules.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 38 def primary_tag @primary_tag end |
#service ⇒ Object
The service being deployed.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 41 def service @service end |
#version ⇒ Object
The version of the deployment. Required for APM Faulty Deployment Detection rules.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/deployment_gates_evaluation_request_attributes.rb', line 44 def version @version end |