Class: DatadogAPIClient::V2::EventAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::EventAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/event_attributes.rb
Overview
Object description of attributes from your event.
Instance Attribute Summary collapse
-
#aggregation_key ⇒ Object
Aggregation key of the event.
-
#date_happened ⇒ Object
POSIX timestamp of the event.
-
#device_name ⇒ Object
A device name.
-
#duration ⇒ Object
The duration between the triggering of the event and its recovery in nanoseconds.
-
#event_object ⇒ Object
The event title.
-
#evt ⇒ Object
The metadata associated with a request.
-
#hostname ⇒ Object
Host name to associate with the event.
-
#monitor ⇒ Object
Attributes from the monitor that triggered the event.
-
#monitor_groups ⇒ Object
List of groups referred to in the event.
-
#monitor_id ⇒ Object
ID of the monitor that triggered the event.
-
#priority ⇒ Object
The priority of the event’s monitor.
-
#related_event_id ⇒ Object
Related event ID.
-
#service ⇒ Object
Service that triggered the event.
-
#source_type_name ⇒ Object
The type of event being posted.
-
#sourcecategory ⇒ Object
Identifier for the source of the event, such as a monitor alert, an externally-submitted event, or an integration.
-
#status ⇒ Object
If an alert event is enabled, its status is one of the following:
failure,error,warning,info,success,user_update,recommendation, orsnapshot. -
#tags ⇒ Object
A list of tags to apply to the event.
-
#timestamp ⇒ Object
POSIX timestamp of your event in milliseconds.
-
#title ⇒ Object
The event title.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#aggregation_key ⇒ Object
Aggregation key of the event.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 29 def aggregation_key @aggregation_key end |
#date_happened ⇒ Object
POSIX timestamp of the event. Must be sent as an integer (no quotation marks). Limited to events no older than 18 hours.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 33 def date_happened @date_happened end |
#device_name ⇒ Object
A device name.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 36 def device_name @device_name end |
#duration ⇒ Object
The duration between the triggering of the event and its recovery in nanoseconds.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 39 def duration @duration end |
#event_object ⇒ Object
The event title.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 42 def event_object @event_object end |
#evt ⇒ Object
The metadata associated with a request.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 45 def evt @evt end |
#hostname ⇒ Object
Host name to associate with the event. Any tags associated with the host are also applied to this event.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 49 def hostname @hostname end |
#monitor ⇒ Object
Attributes from the monitor that triggered the event.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 52 def monitor @monitor end |
#monitor_groups ⇒ Object
List of groups referred to in the event.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 55 def monitor_groups @monitor_groups end |
#monitor_id ⇒ Object
ID of the monitor that triggered the event. When an event isn’t related to a monitor, this field is empty.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 58 def monitor_id @monitor_id end |
#priority ⇒ Object
The priority of the event’s monitor. For example, normal or low.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 61 def priority @priority end |
#related_event_id ⇒ Object
Related event ID.
64 65 66 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 64 def @related_event_id end |
#service ⇒ Object
Service that triggered the event.
67 68 69 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 67 def service @service end |
#source_type_name ⇒ Object
The type of event being posted. For example, nagios, hudson, jenkins, my_apps, chef, puppet, git or bitbucket. The list of standard source attribute values is [available here](docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value).
72 73 74 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 72 def source_type_name @source_type_name end |
#sourcecategory ⇒ Object
Identifier for the source of the event, such as a monitor alert, an externally-submitted event, or an integration.
75 76 77 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 75 def sourcecategory @sourcecategory end |
#status ⇒ Object
If an alert event is enabled, its status is one of the following: failure, error, warning, info, success, user_update, recommendation, or snapshot.
80 81 82 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 80 def status @status end |
#tags ⇒ Object
A list of tags to apply to the event.
83 84 85 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 83 def @tags end |
#timestamp ⇒ Object
POSIX timestamp of your event in milliseconds.
86 87 88 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 86 def @timestamp end |
#title ⇒ Object
The event title.
89 90 91 |
# File 'lib/datadog_api_client/v2/models/event_attributes.rb', line 89 def title @title end |