Class: DatadogAPIClient::V2::EventsAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::EventsAPI
- Defined in:
- lib/datadog_api_client/v2/api/events_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ EventsAPI
constructor
A new instance of EventsAPI.
-
#list_events(opts = {}) ⇒ Object
Get a list of events.
-
#list_events_with_http_info(opts = {}) ⇒ Array<(EventsListResponse, Integer, Hash)>
Get a list of events.
-
#list_events_with_pagination(opts = {}) {|EventResponse| ... } ⇒ Object
Get a list of events.
-
#search_events(opts = {}) ⇒ Object
Search events.
-
#search_events_with_http_info(opts = {}) ⇒ Array<(EventsListResponse, Integer, Hash)>
Search events.
-
#search_events_with_pagination(opts = {}) {|EventResponse| ... } ⇒ Object
Search events.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ EventsAPI
Returns a new instance of EventsAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#list_events(opts = {}) ⇒ Object
Get a list of events.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 29 def list_events(opts = {}) data, _status_code, _headers = list_events_with_http_info(opts) data end |
#list_events_with_http_info(opts = {}) ⇒ Array<(EventsListResponse, Integer, Hash)>
Get a list of events.
List endpoint returns events that match an events search query. [Results are paginated similarly to logs](docs.datadoghq.com/logs/guide/collect-multiple-logs-with-pagination).
Use this endpoint to see your latest events.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 49 def list_events_with_http_info(opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.list_events".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.list_events") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.list_events")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsAPI.list_events ...' end allowable_values = ['timestamp', '-timestamp'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end if @api_client.config.client_side_validation && !opts[:'page_limit'].nil? && opts[:'page_limit'] > 1000 fail ArgumentError, 'invalid value for "opts[:"page_limit"]" when calling EventsAPI.list_events, must be smaller than or equal to 1000.' end # resource path local_var_path = '/api/v2/events' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[query]'] = opts[:'filter_query'] if !opts[:'filter_query'].nil? query_params[:'filter[from]'] = opts[:'filter_from'] if !opts[:'filter_from'].nil? query_params[:'filter[to]'] = opts[:'filter_to'] if !opts[:'filter_to'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'page[cursor]'] = opts[:'page_cursor'] if !opts[:'page_cursor'].nil? query_params[:'page[limit]'] = opts[:'page_limit'] if !opts[:'page_limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'EventsListResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :list_events, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsAPI#list_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_events_with_pagination(opts = {}) {|EventResponse| ... } ⇒ Object
Get a list of events.
Provide a paginated version of #list_events, returning all items.
To use it you need to use a block: list_events_with_pagination { |item| p item }
121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 121 def list_events_with_pagination(opts = {}) api_version = "V2" page_size = @api_client.get_attribute_from_path(opts, "page_limit", 10) @api_client.set_attribute_from_path(api_version, opts, "page_limit", Integer, page_size) while true do response = list_events(opts) @api_client.get_attribute_from_path(response, "data").each { |item| yield(item) } if @api_client.get_attribute_from_path(response, "data").length < page_size break end @api_client.set_attribute_from_path(api_version, opts, "page_cursor", Integer, @api_client.get_attribute_from_path(response, "meta.page.after")) end end |
#search_events(opts = {}) ⇒ Object
Search events.
138 139 140 141 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 138 def search_events(opts = {}) data, _status_code, _headers = search_events_with_http_info(opts) data end |
#search_events_with_http_info(opts = {}) ⇒ Array<(EventsListResponse, Integer, Hash)>
Search events.
List endpoint returns events that match an events search query. [Results are paginated similarly to logs](docs.datadoghq.com/logs/guide/collect-multiple-logs-with-pagination).
Use this endpoint to build complex events filtering and search.
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 153 def search_events_with_http_info(opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.search_events".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.search_events") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.search_events")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: EventsAPI.search_events ...' end # resource path local_var_path = '/api/v2/events/search' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'body']) # return_type return_type = opts[:debug_return_type] || 'EventsListResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :search_events, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: EventsAPI#search_events\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#search_events_with_pagination(opts = {}) {|EventResponse| ... } ⇒ Object
Search events.
Provide a paginated version of #search_events, returning all items.
To use it you need to use a block: search_events_with_pagination { |item| p item }
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/datadog_api_client/v2/api/events_api.rb', line 214 def search_events_with_pagination(opts = {}) api_version = "V2" page_size = @api_client.get_attribute_from_path(opts, "body.page.limit", 10) @api_client.set_attribute_from_path(api_version, opts, "body.page.limit", EventsListRequest, page_size) while true do response = search_events(opts) @api_client.get_attribute_from_path(response, "data").each { |item| yield(item) } if @api_client.get_attribute_from_path(response, "data").length < page_size break end @api_client.set_attribute_from_path(api_version, opts, "body.page.cursor", EventsListRequest, @api_client.get_attribute_from_path(response, "meta.page.after")) end end |