Class: DatadogAPIClient::V2::FleetAgentV2Attributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetAgentV2Attributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb
Overview
Attributes of a Datadog Agent in the v2 list response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#agent_version ⇒ Object
The Datadog Agent version.
-
#api_key_name ⇒ Object
The name of the API key used by the agent, if available and not redacted.
-
#api_key_uuid ⇒ Object
The UUID of the API key used by the agent.
-
#cloud_provider ⇒ Object
The cloud provider where the agent is running.
-
#cluster_name ⇒ Object
The Kubernetes cluster name, if the agent runs in a cluster.
-
#datadog_data_center ⇒ Object
The Datadog data center the agent reports to.
-
#ecs_fargate_cluster_name ⇒ Object
The ECS Fargate cluster name, if the agent runs in an ECS Fargate environment.
-
#ecs_fargate_task_arn ⇒ Object
The ECS Fargate task ARN, if the agent runs in an ECS Fargate environment.
-
#enabled_products ⇒ Object
Datadog products enabled on the agent.
-
#env ⇒ Object
Environments the agent is reporting from.
-
#first_seen_at ⇒ Object
Unix timestamp when the agent was first seen.
-
#fleet_policies ⇒ Object
Identifiers of fleet policies applied to the agent.
-
#hostname ⇒ Object
The hostname of the agent.
-
#instrumentation_error_counts ⇒ Object
Number of instrumentation errors on the agent.
-
#instrumentation_status ⇒ Object
The single-step instrumentation status of the Agent.
-
#integrations ⇒ Object
Names of integrations configured on the agent.
-
#ip_addresses ⇒ Object
IP addresses of the agent host.
-
#is_single_step_instrumentation_enabled ⇒ Object
Whether single-step instrumentation is enabled on the agent.
-
#last_restart_at ⇒ Object
Unix timestamp of the last agent restart.
-
#os ⇒ Object
The operating system of the host.
-
#otel_collector_deployment_types ⇒ Object
OpenTelemetry collector deployment types associated with the agent.
-
#otel_collector_distributions ⇒ Object
OpenTelemetry collector distributions associated with the agent.
-
#otel_collector_versions ⇒ Object
All OpenTelemetry collector versions associated with the agent.
-
#otel_resource_attributes ⇒ Object
OpenTelemetry resource attributes reported by the agent.
-
#pod_name ⇒ Object
The Kubernetes pod name, if the agent runs as a pod.
-
#remote_agent_management ⇒ Object
The remote agent management status.
-
#remote_config_status ⇒ Object
The remote configuration connection status of the agent.
-
#services ⇒ Object
Services running on the agent.
-
#tags ⇒ Object
Tags associated with the agent.
-
#team ⇒ Object
The team associated with the agent.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
114 115 116 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 114 def additional_properties @additional_properties end |
#agent_version ⇒ Object
The Datadog Agent version.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 25 def agent_version @agent_version end |
#api_key_name ⇒ Object
The name of the API key used by the agent, if available and not redacted.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 28 def api_key_name @api_key_name end |
#api_key_uuid ⇒ Object
The UUID of the API key used by the agent.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 31 def api_key_uuid @api_key_uuid end |
#cloud_provider ⇒ Object
The cloud provider where the agent is running.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 34 def cloud_provider @cloud_provider end |
#cluster_name ⇒ Object
The Kubernetes cluster name, if the agent runs in a cluster.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 37 def cluster_name @cluster_name end |
#datadog_data_center ⇒ Object
The Datadog data center the agent reports to.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 40 def datadog_data_center @datadog_data_center end |
#ecs_fargate_cluster_name ⇒ Object
The ECS Fargate cluster name, if the agent runs in an ECS Fargate environment.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 43 def ecs_fargate_cluster_name @ecs_fargate_cluster_name end |
#ecs_fargate_task_arn ⇒ Object
The ECS Fargate task ARN, if the agent runs in an ECS Fargate environment.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 46 def ecs_fargate_task_arn @ecs_fargate_task_arn end |
#enabled_products ⇒ Object
Datadog products enabled on the agent.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 49 def enabled_products @enabled_products end |
#env ⇒ Object
Environments the agent is reporting from.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 52 def env @env end |
#first_seen_at ⇒ Object
Unix timestamp when the agent was first seen.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 55 def first_seen_at @first_seen_at end |
#fleet_policies ⇒ Object
Identifiers of fleet policies applied to the agent.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 58 def fleet_policies @fleet_policies end |
#hostname ⇒ Object
The hostname of the agent.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 61 def hostname @hostname end |
#instrumentation_error_counts ⇒ Object
Number of instrumentation errors on the agent. Absent from the response when the count is zero.
64 65 66 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 64 def instrumentation_error_counts @instrumentation_error_counts end |
#instrumentation_status ⇒ Object
The single-step instrumentation status of the Agent.
67 68 69 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 67 def instrumentation_status @instrumentation_status end |
#integrations ⇒ Object
Names of integrations configured on the agent.
70 71 72 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 70 def integrations @integrations end |
#ip_addresses ⇒ Object
IP addresses of the agent host.
73 74 75 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 73 def ip_addresses @ip_addresses end |
#is_single_step_instrumentation_enabled ⇒ Object
Whether single-step instrumentation is enabled on the agent.
76 77 78 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 76 def is_single_step_instrumentation_enabled @is_single_step_instrumentation_enabled end |
#last_restart_at ⇒ Object
Unix timestamp of the last agent restart.
79 80 81 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 79 def last_restart_at @last_restart_at end |
#os ⇒ Object
The operating system of the host.
82 83 84 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 82 def os @os end |
#otel_collector_deployment_types ⇒ Object
OpenTelemetry collector deployment types associated with the agent.
85 86 87 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 85 def otel_collector_deployment_types @otel_collector_deployment_types end |
#otel_collector_distributions ⇒ Object
OpenTelemetry collector distributions associated with the agent.
88 89 90 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 88 def otel_collector_distributions @otel_collector_distributions end |
#otel_collector_versions ⇒ Object
All OpenTelemetry collector versions associated with the agent.
91 92 93 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 91 def otel_collector_versions @otel_collector_versions end |
#otel_resource_attributes ⇒ Object
OpenTelemetry resource attributes reported by the agent.
94 95 96 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 94 def otel_resource_attributes @otel_resource_attributes end |
#pod_name ⇒ Object
The Kubernetes pod name, if the agent runs as a pod.
97 98 99 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 97 def pod_name @pod_name end |
#remote_agent_management ⇒ Object
The remote agent management status.
100 101 102 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 100 def remote_agent_management @remote_agent_management end |
#remote_config_status ⇒ Object
The remote configuration connection status of the agent.
103 104 105 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 103 def remote_config_status @remote_config_status end |
#services ⇒ Object
Services running on the agent.
106 107 108 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 106 def services @services end |
#tags ⇒ Object
Tags associated with the agent. Returned as an empty array when the agent has no tags.
109 110 111 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 109 def @tags end |
#team ⇒ Object
The team associated with the agent.
112 113 114 |
# File 'lib/datadog_api_client/v2/models/fleet_agent_v2_attributes.rb', line 112 def team @team end |