Class: DatadogAPIClient::V2::FleetDeploymentConfigureV2Attributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetDeploymentConfigureV2Attributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_attributes.rb
Overview
Attributes for creating a new v2 configuration deployment.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#config_operations ⇒ Object
readonly
Ordered list of configuration file operations to perform on the target hosts.
-
#dry_run ⇒ Object
Set to
trueto validate the configuration and resolve target hosts and packages without deploying anything. -
#filter_query ⇒ Object
readonly
Query used to filter and select target hosts for the deployment.
-
#target_packages ⇒ Object
List of packages and their target versions to additionally deploy alongside the configuration change.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_attributes.rb', line 39 def additional_properties @additional_properties end |
#config_operations ⇒ Object
Ordered list of configuration file operations to perform on the target hosts.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_attributes.rb', line 25 def config_operations @config_operations end |
#dry_run ⇒ Object
Set to true to validate the configuration and resolve target hosts and packages
without deploying anything. Returns a 200 with the validation result instead of
creating and starting a real deployment.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_attributes.rb', line 30 def dry_run @dry_run end |
#filter_query ⇒ Object
Query used to filter and select target hosts for the deployment. Uses the Datadog query syntax.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_attributes.rb', line 33 def filter_query @filter_query end |
#target_packages ⇒ Object
List of packages and their target versions to additionally deploy alongside the configuration change.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_configure_v2_attributes.rb', line 37 def target_packages @target_packages end |