Class: DatadogAPIClient::V2::FleetDeploymentV2DetailAgent
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetDeploymentV2DetailAgent
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb
Overview
Per-host status entry for a deployment.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#error ⇒ Object
Error message if the deployment failed on this host.
-
#hostname ⇒ Object
Hostname of the agent.
-
#running_step ⇒ Object
Name of the step currently executing on this host.
-
#status ⇒ Object
Deployment status for this host (for example, "pending", "running", "succeeded", "failed").
-
#status_details ⇒ Object
Additional details about the current deployment status on this host.
-
#versions ⇒ Object
Package version details for this host.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 42 def additional_properties @additional_properties end |
#error ⇒ Object
Error message if the deployment failed on this host.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 25 def error @error end |
#hostname ⇒ Object
Hostname of the agent.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 28 def hostname @hostname end |
#running_step ⇒ Object
Name of the step currently executing on this host.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 31 def running_step @running_step end |
#status ⇒ Object
Deployment status for this host (for example, "pending", "running", "succeeded", "failed").
34 35 36 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 34 def status @status end |
#status_details ⇒ Object
Additional details about the current deployment status on this host.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 37 def status_details @status_details end |
#versions ⇒ Object
Package version details for this host.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/fleet_deployment_v2_detail_agent.rb', line 40 def versions @versions end |