Class: DatadogAPIClient::V2::FleetInstrumentedPodGroupAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::FleetInstrumentedPodGroupAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb
Overview
Attributes of a group of instrumented pods targeted for SSI injection.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#applied_target ⇒ Object
The SSI injection target configuration applied to the pod group.
-
#applied_target_name ⇒ Object
The name of the applied SSI injection target.
-
#injected_tags ⇒ Object
Tags injected into the pods by the Admission Controller.
-
#kube_ownerref_kind ⇒ Object
The kind of the Kubernetes owner reference.
-
#kube_ownerref_name ⇒ Object
The name of the Kubernetes owner reference (deployment, statefulset, etc.).
-
#lib_injection_annotations ⇒ Object
Library injection annotations on the pod group.
-
#namespace ⇒ Object
The Kubernetes namespace of the pod group.
-
#pod_count ⇒ Object
Total number of pods in the group.
-
#pod_names ⇒ Object
Names of the individual pods in the group.
-
#tags ⇒ Object
Additional tags associated with the pod group.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 54 def additional_properties @additional_properties end |
#applied_target ⇒ Object
The SSI injection target configuration applied to the pod group.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 25 def applied_target @applied_target end |
#applied_target_name ⇒ Object
The name of the applied SSI injection target.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 28 def applied_target_name @applied_target_name end |
#injected_tags ⇒ Object
Tags injected into the pods by the Admission Controller.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 31 def @injected_tags end |
#kube_ownerref_kind ⇒ Object
The kind of the Kubernetes owner reference.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 34 def kube_ownerref_kind @kube_ownerref_kind end |
#kube_ownerref_name ⇒ Object
The name of the Kubernetes owner reference (deployment, statefulset, etc.).
37 38 39 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 37 def kube_ownerref_name @kube_ownerref_name end |
#lib_injection_annotations ⇒ Object
Library injection annotations on the pod group.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 40 def lib_injection_annotations @lib_injection_annotations end |
#namespace ⇒ Object
The Kubernetes namespace of the pod group.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 43 def namespace @namespace end |
#pod_count ⇒ Object
Total number of pods in the group.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 46 def pod_count @pod_count end |
#pod_names ⇒ Object
Names of the individual pods in the group.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 49 def pod_names @pod_names end |
#tags ⇒ Object
Additional tags associated with the pod group.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/fleet_instrumented_pod_group_attributes.rb', line 52 def @tags end |