Class: DatadogAPIClient::V2::GovernanceControlDetectionAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::GovernanceControlDetectionAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb
Overview
The attributes of a governance control detection.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#assigned_team ⇒ Object
The identifier of the team the detection is assigned to, if any.
-
#assigned_to ⇒ Object
The identifier of the user the detection is assigned to, if any.
-
#assignment_source ⇒ Object
readonly
How the detection's current assignment was determined.
-
#control_id ⇒ Object
readonly
DEPRECATED: mirrors
detection_typefor backward compatibility; usedetection_typeinstead. -
#created_at ⇒ Object
readonly
The date and time when the detection was created.
-
#detection_type ⇒ Object
readonly
The type of detection, which determines what condition was detected.
-
#display_name ⇒ Object
readonly
The human-readable name of the detected resource.
-
#exception_at ⇒ Object
The date and time when the detection was marked as an exception, if applicable.
-
#exception_by ⇒ Object
The identifier of the user who marked the detection as an exception, if applicable.
-
#metadata ⇒ Object
Free-form metadata associated with the detection.
-
#mitigate_after ⇒ Object
The date and time after which the detection is scheduled to be mitigated, if applicable.
-
#mitigated_at ⇒ Object
The date and time when the detection was mitigated, if applicable.
-
#priority ⇒ Object
readonly
The priority of the detection, if set.
-
#resource_id ⇒ Object
readonly
The identifier of the resource the detection applies to.
-
#resource_type ⇒ Object
readonly
The type of resource the detection applies to, for example
api_keyordashboard. -
#state ⇒ Object
readonly
The current state of the detection.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
73 74 75 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 73 def additional_properties @additional_properties end |
#assigned_team ⇒ Object
The identifier of the team the detection is assigned to, if any.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 25 def assigned_team @assigned_team end |
#assigned_to ⇒ Object
The identifier of the user the detection is assigned to, if any.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 28 def assigned_to @assigned_to end |
#assignment_source ⇒ Object
How the detection's current assignment was determined. Possible values are auto_resolved, manual, reassigned, and cleared.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 31 def assignment_source @assignment_source end |
#control_id ⇒ Object
DEPRECATED: mirrors detection_type for backward compatibility; use detection_type
instead.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 35 def control_id @control_id end |
#created_at ⇒ Object
The date and time when the detection was created.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 38 def created_at @created_at end |
#detection_type ⇒ Object
The type of detection, which determines what condition was detected.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 41 def detection_type @detection_type end |
#display_name ⇒ Object
The human-readable name of the detected resource.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 44 def display_name @display_name end |
#exception_at ⇒ Object
The date and time when the detection was marked as an exception, if applicable.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 47 def exception_at @exception_at end |
#exception_by ⇒ Object
The identifier of the user who marked the detection as an exception, if applicable.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 50 def exception_by @exception_by end |
#metadata ⇒ Object
Free-form metadata associated with the detection.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 53 def @metadata end |
#mitigate_after ⇒ Object
The date and time after which the detection is scheduled to be mitigated, if applicable.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 56 def mitigate_after @mitigate_after end |
#mitigated_at ⇒ Object
The date and time when the detection was mitigated, if applicable.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 59 def mitigated_at @mitigated_at end |
#priority ⇒ Object
The priority of the detection, if set.
62 63 64 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 62 def priority @priority end |
#resource_id ⇒ Object
The identifier of the resource the detection applies to.
65 66 67 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 65 def resource_id @resource_id end |
#resource_type ⇒ Object
The type of resource the detection applies to, for example api_key or dashboard.
68 69 70 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 68 def resource_type @resource_type end |
#state ⇒ Object
The current state of the detection. Possible values are active, exception, mitigated, inactive, obsolete, resolved_externally, and mitigation_in_progress.
71 72 73 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_attributes.rb', line 71 def state @state end |