Class: DatadogAPIClient::V2::GovernanceControlDetectionUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::GovernanceControlDetectionUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/governance_control_detection_update_attributes.rb
Overview
The attributes of a governance control detection that can be updated. Only the attributes present in the request are modified.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#assigned_team ⇒ Object
The handle of the team the detection is assigned to.
-
#assigned_to ⇒ Object
The UUID of the user the detection is assigned to.
-
#mitigate_after ⇒ Object
The timestamp after which the detection becomes eligible for mitigation.
-
#state ⇒ Object
The new state to set for the detection.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_attributes.rb', line 36 def additional_properties @additional_properties end |
#assigned_team ⇒ Object
The handle of the team the detection is assigned to. Set to an empty string to clear the assignment.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_attributes.rb', line 25 def assigned_team @assigned_team end |
#assigned_to ⇒ Object
The UUID of the user the detection is assigned to. Set to an empty string to clear the assignment.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_attributes.rb', line 28 def assigned_to @assigned_to end |
#mitigate_after ⇒ Object
The timestamp after which the detection becomes eligible for mitigation. Used to defer mitigation to a later time.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_attributes.rb', line 31 def mitigate_after @mitigate_after end |
#state ⇒ Object
The new state to set for the detection. Set to exception to acknowledge the detection and exclude it from active counts, or active to reopen it.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/governance_control_detection_update_attributes.rb', line 34 def state @state end |