Class: DatadogAPIClient::V2::GovernanceInsightAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::GovernanceInsightAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/governance_insight_attributes.rb
Overview
The attributes of a governance insight. Exactly one of metric_query, event_query,
usage_query, audit_query, or percentage_query is populated, depending on the data
source the insight is computed from; the rest are null.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#audit_query ⇒ Object
An audit log query used to compute an insight value.
-
#description ⇒ Object
readonly
A human-readable description of what the insight measures.
-
#display_name ⇒ Object
readonly
Human-readable name of the insight.
-
#event_query ⇒ Object
An event query used to compute an insight value.
-
#metric_query ⇒ Object
A metric query used to compute an insight value.
-
#percentage_query ⇒ Object
A percentage query that computes an insight value as a ratio of two metric queries.
-
#product ⇒ Object
readonly
The product the insight belongs to.
-
#query_config ⇒ Object
Query execution context for running insight queries directly.
-
#sub_product ⇒ Object
readonly
The sub-product the insight belongs to, if any.
-
#time_range ⇒ Object
readonly
The time range the insight value is computed over, if applicable.
-
#unit_name ⇒ Object
readonly
The unit that the insight's value is measured in.
-
#usage_query ⇒ Object
A usage query used to compute an insight value.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
62 63 64 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 62 def additional_properties @additional_properties end |
#audit_query ⇒ Object
An audit log query used to compute an insight value.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 27 def audit_query @audit_query end |
#description ⇒ Object
A human-readable description of what the insight measures.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 30 def description @description end |
#display_name ⇒ Object
Human-readable name of the insight.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 33 def display_name @display_name end |
#event_query ⇒ Object
An event query used to compute an insight value.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 36 def event_query @event_query end |
#metric_query ⇒ Object
A metric query used to compute an insight value.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 39 def metric_query @metric_query end |
#percentage_query ⇒ Object
A percentage query that computes an insight value as a ratio of two metric queries.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 42 def percentage_query @percentage_query end |
#product ⇒ Object
The product the insight belongs to.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 45 def product @product end |
#query_config ⇒ Object
Query execution context for running insight queries directly.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 48 def query_config @query_config end |
#sub_product ⇒ Object
The sub-product the insight belongs to, if any.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 51 def sub_product @sub_product end |
#time_range ⇒ Object
The time range the insight value is computed over, if applicable.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 54 def time_range @time_range end |
#unit_name ⇒ Object
The unit that the insight's value is measured in.
57 58 59 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 57 def unit_name @unit_name end |
#usage_query ⇒ Object
A usage query used to compute an insight value.
60 61 62 |
# File 'lib/datadog_api_client/v2/models/governance_insight_attributes.rb', line 60 def usage_query @usage_query end |