Class: DatadogAPIClient::V2::GovernanceNotificationSettingsUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::GovernanceNotificationSettingsUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/governance_notification_settings_update_attributes.rb
Overview
The attributes of the governance notification settings that can be updated. Only the attributes present in the request are modified.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#assignment_notifications_enabled ⇒ Object
Whether notifications are sent to users when detections are assigned to them.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/governance_notification_settings_update_attributes.rb', line 27 def additional_properties @additional_properties end |
#assignment_notifications_enabled ⇒ Object
Whether notifications are sent to users when detections are assigned to them.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/governance_notification_settings_update_attributes.rb', line 25 def assignment_notifications_enabled @assignment_notifications_enabled end |