Class: DatadogAPIClient::V2::GroupScalarColumn
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::GroupScalarColumn
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/group_scalar_column.rb
Overview
A column containing the tag keys and values in a group.
Instance Attribute Summary collapse
-
#name ⇒ Object
The name of the tag key or group.
-
#type ⇒ Object
The type of column present.
-
#values ⇒ Object
The array of tag values for each group found for the results of the formulas or queries.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#name ⇒ Object
The name of the tag key or group.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/group_scalar_column.rb', line 29 def name @name end |
#type ⇒ Object
The type of column present.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/group_scalar_column.rb', line 32 def type @type end |
#values ⇒ Object
The array of tag values for each group found for the results of the formulas or queries.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/group_scalar_column.rb', line 35 def values @values end |