Class: DatadogAPIClient::V2::IncidentCreateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentCreateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_create_attributes.rb
Overview
The incident’s attributes for a create request.
Instance Attribute Summary collapse
-
#customer_impacted ⇒ Object
readonly
A flag indicating whether the incident caused customer impact.
-
#fields ⇒ Object
A condensed view of the user-defined fields for which to create initial selections.
-
#initial_cells ⇒ Object
An array of initial timeline cells to be placed at the beginning of the incident timeline.
-
#notification_handles ⇒ Object
Notification handles that will be notified of the incident at creation.
-
#title ⇒ Object
readonly
The title of the incident, which summarizes what happened.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#customer_impacted ⇒ Object
A flag indicating whether the incident caused customer impact.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 29 def customer_impacted @customer_impacted end |
#fields ⇒ Object
A condensed view of the user-defined fields for which to create initial selections.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 32 def fields @fields end |
#initial_cells ⇒ Object
An array of initial timeline cells to be placed at the beginning of the incident timeline.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 35 def initial_cells @initial_cells end |
#notification_handles ⇒ Object
Notification handles that will be notified of the incident at creation.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 38 def notification_handles @notification_handles end |
#title ⇒ Object
The title of the incident, which summarizes what happened.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/incident_create_attributes.rb', line 41 def title @title end |