Class: DatadogAPIClient::V2::IncidentServicesAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentServicesAPI
- Defined in:
- lib/datadog_api_client/v2/api/incident_services_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_incident_service(body, opts = {}) ⇒ Object
Create a new incident service.
-
#create_incident_service_with_http_info(body, opts = {}) ⇒ Array<(IncidentServiceResponse, Integer, Hash)>
Create a new incident service.
-
#delete_incident_service(service_id, opts = {}) ⇒ Object
Delete an existing incident service.
-
#delete_incident_service_with_http_info(service_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an existing incident service.
-
#get_incident_service(service_id, opts = {}) ⇒ Object
Get details of an incident service.
-
#get_incident_service_with_http_info(service_id, opts = {}) ⇒ Array<(IncidentServiceResponse, Integer, Hash)>
Get details of an incident service.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ IncidentServicesAPI
constructor
A new instance of IncidentServicesAPI.
-
#list_incident_services(opts = {}) ⇒ Object
Get a list of all incident services.
-
#list_incident_services_with_http_info(opts = {}) ⇒ Array<(IncidentServicesResponse, Integer, Hash)>
Get a list of all incident services.
-
#update_incident_service(service_id, body, opts = {}) ⇒ Object
Update an existing incident service.
-
#update_incident_service_with_http_info(service_id, body, opts = {}) ⇒ Array<(IncidentServiceResponse, Integer, Hash)>
Update an existing incident service.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ IncidentServicesAPI
Returns a new instance of IncidentServicesAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#create_incident_service(body, opts = {}) ⇒ Object
Create a new incident service.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 29 def create_incident_service(body, opts = {}) data, _status_code, _headers = create_incident_service_with_http_info(body, opts) data end |
#create_incident_service_with_http_info(body, opts = {}) ⇒ Array<(IncidentServiceResponse, Integer, Hash)>
Create a new incident service.
Creates a new incident service.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 41 def create_incident_service_with_http_info(body, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.create_incident_service".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.create_incident_service") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.create_incident_service")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IncidentServicesAPI.create_incident_service ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IncidentServicesAPI.create_incident_service" end # resource path local_var_path = '/api/v2/services' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'IncidentServiceResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :create_incident_service, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IncidentServicesAPI#create_incident_service\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_incident_service(service_id, opts = {}) ⇒ Object
Delete an existing incident service.
102 103 104 105 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 102 def delete_incident_service(service_id, opts = {}) delete_incident_service_with_http_info(service_id, opts) nil end |
#delete_incident_service_with_http_info(service_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an existing incident service.
Deletes an existing incident service.
114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 114 def delete_incident_service_with_http_info(service_id, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.delete_incident_service".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.delete_incident_service") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.delete_incident_service")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IncidentServicesAPI.delete_incident_service ...' end # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling IncidentServicesAPI.delete_incident_service" end # resource path local_var_path = '/api/v2/services/{service_id}'.sub('{service_id}', CGI.escape(service_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :delete_incident_service, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IncidentServicesAPI#delete_incident_service\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_incident_service(service_id, opts = {}) ⇒ Object
Get details of an incident service.
173 174 175 176 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 173 def get_incident_service(service_id, opts = {}) data, _status_code, _headers = get_incident_service_with_http_info(service_id, opts) data end |
#get_incident_service_with_http_info(service_id, opts = {}) ⇒ Array<(IncidentServiceResponse, Integer, Hash)>
Get details of an incident service.
Get details of an incident service. If the include[users] query parameter is provided, the included attribute will contain the users related to these incident services.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 187 def get_incident_service_with_http_info(service_id, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.get_incident_service".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.get_incident_service") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.get_incident_service")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IncidentServicesAPI.get_incident_service ...' end # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling IncidentServicesAPI.get_incident_service" end allowable_values = ['users', 'attachments'] if @api_client.config.client_side_validation && opts[:'include'] && !allowable_values.include?(opts[:'include']) fail ArgumentError, "invalid value for \"include\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/services/{service_id}'.sub('{service_id}', CGI.escape(service_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IncidentServiceResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :get_incident_service, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IncidentServicesAPI#get_incident_service\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_incident_services(opts = {}) ⇒ Object
Get a list of all incident services.
251 252 253 254 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 251 def list_incident_services(opts = {}) data, _status_code, _headers = list_incident_services_with_http_info(opts) data end |
#list_incident_services_with_http_info(opts = {}) ⇒ Array<(IncidentServicesResponse, Integer, Hash)>
Get a list of all incident services.
Get all incident services uploaded for the requesting user’s organization. If the include[users] query parameter is provided, the included attribute will contain the users related to these incident services.
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 266 def list_incident_services_with_http_info(opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.list_incident_services".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.list_incident_services") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.list_incident_services")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IncidentServicesAPI.list_incident_services ...' end allowable_values = ['users', 'attachments'] if @api_client.config.client_side_validation && opts[:'include'] && !allowable_values.include?(opts[:'include']) fail ArgumentError, "invalid value for \"include\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/services' # query parameters query_params = opts[:query_params] || {} query_params[:'include'] = opts[:'include'] if !opts[:'include'].nil? query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[offset]'] = opts[:'page_offset'] if !opts[:'page_offset'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IncidentServicesResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :list_incident_services, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IncidentServicesAPI#list_incident_services\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_incident_service(service_id, body, opts = {}) ⇒ Object
Update an existing incident service.
329 330 331 332 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 329 def update_incident_service(service_id, body, opts = {}) data, _status_code, _headers = update_incident_service_with_http_info(service_id, body, opts) data end |
#update_incident_service_with_http_info(service_id, body, opts = {}) ⇒ Array<(IncidentServiceResponse, Integer, Hash)>
Update an existing incident service.
Updates an existing incident service. Only provide the attributes which should be updated as this request is a partial update.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/datadog_api_client/v2/api/incident_services_api.rb', line 342 def update_incident_service_with_http_info(service_id, body, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.update_incident_service".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_incident_service") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_incident_service")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IncidentServicesAPI.update_incident_service ...' end # verify the required parameter 'service_id' is set if @api_client.config.client_side_validation && service_id.nil? fail ArgumentError, "Missing the required parameter 'service_id' when calling IncidentServicesAPI.update_incident_service" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling IncidentServicesAPI.update_incident_service" end # resource path local_var_path = '/api/v2/services/{service_id}'.sub('{service_id}', CGI.escape(service_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'IncidentServiceResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :update_incident_service, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IncidentServicesAPI#update_incident_service\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |