Class: DatadogAPIClient::V2::IncidentTimelineCellMarkdownCreateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentTimelineCellMarkdownCreateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_timeline_cell_markdown_create_attributes.rb
Overview
Timeline cell data for Markdown timeline cells for a create request.
Instance Attribute Summary collapse
-
#cell_type ⇒ Object
readonly
Type of the Markdown timeline cell.
-
#content ⇒ Object
readonly
The Markdown timeline cell contents.
-
#important ⇒ Object
A flag indicating whether the timeline cell is important and should be highlighted.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#cell_type ⇒ Object
Type of the Markdown timeline cell.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/incident_timeline_cell_markdown_create_attributes.rb', line 29 def cell_type @cell_type end |
#content ⇒ Object
The Markdown timeline cell contents.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/incident_timeline_cell_markdown_create_attributes.rb', line 32 def content @content end |
#important ⇒ Object
A flag indicating whether the timeline cell is important and should be highlighted.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/incident_timeline_cell_markdown_create_attributes.rb', line 35 def important @important end |