Class: DatadogAPIClient::V2::IncidentUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IncidentUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/incident_update_attributes.rb
Overview
The incident’s attributes for an update request.
Instance Attribute Summary collapse
-
#customer_impact_end ⇒ Object
Timestamp when customers were no longer impacted by the incident.
-
#customer_impact_scope ⇒ Object
A summary of the impact customers experienced during the incident.
-
#customer_impact_start ⇒ Object
Timestamp when customers began being impacted by the incident.
-
#customer_impacted ⇒ Object
A flag indicating whether the incident caused customer impact.
-
#detected ⇒ Object
Timestamp when the incident was detected.
-
#fields ⇒ Object
A condensed view of the user-defined fields for which to update selections.
-
#notification_handles ⇒ Object
Notification handles that will be notified of the incident during update.
-
#title ⇒ Object
The title of the incident, which summarizes what happened.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#customer_impact_end ⇒ Object
Timestamp when customers were no longer impacted by the incident.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 29 def customer_impact_end @customer_impact_end end |
#customer_impact_scope ⇒ Object
A summary of the impact customers experienced during the incident.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 32 def customer_impact_scope @customer_impact_scope end |
#customer_impact_start ⇒ Object
Timestamp when customers began being impacted by the incident.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 35 def customer_impact_start @customer_impact_start end |
#customer_impacted ⇒ Object
A flag indicating whether the incident caused customer impact.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 38 def customer_impacted @customer_impacted end |
#detected ⇒ Object
Timestamp when the incident was detected.
41 42 43 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 41 def detected @detected end |
#fields ⇒ Object
A condensed view of the user-defined fields for which to update selections.
44 45 46 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 44 def fields @fields end |
#notification_handles ⇒ Object
Notification handles that will be notified of the incident during update.
47 48 49 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 47 def notification_handles @notification_handles end |
#title ⇒ Object
The title of the incident, which summarizes what happened.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/incident_update_attributes.rb', line 50 def title @title end |