Class: DatadogAPIClient::V2::IoCIndicator
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::IoCIndicator
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/io_c_indicator.rb
Overview
An indicator of compromise with threat intelligence data.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#as_geo ⇒ Object
Geographic location information for an IP indicator.
-
#as_type ⇒ Object
Autonomous system type.
-
#benign_sources ⇒ Object
Threat intelligence sources that flagged this indicator as benign.
-
#categories ⇒ Object
Threat categories associated with the indicator.
-
#first_seen ⇒ Object
Timestamp when the indicator was first seen.
-
#id ⇒ Object
Unique identifier for the indicator.
-
#indicator ⇒ Object
The indicator value (for example, an IP address or domain).
-
#indicator_type ⇒ Object
Type of indicator (for example, IP address or domain).
-
#last_seen ⇒ Object
Timestamp when the indicator was last seen.
-
#log_matches ⇒ Object
Number of logs that matched this indicator.
-
#m_as_type ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
-
#m_persistence ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
-
#m_signal ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
-
#m_sources ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
-
#malicious_sources ⇒ Object
Threat intelligence sources that flagged this indicator as malicious.
-
#max_trust_score ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
-
#score ⇒ Object
Threat score for the indicator (0-100).
-
#signal_matches ⇒ Object
Number of security signals that matched this indicator.
-
#signal_tier ⇒ Object
Signal tier level.
-
#suspicious_sources ⇒ Object
Threat intelligence sources that flagged this indicator as suspicious.
-
#tags ⇒ Object
Tags associated with the indicator.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
87 88 89 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 87 def additional_properties @additional_properties end |
#as_geo ⇒ Object
Geographic location information for an IP indicator.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 25 def as_geo @as_geo end |
#as_type ⇒ Object
Autonomous system type.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 28 def as_type @as_type end |
#benign_sources ⇒ Object
Threat intelligence sources that flagged this indicator as benign.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 31 def benign_sources @benign_sources end |
#categories ⇒ Object
Threat categories associated with the indicator.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 34 def categories @categories end |
#first_seen ⇒ Object
Timestamp when the indicator was first seen.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 37 def first_seen @first_seen end |
#id ⇒ Object
Unique identifier for the indicator.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 40 def id @id end |
#indicator ⇒ Object
The indicator value (for example, an IP address or domain).
43 44 45 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 43 def indicator @indicator end |
#indicator_type ⇒ Object
Type of indicator (for example, IP address or domain).
46 47 48 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 46 def indicator_type @indicator_type end |
#last_seen ⇒ Object
Timestamp when the indicator was last seen.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 49 def last_seen @last_seen end |
#log_matches ⇒ Object
Number of logs that matched this indicator.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 52 def log_matches @log_matches end |
#m_as_type ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 55 def m_as_type @m_as_type end |
#m_persistence ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
58 59 60 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 58 def m_persistence @m_persistence end |
#m_signal ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 61 def m_signal @m_signal end |
#m_sources ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
64 65 66 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 64 def m_sources @m_sources end |
#malicious_sources ⇒ Object
Threat intelligence sources that flagged this indicator as malicious.
67 68 69 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 67 def malicious_sources @malicious_sources end |
#max_trust_score ⇒ Object
Effect of a scoring factor on the indicator’s threat score.
70 71 72 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 70 def max_trust_score @max_trust_score end |
#score ⇒ Object
Threat score for the indicator (0-100).
73 74 75 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 73 def score @score end |
#signal_matches ⇒ Object
Number of security signals that matched this indicator.
76 77 78 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 76 def signal_matches @signal_matches end |
#signal_tier ⇒ Object
Signal tier level.
79 80 81 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 79 def signal_tier @signal_tier end |
#suspicious_sources ⇒ Object
Threat intelligence sources that flagged this indicator as suspicious.
82 83 84 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 82 def suspicious_sources @suspicious_sources end |
#tags ⇒ Object
Tags associated with the indicator.
85 86 87 |
# File 'lib/datadog_api_client/v2/models/io_c_indicator.rb', line 85 def @tags end |