Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsCustomEvalConfigAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb
Overview
Attributes of a custom LLM Observability evaluator configuration.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#category ⇒ Object
Category of the evaluator.
-
#created_at ⇒ Object
readonly
Timestamp when the evaluator configuration was created.
-
#created_by ⇒ Object
A Datadog user associated with a custom evaluator configuration.
-
#eval_name ⇒ Object
readonly
Name of the custom evaluator.
-
#last_updated_by ⇒ Object
A Datadog user associated with a custom evaluator configuration.
-
#llm_judge_config ⇒ Object
LLM judge configuration for a custom evaluator.
-
#llm_provider ⇒ Object
LLM provider configuration for a custom evaluator.
-
#target ⇒ Object
Target application configuration for a custom evaluator.
-
#updated_at ⇒ Object
readonly
Timestamp when the evaluator configuration was last updated.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 51 def additional_properties @additional_properties end |
#category ⇒ Object
Category of the evaluator.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 25 def category @category end |
#created_at ⇒ Object
Timestamp when the evaluator configuration was created.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 28 def created_at @created_at end |
#created_by ⇒ Object
A Datadog user associated with a custom evaluator configuration.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 31 def created_by @created_by end |
#eval_name ⇒ Object
Name of the custom evaluator.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 34 def eval_name @eval_name end |
#last_updated_by ⇒ Object
A Datadog user associated with a custom evaluator configuration.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 37 def last_updated_by @last_updated_by end |
#llm_judge_config ⇒ Object
LLM judge configuration for a custom evaluator.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 40 def llm_judge_config @llm_judge_config end |
#llm_provider ⇒ Object
LLM provider configuration for a custom evaluator.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 43 def llm_provider @llm_provider end |
#target ⇒ Object
Target application configuration for a custom evaluator.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 46 def target @target end |
#updated_at ⇒ Object
Timestamp when the evaluator configuration was last updated.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_attributes.rb', line 49 def updated_at @updated_at end |