Class: DatadogAPIClient::V2::LLMObsCustomEvalConfigLLMJudgeConfig
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsCustomEvalConfigLLMJudgeConfig
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb
Overview
LLM judge configuration for a custom evaluator.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#assessment_criteria ⇒ Object
Criteria used to assess the pass/fail result of a custom evaluator.
-
#inference_params ⇒ Object
readonly
LLM inference parameters for a custom evaluator.
-
#last_used_library_prompt_template_name ⇒ Object
Name of the last library prompt template used.
-
#modified_library_prompt_template ⇒ Object
Whether the library prompt template was modified.
-
#output_schema ⇒ Object
JSON schema describing the expected output format of the LLM judge.
-
#parsing_type ⇒ Object
Output parsing type for a custom LLM judge evaluator.
-
#prompt_template ⇒ Object
List of messages forming the LLM judge prompt template.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 45 def additional_properties @additional_properties end |
#assessment_criteria ⇒ Object
Criteria used to assess the pass/fail result of a custom evaluator.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 25 def assessment_criteria @assessment_criteria end |
#inference_params ⇒ Object
LLM inference parameters for a custom evaluator.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 28 def inference_params @inference_params end |
#last_used_library_prompt_template_name ⇒ Object
Name of the last library prompt template used.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 31 def last_used_library_prompt_template_name @last_used_library_prompt_template_name end |
#modified_library_prompt_template ⇒ Object
Whether the library prompt template was modified.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 34 def modified_library_prompt_template @modified_library_prompt_template end |
#output_schema ⇒ Object
JSON schema describing the expected output format of the LLM judge.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 37 def output_schema @output_schema end |
#parsing_type ⇒ Object
Output parsing type for a custom LLM judge evaluator.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 40 def parsing_type @parsing_type end |
#prompt_template ⇒ Object
List of messages forming the LLM judge prompt template.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/llm_obs_custom_eval_config_llm_judge_config.rb', line 43 def prompt_template @prompt_template end |