Class: DatadogAPIClient::V2::LLMObsPatternsClusteredPoint
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LLMObsPatternsClusteredPoint
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb
Overview
A single data point grouped into a topic.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#event_id ⇒ Object
readonly
Identifier of the source event.
-
#id ⇒ Object
readonly
Unique identifier of the clustered point.
-
#input ⇒ Object
readonly
Input text of the source span.
-
#is_included ⇒ Object
readonly
Whether the point is included in the patterns dataset.
-
#is_suggested ⇒ Object
readonly
Whether the point is suggested for inclusion in the patterns dataset.
-
#session_id ⇒ Object
readonly
Identifier of the source session.
-
#span_id ⇒ Object
readonly
Identifier of the source span.
-
#topic_id ⇒ Object
readonly
Identifier of the topic the point belongs to.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 48 def additional_properties @additional_properties end |
#event_id ⇒ Object
Identifier of the source event.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 25 def event_id @event_id end |
#id ⇒ Object
Unique identifier of the clustered point.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 28 def id @id end |
#input ⇒ Object
Input text of the source span.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 31 def input @input end |
#is_included ⇒ Object
Whether the point is included in the patterns dataset.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 34 def is_included @is_included end |
#is_suggested ⇒ Object
Whether the point is suggested for inclusion in the patterns dataset.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 37 def is_suggested @is_suggested end |
#session_id ⇒ Object
Identifier of the source session.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 40 def session_id @session_id end |
#span_id ⇒ Object
Identifier of the source span.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 43 def span_id @span_id end |
#topic_id ⇒ Object
Identifier of the topic the point belongs to.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/llm_obs_patterns_clustered_point.rb', line 46 def topic_id @topic_id end |