Class: DatadogAPIClient::V2::LogsQueryFilter
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::LogsQueryFilter
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/logs_query_filter.rb
Overview
The search and filter query settings
Instance Attribute Summary collapse
-
#from ⇒ Object
The minimum time for the requested logs, supports date math and regular timestamps (milliseconds).
-
#indexes ⇒ Object
For customers with multiple indexes, the indexes to search.
-
#query ⇒ Object
The search query - following the log search syntax.
-
#storage_tier ⇒ Object
Specifies storage type as indexes or online-archives.
-
#to ⇒ Object
The maximum time for the requested logs, supports date math and regular timestamps (milliseconds).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#from ⇒ Object
The minimum time for the requested logs, supports date math and regular timestamps (milliseconds).
29 30 31 |
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 29 def from @from end |
#indexes ⇒ Object
For customers with multiple indexes, the indexes to search. Defaults to [‘*’] which means all indexes.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 32 def indexes @indexes end |
#query ⇒ Object
The search query - following the log search syntax.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 35 def query @query end |
#storage_tier ⇒ Object
Specifies storage type as indexes or online-archives
38 39 40 |
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 38 def storage_tier @storage_tier end |
#to ⇒ Object
The maximum time for the requested logs, supports date math and regular timestamps (milliseconds).
41 42 43 |
# File 'lib/datadog_api_client/v2/models/logs_query_filter.rb', line 41 def to @to end |