Class: DatadogAPIClient::V2::MetricBulkTagConfigStatusAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::MetricBulkTagConfigStatusAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb
Overview
Optional attributes for the status of a bulk tag configuration request.
Instance Attribute Summary collapse
-
#emails ⇒ Object
A list of account emails to notify when the configuration is applied.
-
#status ⇒ Object
The status of the request.
-
#tags ⇒ Object
A list of tag names to apply to the configuration.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#emails ⇒ Object
A list of account emails to notify when the configuration is applied.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb', line 29 def emails @emails end |
#status ⇒ Object
The status of the request.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb', line 32 def status @status end |
#tags ⇒ Object
A list of tag names to apply to the configuration.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/metric_bulk_tag_config_status_attributes.rb', line 35 def end |