Class: DatadogAPIClient::V2::MetricEstimateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::MetricEstimateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/metric_estimate_attributes.rb
Overview
Object containing the definition of a metric estimate attribute.
Instance Attribute Summary collapse
-
#estimate_type ⇒ Object
Estimate type based on the queried configuration.
-
#estimated_at ⇒ Object
Timestamp when the cardinality estimate was requested.
-
#estimated_output_series ⇒ Object
Estimated cardinality of the metric based on the queried configuration.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#estimate_type ⇒ Object
Estimate type based on the queried configuration. By default, count_or_gauge is returned. distribution is returned for distribution metrics without percentiles enabled. Lastly, percentile is returned if ‘filter=true` is queried with a distribution metric.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/metric_estimate_attributes.rb', line 29 def estimate_type @estimate_type end |
#estimated_at ⇒ Object
Timestamp when the cardinality estimate was requested.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/metric_estimate_attributes.rb', line 32 def estimated_at @estimated_at end |
#estimated_output_series ⇒ Object
Estimated cardinality of the metric based on the queried configuration.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/metric_estimate_attributes.rb', line 35 def estimated_output_series @estimated_output_series end |