Class: DatadogAPIClient::V2::OrgGroupPolicyCreateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::OrgGroupPolicyCreateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/org_group_policy_create_attributes.rb
Overview
Attributes for creating an org group policy. If ‘policy_type` or `enforcement_tier` are not provided, they default to `org_config` and `DEFAULT` respectively.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#content ⇒ Object
readonly
The policy content as key-value pairs.
-
#enforcement_tier ⇒ Object
The enforcement tier of the policy.
-
#policy_name ⇒ Object
readonly
The name of the policy.
-
#policy_type ⇒ Object
The type of the policy.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/org_group_policy_create_attributes.rb', line 36 def additional_properties @additional_properties end |
#content ⇒ Object
The policy content as key-value pairs.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/org_group_policy_create_attributes.rb', line 25 def content @content end |
#enforcement_tier ⇒ Object
The enforcement tier of the policy. ‘DEFAULT` means the policy is set but member orgs may mutate it. `ENFORCE` means the policy is strictly controlled and mutations are blocked for affected orgs. `DELEGATE` means each member org controls its own value.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/org_group_policy_create_attributes.rb', line 28 def enforcement_tier @enforcement_tier end |
#policy_name ⇒ Object
The name of the policy.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/org_group_policy_create_attributes.rb', line 31 def policy_name @policy_name end |
#policy_type ⇒ Object
The type of the policy. Only ‘org_config` is supported, indicating a policy backed by an organization configuration setting.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/org_group_policy_create_attributes.rb', line 34 def policy_type @policy_type end |