Class: DatadogAPIClient::V2::OrganizationsAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::OrganizationsAPI
- Defined in:
- lib/datadog_api_client/v2/api/organizations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_org_config(org_config_name, opts = {}) ⇒ Object
Get a specific Org Config value.
-
#get_org_config_with_http_info(org_config_name, opts = {}) ⇒ Array<(OrgConfigGetResponse, Integer, Hash)>
Get a specific Org Config value.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ OrganizationsAPI
constructor
A new instance of OrganizationsAPI.
-
#list_org_configs(opts = {}) ⇒ Object
List Org Configs.
-
#list_org_configs_with_http_info(opts = {}) ⇒ Array<(OrgConfigListResponse, Integer, Hash)>
List Org Configs.
-
#list_orgs(opts = {}) ⇒ Object
List your managed organizations.
-
#list_orgs_with_http_info(opts = {}) ⇒ Array<(ManagedOrgsResponse, Integer, Hash)>
List your managed organizations.
-
#update_org_config(org_config_name, body, opts = {}) ⇒ Object
Update a specific Org Config.
-
#update_org_config_with_http_info(org_config_name, body, opts = {}) ⇒ Array<(OrgConfigGetResponse, Integer, Hash)>
Update a specific Org Config.
-
#upload_idp_metadata(opts = {}) ⇒ Object
Upload IdP metadata.
-
#upload_idp_metadata_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Upload IdP metadata.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ OrganizationsAPI
Returns a new instance of OrganizationsAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#get_org_config(org_config_name, opts = {}) ⇒ Object
Get a specific Org Config value.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 29 def get_org_config(org_config_name, opts = {}) data, _status_code, _headers = get_org_config_with_http_info(org_config_name, opts) data end |
#get_org_config_with_http_info(org_config_name, opts = {}) ⇒ Array<(OrgConfigGetResponse, Integer, Hash)>
Get a specific Org Config value.
Return the name, description, and value of a specific Org Config.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 41 def get_org_config_with_http_info(org_config_name, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationsAPI.get_org_config ...' end # verify the required parameter 'org_config_name' is set if @api_client.config.client_side_validation && org_config_name.nil? fail ArgumentError, "Missing the required parameter 'org_config_name' when calling OrganizationsAPI.get_org_config" end # resource path local_var_path = '/api/v2/org_configs/{org_config_name}'.sub('{org_config_name}', CGI.escape(org_config_name.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrgConfigGetResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_org_config, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsAPI#get_org_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_org_configs(opts = {}) ⇒ Object
List Org Configs.
94 95 96 97 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 94 def list_org_configs(opts = {}) data, _status_code, _headers = list_org_configs_with_http_info(opts) data end |
#list_org_configs_with_http_info(opts = {}) ⇒ Array<(OrgConfigListResponse, Integer, Hash)>
List Org Configs.
Returns all Org Configs (name, description, and value).
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 105 def list_org_configs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationsAPI.list_org_configs ...' end # resource path local_var_path = '/api/v2/org_configs' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'OrgConfigListResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_org_configs, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsAPI#list_org_configs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_orgs(opts = {}) ⇒ Object
List your managed organizations.
154 155 156 157 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 154 def list_orgs(opts = {}) data, _status_code, _headers = list_orgs_with_http_info(opts) data end |
#list_orgs_with_http_info(opts = {}) ⇒ Array<(ManagedOrgsResponse, Integer, Hash)>
List your managed organizations.
Returns the current organization and its managed organizations in JSON:API format.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 166 def list_orgs_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationsAPI.list_orgs ...' end # resource path local_var_path = '/api/v2/org' # query parameters query_params = opts[:query_params] || {} query_params[:'filter[name]'] = opts[:'filter_name'] if !opts[:'filter_name'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ManagedOrgsResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ] = opts.merge( :operation => :list_orgs, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsAPI#list_orgs\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_org_config(org_config_name, body, opts = {}) ⇒ Object
Update a specific Org Config.
216 217 218 219 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 216 def update_org_config(org_config_name, body, opts = {}) data, _status_code, _headers = update_org_config_with_http_info(org_config_name, body, opts) data end |
#update_org_config_with_http_info(org_config_name, body, opts = {}) ⇒ Array<(OrgConfigGetResponse, Integer, Hash)>
Update a specific Org Config.
Update the value of a specific Org Config.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 229 def update_org_config_with_http_info(org_config_name, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationsAPI.update_org_config ...' end # verify the required parameter 'org_config_name' is set if @api_client.config.client_side_validation && org_config_name.nil? fail ArgumentError, "Missing the required parameter 'org_config_name' when calling OrganizationsAPI.update_org_config" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling OrganizationsAPI.update_org_config" end # resource path local_var_path = '/api/v2/org_configs/{org_config_name}'.sub('{org_config_name}', CGI.escape(org_config_name.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'OrgConfigGetResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_org_config, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsAPI#update_org_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upload_idp_metadata(opts = {}) ⇒ Object
Upload IdP metadata.
288 289 290 291 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 288 def (opts = {}) (opts) nil end |
#upload_idp_metadata_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Upload IdP metadata.
Endpoint for uploading IdP metadata for SAML setup.
Use this endpoint to upload or replace IdP metadata for SAML login configuration.
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/datadog_api_client/v2/api/organizations_api.rb', line 302 def (opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OrganizationsAPI.upload_idp_metadata ...' end # resource path local_var_path = '/api/v2/saml_configurations/idp_metadata' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['multipart/form-data']) # form parameters form_params = opts[:form_params] || {} form_params['idp_file'] = opts[:'idp_file'] if !opts[:'idp_file'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :upload_idp_metadata, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OrganizationsAPI#upload_idp_metadata\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |