Class: DatadogAPIClient::V2::PartialApplicationKeyAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::PartialApplicationKeyAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/partial_application_key_attributes.rb
Overview
Attributes of a partial application key.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Creation date of the application key.
-
#last4 ⇒ Object
readonly
The last four characters of the application key.
-
#name ⇒ Object
Name of the application key.
-
#scopes ⇒ Object
Array of scopes to grant the application key.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#created_at ⇒ Object
Creation date of the application key.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/partial_application_key_attributes.rb', line 29 def created_at @created_at end |
#last4 ⇒ Object
The last four characters of the application key.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/partial_application_key_attributes.rb', line 32 def last4 @last4 end |
#name ⇒ Object
Name of the application key.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/partial_application_key_attributes.rb', line 35 def name @name end |
#scopes ⇒ Object
Array of scopes to grant the application key. This feature is in private beta, please contact Datadog support to enable scopes for your application keys.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/partial_application_key_attributes.rb', line 38 def scopes @scopes end |