Class: DatadogAPIClient::V2::ProcessSummariesMetaPage
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ProcessSummariesMetaPage
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/process_summaries_meta_page.rb
Overview
Paging attributes.
Instance Attribute Summary collapse
-
#after ⇒ Object
The cursor used to get the next results, if any.
-
#size ⇒ Object
readonly
Number of results returned.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#after ⇒ Object
The cursor used to get the next results, if any. To make the next request, use the same parameters with the addition of the page[cursor].
30 31 32 |
# File 'lib/datadog_api_client/v2/models/process_summaries_meta_page.rb', line 30 def after @after end |
#size ⇒ Object
Number of results returned.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/process_summaries_meta_page.rb', line 33 def size @size end |