Class: DatadogAPIClient::V2::RUMOperationJourneyStep
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RUMOperationJourneyStep
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_operation_journey_step.rb
Overview
A single step of a RUM operation's journey. Matches RUM events either through a list of nodes
or through a composite rule; the two are mutually exclusive.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#composite ⇒ Object
A composite rule combining several predicates.
-
#nodes ⇒ Object
The list of nodes that can match this step.
-
#type ⇒ Object
readonly
The type of a step within a RUM operation's journey.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_step.rb', line 35 def additional_properties @additional_properties end |
#composite ⇒ Object
A composite rule combining several predicates. Used as an alternative to nodes on a journey
step when several conditions must be matched together, in any order or in a specific order.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_step.rb', line 27 def composite @composite end |
#nodes ⇒ Object
The list of nodes that can match this step. Mutually exclusive with composite.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_step.rb', line 30 def nodes @nodes end |
#type ⇒ Object
The type of a step within a RUM operation's journey.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/rum_operation_journey_step.rb', line 33 def type @type end |