Class: DatadogAPIClient::V2::RUMOperationStrongLinkResponseAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RUMOperationStrongLinkResponseAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb
Overview
Attributes of a RUM operation strong link response.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#created_at ⇒ Object
The timestamp when the strong link was created.
-
#description ⇒ Object
A description of the strong link.
-
#feature_id ⇒ Object
readonly
The unique identifier of the linked feature.
-
#operation_id ⇒ Object
readonly
The unique identifier of the linked RUM operation.
-
#status ⇒ Object
readonly
The status of a RUM operation strong link.
-
#tags ⇒ Object
A list of tags associated with the strong link.
-
#updated_at ⇒ Object
The timestamp when the strong link was last updated.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 45 def additional_properties @additional_properties end |
#created_at ⇒ Object
The timestamp when the strong link was created.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 25 def created_at @created_at end |
#description ⇒ Object
A description of the strong link.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 28 def description @description end |
#feature_id ⇒ Object
The unique identifier of the linked feature.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 31 def feature_id @feature_id end |
#operation_id ⇒ Object
The unique identifier of the linked RUM operation.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 34 def operation_id @operation_id end |
#status ⇒ Object
The status of a RUM operation strong link.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 37 def status @status end |
#tags ⇒ Object
A list of tags associated with the strong link.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 40 def @tags end |
#updated_at ⇒ Object
The timestamp when the strong link was last updated.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/rum_operation_strong_link_response_attributes.rb', line 43 def updated_at @updated_at end |