Class: DatadogAPIClient::V2::RuleBasedViewRule
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::RuleBasedViewRule
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/rule_based_view_rule.rb
Overview
A compliance rule along with its evaluation statistics and framework mappings.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#compliance_frameworks ⇒ Object
readonly
List of compliance framework mappings associated with the rule.
-
#enabled ⇒ Object
readonly
Whether the rule is enabled.
-
#id ⇒ Object
readonly
Unique identifier of the rule.
-
#name ⇒ Object
readonly
Human-readable name of the rule.
-
#resource_attributes ⇒ Object
readonly
List of resource attribute names exposed by the rule.
-
#resource_category ⇒ Object
readonly
Resource category targeted by the rule.
-
#resource_type ⇒ Object
readonly
Resource type targeted by the rule.
-
#stats ⇒ Object
readonly
Counts of findings for the rule, grouped by their evaluation status.
-
#status ⇒ Object
readonly
Severity associated with the rule (for example, ‘info`, `low`, `medium`, `high`, or `critical`).
-
#tags ⇒ Object
readonly
List of tags attached to the rule.
-
#type ⇒ Object
readonly
The category of the security rule.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
57 58 59 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 57 def additional_properties @additional_properties end |
#compliance_frameworks ⇒ Object
List of compliance framework mappings associated with the rule.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 25 def compliance_frameworks @compliance_frameworks end |
#enabled ⇒ Object
Whether the rule is enabled.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 28 def enabled @enabled end |
#id ⇒ Object
Unique identifier of the rule.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 31 def id @id end |
#name ⇒ Object
Human-readable name of the rule.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 34 def name @name end |
#resource_attributes ⇒ Object
List of resource attribute names exposed by the rule.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 37 def resource_attributes @resource_attributes end |
#resource_category ⇒ Object
Resource category targeted by the rule.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 40 def resource_category @resource_category end |
#resource_type ⇒ Object
Resource type targeted by the rule.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 43 def resource_type @resource_type end |
#stats ⇒ Object
Counts of findings for the rule, grouped by their evaluation status.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 46 def stats @stats end |
#status ⇒ Object
Severity associated with the rule (for example, ‘info`, `low`, `medium`, `high`, or `critical`).
49 50 51 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 49 def status @status end |
#tags ⇒ Object
List of tags attached to the rule.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 52 def @tags end |
#type ⇒ Object
The category of the security rule.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/rule_based_view_rule.rb', line 55 def type @type end |