Class: DatadogAPIClient::V2::SensitiveDataScannerRuleAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SensitiveDataScannerRuleAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb
Overview
Attributes of the Sensitive Data Scanner rule.
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the rule.
-
#excluded_namespaces ⇒ Object
Attributes excluded from the scan.
-
#is_enabled ⇒ Object
Whether or not the rule is enabled.
-
#name ⇒ Object
Name of the rule.
-
#namespaces ⇒ Object
Attributes included in the scan.
-
#pattern ⇒ Object
Not included if there is a relationship to a standard pattern.
-
#tags ⇒ Object
List of tags.
-
#text_replacement ⇒ Object
Object describing how the scanned event will be replaced.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#description ⇒ Object
Description of the rule.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 29 def description @description end |
#excluded_namespaces ⇒ Object
Attributes excluded from the scan. If namespaces is provided, it has to be a sub-path of the namespaces array.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 32 def excluded_namespaces @excluded_namespaces end |
#is_enabled ⇒ Object
Whether or not the rule is enabled.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 35 def is_enabled @is_enabled end |
#name ⇒ Object
Name of the rule.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 38 def name @name end |
#namespaces ⇒ Object
Attributes included in the scan. If namespaces is empty or missing, all attributes except excluded_namespaces are scanned. If both are missing the whole event is scanned.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 42 def namespaces @namespaces end |
#pattern ⇒ Object
Not included if there is a relationship to a standard pattern.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 45 def pattern @pattern end |
#tags ⇒ Object
List of tags.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 48 def end |
#text_replacement ⇒ Object
Object describing how the scanned event will be replaced.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/sensitive_data_scanner_rule_attributes.rb', line 51 def text_replacement @text_replacement end |