Class: DatadogAPIClient::V2::ServiceAccountsAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::ServiceAccountsAPI
- Defined in:
- lib/datadog_api_client/v2/api/service_accounts_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_service_account(body, opts = {}) ⇒ Object
Create a service account.
-
#create_service_account_access_token(service_account_id, body, opts = {}) ⇒ Object
Create an access token for a service account.
-
#create_service_account_access_token_with_http_info(service_account_id, body, opts = {}) ⇒ Array<(PersonalAccessTokenCreateResponse, Integer, Hash)>
Create an access token for a service account.
-
#create_service_account_application_key(service_account_id, body, opts = {}) ⇒ Object
Create an application key for this service account.
-
#create_service_account_application_key_with_http_info(service_account_id, body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Create an application key for this service account.
-
#create_service_account_with_http_info(body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Create a service account.
-
#delete_service_account_application_key(service_account_id, app_key_id, opts = {}) ⇒ Object
Delete an application key for this service account.
-
#delete_service_account_application_key_with_http_info(service_account_id, app_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an application key for this service account.
-
#get_service_account_access_token(service_account_id, pat_id, opts = {}) ⇒ Object
Get an access token for a service account.
-
#get_service_account_access_token_with_http_info(service_account_id, pat_id, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Get an access token for a service account.
-
#get_service_account_application_key(service_account_id, app_key_id, opts = {}) ⇒ Object
Get one application key for this service account.
-
#get_service_account_application_key_with_http_info(service_account_id, app_key_id, opts = {}) ⇒ Array<(PartialApplicationKeyResponse, Integer, Hash)>
Get one application key for this service account.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ ServiceAccountsAPI
constructor
A new instance of ServiceAccountsAPI.
-
#list_service_account_access_tokens(service_account_id, opts = {}) ⇒ Object
List access tokens for a service account.
-
#list_service_account_access_tokens_with_http_info(service_account_id, opts = {}) ⇒ Array<(ListPersonalAccessTokensResponse, Integer, Hash)>
List access tokens for a service account.
-
#list_service_account_application_keys(service_account_id, opts = {}) ⇒ Object
List application keys for this service account.
-
#list_service_account_application_keys_with_http_info(service_account_id, opts = {}) ⇒ Array<(ListApplicationKeysResponse, Integer, Hash)>
List application keys for this service account.
-
#revoke_service_account_access_token(service_account_id, pat_id, opts = {}) ⇒ Object
Revoke an access token for a service account.
-
#revoke_service_account_access_token_with_http_info(service_account_id, pat_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke an access token for a service account.
-
#update_service_account_access_token(service_account_id, pat_id, body, opts = {}) ⇒ Object
Update an access token for a service account.
-
#update_service_account_access_token_with_http_info(service_account_id, pat_id, body, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Update an access token for a service account.
-
#update_service_account_application_key(service_account_id, app_key_id, body, opts = {}) ⇒ Object
Edit an application key for this service account.
-
#update_service_account_application_key_with_http_info(service_account_id, app_key_id, body, opts = {}) ⇒ Array<(PartialApplicationKeyResponse, Integer, Hash)>
Edit an application key for this service account.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ ServiceAccountsAPI
Returns a new instance of ServiceAccountsAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#create_service_account(body, opts = {}) ⇒ Object
Create a service account.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 29 def create_service_account(body, opts = {}) data, _status_code, _headers = create_service_account_with_http_info(body, opts) data end |
#create_service_account_access_token(service_account_id, body, opts = {}) ⇒ Object
Create an access token for a service account.
96 97 98 99 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 96 def create_service_account_access_token(service_account_id, body, opts = {}) data, _status_code, _headers = create_service_account_access_token_with_http_info(service_account_id, body, opts) data end |
#create_service_account_access_token_with_http_info(service_account_id, body, opts = {}) ⇒ Array<(PersonalAccessTokenCreateResponse, Integer, Hash)>
Create an access token for a service account.
Create an access token for a service account.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 109 def create_service_account_access_token_with_http_info(service_account_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.create_service_account_access_token ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.create_service_account_access_token" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ServiceAccountsAPI.create_service_account_access_token" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/access_tokens'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'PersonalAccessTokenCreateResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_service_account_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#create_service_account_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_service_account_application_key(service_account_id, body, opts = {}) ⇒ Object
Create an application key for this service account.
168 169 170 171 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 168 def create_service_account_application_key(service_account_id, body, opts = {}) data, _status_code, _headers = create_service_account_application_key_with_http_info(service_account_id, body, opts) data end |
#create_service_account_application_key_with_http_info(service_account_id, body, opts = {}) ⇒ Array<(ApplicationKeyResponse, Integer, Hash)>
Create an application key for this service account.
Create an application key for this service account.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 181 def create_service_account_application_key_with_http_info(service_account_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.create_service_account_application_key ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.create_service_account_application_key" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ServiceAccountsAPI.create_service_account_application_key" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/application_keys'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'ApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_service_account_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#create_service_account_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_service_account_with_http_info(body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Create a service account.
Create a service account for your organization.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 41 def create_service_account_with_http_info(body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.create_service_account ...' end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ServiceAccountsAPI.create_service_account" end # resource path local_var_path = '/api/v2/service_accounts' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'UserResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_service_account, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#create_service_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_service_account_application_key(service_account_id, app_key_id, opts = {}) ⇒ Object
Delete an application key for this service account.
240 241 242 243 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 240 def delete_service_account_application_key(service_account_id, app_key_id, opts = {}) delete_service_account_application_key_with_http_info(service_account_id, app_key_id, opts) nil end |
#delete_service_account_application_key_with_http_info(service_account_id, app_key_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete an application key for this service account.
Delete an application key owned by this service account.
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 253 def delete_service_account_application_key_with_http_info(service_account_id, app_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.delete_service_account_application_key ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.delete_service_account_application_key" end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling ServiceAccountsAPI.delete_service_account_application_key" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')).sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :delete_service_account_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#delete_service_account_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_service_account_access_token(service_account_id, pat_id, opts = {}) ⇒ Object
Get an access token for a service account.
310 311 312 313 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 310 def get_service_account_access_token(service_account_id, pat_id, opts = {}) data, _status_code, _headers = get_service_account_access_token_with_http_info(service_account_id, pat_id, opts) data end |
#get_service_account_access_token_with_http_info(service_account_id, pat_id, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Get an access token for a service account.
Get a specific access token for a service account by its UUID.
323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 323 def get_service_account_access_token_with_http_info(service_account_id, pat_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.get_service_account_access_token ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.get_service_account_access_token" end # verify the required parameter 'pat_id' is set if @api_client.config.client_side_validation && pat_id.nil? fail ArgumentError, "Missing the required parameter 'pat_id' when calling ServiceAccountsAPI.get_service_account_access_token" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/access_tokens/{pat_id}'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')).sub('{pat_id}', CGI.escape(pat_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PersonalAccessTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_service_account_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#get_service_account_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_service_account_application_key(service_account_id, app_key_id, opts = {}) ⇒ Object
Get one application key for this service account.
380 381 382 383 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 380 def get_service_account_application_key(service_account_id, app_key_id, opts = {}) data, _status_code, _headers = get_service_account_application_key_with_http_info(service_account_id, app_key_id, opts) data end |
#get_service_account_application_key_with_http_info(service_account_id, app_key_id, opts = {}) ⇒ Array<(PartialApplicationKeyResponse, Integer, Hash)>
Get one application key for this service account.
Get an application key owned by this service account.
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 393 def get_service_account_application_key_with_http_info(service_account_id, app_key_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.get_service_account_application_key ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.get_service_account_application_key" end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling ServiceAccountsAPI.get_service_account_application_key" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')).sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PartialApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_service_account_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#get_service_account_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_service_account_access_tokens(service_account_id, opts = {}) ⇒ Object
List access tokens for a service account.
450 451 452 453 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 450 def list_service_account_access_tokens(service_account_id, opts = {}) data, _status_code, _headers = list_service_account_access_tokens_with_http_info(service_account_id, opts) data end |
#list_service_account_access_tokens_with_http_info(service_account_id, opts = {}) ⇒ Array<(ListPersonalAccessTokensResponse, Integer, Hash)>
List access tokens for a service account.
List all access tokens for a specific service account.
466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 466 def list_service_account_access_tokens_with_http_info(service_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.list_service_account_access_tokens ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.list_service_account_access_tokens" end allowable_values = ['name', '-name', 'created_at', '-created_at', 'expires_at', '-expires_at'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/access_tokens'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListPersonalAccessTokensResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_service_account_access_tokens, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#list_service_account_access_tokens\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_service_account_application_keys(service_account_id, opts = {}) ⇒ Object
List application keys for this service account.
527 528 529 530 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 527 def list_service_account_application_keys(service_account_id, opts = {}) data, _status_code, _headers = list_service_account_application_keys_with_http_info(service_account_id, opts) data end |
#list_service_account_application_keys_with_http_info(service_account_id, opts = {}) ⇒ Array<(ListApplicationKeysResponse, Integer, Hash)>
List application keys for this service account.
List all application keys available for this service account.
545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 545 def list_service_account_application_keys_with_http_info(service_account_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.list_service_account_application_keys ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.list_service_account_application_keys" end allowable_values = ['created_at', '-created_at', 'last4', '-last4', 'name', '-name'] if @api_client.config.client_side_validation && opts[:'sort'] && !allowable_values.include?(opts[:'sort']) fail ArgumentError, "invalid value for \"sort\", must be one of #{allowable_values}" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/application_keys'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} query_params[:'page[size]'] = opts[:'page_size'] if !opts[:'page_size'].nil? query_params[:'page[number]'] = opts[:'page_number'] if !opts[:'page_number'].nil? query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'filter[created_at][start]'] = opts[:'filter_created_at_start'] if !opts[:'filter_created_at_start'].nil? query_params[:'filter[created_at][end]'] = opts[:'filter_created_at_end'] if !opts[:'filter_created_at_end'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListApplicationKeysResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_service_account_application_keys, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#list_service_account_application_keys\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#revoke_service_account_access_token(service_account_id, pat_id, opts = {}) ⇒ Object
Revoke an access token for a service account.
608 609 610 611 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 608 def revoke_service_account_access_token(service_account_id, pat_id, opts = {}) revoke_service_account_access_token_with_http_info(service_account_id, pat_id, opts) nil end |
#revoke_service_account_access_token_with_http_info(service_account_id, pat_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Revoke an access token for a service account.
Revoke a specific access token for a service account.
621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 621 def revoke_service_account_access_token_with_http_info(service_account_id, pat_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.revoke_service_account_access_token ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.revoke_service_account_access_token" end # verify the required parameter 'pat_id' is set if @api_client.config.client_side_validation && pat_id.nil? fail ArgumentError, "Missing the required parameter 'pat_id' when calling ServiceAccountsAPI.revoke_service_account_access_token" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/access_tokens/{pat_id}'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')).sub('{pat_id}', CGI.escape(pat_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :revoke_service_account_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#revoke_service_account_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_service_account_access_token(service_account_id, pat_id, body, opts = {}) ⇒ Object
Update an access token for a service account.
678 679 680 681 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 678 def update_service_account_access_token(service_account_id, pat_id, body, opts = {}) data, _status_code, _headers = update_service_account_access_token_with_http_info(service_account_id, pat_id, body, opts) data end |
#update_service_account_access_token_with_http_info(service_account_id, pat_id, body, opts = {}) ⇒ Array<(PersonalAccessTokenResponse, Integer, Hash)>
Update an access token for a service account.
Update a specific access token for a service account.
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 692 def update_service_account_access_token_with_http_info(service_account_id, pat_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.update_service_account_access_token ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.update_service_account_access_token" end # verify the required parameter 'pat_id' is set if @api_client.config.client_side_validation && pat_id.nil? fail ArgumentError, "Missing the required parameter 'pat_id' when calling ServiceAccountsAPI.update_service_account_access_token" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ServiceAccountsAPI.update_service_account_access_token" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/access_tokens/{pat_id}'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')).sub('{pat_id}', CGI.escape(pat_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'PersonalAccessTokenResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_service_account_access_token, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#update_service_account_access_token\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_service_account_application_key(service_account_id, app_key_id, body, opts = {}) ⇒ Object
Edit an application key for this service account.
755 756 757 758 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 755 def update_service_account_application_key(service_account_id, app_key_id, body, opts = {}) data, _status_code, _headers = update_service_account_application_key_with_http_info(service_account_id, app_key_id, body, opts) data end |
#update_service_account_application_key_with_http_info(service_account_id, app_key_id, body, opts = {}) ⇒ Array<(PartialApplicationKeyResponse, Integer, Hash)>
Edit an application key for this service account.
Edit an application key owned by this service account.
769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 |
# File 'lib/datadog_api_client/v2/api/service_accounts_api.rb', line 769 def update_service_account_application_key_with_http_info(service_account_id, app_key_id, body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ServiceAccountsAPI.update_service_account_application_key ...' end # verify the required parameter 'service_account_id' is set if @api_client.config.client_side_validation && service_account_id.nil? fail ArgumentError, "Missing the required parameter 'service_account_id' when calling ServiceAccountsAPI.update_service_account_application_key" end # verify the required parameter 'app_key_id' is set if @api_client.config.client_side_validation && app_key_id.nil? fail ArgumentError, "Missing the required parameter 'app_key_id' when calling ServiceAccountsAPI.update_service_account_application_key" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling ServiceAccountsAPI.update_service_account_application_key" end # resource path local_var_path = '/api/v2/service_accounts/{service_account_id}/application_keys/{app_key_id}'.sub('{service_account_id}', CGI.escape(service_account_id.to_s).gsub('%2F', '/')).sub('{app_key_id}', CGI.escape(app_key_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'PartialApplicationKeyResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_service_account_application_key, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ServiceAccountsAPI#update_service_account_application_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |