Class: DatadogAPIClient::V2::SyntheticsTestResultBucketKeys
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultBucketKeys
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb
Overview
Storage bucket keys for artifacts produced during a step or test.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#after_step_screenshot ⇒ Object
Key for the screenshot captured after the step (goal-based tests).
-
#after_turn_screenshot ⇒ Object
Key for the screenshot captured after the turn (goal-based tests).
-
#artifacts ⇒ Object
Key for miscellaneous artifacts.
-
#before_step_screenshot ⇒ Object
Key for the screenshot captured before the step (goal-based tests).
-
#before_turn_screenshot ⇒ Object
Key for the screenshot captured before the turn (goal-based tests).
-
#crash_report ⇒ Object
Key for a captured crash report.
-
#device_logs ⇒ Object
Key for captured device logs.
-
#email_messages ⇒ Object
Keys for email message payloads captured by the step.
-
#screenshot ⇒ Object
Key for the captured screenshot.
-
#snapshot ⇒ Object
Key for the captured DOM snapshot.
-
#source ⇒ Object
Key for the page source or element source.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
57 58 59 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 57 def additional_properties @additional_properties end |
#after_step_screenshot ⇒ Object
Key for the screenshot captured after the step (goal-based tests).
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 25 def after_step_screenshot @after_step_screenshot end |
#after_turn_screenshot ⇒ Object
Key for the screenshot captured after the turn (goal-based tests).
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 28 def after_turn_screenshot @after_turn_screenshot end |
#artifacts ⇒ Object
Key for miscellaneous artifacts.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 31 def artifacts @artifacts end |
#before_step_screenshot ⇒ Object
Key for the screenshot captured before the step (goal-based tests).
34 35 36 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 34 def before_step_screenshot @before_step_screenshot end |
#before_turn_screenshot ⇒ Object
Key for the screenshot captured before the turn (goal-based tests).
37 38 39 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 37 def before_turn_screenshot @before_turn_screenshot end |
#crash_report ⇒ Object
Key for a captured crash report.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 40 def crash_report @crash_report end |
#device_logs ⇒ Object
Key for captured device logs.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 43 def device_logs @device_logs end |
#email_messages ⇒ Object
Keys for email message payloads captured by the step.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 46 def @email_messages end |
#screenshot ⇒ Object
Key for the captured screenshot.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 49 def screenshot @screenshot end |
#snapshot ⇒ Object
Key for the captured DOM snapshot.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 52 def snapshot @snapshot end |
#source ⇒ Object
Key for the page source or element source.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_bucket_keys.rb', line 55 def source @source end |