Class: DatadogAPIClient::V2::SyntheticsTestResultDevice
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultDevice
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_device.rb
Overview
Device information for the test result (browser and mobile tests).
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#browser ⇒ Object
Browser information for the device used to run the test.
-
#id ⇒ Object
Device identifier.
-
#name ⇒ Object
Device name.
-
#platform ⇒ Object
Platform information for the device used to run the test.
-
#resolution ⇒ Object
Screen resolution of the device used to run the test.
-
#type ⇒ Object
Device type.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 42 def additional_properties @additional_properties end |
#browser ⇒ Object
Browser information for the device used to run the test.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 25 def browser @browser end |
#id ⇒ Object
Device identifier.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 28 def id @id end |
#name ⇒ Object
Device name.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 31 def name @name end |
#platform ⇒ Object
Platform information for the device used to run the test.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 34 def platform @platform end |
#resolution ⇒ Object
Screen resolution of the device used to run the test.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 37 def resolution @resolution end |
#type ⇒ Object
Device type.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_device.rb', line 40 def type @type end |