Class: DatadogAPIClient::V2::SyntheticsTestResultRequestInfo
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultRequestInfo
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb
Overview
Details of the outgoing request made during the test execution.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#allow_insecure ⇒ Object
Whether insecure certificates are allowed for this request.
-
#body ⇒ Object
Body sent with the request.
-
#call_type ⇒ Object
gRPC call type (for example, ‘unary`, `healthCheck`, or `reflection`).
-
#destination_service ⇒ Object
Destination service for a Network Path test.
-
#dns_server ⇒ Object
DNS server used to resolve the target host.
-
#dns_server_port ⇒ Object
Port of the DNS server used for resolution.
-
#e2e_queries ⇒ Object
Number of end-to-end probe queries issued.
-
#files ⇒ Object
Files attached to the request.
-
#headers ⇒ Object
Headers sent with the request.
-
#host ⇒ Object
Host targeted by the request.
-
#max_ttl ⇒ Object
Maximum TTL for network probe packets.
-
#message ⇒ Object
Message sent with the request (for WebSocket/TCP/UDP tests).
-
#method ⇒ Object
HTTP method used for the request.
-
#no_saving_response_body ⇒ Object
Whether the response body was not saved.
-
#port ⇒ Object
Port targeted by the request.
-
#service ⇒ Object
Service name targeted by the request (for gRPC tests).
-
#source_service ⇒ Object
Source service for a Network Path test.
-
#timeout ⇒ Object
Request timeout in milliseconds.
-
#tool_name ⇒ Object
Name of the MCP tool called (MCP tests only).
-
#traceroute_queries ⇒ Object
Number of traceroute probe queries issued.
-
#url ⇒ Object
URL targeted by the request.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
87 88 89 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 87 def additional_properties @additional_properties end |
#allow_insecure ⇒ Object
Whether insecure certificates are allowed for this request.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 25 def allow_insecure @allow_insecure end |
#body ⇒ Object
Body sent with the request.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 28 def body @body end |
#call_type ⇒ Object
gRPC call type (for example, ‘unary`, `healthCheck`, or `reflection`).
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 31 def call_type @call_type end |
#destination_service ⇒ Object
Destination service for a Network Path test.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 34 def destination_service @destination_service end |
#dns_server ⇒ Object
DNS server used to resolve the target host.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 37 def dns_server @dns_server end |
#dns_server_port ⇒ Object
Port of the DNS server used for resolution.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 40 def dns_server_port @dns_server_port end |
#e2e_queries ⇒ Object
Number of end-to-end probe queries issued.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 43 def e2e_queries @e2e_queries end |
#files ⇒ Object
Files attached to the request.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 46 def files @files end |
#headers ⇒ Object
Headers sent with the request.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 49 def headers @headers end |
#host ⇒ Object
Host targeted by the request.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 52 def host @host end |
#max_ttl ⇒ Object
Maximum TTL for network probe packets.
55 56 57 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 55 def max_ttl @max_ttl end |
#message ⇒ Object
Message sent with the request (for WebSocket/TCP/UDP tests).
58 59 60 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 58 def @message end |
#method ⇒ Object
HTTP method used for the request.
61 62 63 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 61 def method @method end |
#no_saving_response_body ⇒ Object
Whether the response body was not saved.
64 65 66 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 64 def no_saving_response_body @no_saving_response_body end |
#port ⇒ Object
Port targeted by the request. Can be a number or a string variable reference.
67 68 69 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 67 def port @port end |
#service ⇒ Object
Service name targeted by the request (for gRPC tests).
70 71 72 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 70 def service @service end |
#source_service ⇒ Object
Source service for a Network Path test.
73 74 75 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 73 def source_service @source_service end |
#timeout ⇒ Object
Request timeout in milliseconds.
76 77 78 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 76 def timeout @timeout end |
#tool_name ⇒ Object
Name of the MCP tool called (MCP tests only).
79 80 81 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 79 def tool_name @tool_name end |
#traceroute_queries ⇒ Object
Number of traceroute probe queries issued.
82 83 84 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 82 def traceroute_queries @traceroute_queries end |
#url ⇒ Object
URL targeted by the request.
85 86 87 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_request_info.rb', line 85 def url @url end |