Class: DatadogAPIClient::V2::SyntheticsTestResultSummaryAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::SyntheticsTestResultSummaryAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb
Overview
Attributes of a Synthetic test result summary.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#device ⇒ Object
Device information for the test result (browser and mobile tests).
-
#execution_info ⇒ Object
Execution details for a Synthetic test result.
-
#finished_at ⇒ Object
Timestamp of when the test finished (in milliseconds).
-
#location ⇒ Object
Location information for a Synthetic test result.
-
#run_type ⇒ Object
The type of run for a Synthetic test result.
-
#started_at ⇒ Object
Timestamp of when the test started (in milliseconds).
-
#status ⇒ Object
Status of a Synthetic test result.
-
#steps_info ⇒ Object
Step execution summary for a Synthetic test result.
-
#test_sub_type ⇒ Object
Subtype of the Synthetic test that produced this result.
-
#test_type ⇒ Object
Type of the Synthetic test that produced this result.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 54 def additional_properties @additional_properties end |
#device ⇒ Object
Device information for the test result (browser and mobile tests).
25 26 27 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 25 def device @device end |
#execution_info ⇒ Object
Execution details for a Synthetic test result.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 28 def execution_info @execution_info end |
#finished_at ⇒ Object
Timestamp of when the test finished (in milliseconds).
31 32 33 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 31 def finished_at @finished_at end |
#location ⇒ Object
Location information for a Synthetic test result.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 34 def location @location end |
#run_type ⇒ Object
The type of run for a Synthetic test result.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 37 def run_type @run_type end |
#started_at ⇒ Object
Timestamp of when the test started (in milliseconds).
40 41 42 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 40 def started_at @started_at end |
#status ⇒ Object
Status of a Synthetic test result.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 43 def status @status end |
#steps_info ⇒ Object
Step execution summary for a Synthetic test result.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 46 def steps_info @steps_info end |
#test_sub_type ⇒ Object
Subtype of the Synthetic test that produced this result.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 49 def test_sub_type @test_sub_type end |
#test_type ⇒ Object
Type of the Synthetic test that produced this result.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/synthetics_test_result_summary_attributes.rb', line 52 def test_type @test_type end |