Class: DatadogAPIClient::V2::TagPolicyAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::TagPolicyAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/tag_policy_attributes.rb
Overview
The attributes of a tag policy resource.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#created_at ⇒ Object
readonly
The RFC 3339 timestamp at which the policy was created.
-
#created_by ⇒ Object
readonly
The identifier of the user who created the policy.
-
#deleted_at ⇒ Object
The RFC 3339 timestamp at which the policy was soft-deleted.
-
#deleted_by ⇒ Object
The identifier of the user who soft-deleted the policy.
-
#enabled ⇒ Object
readonly
Whether the policy is currently enforced.
-
#modified_at ⇒ Object
readonly
The RFC 3339 timestamp at which the policy was last modified.
-
#modified_by ⇒ Object
readonly
The identifier of the user who last modified the policy.
-
#negated ⇒ Object
readonly
When ‘true`, the policy matches tag values that do NOT match any of the supplied patterns.
-
#policy_name ⇒ Object
readonly
Human-readable name for the tag policy.
-
#policy_type ⇒ Object
readonly
How the policy is enforced.
-
#required ⇒ Object
readonly
When ‘true`, telemetry without this tag is treated as a violation.
-
#scope ⇒ Object
readonly
The scope the policy applies within.
-
#source ⇒ Object
readonly
The telemetry source that a tag policy applies to.
-
#tag_key ⇒ Object
readonly
The tag key that the policy governs.
-
#tag_value_patterns ⇒ Object
readonly
The patterns that valid values for the tag key must match.
-
#version ⇒ Object
readonly
A monotonically increasing version counter that is incremented on each update.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
73 74 75 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 73 def additional_properties @additional_properties end |
#created_at ⇒ Object
The RFC 3339 timestamp at which the policy was created.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 25 def created_at @created_at end |
#created_by ⇒ Object
The identifier of the user who created the policy.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 28 def created_by @created_by end |
#deleted_at ⇒ Object
The RFC 3339 timestamp at which the policy was soft-deleted. ‘null` if the policy has not been deleted. Only present when `include_deleted=true` is requested.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 31 def deleted_at @deleted_at end |
#deleted_by ⇒ Object
The identifier of the user who soft-deleted the policy. ‘null` if the policy has not been deleted.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 34 def deleted_by @deleted_by end |
#enabled ⇒ Object
Whether the policy is currently enforced.
37 38 39 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 37 def enabled @enabled end |
#modified_at ⇒ Object
The RFC 3339 timestamp at which the policy was last modified.
40 41 42 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 40 def modified_at @modified_at end |
#modified_by ⇒ Object
The identifier of the user who last modified the policy.
43 44 45 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 43 def modified_by @modified_by end |
#negated ⇒ Object
When ‘true`, the policy matches tag values that do NOT match any of the supplied patterns.
46 47 48 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 46 def negated @negated end |
#policy_name ⇒ Object
Human-readable name for the tag policy.
49 50 51 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 49 def policy_name @policy_name end |
#policy_type ⇒ Object
How the policy is enforced. ‘blocking` rejects telemetry that violates the policy. `surfacing` only highlights non-compliant telemetry without blocking it.
53 54 55 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 53 def policy_type @policy_type end |
#required ⇒ Object
When ‘true`, telemetry without this tag is treated as a violation.
56 57 58 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 56 def required @required end |
#scope ⇒ Object
The scope the policy applies within.
59 60 61 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 59 def scope @scope end |
#source ⇒ Object
The telemetry source that a tag policy applies to.
62 63 64 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 62 def source @source end |
#tag_key ⇒ Object
The tag key that the policy governs.
65 66 67 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 65 def tag_key @tag_key end |
#tag_value_patterns ⇒ Object
The patterns that valid values for the tag key must match.
68 69 70 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 68 def tag_value_patterns @tag_value_patterns end |
#version ⇒ Object
A monotonically increasing version counter that is incremented on each update.
71 72 73 |
# File 'lib/datadog_api_client/v2/models/tag_policy_attributes.rb', line 71 def version @version end |