Class: DatadogAPIClient::V2::TagPolicyCreateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::TagPolicyCreateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb
Overview
Attributes that can be supplied when creating a tag policy.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#enabled ⇒ Object
Whether the policy is currently enforced.
-
#negated ⇒ Object
When ‘true`, the policy matches tag values that do NOT match any of the supplied patterns.
-
#policy_name ⇒ Object
readonly
Human-readable name for the tag policy.
-
#policy_type ⇒ Object
readonly
The policy type allowed when creating a tag policy.
-
#required ⇒ Object
When ‘true`, telemetry without this tag is treated as a violation.
-
#scope ⇒ Object
readonly
The scope the policy applies within.
-
#source ⇒ Object
readonly
The telemetry source that a tag policy applies to.
-
#tag_key ⇒ Object
readonly
The tag key that the policy governs (for example, ‘service`).
-
#tag_value_patterns ⇒ Object
readonly
One or more patterns that valid values for the tag key must match.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 54 def additional_properties @additional_properties end |
#enabled ⇒ Object
Whether the policy is currently enforced. Defaults to ‘true` for newly created policies.
25 26 27 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 25 def enabled @enabled end |
#negated ⇒ Object
When ‘true`, the policy matches tag values that do NOT match any of the supplied patterns. Defaults to `false`.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 28 def negated @negated end |
#policy_name ⇒ Object
Human-readable name for the tag policy.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 31 def policy_name @policy_name end |
#policy_type ⇒ Object
The policy type allowed when creating a tag policy. Only ‘surfacing` is accepted at creation time.
35 36 37 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 35 def policy_type @policy_type end |
#required ⇒ Object
When ‘true`, telemetry without this tag is treated as a violation. Defaults to `false`.
38 39 40 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 38 def required @required end |
#scope ⇒ Object
The scope the policy applies within. Typically an environment, team, or organization-level identifier used to limit where the policy is enforced.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 42 def scope @scope end |
#source ⇒ Object
The telemetry source that a tag policy applies to.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 45 def source @source end |
#tag_key ⇒ Object
The tag key that the policy governs (for example, ‘service`).
48 49 50 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 48 def tag_key @tag_key end |
#tag_value_patterns ⇒ Object
One or more patterns that valid values for the tag key must match. At least one pattern is required.
52 53 54 |
# File 'lib/datadog_api_client/v2/models/tag_policy_create_attributes.rb', line 52 def tag_value_patterns @tag_value_patterns end |