Class: DatadogAPIClient::V2::TagPolicyUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::TagPolicyUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb
Overview
Mutable attributes of a tag policy. Each field is optional; omitting a field leaves its current value unchanged. The ‘source` of a policy cannot be changed.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#enabled ⇒ Object
Whether the policy is currently enforced.
-
#negated ⇒ Object
When ‘true`, the policy matches tag values that do NOT match any of the supplied patterns.
-
#policy_name ⇒ Object
Human-readable name for the tag policy.
-
#policy_type ⇒ Object
How the policy is enforced.
-
#required ⇒ Object
When ‘true`, telemetry without this tag is treated as a violation.
-
#scope ⇒ Object
The scope the policy applies within.
-
#tag_key ⇒ Object
The tag key that the policy governs.
-
#tag_value_patterns ⇒ Object
One or more patterns that valid values for the tag key must match.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
50 51 52 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 50 def additional_properties @additional_properties end |
#enabled ⇒ Object
Whether the policy is currently enforced.
26 27 28 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 26 def enabled @enabled end |
#negated ⇒ Object
When ‘true`, the policy matches tag values that do NOT match any of the supplied patterns.
29 30 31 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 29 def negated @negated end |
#policy_name ⇒ Object
Human-readable name for the tag policy.
32 33 34 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 32 def policy_name @policy_name end |
#policy_type ⇒ Object
How the policy is enforced. ‘blocking` rejects telemetry that violates the policy. `surfacing` only highlights non-compliant telemetry without blocking it.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 36 def policy_type @policy_type end |
#required ⇒ Object
When ‘true`, telemetry without this tag is treated as a violation.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 39 def required @required end |
#scope ⇒ Object
The scope the policy applies within.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 42 def scope @scope end |
#tag_key ⇒ Object
The tag key that the policy governs.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 45 def tag_key @tag_key end |
#tag_value_patterns ⇒ Object
One or more patterns that valid values for the tag key must match.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/tag_policy_update_attributes.rb', line 48 def tag_value_patterns @tag_value_patterns end |