Class: DatadogAPIClient::V2::TestOptimizationAPI

Inherits:
Object
  • Object
show all
Defined in:
lib/datadog_api_client/v2/api/test_optimization_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ TestOptimizationAPI

Returns a new instance of TestOptimizationAPI.



22
23
24
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 22

def initialize(api_client = DatadogAPIClient::APIClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



20
21
22
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 20

def api_client
  @api_client
end

Instance Method Details

#delete_test_optimization_service_settings(body, opts = {}) ⇒ Object

Delete Test Optimization service settings.



29
30
31
32
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 29

def delete_test_optimization_service_settings(body, opts = {})
  delete_test_optimization_service_settings_with_http_info(body, opts)
  nil
end

#delete_test_optimization_service_settings_with_http_info(body, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Test Optimization service settings.

Delete Test Optimization settings for a specific service identified by repository, service name, and environment.

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 41

def delete_test_optimization_service_settings_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.delete_test_optimization_service_settings".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.delete_test_optimization_service_settings")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.delete_test_optimization_service_settings"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.delete_test_optimization_service_settings ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling TestOptimizationAPI.delete_test_optimization_service_settings"
  end
  # resource path
  local_var_path = '/api/v2/ci/test-optimization/settings/service'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['*/*'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :delete_test_optimization_service_settings,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#delete_test_optimization_service_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_flaky_tests_management_policies(body, opts = {}) ⇒ Object

Get Flaky Tests Management policies.



102
103
104
105
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 102

def get_flaky_tests_management_policies(body, opts = {})
  data, _status_code, _headers = get_flaky_tests_management_policies_with_http_info(body, opts)
  data
end

#get_flaky_tests_management_policies_with_http_info(body, opts = {}) ⇒ Array<(TestOptimizationFlakyTestsManagementPoliciesResponse, Integer, Hash)>

Get Flaky Tests Management policies.

Retrieve Flaky Tests Management repository-level policies for the given repository.

Parameters:

Returns:



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 114

def get_flaky_tests_management_policies_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.get_flaky_tests_management_policies".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.get_flaky_tests_management_policies")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.get_flaky_tests_management_policies"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.get_flaky_tests_management_policies ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling TestOptimizationAPI.get_flaky_tests_management_policies"
  end
  # resource path
  local_var_path = '/api/v2/ci/test-optimization/settings/policies'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'TestOptimizationFlakyTestsManagementPoliciesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :get_flaky_tests_management_policies,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#get_flaky_tests_management_policies\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_test_optimization_service_settings(body, opts = {}) ⇒ Object

Get Test Optimization service settings.



175
176
177
178
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 175

def get_test_optimization_service_settings(body, opts = {})
  data, _status_code, _headers = get_test_optimization_service_settings_with_http_info(body, opts)
  data
end

#get_test_optimization_service_settings_with_http_info(body, opts = {}) ⇒ Array<(TestOptimizationServiceSettingsResponse, Integer, Hash)>

Get Test Optimization service settings.

Retrieve Test Optimization settings for a specific service identified by repository, service name, and environment.

Parameters:

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 187

def get_test_optimization_service_settings_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.get_test_optimization_service_settings".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.get_test_optimization_service_settings")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.get_test_optimization_service_settings"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.get_test_optimization_service_settings ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling TestOptimizationAPI.get_test_optimization_service_settings"
  end
  # resource path
  local_var_path = '/api/v2/ci/test-optimization/settings/service'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'TestOptimizationServiceSettingsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :get_test_optimization_service_settings,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#get_test_optimization_service_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search_flaky_tests(opts = {}) ⇒ Object

Search flaky tests.



248
249
250
251
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 248

def search_flaky_tests(opts = {})
  data, _status_code, _headers = search_flaky_tests_with_http_info(opts)
  data
end

#search_flaky_tests_with_http_info(opts = {}) ⇒ Array<(FlakyTestsSearchResponse, Integer, Hash)>

Search flaky tests.

List endpoint returning flaky tests from Flaky Test Management. Results are paginated.

The response includes comprehensive test information including:

  • Test identification and metadata (module, suite, name)

  • Flaky state and categorization

  • First and last flake occurrences (timestamp, branch, commit SHA)

  • Test execution statistics from the last 7 days (failure rate)

  • Pipeline impact metrics (failed pipelines count, total lost time)

  • Complete status change history (optional, ordered from most recent to oldest)

Set ‘include_history` to `true` in the request to receive the status change history for each test. History is disabled by default for better performance.

Results support filtering by various facets including service, environment, repository, branch, and test state.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(FlakyTestsSearchResponse, Integer, Hash)>)

    FlakyTestsSearchResponse data, response status code and response headers



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 273

def search_flaky_tests_with_http_info(opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.search_flaky_tests".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.search_flaky_tests")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.search_flaky_tests"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.search_flaky_tests ...'
  end
  # resource path
  local_var_path = '/api/v2/test/flaky-test-management/tests'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'body'])

  # return_type
  return_type = opts[:debug_return_type] || 'FlakyTestsSearchResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :search_flaky_tests,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#search_flaky_tests\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#search_flaky_tests_with_pagination(opts = {}) {|FlakyTest| ... } ⇒ Object

Search flaky tests.

Provide a paginated version of #search_flaky_tests, returning all items.

To use it you need to use a block: search_flaky_tests_with_pagination { |item| p item }

Yields:



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 334

def search_flaky_tests_with_pagination(opts = {})
    api_version = "V2"
    page_size = @api_client.get_attribute_from_path(opts, "body.data.attributes.page.limit", 10)
    @api_client.set_attribute_from_path(api_version, opts, "body.data.attributes.page.limit", FlakyTestsSearchRequest, page_size)
    while true do
        response = search_flaky_tests(opts)
        @api_client.get_attribute_from_path(response, "data").each { |item| yield(item) }
        if @api_client.get_attribute_from_path(response, "data").length == 0
          break
        end
        @api_client.set_attribute_from_path(api_version, opts, "body.data.attributes.page.cursor", FlakyTestsSearchRequest, @api_client.get_attribute_from_path(response, "meta.pagination.next_page"))
    end
end

#update_flaky_tests(body, opts = {}) ⇒ Object

Update flaky test states.



351
352
353
354
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 351

def update_flaky_tests(body, opts = {})
  data, _status_code, _headers = update_flaky_tests_with_http_info(body, opts)
  data
end

#update_flaky_tests_management_policies(body, opts = {}) ⇒ Object

Update Flaky Tests Management policies.



424
425
426
427
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 424

def update_flaky_tests_management_policies(body, opts = {})
  data, _status_code, _headers = update_flaky_tests_management_policies_with_http_info(body, opts)
  data
end

#update_flaky_tests_management_policies_with_http_info(body, opts = {}) ⇒ Array<(TestOptimizationFlakyTestsManagementPoliciesResponse, Integer, Hash)>

Update Flaky Tests Management policies.

Partially update Flaky Tests Management repository-level policies for the given repository. Only provided policy blocks are updated; omitted blocks are left unchanged.

Parameters:

Returns:



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 437

def update_flaky_tests_management_policies_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.update_flaky_tests_management_policies".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_flaky_tests_management_policies")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_flaky_tests_management_policies"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.update_flaky_tests_management_policies ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling TestOptimizationAPI.update_flaky_tests_management_policies"
  end
  # resource path
  local_var_path = '/api/v2/ci/test-optimization/settings/policies'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'TestOptimizationFlakyTestsManagementPoliciesResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :update_flaky_tests_management_policies,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#update_flaky_tests_management_policies\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_flaky_tests_with_http_info(body, opts = {}) ⇒ Array<(UpdateFlakyTestsResponse, Integer, Hash)>

Update flaky test states.

Update the state of multiple flaky tests in Flaky Test Management.

Parameters:

Returns:

  • (Array<(UpdateFlakyTestsResponse, Integer, Hash)>)

    UpdateFlakyTestsResponse data, response status code and response headers



363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 363

def update_flaky_tests_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.update_flaky_tests".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_flaky_tests")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_flaky_tests"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.update_flaky_tests ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling TestOptimizationAPI.update_flaky_tests"
  end
  # resource path
  local_var_path = '/api/v2/test/flaky-test-management/tests'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'UpdateFlakyTestsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :update_flaky_tests,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#update_flaky_tests\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_test_optimization_service_settings(body, opts = {}) ⇒ Object

Update Test Optimization service settings.



498
499
500
501
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 498

def update_test_optimization_service_settings(body, opts = {})
  data, _status_code, _headers = update_test_optimization_service_settings_with_http_info(body, opts)
  data
end

#update_test_optimization_service_settings_with_http_info(body, opts = {}) ⇒ Array<(TestOptimizationServiceSettingsResponse, Integer, Hash)>

Update Test Optimization service settings.

Partially update Test Optimization settings for a specific service identified by repository, service name, and environment. Only provided fields are updated; null or omitted fields are left unchanged.

Parameters:

Returns:



511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
# File 'lib/datadog_api_client/v2/api/test_optimization_api.rb', line 511

def update_test_optimization_service_settings_with_http_info(body, opts = {})
  unstable_enabled = @api_client.config.unstable_operations["v2.update_test_optimization_service_settings".to_sym]
  if unstable_enabled
    @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_test_optimization_service_settings")
  else
    raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_test_optimization_service_settings"))
  end

  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: TestOptimizationAPI.update_test_optimization_service_settings ...'
  end
  # verify the required parameter 'body' is set
  if @api_client.config.client_side_validation && body.nil?
    fail ArgumentError, "Missing the required parameter 'body' when calling TestOptimizationAPI.update_test_optimization_service_settings"
  end
  # resource path
  local_var_path = '/api/v2/ci/test-optimization/settings/service'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(body)

  # return_type
  return_type = opts[:debug_return_type] || 'TestOptimizationServiceSettingsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth, :AuthZ]

  new_options = opts.merge(
    :operation => :update_test_optimization_service_settings,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type,
    :api_version => "V2"
  )

  data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: TestOptimizationAPI#update_test_optimization_service_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end