Class: DatadogAPIClient::V2::TestOptimizationUpdateServiceSettingsRequestAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::TestOptimizationUpdateServiceSettingsRequestAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb
Overview
Attributes for updating Test Optimization service settings.
All non-required fields are optional; only provided fields will be updated.
Setting a field to null is a no-op. To reset a setting to inherit from the repository level, use the corresponding <setting>_inherit field.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#auto_test_retries_enabled ⇒ Object
Whether Auto Test Retries are enabled for this service.
-
#auto_test_retries_enabled_inherit ⇒ Object
When
true, resets the Auto Test Retries setting to inherit from the repository level. -
#code_coverage_enabled ⇒ Object
Whether Code Coverage is enabled for this service.
-
#code_coverage_enabled_inherit ⇒ Object
When
true, resets the Code Coverage setting to inherit from the repository level. -
#early_flake_detection_enabled ⇒ Object
Whether Early Flake Detection is enabled for this service.
-
#early_flake_detection_enabled_inherit ⇒ Object
When
true, resets the Early Flake Detection setting to inherit from the repository level. -
#env ⇒ Object
The environment name.
-
#failed_test_replay_enabled ⇒ Object
Whether Failed Test Replay is enabled for this service.
-
#failed_test_replay_enabled_inherit ⇒ Object
When
true, resets the Failed Test Replay setting to inherit from the repository level. -
#pr_comments_enabled ⇒ Object
This field is ignored.
-
#repository_id ⇒ Object
readonly
The repository identifier.
-
#service_name ⇒ Object
readonly
The service name.
-
#test_impact_analysis_enabled ⇒ Object
Whether Test Impact Analysis is enabled for this service.
-
#test_impact_analysis_enabled_inherit ⇒ Object
When
true, resets the Test Impact Analysis setting to inherit from the repository level.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
68 69 70 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 68 def additional_properties @additional_properties end |
#auto_test_retries_enabled ⇒ Object
Whether Auto Test Retries are enabled for this service. Setting to null is a no-op; use auto_test_retries_enabled_inherit to reset to repository-level inheritance.
27 28 29 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 27 def auto_test_retries_enabled @auto_test_retries_enabled end |
#auto_test_retries_enabled_inherit ⇒ Object
When true, resets the Auto Test Retries setting to inherit from the repository level.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 30 def auto_test_retries_enabled_inherit @auto_test_retries_enabled_inherit end |
#code_coverage_enabled ⇒ Object
Whether Code Coverage is enabled for this service. Setting to null is a no-op; use code_coverage_enabled_inherit to reset to repository-level inheritance.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 33 def code_coverage_enabled @code_coverage_enabled end |
#code_coverage_enabled_inherit ⇒ Object
When true, resets the Code Coverage setting to inherit from the repository level.
36 37 38 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 36 def code_coverage_enabled_inherit @code_coverage_enabled_inherit end |
#early_flake_detection_enabled ⇒ Object
Whether Early Flake Detection is enabled for this service. Setting to null is a no-op; use early_flake_detection_enabled_inherit to reset to repository-level inheritance.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 39 def early_flake_detection_enabled @early_flake_detection_enabled end |
#early_flake_detection_enabled_inherit ⇒ Object
When true, resets the Early Flake Detection setting to inherit from the repository level.
42 43 44 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 42 def early_flake_detection_enabled_inherit @early_flake_detection_enabled_inherit end |
#env ⇒ Object
The environment name. If omitted, defaults to none.
45 46 47 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 45 def env @env end |
#failed_test_replay_enabled ⇒ Object
Whether Failed Test Replay is enabled for this service. Setting to null is a no-op; use failed_test_replay_enabled_inherit to reset to repository-level inheritance.
48 49 50 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 48 def failed_test_replay_enabled @failed_test_replay_enabled end |
#failed_test_replay_enabled_inherit ⇒ Object
When true, resets the Failed Test Replay setting to inherit from the repository level.
51 52 53 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 51 def failed_test_replay_enabled_inherit @failed_test_replay_enabled_inherit end |
#pr_comments_enabled ⇒ Object
This field is ignored. PR Comments cannot be overridden at the service level.
54 55 56 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 54 def pr_comments_enabled @pr_comments_enabled end |
#repository_id ⇒ Object
The repository identifier.
57 58 59 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 57 def repository_id @repository_id end |
#service_name ⇒ Object
The service name.
60 61 62 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 60 def service_name @service_name end |
#test_impact_analysis_enabled ⇒ Object
Whether Test Impact Analysis is enabled for this service. Setting to null is a no-op; use test_impact_analysis_enabled_inherit to reset to repository-level inheritance.
63 64 65 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 63 def test_impact_analysis_enabled @test_impact_analysis_enabled end |
#test_impact_analysis_enabled_inherit ⇒ Object
When true, resets the Test Impact Analysis setting to inherit from the repository level.
66 67 68 |
# File 'lib/datadog_api_client/v2/models/test_optimization_update_service_settings_request_attributes.rb', line 66 def test_impact_analysis_enabled_inherit @test_impact_analysis_enabled_inherit end |