Class: DatadogAPIClient::V2::UpsertCloudInventorySyncConfigRequestData
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::UpsertCloudInventorySyncConfigRequestData
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb
Overview
Storage Management configuration data for the create or update request.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#attributes ⇒ Object
readonly
Settings for the cloud provider specified in ‘data.id`.
-
#id ⇒ Object
readonly
Cloud provider for this sync configuration (‘aws`, `gcp`, or `azure`).
-
#type ⇒ Object
readonly
Always ‘cloud_provider`.
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
33 34 35 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 33 def additional_properties @additional_properties end |
#attributes ⇒ Object
Settings for the cloud provider specified in ‘data.id`. Include only the matching provider object (`aws`, `gcp`, or `azure`).
25 26 27 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 25 def attributes @attributes end |
#id ⇒ Object
Cloud provider for this sync configuration (‘aws`, `gcp`, or `azure`). For requests, must match the provider block supplied under `attributes`.
28 29 30 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 28 def id @id end |
#type ⇒ Object
Always ‘cloud_provider`.
31 32 33 |
# File 'lib/datadog_api_client/v2/models/upsert_cloud_inventory_sync_config_request_data.rb', line 31 def type @type end |