Class: DatadogAPIClient::V2::UserUpdateAttributes
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::UserUpdateAttributes
- Includes:
- BaseGenericModel
- Defined in:
- lib/datadog_api_client/v2/models/user_update_attributes.rb
Overview
Attributes of the edited user.
Instance Attribute Summary collapse
-
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
-
#disabled ⇒ Object
When set to ‘true`, the user is deactivated and can no longer log in.
-
#email ⇒ Object
The email address of the user, used for login and notifications.
-
#name ⇒ Object
The full display name of the user as shown in the Datadog UI.
-
#title ⇒ Object
The job title of the user (for example, “Senior Engineer” or “Product Manager”).
Method Summary
Methods included from BaseGenericModel
Instance Attribute Details
#additional_properties ⇒ Object
Returns the value of attribute additional_properties.
39 40 41 |
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 39 def additional_properties @additional_properties end |
#disabled ⇒ Object
When set to ‘true`, the user is deactivated and can no longer log in. When `false`, the user is active.
26 27 28 |
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 26 def disabled @disabled end |
#email ⇒ Object
The email address of the user, used for login and notifications. Must be a valid email format.
30 31 32 |
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 30 def email @email end |
#name ⇒ Object
The full display name of the user as shown in the Datadog UI. Maximum 55 characters, cannot contain ‘<` or `>`.
34 35 36 |
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 34 def name @name end |
#title ⇒ Object
The job title of the user (for example, “Senior Engineer” or “Product Manager”).
37 38 39 |
# File 'lib/datadog_api_client/v2/models/user_update_attributes.rb', line 37 def title @title end |