Class: DatadogAPIClient::V2::WebIntegrationsAPI
- Inherits:
-
Object
- Object
- DatadogAPIClient::V2::WebIntegrationsAPI
- Defined in:
- lib/datadog_api_client/v2/api/web_integrations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_web_integration_account(integration_name, body, opts = {}) ⇒ Object
Create a web integration account.
-
#create_web_integration_account_with_http_info(integration_name, body, opts = {}) ⇒ Array<(WebIntegrationAccountResponse, Integer, Hash)>
Create a web integration account.
-
#delete_web_integration_account(integration_name, account_id, opts = {}) ⇒ Object
Delete a web integration account.
-
#delete_web_integration_account_with_http_info(integration_name, account_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a web integration account.
-
#get_web_integration_account(integration_name, account_id, opts = {}) ⇒ Object
Get a web integration account.
-
#get_web_integration_account_with_http_info(integration_name, account_id, opts = {}) ⇒ Array<(WebIntegrationAccountResponse, Integer, Hash)>
Get a web integration account.
-
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ WebIntegrationsAPI
constructor
A new instance of WebIntegrationsAPI.
-
#list_web_integration_accounts(integration_name, opts = {}) ⇒ Object
List web integration accounts.
-
#list_web_integration_accounts_with_http_info(integration_name, opts = {}) ⇒ Array<(WebIntegrationAccountsResponse, Integer, Hash)>
List web integration accounts.
-
#update_web_integration_account(integration_name, account_id, body, opts = {}) ⇒ Object
Update a web integration account.
-
#update_web_integration_account_with_http_info(integration_name, account_id, body, opts = {}) ⇒ Array<(WebIntegrationAccountResponse, Integer, Hash)>
Update a web integration account.
Constructor Details
#initialize(api_client = DatadogAPIClient::APIClient.default) ⇒ WebIntegrationsAPI
Returns a new instance of WebIntegrationsAPI.
22 23 24 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 22 def initialize(api_client = DatadogAPIClient::APIClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
20 21 22 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 20 def api_client @api_client end |
Instance Method Details
#create_web_integration_account(integration_name, body, opts = {}) ⇒ Object
Create a web integration account.
29 30 31 32 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 29 def create_web_integration_account(integration_name, body, opts = {}) data, _status_code, _headers = create_web_integration_account_with_http_info(integration_name, body, opts) data end |
#create_web_integration_account_with_http_info(integration_name, body, opts = {}) ⇒ Array<(WebIntegrationAccountResponse, Integer, Hash)>
Create a web integration account.
Create a new account for a given web integration.
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 42 def create_web_integration_account_with_http_info(integration_name, body, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.create_web_integration_account".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.create_web_integration_account") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.create_web_integration_account")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebIntegrationsAPI.create_web_integration_account ...' end # verify the required parameter 'integration_name' is set if @api_client.config.client_side_validation && integration_name.nil? fail ArgumentError, "Missing the required parameter 'integration_name' when calling WebIntegrationsAPI.create_web_integration_account" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WebIntegrationsAPI.create_web_integration_account" end # resource path local_var_path = '/api/v2/web-integrations/{integration_name}/accounts'.sub('{integration_name}', CGI.escape(integration_name.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'WebIntegrationAccountResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :create_web_integration_account, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Post, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebIntegrationsAPI#create_web_integration_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_web_integration_account(integration_name, account_id, opts = {}) ⇒ Object
Delete a web integration account.
107 108 109 110 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 107 def delete_web_integration_account(integration_name, account_id, opts = {}) delete_web_integration_account_with_http_info(integration_name, account_id, opts) nil end |
#delete_web_integration_account_with_http_info(integration_name, account_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a web integration account.
Delete an account for a given web integration.
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 120 def delete_web_integration_account_with_http_info(integration_name, account_id, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.delete_web_integration_account".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.delete_web_integration_account") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.delete_web_integration_account")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebIntegrationsAPI.delete_web_integration_account ...' end # verify the required parameter 'integration_name' is set if @api_client.config.client_side_validation && integration_name.nil? fail ArgumentError, "Missing the required parameter 'integration_name' when calling WebIntegrationsAPI.delete_web_integration_account" end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling WebIntegrationsAPI.delete_web_integration_account" end # resource path local_var_path = '/api/v2/web-integrations/{integration_name}/accounts/{account_id}'.sub('{integration_name}', CGI.escape(integration_name.to_s).gsub('%2F', '/')).sub('{account_id}', CGI.escape(account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['*/*']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :delete_web_integration_account, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Delete, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebIntegrationsAPI#delete_web_integration_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_web_integration_account(integration_name, account_id, opts = {}) ⇒ Object
Get a web integration account.
183 184 185 186 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 183 def get_web_integration_account(integration_name, account_id, opts = {}) data, _status_code, _headers = get_web_integration_account_with_http_info(integration_name, account_id, opts) data end |
#get_web_integration_account_with_http_info(integration_name, account_id, opts = {}) ⇒ Array<(WebIntegrationAccountResponse, Integer, Hash)>
Get a web integration account.
Get a single account for a given web integration.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 196 def get_web_integration_account_with_http_info(integration_name, account_id, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.get_web_integration_account".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.get_web_integration_account") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.get_web_integration_account")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebIntegrationsAPI.get_web_integration_account ...' end # verify the required parameter 'integration_name' is set if @api_client.config.client_side_validation && integration_name.nil? fail ArgumentError, "Missing the required parameter 'integration_name' when calling WebIntegrationsAPI.get_web_integration_account" end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling WebIntegrationsAPI.get_web_integration_account" end # resource path local_var_path = '/api/v2/web-integrations/{integration_name}/accounts/{account_id}'.sub('{integration_name}', CGI.escape(integration_name.to_s).gsub('%2F', '/')).sub('{account_id}', CGI.escape(account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebIntegrationAccountResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :get_web_integration_account, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebIntegrationsAPI#get_web_integration_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_web_integration_accounts(integration_name, opts = {}) ⇒ Object
List web integration accounts.
259 260 261 262 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 259 def list_web_integration_accounts(integration_name, opts = {}) data, _status_code, _headers = list_web_integration_accounts_with_http_info(integration_name, opts) data end |
#list_web_integration_accounts_with_http_info(integration_name, opts = {}) ⇒ Array<(WebIntegrationAccountsResponse, Integer, Hash)>
List web integration accounts.
List accounts for a given web integration.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 271 def list_web_integration_accounts_with_http_info(integration_name, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.list_web_integration_accounts".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.list_web_integration_accounts") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.list_web_integration_accounts")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebIntegrationsAPI.list_web_integration_accounts ...' end # verify the required parameter 'integration_name' is set if @api_client.config.client_side_validation && integration_name.nil? fail ArgumentError, "Missing the required parameter 'integration_name' when calling WebIntegrationsAPI.list_web_integration_accounts" end # resource path local_var_path = '/api/v2/web-integrations/{integration_name}/accounts'.sub('{integration_name}', CGI.escape(integration_name.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WebIntegrationAccountsResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :list_web_integration_accounts, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Get, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebIntegrationsAPI#list_web_integration_accounts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_web_integration_account(integration_name, account_id, body, opts = {}) ⇒ Object
Update a web integration account.
330 331 332 333 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 330 def update_web_integration_account(integration_name, account_id, body, opts = {}) data, _status_code, _headers = update_web_integration_account_with_http_info(integration_name, account_id, body, opts) data end |
#update_web_integration_account_with_http_info(integration_name, account_id, body, opts = {}) ⇒ Array<(WebIntegrationAccountResponse, Integer, Hash)>
Update a web integration account.
Update an existing account for a given web integration.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/datadog_api_client/v2/api/web_integrations_api.rb', line 344 def update_web_integration_account_with_http_info(integration_name, account_id, body, opts = {}) unstable_enabled = @api_client.config.unstable_operations["v2.update_web_integration_account".to_sym] if unstable_enabled @api_client.config.logger.warn format("Using unstable operation '%s'", "v2.update_web_integration_account") else raise DatadogAPIClient::APIError.new(message: format("Unstable operation '%s' is disabled", "v2.update_web_integration_account")) end if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WebIntegrationsAPI.update_web_integration_account ...' end # verify the required parameter 'integration_name' is set if @api_client.config.client_side_validation && integration_name.nil? fail ArgumentError, "Missing the required parameter 'integration_name' when calling WebIntegrationsAPI.update_web_integration_account" end # verify the required parameter 'account_id' is set if @api_client.config.client_side_validation && account_id.nil? fail ArgumentError, "Missing the required parameter 'account_id' when calling WebIntegrationsAPI.update_web_integration_account" end # verify the required parameter 'body' is set if @api_client.config.client_side_validation && body.nil? fail ArgumentError, "Missing the required parameter 'body' when calling WebIntegrationsAPI.update_web_integration_account" end # resource path local_var_path = '/api/v2/web-integrations/{integration_name}/accounts/{account_id}'.sub('{integration_name}', CGI.escape(integration_name.to_s).gsub('%2F', '/')).sub('{account_id}', CGI.escape(account_id.to_s).gsub('%2F', '/')) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(body) # return_type return_type = opts[:debug_return_type] || 'WebIntegrationAccountResponse' # auth_names auth_names = opts[:debug_auth_names] || [:apiKeyAuth, :appKeyAuth] = opts.merge( :operation => :update_web_integration_account, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type, :api_version => "V2" ) data, status_code, headers = @api_client.call_api(Net::HTTP::Patch, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WebIntegrationsAPI#update_web_integration_account\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |